/**
 * console
 */
// 当某些调试场景下需要用到 JS 引擎自带的 console 时，保留其原生 console 对象，如没有则为 undefined
var dmServiceInvokeStartTime = Date.now()
var __console__ = console
var __setTimeout__ = setTimeout
var __clearTimeout__ = clearTimeout
var __setInterval__ = setInterval
var __clearInterval__ = clearInterval
var console = (function() {
  var CONSOLE_TYPE_ENUM = {
    LOG: 0,
    INFO: 1,
    WARN: 2,
    ERROR: 3
  };
  var DEFAULT_LABEL = 'default';
  var timeMap = Object.create(null);
  return {
    log: function() {
      try {
        var msg = '';
        for (var i = 0, item; i < arguments.length; i++) {
          item = arguments[i];
          msg += (typeof item === 'string' ? item : JSON.stringify(item));
        }
        nativeLog(CONSOLE_TYPE_ENUM.LOG, msg);
      } catch (e) {
        nativeLog(CONSOLE_TYPE_ENUM.ERROR, e.message);
      }
    },
    info: function() {
      try {
        var msg = '';
        for (var i = 0, item; i < arguments.length; i++) {
          item = arguments[i];
          msg += (typeof item === 'string' ? item : JSON.stringify(item));
        }
        nativeLog(CONSOLE_TYPE_ENUM.INFO, msg);
      } catch (e) {
        nativeLog(CONSOLE_TYPE_ENUM.ERROR, e.message);
      }
    },
    warn: function() {
      try {
        var msg = '';
        for (var i = 0, item; i < arguments.length; i++) {
          item = arguments[i];
          msg += (typeof item === 'string' ? item : JSON.stringify(item));
        }
        nativeLog(CONSOLE_TYPE_ENUM.WARN, msg);
      } catch (e) {
        nativeLog(CONSOLE_TYPE_ENUM.ERROR, e.message);
      }
    },
    group: function() {
    },
    groupEnd: function() {
    },
    dmReportError: function(err) {
      // 主动调用底层异常上报功能
      if (err instanceof Error) {
        __appServiceSDK__.reportUncaughtError({
          info: `User report ${err.toString()}`,
          stack: err.stack,
          disableAppError: true
        });
      }
    },
    error: function() {
      try {
        var msg = '';
        for (var i = 0, item; i < arguments.length; i++) {
          item = arguments[i];
          msg += (typeof item === 'string' ? item : JSON.stringify(item));
        }
        nativeLog(CONSOLE_TYPE_ENUM.ERROR, msg);
      } catch (e) {
        nativeLog(CONSOLE_TYPE_ENUM.ERROR, e.message);
      }
    },
    time: function(label) {
      label = label == null ? DEFAULT_LABEL : label.toString();
      timeMap[label] = Date.now();
    },
    timeLog: function(label) {
      label = label == null ? DEFAULT_LABEL : label.toString();
      if (timeMap[label]) {
        var old = timeMap[label]
        nativeLog(CONSOLE_TYPE_ENUM.LOG, label + ': ' + ((timeMap[label] = Date.now()) - old) + ' ms')
      } else {
        nativeLog(CONSOLE_TYPE_ENUM.WARN, 'Timer \'' + label + '\' does not exist')
      }
    },
    timeEnd: function(label) {
      label = label == null ? DEFAULT_LABEL : label.toString();
      if (timeMap[label]) {
        var old = timeMap[label]
        delete timeMap[label]
        nativeLog(CONSOLE_TYPE_ENUM.LOG, label + ': ' + (Date.now() - old) + ' ms')
      } else {
        nativeLog(CONSOLE_TYPE_ENUM.WARN, 'Timer \'' + label + '\' does not exist')
      }
    }
  };
})();


/**
 * Timeout & Interval
 */

var timeoutMap = {};
var timeoutId = 0;

var setTimeout = function(cb, timeout) {
  if (timeout === undefined || timeout === null) {
    timeout = 0
  }
  var funcId = timeoutId++
  timeoutMap[funcId] = cb
  // native的方法
  setTimeoutNative(funcId, timeout)
  return funcId
}

// native 方法 ，需要暴露在全局
var setTimeoutCallback = function(funcId) {
  if (typeof timeoutMap[funcId] === 'function') {
    try {
      timeoutMap[funcId]();
    } catch (err) {
      // 计时器处理函数未处理异常
      __appServiceSDK__.reportUncaughtError({
        info: err.toString(),
        stack: err.stack
      })
    } finally {
      timeoutMap[funcId] = null
      delete timeoutMap[funcId]
    }


  } else {
    console.error("[setTimeoutNative]: setTimeOut fn is not a fn " + funcId)
  }
}

var clearTimeout = function(funcId) {
  if (funcId && timeoutMap[funcId]) {
    clearTimeoutNative(funcId);
    timeoutMap[funcId] = null;
    delete timeoutMap[funcId];
  }
}

var setInterval = function(cb, timeout) {
  if (timeout === undefined || timeout === null) {
    timeout = 0
  }
  var funcId = timeoutId++;
  timeoutMap[funcId] = cb;
  setIntervalNative(funcId, timeout);
  return funcId;
}

var setIntervalCallback = function(funcId) {
  if (typeof timeoutMap[funcId] === 'function') {
    try {
      timeoutMap[funcId]();
    } catch (err) {
      // 计时器处理函数未处理异常
      __appServiceSDK__.reportUncaughtError({
        info: err.toString(),
        stack: err.stack
      })
    }
  } else {
    console.error("[setIntervalCallback]: setInterval fn is not a fn " + funcId);
  }
}

var clearInterval = function(funcId) {
  if (funcId && timeoutMap[funcId]) {
    clearIntervalNative(funcId);
    timeoutMap[funcId] = null;
    delete timeoutMap[funcId];
  }
}

/**
 * 全局变量
 */
var globalThis = (function() {
  return this
})();

// 谷歌渠道,jscore改成webview,因此window上会存在全局变量,会去访问document变量
globalThis && globalThis.MutationObserver && (MutationObserver = null)
globalThis && globalThis.WebKitMutationObserver && (WebKitMutationObserver = null)
if (globalThis) {
  globalThis.onunhandledrejection = function(params) {
    __appServiceSDK__.dd && __appServiceSDK__.dd.emitUnhandledRejection && __appServiceSDK__.dd.emitUnhandledRejection(params)
  }
  globalThis.onunhandledrejectionForNative = function(promise, reason) {
    globalThis.onunhandledrejection && globalThis.onunhandledrejection({ promise, reason })
    __appServiceSDK__.reportNative('pub_native_unhandlereject_bt', {
      reason: '' + reason
    })
  }
}
globalThis && globalThis.WebKitMutationObserver && (WebKitMutationObserver = null)

var __ddLibrary = {
  envType: 'Service',
  contextType: '',
  fileName: 'WAService.js',
  execStart: Date.now()
};
var __libVersionInfo__ = {}
/** wcc config start */
var window = {};
window.__wcc_version_info__ = {
  customComponents: true,
  fixZeroRpx: true,
  propValueDeepCopy: false
};
/** wcc config end */

var __ddAppData = __ddAppData || {};
var __ddRoute = __ddRoute || '';
var __ddRouteBegin = __ddRouteBegin || "";
var __ddAppCurrentFile__ = __ddAppCurrentFile__ || "";
var __define__;
var __routePackages__;
var global = global || {};
var __ddConfigWindow__ = {};
var Reporter = {};
var __vd_version_info__ = {
  delayedGwx: true
};
var __ddConfig = {
  envVersion: 'release',
  platform: '',
  isIsolateContext: false     // 是否是游戏，游戏为true，不是游戏，字段缺省或者为false
};
var __MAIN_PKG_DIR__ = 'app';
var __APP_RESOURCES_SUB_DIR__ = 'res';
var currentStackId = -1;
var tabBarTapList = []

var isDevTools = typeof acquireLocalBridge === 'function'
if (isDevTools) {
  __ddConfig.platform = 'devtools'
}

if (isDevTools) {
  // ide 环境重写对象
  console = __console__;
  setTimeout = __setTimeout__;
  clearTimeout = __clearTimeout__;
  setInterval = __setInterval__;
  clearInterval = __clearInterval__;
}


/**
 * 基础库的 service 的代码
 */
if (isDevTools) {
  __ddConfig.platform = 'devtools'
}
var Foundation=function(){"use strict";function t(n){return t="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},t(n)}function n(){return n=Object.assign||function(t){for(var n=1;n<arguments.length;n++){var e=arguments[n];for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&(t[r]=e[r])}return t},n.apply(this,arguments)}var e=function(t,n){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(t,n){t.__proto__=n}||function(t,n){for(var e in n)Object.prototype.hasOwnProperty.call(n,e)&&(t[e]=n[e])},e(t,n)};var r="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function o(t,n,e){return t(e={path:n,exports:{},require:function(t,n){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==n&&e.path)}},e.exports),e.exports}var i,u,c=function(t){return t&&t.Math==Math&&t},a=c("object"==typeof globalThis&&globalThis)||c("object"==typeof window&&window)||c("object"==typeof self&&self)||c("object"==typeof r&&r)||function(){return this}()||Function("return this")(),f={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0},s=function(t){return"function"==typeof t},l=function(t){return"object"==typeof t?null!==t:s(t)},p=a.document,y=l(p)&&l(p.createElement),d=function(t){return y?p.createElement(t):{}},g=d("span").classList,v=g&&g.constructor&&g.constructor.prototype,h=v===Object.prototype?void 0:v,b=function(t){try{return!!t()}catch(t){return!0}},m=!b((function(){var t=function(){}.bind();return"function"!=typeof t||t.hasOwnProperty("prototype")})),S=Function.prototype,x=S.bind,O=S.call,w=m&&x.bind(O,O),_=m?function(t){return t&&w(t)}:function(t){return t&&function(){return O.apply(t,arguments)}},E=String,C=TypeError,I=function(t){if(s(t))return t;throw C(function(t){try{return E(t)}catch(t){return"Object"}}(t)+" is not a function")},j=_(_.bind),R=_({}.toString),T=_("".slice),A=function(t){return T(R(t),8,-1)},L=Object,P=_("".split),D=b((function(){return!L("z").propertyIsEnumerable(0)}))?function(t){return"String"==A(t)?P(t,""):L(t)}:L,F=TypeError,k=function(t){if(null==t)throw F("Can't call method on "+t);return t},M=Object,N=function(t){return M(k(t))},G=Math.ceil,V=Math.floor,Y=Math.trunc||function(t){var n=+t;return(n>0?V:G)(n)},B=function(t){var n=+t;return n!=n||0===n?0:Y(n)},W=Math.min,z=function(t){return t>0?W(B(t),9007199254740991):0},U=function(t){return z(t.length)},K=Array.isArray||function(t){return"Array"==A(t)},q=Object.defineProperty,H=function(t,n){try{q(a,t,{value:n,configurable:!0,writable:!0})}catch(e){a[t]=n}return n},$="__core-js_shared__",X=a[$]||H($,{}),J=o((function(t){(t.exports=function(t,n){return X[t]||(X[t]=void 0!==n?n:{})})("versions",[]).push({version:"3.24.1",mode:"global",copyright:"© 2014-2022 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.24.1/LICENSE",source:"https://github.com/zloirock/core-js"})})),Q=_({}.hasOwnProperty),Z=Object.hasOwn||function(t,n){return Q(N(t),n)},tt=0,nt=Math.random(),et=_(1..toString),rt=function(t){return"Symbol("+(void 0===t?"":t)+")_"+et(++tt+nt,36)},ot=function(t){return s(t)?t:void 0},it=function(t,n){return arguments.length<2?ot(a[t]):a[t]&&a[t][n]},ut=it("navigator","userAgent")||"",ct=a.process,at=a.Deno,ft=ct&&ct.versions||at&&at.version,st=ft&&ft.v8;st&&(u=(i=st.split("."))[0]>0&&i[0]<4?1:+(i[0]+i[1])),!u&&ut&&(!(i=ut.match(/Edge\/(\d+)/))||i[1]>=74)&&(i=ut.match(/Chrome\/(\d+)/))&&(u=+i[1]);var lt=u,pt=!!Object.getOwnPropertySymbols&&!b((function(){var t=Symbol();return!String(t)||!(Object(t)instanceof Symbol)||!Symbol.sham&&lt&&lt<41})),yt=pt&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,dt=J("wks"),gt=a.Symbol,vt=gt&&gt.for,ht=yt?gt:gt&&gt.withoutSetter||rt,bt=function(t){if(!Z(dt,t)||!pt&&"string"!=typeof dt[t]){var n="Symbol."+t;pt&&Z(gt,t)?dt[t]=gt[t]:dt[t]=yt&&vt?vt(n):ht(n)}return dt[t]},mt={};mt[bt("toStringTag")]="z";var St="[object z]"===String(mt),xt=bt("toStringTag"),Ot=Object,wt="Arguments"==A(function(){return arguments}()),_t=St?A:function(t){var n,e,r;return void 0===t?"Undefined":null===t?"Null":"string"==typeof(e=function(t,n){try{return t[n]}catch(t){}}(n=Ot(t),xt))?e:wt?A(n):"Object"==(r=A(n))&&s(n.callee)?"Arguments":r},Et=_(Function.toString);s(X.inspectSource)||(X.inspectSource=function(t){return Et(t)});var Ct=X.inspectSource,It=function(){},jt=[],Rt=it("Reflect","construct"),Tt=/^\s*(?:class|function)\b/,At=_(Tt.exec),Lt=!Tt.exec(It),Pt=function(t){if(!s(t))return!1;try{return Rt(It,jt,t),!0}catch(t){return!1}},Dt=function(t){if(!s(t))return!1;switch(_t(t)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return Lt||!!At(Tt,Ct(t))}catch(t){return!0}};Dt.sham=!0;var Ft=!Rt||b((function(){var t;return Pt(Pt.call)||!Pt(Object)||!Pt((function(){t=!0}))||t}))?Dt:Pt,kt=bt("species"),Mt=Array,Nt=function(t,n){return new(function(t){var n;return K(t)&&(n=t.constructor,(Ft(n)&&(n===Mt||K(n.prototype))||l(n)&&null===(n=n[kt]))&&(n=void 0)),void 0===n?Mt:n}(t))(0===n?0:n)},Gt=_([].push),Vt=function(t){var n=1==t,e=2==t,r=3==t,o=4==t,i=6==t,u=7==t,c=5==t||i;return function(a,f,s,l){for(var p,y,d=N(a),g=D(d),v=function(t,n){return I(t),void 0===n?t:m?j(t,n):function(){return t.apply(n,arguments)}}(f,s),h=U(g),b=0,S=l||Nt,x=n?S(a,h):e||u?S(a,0):void 0;h>b;b++)if((c||b in g)&&(y=v(p=g[b],b,d),t))if(n)x[b]=y;else if(y)switch(t){case 3:return!0;case 5:return p;case 6:return b;case 2:Gt(x,p)}else switch(t){case 4:return!1;case 7:Gt(x,p)}return i?-1:r||o?o:x}},Yt={forEach:Vt(0),map:Vt(1),filter:Vt(2),some:Vt(3),every:Vt(4),find:Vt(5),findIndex:Vt(6),filterReject:Vt(7)},Bt=function(t,n){var e=[][t];return!!e&&b((function(){e.call(null,n||function(){return 1},1)}))},Wt=Yt.forEach,zt=Bt("forEach")?[].forEach:function(t){return Wt(this,t,arguments.length>1?arguments[1]:void 0)},Ut=!b((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),Kt=!Ut&&!b((function(){return 7!=Object.defineProperty(d("div"),"a",{get:function(){return 7}}).a})),qt=Ut&&b((function(){return 42!=Object.defineProperty((function(){}),"prototype",{value:42,writable:!1}).prototype})),Ht=String,$t=TypeError,Xt=function(t){if(l(t))return t;throw $t(Ht(t)+" is not an object")},Jt=Function.prototype.call,Qt=m?Jt.bind(Jt):function(){return Jt.apply(Jt,arguments)},Zt=_({}.isPrototypeOf),tn=Object,nn=yt?function(t){return"symbol"==typeof t}:function(t){var n=it("Symbol");return s(n)&&Zt(n.prototype,tn(t))},en=function(t,n){var e=t[n];return null==e?void 0:I(e)},rn=TypeError,on=TypeError,un=bt("toPrimitive"),cn=function(t,n){if(!l(t)||nn(t))return t;var e,r=en(t,un);if(r){if(void 0===n&&(n="default"),e=Qt(r,t,n),!l(e)||nn(e))return e;throw on("Can't convert object to primitive value")}return void 0===n&&(n="number"),function(t,n){var e,r;if("string"===n&&s(e=t.toString)&&!l(r=Qt(e,t)))return r;if(s(e=t.valueOf)&&!l(r=Qt(e,t)))return r;if("string"!==n&&s(e=t.toString)&&!l(r=Qt(e,t)))return r;throw rn("Can't convert object to primitive value")}(t,n)},an=function(t){var n=cn(t,"string");return nn(n)?n:n+""},fn=TypeError,sn=Object.defineProperty,ln=Object.getOwnPropertyDescriptor,pn="enumerable",yn="configurable",dn="writable",gn={f:Ut?qt?function(t,n,e){if(Xt(t),n=an(n),Xt(e),"function"==typeof t&&"prototype"===n&&"value"in e&&dn in e&&!e.writable){var r=ln(t,n);r&&r.writable&&(t[n]=e.value,e={configurable:yn in e?e.configurable:r.configurable,enumerable:pn in e?e.enumerable:r.enumerable,writable:!1})}return sn(t,n,e)}:sn:function(t,n,e){if(Xt(t),n=an(n),Xt(e),Kt)try{return sn(t,n,e)}catch(t){}if("get"in e||"set"in e)throw fn("Accessors not supported");return"value"in e&&(t[n]=e.value),t}},vn=function(t,n){return{enumerable:!(1&t),configurable:!(2&t),writable:!(4&t),value:n}},hn=Ut?function(t,n,e){return gn.f(t,n,vn(1,e))}:function(t,n,e){return t[n]=e,t},bn=function(t){if(t&&t.forEach!==zt)try{hn(t,"forEach",zt)}catch(n){t.forEach=zt}};for(var mn in f)f[mn]&&bn(a[mn]&&a[mn].prototype);bn(h);var Sn,xn,On,wn={}.propertyIsEnumerable,_n=Object.getOwnPropertyDescriptor,En={f:_n&&!wn.call({1:2},1)?function(t){var n=_n(this,t);return!!n&&n.enumerable}:wn},Cn=function(t){return D(k(t))},In=Object.getOwnPropertyDescriptor,jn={f:Ut?In:function(t,n){if(t=Cn(t),n=an(n),Kt)try{return In(t,n)}catch(t){}if(Z(t,n))return vn(!Qt(En.f,t,n),t[n])}},Rn=Function.prototype,Tn=Ut&&Object.getOwnPropertyDescriptor,An=Z(Rn,"name"),Ln={EXISTS:An,PROPER:An&&"something"===function(){}.name,CONFIGURABLE:An&&(!Ut||Ut&&Tn(Rn,"name").configurable)},Pn=a.WeakMap,Dn=s(Pn)&&/native code/.test(Ct(Pn)),Fn=J("keys"),kn=function(t){return Fn[t]||(Fn[t]=rt(t))},Mn={},Nn="Object already initialized",Gn=a.TypeError,Vn=a.WeakMap;if(Dn||X.state){var Yn=X.state||(X.state=new Vn),Bn=_(Yn.get),Wn=_(Yn.has),zn=_(Yn.set);Sn=function(t,n){if(Wn(Yn,t))throw new Gn(Nn);return n.facade=t,zn(Yn,t,n),n},xn=function(t){return Bn(Yn,t)||{}},On=function(t){return Wn(Yn,t)}}else{var Un=kn("state");Mn[Un]=!0,Sn=function(t,n){if(Z(t,Un))throw new Gn(Nn);return n.facade=t,hn(t,Un,n),n},xn=function(t){return Z(t,Un)?t[Un]:{}},On=function(t){return Z(t,Un)}}var Kn,qn={set:Sn,get:xn,has:On,enforce:function(t){return On(t)?xn(t):Sn(t,{})},getterFor:function(t){return function(n){var e;if(!l(n)||(e=xn(n)).type!==t)throw Gn("Incompatible receiver, "+t+" required");return e}}},Hn=o((function(t){var n=Ln.CONFIGURABLE,e=qn.enforce,r=qn.get,o=Object.defineProperty,i=Ut&&!b((function(){return 8!==o((function(){}),"length",{value:8}).length})),u=String(String).split("String"),c=t.exports=function(t,r,c){"Symbol("===String(r).slice(0,7)&&(r="["+String(r).replace(/^Symbol\(([^)]*)\)/,"$1")+"]"),c&&c.getter&&(r="get "+r),c&&c.setter&&(r="set "+r),(!Z(t,"name")||n&&t.name!==r)&&(Ut?o(t,"name",{value:r,configurable:!0}):t.name=r),i&&c&&Z(c,"arity")&&t.length!==c.arity&&o(t,"length",{value:c.arity});try{c&&Z(c,"constructor")&&c.constructor?Ut&&o(t,"prototype",{writable:!1}):t.prototype&&(t.prototype=void 0)}catch(t){}var a=e(t);return Z(a,"source")||(a.source=u.join("string"==typeof r?r:"")),t};Function.prototype.toString=c((function(){return s(this)&&r(this).source||Ct(this)}),"toString")})),$n=function(t,n,e,r){r||(r={});var o=r.enumerable,i=void 0!==r.name?r.name:n;if(s(e)&&Hn(e,i,r),r.global)o?t[n]=e:H(n,e);else{try{r.unsafe?t[n]&&(o=!0):delete t[n]}catch(t){}o?t[n]=e:gn.f(t,n,{value:e,enumerable:!1,configurable:!r.nonConfigurable,writable:!r.nonWritable})}return t},Xn=Math.max,Jn=Math.min,Qn=function(t){return function(n,e,r){var o,i=Cn(n),u=U(i),c=function(t,n){var e=B(t);return e<0?Xn(e+n,0):Jn(e,n)}(r,u);if(t&&e!=e){for(;u>c;)if((o=i[c++])!=o)return!0}else for(;u>c;c++)if((t||c in i)&&i[c]===e)return t||c||0;return!t&&-1}},Zn={includes:Qn(!0),indexOf:Qn(!1)},te=Zn.indexOf,ne=_([].push),ee=function(t,n){var e,r=Cn(t),o=0,i=[];for(e in r)!Z(Mn,e)&&Z(r,e)&&ne(i,e);for(;n.length>o;)Z(r,e=n[o++])&&(~te(i,e)||ne(i,e));return i},re=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],oe=re.concat("length","prototype"),ie={f:Object.getOwnPropertyNames||function(t){return ee(t,oe)}},ue={f:Object.getOwnPropertySymbols},ce=_([].concat),ae=it("Reflect","ownKeys")||function(t){var n=ie.f(Xt(t)),e=ue.f;return e?ce(n,e(t)):n},fe=function(t,n,e){for(var r=ae(n),o=gn.f,i=jn.f,u=0;u<r.length;u++){var c=r[u];Z(t,c)||e&&Z(e,c)||o(t,c,i(n,c))}},se=/#|\.prototype\./,le=function(t,n){var e=ye[pe(t)];return e==ge||e!=de&&(s(n)?b(n):!!n)},pe=le.normalize=function(t){return String(t).replace(se,".").toLowerCase()},ye=le.data={},de=le.NATIVE="N",ge=le.POLYFILL="P",ve=le,he=jn.f,be=function(t,n){var e,r,o,i,u,c=t.target,f=t.global,s=t.stat;if(e=f?a:s?a[c]||H(c,{}):(a[c]||{}).prototype)for(r in n){if(i=n[r],o=t.dontCallGetSet?(u=he(e,r))&&u.value:e[r],!ve(f?r:c+(s?".":"#")+r,t.forced)&&void 0!==o){if(typeof i==typeof o)continue;fe(i,o)}(t.sham||o&&o.sham)&&hn(i,"sham",!0),$n(e,r,i,t)}},me=bt("species"),Se=Yt.filter;be({target:"Array",proto:!0,forced:!(Kn="filter",lt>=51||!b((function(){var t=[];return(t.constructor={})[me]=function(){return{foo:1}},1!==t[Kn](Boolean).foo})))},{filter:function(t){return Se(this,t,arguments.length>1?arguments[1]:void 0)}});var xe=function(){function t(){this.listeners={}}return t.prototype.emit=function(t,n){if(this.listeners[t]&&this.listeners[t].length>0){var e=!1;return this.listeners[t].forEach((function(t){0!==t.count&&t.cb(n),t.count>0&&t.count--,0===t.count&&(e=!0)})),e&&(this.listeners[t]=this.listeners[t].filter((function(t){return 0!==t.count}))),!0}return!1},t.prototype.many=function(t,n,e){if(!n)return this;var r={count:e,cb:n};return this.listeners[t]?this.listeners[t].push(r):this.listeners[t]=[r],this},t.prototype.on=function(t,n){this.many(t,n,-1)},t.prototype.off=function(t,n){for(var e=0;e<this.listeners[t].length;e++){var r=this.listeners[t][e];if(r.cb===n)return void(r.count=0)}},t.prototype.once=function(t,n){this.many(t,n,1)},t}(),Oe=String,we=TypeError,_e=Object.setPrototypeOf||("__proto__"in{}?function(){var t,n=!1,e={};try{(t=_(Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set))(e,[]),n=e instanceof Array}catch(t){}return function(e,r){return Xt(e),function(t){if("object"==typeof t||s(t))return t;throw we("Can't set "+Oe(t)+" as a prototype")}(r),n?t(e,r):e.__proto__=r,e}}():void 0),Ee=bt("match"),Ce=String,Ie=function(t){if("Symbol"===_t(t))throw TypeError("Cannot convert a Symbol value to a string");return Ce(t)},je=function(){var t=Xt(this),n="";return t.hasIndices&&(n+="d"),t.global&&(n+="g"),t.ignoreCase&&(n+="i"),t.multiline&&(n+="m"),t.dotAll&&(n+="s"),t.unicode&&(n+="u"),t.unicodeSets&&(n+="v"),t.sticky&&(n+="y"),n},Re=RegExp.prototype,Te=function(t){var n=t.flags;return void 0!==n||"flags"in Re||Z(t,"flags")||!Zt(Re,t)?n:Qt(je,t)},Ae=a.RegExp,Le=b((function(){var t=Ae("a","y");return t.lastIndex=2,null!=t.exec("abcd")})),Pe=Le||b((function(){return!Ae("a","y").sticky})),De={BROKEN_CARET:Le||b((function(){var t=Ae("^r","gy");return t.lastIndex=2,null!=t.exec("str")})),MISSED_STICKY:Pe,UNSUPPORTED_Y:Le},Fe=gn.f,ke=function(t,n,e){e in t||Fe(t,e,{configurable:!0,get:function(){return n[e]},set:function(t){n[e]=t}})},Me=bt("species"),Ne=a.RegExp,Ge=b((function(){var t=Ne(".","s");return!(t.dotAll&&t.exec("\n")&&"s"===t.flags)})),Ve=a.RegExp,Ye=b((function(){var t=Ve("(?<a>b)","g");return"b"!==t.exec("b").groups.a||"bc"!=="b".replace(t,"$<a>c")})),Be=ie.f,We=qn.enforce,ze=bt("match"),Ue=a.RegExp,Ke=Ue.prototype,qe=a.SyntaxError,He=_(Ke.exec),$e=_("".charAt),Xe=_("".replace),Je=_("".indexOf),Qe=_("".slice),Ze=/^\?<[^\s\d!#%&*+<=>@^][^\s!#%&*+<=>@^]*>/,tr=/a/g,nr=/a/g,er=new Ue(tr)!==tr,rr=De.MISSED_STICKY,or=De.UNSUPPORTED_Y,ir=Ut&&(!er||rr||Ge||Ye||b((function(){return nr[ze]=!1,Ue(tr)!=tr||Ue(nr)==nr||"/a/i"!=Ue(tr,"i")})));if(ve("RegExp",ir)){for(var ur=function(t,n){var e,r,o,i,u,c,a,f,p,y,d,g,v,h=Zt(Ke,this),b=l(e=t)&&(void 0!==(r=e[Ee])?!!r:"RegExp"==A(e)),m=void 0===n,S=[],x=t;if(!h&&b&&m&&t.constructor===ur)return t;if((b||Zt(Ke,t))&&(t=t.source,m&&(n=Te(x))),t=void 0===t?"":Ie(t),n=void 0===n?"":Ie(n),x=t,Ge&&"dotAll"in tr&&(i=!!n&&Je(n,"s")>-1)&&(n=Xe(n,/s/g,"")),o=n,rr&&"sticky"in tr&&(u=!!n&&Je(n,"y")>-1)&&or&&(n=Xe(n,/y/g,"")),Ye&&(c=function(t){for(var n,e=t.length,r=0,o="",i=[],u={},c=!1,a=!1,f=0,s="";r<=e;r++){if("\\"===(n=$e(t,r)))n+=$e(t,++r);else if("]"===n)c=!1;else if(!c)switch(!0){case"["===n:c=!0;break;case"("===n:He(Ze,Qe(t,r+1))&&(r+=2,a=!0),o+=n,f++;continue;case">"===n&&a:if(""===s||Z(u,s))throw new qe("Invalid capture group name");u[s]=!0,i[i.length]=[s,f],a=!1,s="";continue}a?s+=n:o+=n}return[o,i]}(t),t=c[0],S=c[1]),p=Ue(t,n),y=h?this:Ke,d=ur,_e&&s(g=y.constructor)&&g!==d&&l(v=g.prototype)&&v!==d.prototype&&_e(p,v),a=p,(i||u||S.length)&&(f=We(a),i&&(f.dotAll=!0,f.raw=ur(function(t){for(var n,e=t.length,r=0,o="",i=!1;r<=e;r++)"\\"!==(n=$e(t,r))?i||"."!==n?("["===n?i=!0:"]"===n&&(i=!1),o+=n):o+="[\\s\\S]":o+=n+$e(t,++r);return o}(t),o)),u&&(f.sticky=!0),S.length&&(f.groups=S)),t!==x)try{hn(a,"source",""===x?"(?:)":x)}catch(t){}return a},cr=Be(Ue),ar=0;cr.length>ar;)ke(ur,Ue,cr[ar++]);Ke.constructor=ur,ur.prototype=Ke,$n(a,"RegExp",ur,{constructor:!0})}!function(t){var n=it(t),e=gn.f;Ut&&n&&!n[Me]&&e(n,Me,{configurable:!0,get:function(){return this}})}("RegExp");var fr,sr=Object.keys||function(t){return ee(t,re)},lr=Ut&&!qt?Object.defineProperties:function(t,n){Xt(t);for(var e,r=Cn(n),o=sr(n),i=o.length,u=0;i>u;)gn.f(t,e=o[u++],r[e]);return t},pr={f:lr},yr=it("document","documentElement"),dr=kn("IE_PROTO"),gr=function(){},vr=function(t){return"<script>"+t+"</"+"script>"},hr=function(t){t.write(vr("")),t.close();var n=t.parentWindow.Object;return t=null,n},br=function(){try{fr=new ActiveXObject("htmlfile")}catch(t){}var t,n;br="undefined"!=typeof document?document.domain&&fr?hr(fr):((n=d("iframe")).style.display="none",yr.appendChild(n),n.src=String("javascript:"),(t=n.contentWindow.document).open(),t.write(vr("document.F=Object")),t.close(),t.F):hr(fr);for(var e=re.length;e--;)delete br.prototype[re[e]];return br()};Mn[dr]=!0;var mr=Object.create||function(t,n){var e;return null!==t?(gr.prototype=Xt(t),e=new gr,gr.prototype=null,e[dr]=t):e=br(),void 0===n?e:pr.f(e,n)},Sr=qn.get,xr=J("native-string-replace",String.prototype.replace),Or=RegExp.prototype.exec,wr=Or,_r=_("".charAt),Er=_("".indexOf),Cr=_("".replace),Ir=_("".slice),jr=function(){var t=/a/,n=/b*/g;return Qt(Or,t,"a"),Qt(Or,n,"a"),0!==t.lastIndex||0!==n.lastIndex}(),Rr=De.BROKEN_CARET,Tr=void 0!==/()??/.exec("")[1];(jr||Tr||Rr||Ge||Ye)&&(wr=function(t){var n,e,r,o,i,u,c,a=this,f=Sr(a),s=Ie(t),l=f.raw;if(l)return l.lastIndex=a.lastIndex,n=Qt(wr,l,s),a.lastIndex=l.lastIndex,n;var p=f.groups,y=Rr&&a.sticky,d=Qt(je,a),g=a.source,v=0,h=s;if(y&&(d=Cr(d,"y",""),-1===Er(d,"g")&&(d+="g"),h=Ir(s,a.lastIndex),a.lastIndex>0&&(!a.multiline||a.multiline&&"\n"!==_r(s,a.lastIndex-1))&&(g="(?: "+g+")",h=" "+h,v++),e=new RegExp("^(?:"+g+")",d)),Tr&&(e=new RegExp("^"+g+"$(?!\\s)",d)),jr&&(r=a.lastIndex),o=Qt(Or,y?e:a,h),y?o?(o.input=Ir(o.input,v),o[0]=Ir(o[0],v),o.index=a.lastIndex,a.lastIndex+=o[0].length):a.lastIndex=0:jr&&o&&(a.lastIndex=a.global?o.index+o[0].length:r),Tr&&o&&o.length>1&&Qt(xr,o[0],e,(function(){for(i=1;i<arguments.length-2;i++)void 0===arguments[i]&&(o[i]=void 0)})),o&&p)for(o.groups=u=mr(null),i=0;i<p.length;i++)u[(c=p[i])[0]]=o[c[1]];return o});var Ar=wr;be({target:"RegExp",proto:!0,forced:/./.exec!==Ar},{exec:Ar});var Lr=Ln.PROPER,Pr="toString",Dr=RegExp.prototype.toString,Fr=b((function(){return"/a/b"!=Dr.call({source:"a",flags:"b"})})),kr=Lr&&Dr.name!=Pr;(Fr||kr)&&$n(RegExp.prototype,Pr,(function(){var t=Xt(this);return"/"+Ie(t.source)+"/"+Ie(Te(t))}),{unsafe:!0});var Mr=Zn.indexOf,Nr=_([].indexOf),Gr=!!Nr&&1/Nr([1],1,-0)<0,Vr=Bt("indexOf");be({target:"Array",proto:!0,forced:Gr||!Vr},{indexOf:function(t){var n=arguments.length>1?arguments[1]:void 0;return Gr?Nr(this,t,n)||0:Mr(this,t,n)}});var Yr=bt("species"),Br=RegExp.prototype,Wr=_("".charAt),zr=_("".charCodeAt),Ur=_("".slice),Kr=function(t){return function(n,e){var r,o,i=Ie(k(n)),u=B(e),c=i.length;return u<0||u>=c?t?"":void 0:(r=zr(i,u))<55296||r>56319||u+1===c||(o=zr(i,u+1))<56320||o>57343?t?Wr(i,u):r:t?Ur(i,u,u+2):o-56320+(r-55296<<10)+65536}},qr={codeAt:Kr(!1),charAt:Kr(!0)}.charAt,Hr=function(t,n,e){return n+(e?qr(t,n).length:1)},$r=TypeError,Xr=function(t,n){var e=t.exec;if(s(e)){var r=Qt(e,t,n);return null!==r&&Xt(r),r}if("RegExp"===A(t))return Qt(Ar,t,n);throw $r("RegExp#exec called on incompatible receiver")};!function(t,n,e,r){var o=bt(t),i=!b((function(){var n={};return n[o]=function(){return 7},7!=""[t](n)})),u=i&&!b((function(){var n=!1,e=/a/;return"split"===t&&((e={}).constructor={},e.constructor[Yr]=function(){return e},e.flags="",e[o]=/./[o]),e.exec=function(){return n=!0,null},e[o](""),!n}));if(!i||!u||e){var c=_(/./[o]),a=n(o,""[t],(function(t,n,e,r,o){var u=_(t),a=n.exec;return a===Ar||a===Br.exec?i&&!o?{done:!0,value:c(n,e,r)}:{done:!0,value:u(e,n,r)}:{done:!1}}));$n(String.prototype,t,a[0]),$n(Br,o,a[1])}r&&hn(Br[o],"sham",!0)}("match",(function(t,n,e){return[function(n){var e=k(this),r=null==n?void 0:en(n,t);return r?Qt(r,n,e):new RegExp(n)[t](Ie(e))},function(t){var r=Xt(this),o=Ie(t),i=e(n,r,o);if(i.done)return i.value;if(!r.global)return Xr(r,o);var u=r.unicode;r.lastIndex=0;for(var c,a=[],f=0;null!==(c=Xr(r,o));){var s=Ie(c[0]);a[f]=s,""===s&&(r.lastIndex=Hr(o,z(r.lastIndex),u)),f++}return 0===f?null:a}]}));var Jr="((?:(?:[0-9]|(?:[1-9](?:[0-9]*))).){2}(?:[0-9]|(?:[1-9](?:[0-9]*))))",Qr=new RegExp("native_sdk/".concat(Jr)),Zr=new RegExp("native_app_version/".concat(Jr));var to=new xe,no={},eo=function(){var n=function(){return this}();try{n=n||new Function("return this")()}catch(e){"object"===("undefined"==typeof window?"undefined":t(window))&&(n=window)}return n}();function ro(t,n){t in no?n&&n(no[t]):to.once("lifeCycle:".concat(t),n)}function oo(t,n){t in no||(no[t]=n,to.emit("lifeCycle:".concat(t),n))}var io=function(t){function r(){var n=t.call(this)||this;return n._STATIC_CONFIG_READY="configReady",n._STATIC_LIB_READY="libraryReady",n.init(),n}return function(t,n){if("function"!=typeof n&&null!==n)throw new TypeError("Class extends value "+String(n)+" is not a constructor or null");function r(){this.constructor=t}e(t,n),t.prototype=null===n?Object.create(n):(r.prototype=n.prototype,new r)}(r,t),r.prototype.init=function(){this.env=function(t){var n=t.__ddLibrary,e=t.__ddConfig,r=n.envType,o=n.contextType,i="Service"===r,u="WebView"===r,c="Worker"===r,a="Widget"===r,f=u||i&&0===o.indexOf("App:"),s=i&&0===o.indexOf("Game:"),l=c&&"function"==typeof t.workerInvokeJsApi,p=!!e.isIsolateContext,y=i&&(p&&0<=o.indexOf("Uncertain")||0<=o.indexOf("MainContext")),d=i&&0<=o.indexOf("SubContext"),g=y||d,v=u||y,h=e.platform,b=e.SDKVersion,m=e.version;if(u){var S=window.navigator.userAgent.toLowerCase();!h&&u&&0<=S.indexOf("devtools")?h="devtools":0<=S.indexOf("miniprogramenv/windows")?h="windows":0<=S.indexOf("miniprogramenv/mac")?h="mac":0<=S.indexOf("iphone")||0<=S.indexOf("ipad")?h="ios":0<=S.indexOf("android")&&(h="android");var x=S.match(Qr),O=S.match(Zr);x&&(b=x[1]||""),O&&(m=O[1]||"")}return{platform:(h||"unknown").toLowerCase(),jssdkVersion:"undefined"==typeof __libVersionInfo__||"develop"===__libVersionInfo__.version?"9.9.9":__libVersionInfo__.version,SDKVersion:b,version:m,isIsolateContext:g,isGame:s,isApp:f,isMainContext:y,isSubContext:d,isSafeEnv:v,isService:i,isWebView:u,isWorker:c,isWidget:a,isSupportWorkerAPI:l,typeStr:r}}(eo),this.global=eo,this.EventEmitter=xe,this.exportConfig={}},r.prototype.emitConfigReady=function(t){oo(this._STATIC_CONFIG_READY,t)},r.prototype.onConfigReady=function(t){ro(this._STATIC_CONFIG_READY,t)},Object.defineProperty(r.prototype,"isConfigReady",{get:function(){return this._STATIC_CONFIG_READY in no},enumerable:!1,configurable:!0}),r.prototype.onLibraryReady=function(t){ro(this._STATIC_LIB_READY,t)},r.prototype.emitLibraryReady=function(t){oo(this._STATIC_LIB_READY,t)},Object.defineProperty(r.prototype,"isLibraryReady",{get:function(){return this._STATIC_LIB_READY in no},enumerable:!1,configurable:!0}),Object.defineProperty(r.prototype,"isBridgeReady",{get:function(){return!1},enumerable:!1,configurable:!0}),r.prototype.onBridgeReady=function(){},r.prototype.refreshDDConfig=function(t){void 0===t&&(t={}),n(__ddConfig,t),n(this.exportConfig,t)},r.prototype.getExportConfig=function(){return this.exportConfig},r.prototype.setExportConfig=function(t){void 0===t&&(t={}),this.exportConfig=t},r.prototype.setDDConfig=function(t){void 0===t&&(t={}),n(__ddConfig,t)},r}(xe);void 0!==eo.__Function__&&(eo.Function=function(){},eo.Function.prototype=eo.__Function__.prototype);var uo=new io;return eo.__ddLibrary&&(eo.__ddLibrary.onEnd=function(){uo.emitLibraryReady({})}),uo}();


var didiJsBridge=function(){"use strict";var t="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function r(t,r,n){return t(n={path:r,exports:{},require:function(t,r){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==r&&n.path)}},n.exports),n.exports}var n,e,o=function(t){return t&&t.Math==Math&&t},i=o("object"==typeof globalThis&&globalThis)||o("object"==typeof window&&window)||o("object"==typeof self&&self)||o("object"==typeof t&&t)||function(){return this}()||Function("return this")(),u=Object.defineProperty,c=function(t,r){try{u(i,t,{value:r,configurable:!0,writable:!0})}catch(n){i[t]=r}return r},a="__core-js_shared__",f=i[a]||c(a,{}),s=r((function(t){(t.exports=function(t,r){return f[t]||(f[t]=void 0!==r?r:{})})("versions",[]).push({version:"3.24.1",mode:"global",copyright:"© 2014-2022 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.24.1/LICENSE",source:"https://github.com/zloirock/core-js"})})),l=function(t){try{return!!t()}catch(t){return!0}},p=!l((function(){var t=function(){}.bind();return"function"!=typeof t||t.hasOwnProperty("prototype")})),v=Function.prototype,g=v.bind,y=v.call,b=p&&g.bind(y,y),h=p?function(t){return t&&b(t)}:function(t){return t&&function(){return y.apply(t,arguments)}},d=TypeError,m=function(t){if(null==t)throw d("Can't call method on "+t);return t},S=Object,w=function(t){return S(m(t))},O=h({}.hasOwnProperty),E=Object.hasOwn||function(t,r){return O(w(t),r)},j=0,T=Math.random(),_=h(1..toString),k=function(t){return"Symbol("+(void 0===t?"":t)+")_"+_(++j+T,36)},I=function(t){return"function"==typeof t},A=function(t){return I(t)?t:void 0},N=function(t,r){return arguments.length<2?A(i[t]):i[t]&&i[t][r]},P=N("navigator","userAgent")||"",B=i.process,x=i.Deno,C=B&&B.versions||x&&x.version,M=C&&C.v8;M&&(e=(n=M.split("."))[0]>0&&n[0]<4?1:+(n[0]+n[1])),!e&&P&&(!(n=P.match(/Edge\/(\d+)/))||n[1]>=74)&&(n=P.match(/Chrome\/(\d+)/))&&(e=+n[1]);var D=e,F=!!Object.getOwnPropertySymbols&&!l((function(){var t=Symbol();return!String(t)||!(Object(t)instanceof Symbol)||!Symbol.sham&&D&&D<41})),R=F&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,L=s("wks"),z=i.Symbol,U=z&&z.for,G=R?z:z&&z.withoutSetter||k,H=function(t){if(!E(L,t)||!F&&"string"!=typeof L[t]){var r="Symbol."+t;F&&E(z,t)?L[t]=z[t]:L[t]=R&&U?U(r):G(r)}return L[t]},V={};V[H("toStringTag")]="z";var W="[object z]"===String(V),q=!l((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),J=function(t){return"object"==typeof t?null!==t:I(t)},K=i.document,X=J(K)&&J(K.createElement),Y=!q&&!l((function(){return 7!=Object.defineProperty((t="div",X?K.createElement(t):{}),"a",{get:function(){return 7}}).a;var t})),Z=q&&l((function(){return 42!=Object.defineProperty((function(){}),"prototype",{value:42,writable:!1}).prototype})),$=String,Q=TypeError,tt=function(t){if(J(t))return t;throw Q($(t)+" is not an object")},rt=Function.prototype.call,nt=p?rt.bind(rt):function(){return rt.apply(rt,arguments)},et=h({}.isPrototypeOf),ot=Object,it=R?function(t){return"symbol"==typeof t}:function(t){var r=N("Symbol");return I(r)&&et(r.prototype,ot(t))},ut=String,ct=function(t){try{return ut(t)}catch(t){return"Object"}},at=TypeError,ft=function(t,r){var n=t[r];return null==n?void 0:function(t){if(I(t))return t;throw at(ct(t)+" is not a function")}(n)},st=TypeError,lt=TypeError,pt=H("toPrimitive"),vt=function(t,r){if(!J(t)||it(t))return t;var n,e=ft(t,pt);if(e){if(void 0===r&&(r="default"),n=nt(e,t,r),!J(n)||it(n))return n;throw lt("Can't convert object to primitive value")}return void 0===r&&(r="number"),function(t,r){var n,e;if("string"===r&&I(n=t.toString)&&!J(e=nt(n,t)))return e;if(I(n=t.valueOf)&&!J(e=nt(n,t)))return e;if("string"!==r&&I(n=t.toString)&&!J(e=nt(n,t)))return e;throw st("Can't convert object to primitive value")}(t,r)},gt=function(t){var r=vt(t,"string");return it(r)?r:r+""},yt=TypeError,bt=Object.defineProperty,ht=Object.getOwnPropertyDescriptor,dt="enumerable",mt="configurable",St="writable",wt={f:q?Z?function(t,r,n){if(tt(t),r=gt(r),tt(n),"function"==typeof t&&"prototype"===r&&"value"in n&&St in n&&!n.writable){var e=ht(t,r);e&&e.writable&&(t[r]=n.value,n={configurable:mt in n?n.configurable:e.configurable,enumerable:dt in n?n.enumerable:e.enumerable,writable:!1})}return bt(t,r,n)}:bt:function(t,r,n){if(tt(t),r=gt(r),tt(n),Y)try{return bt(t,r,n)}catch(t){}if("get"in n||"set"in n)throw yt("Accessors not supported");return"value"in n&&(t[r]=n.value),t}},Ot=Function.prototype,Et=q&&Object.getOwnPropertyDescriptor,jt=E(Ot,"name"),Tt={EXISTS:jt,PROPER:jt&&"something"===function(){}.name,CONFIGURABLE:jt&&(!q||q&&Et(Ot,"name").configurable)},_t=h(Function.toString);I(f.inspectSource)||(f.inspectSource=function(t){return _t(t)});var kt,It,At,Nt=f.inspectSource,Pt=i.WeakMap,Bt=I(Pt)&&/native code/.test(Nt(Pt)),xt=function(t,r){return{enumerable:!(1&t),configurable:!(2&t),writable:!(4&t),value:r}},Ct=q?function(t,r,n){return wt.f(t,r,xt(1,n))}:function(t,r,n){return t[r]=n,t},Mt=s("keys"),Dt={},Ft="Object already initialized",Rt=i.TypeError,Lt=i.WeakMap;if(Bt||f.state){var zt=f.state||(f.state=new Lt),Ut=h(zt.get),Gt=h(zt.has),Ht=h(zt.set);kt=function(t,r){if(Gt(zt,t))throw new Rt(Ft);return r.facade=t,Ht(zt,t,r),r},It=function(t){return Ut(zt,t)||{}},At=function(t){return Gt(zt,t)}}else{var Vt=function(t){return Mt[t]||(Mt[t]=k(t))}("state");Dt[Vt]=!0,kt=function(t,r){if(E(t,Vt))throw new Rt(Ft);return r.facade=t,Ct(t,Vt,r),r},It=function(t){return E(t,Vt)?t[Vt]:{}},At=function(t){return E(t,Vt)}}var Wt={set:kt,get:It,has:At,enforce:function(t){return At(t)?It(t):kt(t,{})},getterFor:function(t){return function(r){var n;if(!J(r)||(n=It(r)).type!==t)throw Rt("Incompatible receiver, "+t+" required");return n}}},qt=r((function(t){var r=Tt.CONFIGURABLE,n=Wt.enforce,e=Wt.get,o=Object.defineProperty,i=q&&!l((function(){return 8!==o((function(){}),"length",{value:8}).length})),u=String(String).split("String"),c=t.exports=function(t,e,c){"Symbol("===String(e).slice(0,7)&&(e="["+String(e).replace(/^Symbol\(([^)]*)\)/,"$1")+"]"),c&&c.getter&&(e="get "+e),c&&c.setter&&(e="set "+e),(!E(t,"name")||r&&t.name!==e)&&(q?o(t,"name",{value:e,configurable:!0}):t.name=e),i&&c&&E(c,"arity")&&t.length!==c.arity&&o(t,"length",{value:c.arity});try{c&&E(c,"constructor")&&c.constructor?q&&o(t,"prototype",{writable:!1}):t.prototype&&(t.prototype=void 0)}catch(t){}var a=n(t);return E(a,"source")||(a.source=u.join("string"==typeof e?e:"")),t};Function.prototype.toString=c((function(){return I(this)&&e(this).source||Nt(this)}),"toString")})),Jt=function(t,r,n,e){e||(e={});var o=e.enumerable,i=void 0!==e.name?e.name:r;if(I(n)&&qt(n,i,e),e.global)o?t[r]=n:c(r,n);else{try{e.unsafe?t[r]&&(o=!0):delete t[r]}catch(t){}o?t[r]=n:wt.f(t,r,{value:n,enumerable:!1,configurable:!e.nonConfigurable,writable:!e.nonWritable})}return t},Kt=h({}.toString),Xt=h("".slice),Yt=function(t){return Xt(Kt(t),8,-1)},Zt=H("toStringTag"),$t=Object,Qt="Arguments"==Yt(function(){return arguments}()),tr=W?Yt:function(t){var r,n,e;return void 0===t?"Undefined":null===t?"Null":"string"==typeof(n=function(t,r){try{return t[r]}catch(t){}}(r=$t(t),Zt))?n:Qt?Yt(r):"Object"==(e=Yt(r))&&I(r.callee)?"Arguments":e},rr=W?{}.toString:function(){return"[object "+tr(this)+"]"};W||Jt(Object.prototype,"toString",rr,{unsafe:!0});var nr=String,er=function(t){if("Symbol"===tr(t))throw TypeError("Cannot convert a Symbol value to a string");return nr(t)},or=function(){var t=tt(this),r="";return t.hasIndices&&(r+="d"),t.global&&(r+="g"),t.ignoreCase&&(r+="i"),t.multiline&&(r+="m"),t.dotAll&&(r+="s"),t.unicode&&(r+="u"),t.unicodeSets&&(r+="v"),t.sticky&&(r+="y"),r},ir=RegExp.prototype,ur=Tt.PROPER,cr="toString",ar=RegExp.prototype.toString,fr=l((function(){return"/a/b"!=ar.call({source:"a",flags:"b"})})),sr=ur&&ar.name!=cr;(fr||sr)&&Jt(RegExp.prototype,cr,(function(){var t=tt(this),r=er(t.source),n=er(function(t){var r=t.flags;return void 0!==r||"flags"in ir||E(t,"flags")||!et(ir,t)?r:nt(or,t)}(t));return"/"+r+"/"+n}),{unsafe:!0});var lr={}.propertyIsEnumerable,pr=Object.getOwnPropertyDescriptor,vr={f:pr&&!lr.call({1:2},1)?function(t){var r=pr(this,t);return!!r&&r.enumerable}:lr},gr=Object,yr=h("".split),br=l((function(){return!gr("z").propertyIsEnumerable(0)}))?function(t){return"String"==Yt(t)?yr(t,""):gr(t)}:gr,hr=function(t){return br(m(t))},dr=Object.getOwnPropertyDescriptor,mr={f:q?dr:function(t,r){if(t=hr(t),r=gt(r),Y)try{return dr(t,r)}catch(t){}if(E(t,r))return xt(!nt(vr.f,t,r),t[r])}},Sr=Math.ceil,wr=Math.floor,Or=Math.trunc||function(t){var r=+t;return(r>0?wr:Sr)(r)},Er=function(t){var r=+t;return r!=r||0===r?0:Or(r)},jr=Math.max,Tr=Math.min,_r=function(t,r){var n=Er(t);return n<0?jr(n+r,0):Tr(n,r)},kr=Math.min,Ir=function(t){return(r=t.length)>0?kr(Er(r),9007199254740991):0;var r},Ar=function(t){return function(r,n,e){var o,i=hr(r),u=Ir(i),c=_r(e,u);if(t&&n!=n){for(;u>c;)if((o=i[c++])!=o)return!0}else for(;u>c;c++)if((t||c in i)&&i[c]===n)return t||c||0;return!t&&-1}},Nr={includes:Ar(!0),indexOf:Ar(!1)}.indexOf,Pr=h([].push),Br=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"].concat("length","prototype"),xr=Object.getOwnPropertyNames||function(t){return function(t,r){var n,e=hr(t),o=0,i=[];for(n in e)!E(Dt,n)&&E(e,n)&&Pr(i,n);for(;r.length>o;)E(e,n=r[o++])&&(~Nr(i,n)||Pr(i,n));return i}(t,Br)},Cr={f:xr},Mr={f:Object.getOwnPropertySymbols},Dr=h([].concat),Fr=N("Reflect","ownKeys")||function(t){var r=Cr.f(tt(t)),n=Mr.f;return n?Dr(r,n(t)):r},Rr=function(t,r,n){for(var e=Fr(r),o=wt.f,i=mr.f,u=0;u<e.length;u++){var c=e[u];E(t,c)||n&&E(n,c)||o(t,c,i(r,c))}},Lr=/#|\.prototype\./,zr=function(t,r){var n=Gr[Ur(t)];return n==Vr||n!=Hr&&(I(r)?l(r):!!r)},Ur=zr.normalize=function(t){return String(t).replace(Lr,".").toLowerCase()},Gr=zr.data={},Hr=zr.NATIVE="N",Vr=zr.POLYFILL="P",Wr=zr,qr=mr.f,Jr=function(t,r){var n,e,o,u,a,f=t.target,s=t.global,l=t.stat;if(n=s?i:l?i[f]||c(f,{}):(i[f]||{}).prototype)for(e in r){if(u=r[e],o=t.dontCallGetSet?(a=qr(n,e))&&a.value:n[e],!Wr(s?e:f+(l?".":"#")+e,t.forced)&&void 0!==o){if(typeof u==typeof o)continue;Rr(u,o)}(t.sham||o&&o.sham)&&Ct(u,"sham",!0),Jt(n,e,u,t)}},Kr=Array.isArray||function(t){return"Array"==Yt(t)},Xr=TypeError,Yr=function(t){if(t>9007199254740991)throw Xr("Maximum allowed index exceeded");return t},Zr=function(t,r,n){var e=gt(r);e in t?wt.f(t,e,xt(0,n)):t[e]=n},$r=function(){},Qr=[],tn=N("Reflect","construct"),rn=/^\s*(?:class|function)\b/,nn=h(rn.exec),en=!rn.exec($r),on=function(t){if(!I(t))return!1;try{return tn($r,Qr,t),!0}catch(t){return!1}},un=function(t){if(!I(t))return!1;switch(tr(t)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return en||!!nn(rn,Nt(t))}catch(t){return!0}};un.sham=!0;var cn=!tn||l((function(){var t;return on(on.call)||!on(Object)||!on((function(){t=!0}))||t}))?un:on,an=H("species"),fn=Array,sn=function(t,r){return new(function(t){var r;return Kr(t)&&(r=t.constructor,(cn(r)&&(r===fn||Kr(r.prototype))||J(r)&&null===(r=r[an]))&&(r=void 0)),void 0===r?fn:r}(t))(0===r?0:r)},ln=H("species"),pn=function(t){return D>=51||!l((function(){var r=[];return(r.constructor={})[ln]=function(){return{foo:1}},1!==r[t](Boolean).foo}))},vn=H("isConcatSpreadable"),gn=D>=51||!l((function(){var t=[];return t[vn]=!1,t.concat()[0]!==t})),yn=pn("concat"),bn=function(t){if(!J(t))return!1;var r=t[vn];return void 0!==r?!!r:Kr(t)};Jr({target:"Array",proto:!0,arity:1,forced:!gn||!yn},{concat:function(t){var r,n,e,o,i,u=w(this),c=sn(u,0),a=0;for(r=-1,e=arguments.length;r<e;r++)if(bn(i=-1===r?u:arguments[r]))for(o=Ir(i),Yr(a+o),n=0;n<o;n++,a++)n in i&&Zr(c,a,i[n]);else Yr(a+1),Zr(c,a++,i);return c.length=a,c}});var hn=TypeError,dn=function(t,r){if(!delete t[r])throw hn("Cannot delete property "+ct(r)+" of "+ct(t))},mn=pn("splice"),Sn=Math.max,wn=Math.min;Jr({target:"Array",proto:!0,forced:!mn},{splice:function(t,r){var n,e,o,i,u,c,a=w(this),f=Ir(a),s=_r(t,f),l=arguments.length;for(0===l?n=e=0:1===l?(n=0,e=f-s):(n=l-2,e=wn(Sn(Er(r),0),f-s)),Yr(f+n-e),o=sn(a,e),i=0;i<e;i++)(u=s+i)in a&&Zr(o,i,a[u]);if(o.length=e,n<e){for(i=s;i<f-e;i++)c=i+n,(u=i+e)in a?a[c]=a[u]:dn(a,c);for(i=f;i>f-e+n;i--)dn(a,i-1)}else if(n>e)for(i=f-e;i>s;i--)c=i+n-1,(u=i+e-1)in a?a[c]=a[u]:dn(a,c);for(i=0;i<n;i++)a[i+s]=arguments[i+2];return a.length=f-e+n,o}});var On=String,En=TypeError,jn=Object.setPrototypeOf||("__proto__"in{}?function(){var t,r=!1,n={};try{(t=h(Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set))(n,[]),r=n instanceof Array}catch(t){}return function(n,e){return tt(n),function(t){if("object"==typeof t||I(t))return t;throw En("Can't set "+On(t)+" as a prototype")}(e),r?t(n,e):n.__proto__=e,n}}():void 0),Tn=function(t,r,n){var e,o;return jn&&I(e=r.constructor)&&e!==n&&J(o=e.prototype)&&o!==n.prototype&&jn(t,o),t},_n=h(1..valueOf),kn=h("".replace),In="[\t\n\v\f\r                　\u2028\u2029\ufeff]",An=RegExp("^"+In+In+"*"),Nn=RegExp(In+In+"*$"),Pn=function(t){return function(r){var n=er(m(r));return 1&t&&(n=kn(n,An,"")),2&t&&(n=kn(n,Nn,"")),n}},Bn={start:Pn(1),end:Pn(2),trim:Pn(3)},xn=Cr.f,Cn=mr.f,Mn=wt.f,Dn=Bn.trim,Fn="Number",Rn=i.Number,Ln=Rn.prototype,zn=i.TypeError,Un=h("".slice),Gn=h("".charCodeAt),Hn=function(t){var r=vt(t,"number");return"bigint"==typeof r?r:Vn(r)},Vn=function(t){var r,n,e,o,i,u,c,a,f=vt(t,"number");if(it(f))throw zn("Cannot convert a Symbol value to a number");if("string"==typeof f&&f.length>2)if(f=Dn(f),43===(r=Gn(f,0))||45===r){if(88===(n=Gn(f,2))||120===n)return NaN}else if(48===r){switch(Gn(f,1)){case 66:case 98:e=2,o=49;break;case 79:case 111:e=8,o=55;break;default:return+f}for(u=(i=Un(f,2)).length,c=0;c<u;c++)if((a=Gn(i,c))<48||a>o)return NaN;return parseInt(i,e)}return+f};if(Wr(Fn,!Rn(" 0o1")||!Rn("0b1")||Rn("+0x1"))){for(var Wn,qn=function(t){var r=arguments.length<1?0:Rn(Hn(t)),n=this;return et(Ln,n)&&l((function(){_n(n)}))?Tn(Object(r),n,qn):r},Jn=q?xn(Rn):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,isFinite,isInteger,isNaN,isSafeInteger,parseFloat,parseInt,fromString,range".split(","),Kn=0;Jn.length>Kn;Kn++)E(Rn,Wn=Jn[Kn])&&!E(qn,Wn)&&Mn(qn,Wn,Cn(Rn,Wn));qn.prototype=Ln,Ln.constructor=qn,Jt(i,Fn,qn,{constructor:!0})}var Xn=r((function(t){!function(){var r="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",n={rotl:function(t,r){return t<<r|t>>>32-r},rotr:function(t,r){return t<<32-r|t>>>r},endian:function(t){if(t.constructor==Number)return 16711935&n.rotl(t,8)|4278255360&n.rotl(t,24);for(var r=0;r<t.length;r++)t[r]=n.endian(t[r]);return t},randomBytes:function(t){for(var r=[];t>0;t--)r.push(Math.floor(256*Math.random()));return r},bytesToWords:function(t){for(var r=[],n=0,e=0;n<t.length;n++,e+=8)r[e>>>5]|=t[n]<<24-e%32;return r},wordsToBytes:function(t){for(var r=[],n=0;n<32*t.length;n+=8)r.push(t[n>>>5]>>>24-n%32&255);return r},bytesToHex:function(t){for(var r=[],n=0;n<t.length;n++)r.push((t[n]>>>4).toString(16)),r.push((15&t[n]).toString(16));return r.join("")},hexToBytes:function(t){for(var r=[],n=0;n<t.length;n+=2)r.push(parseInt(t.substr(n,2),16));return r},bytesToBase64:function(t){for(var n=[],e=0;e<t.length;e+=3)for(var o=t[e]<<16|t[e+1]<<8|t[e+2],i=0;i<4;i++)8*e+6*i<=8*t.length?n.push(r.charAt(o>>>6*(3-i)&63)):n.push("=");return n.join("")},base64ToBytes:function(t){t=t.replace(/[^A-Z0-9+\/]/gi,"");for(var n=[],e=0,o=0;e<t.length;o=++e%4)0!=o&&n.push((r.indexOf(t.charAt(e-1))&Math.pow(2,-2*o+8)-1)<<2*o|r.indexOf(t.charAt(e))>>>6-2*o);return n}};t.exports=n}()})),Yn={utf8:{stringToBytes:function(t){return Yn.bin.stringToBytes(unescape(encodeURIComponent(t)))},bytesToString:function(t){return decodeURIComponent(escape(Yn.bin.bytesToString(t)))}},bin:{stringToBytes:function(t){for(var r=[],n=0;n<t.length;n++)r.push(255&t.charCodeAt(n));return r},bytesToString:function(t){for(var r=[],n=0;n<t.length;n++)r.push(String.fromCharCode(t[n]));return r.join("")}}},Zn=Yn,$n=function(t){return null!=t&&(Qn(t)||function(t){return"function"==typeof t.readFloatLE&&"function"==typeof t.slice&&Qn(t.slice(0,0))}(t)||!!t._isBuffer)};function Qn(t){return!!t.constructor&&"function"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}r((function(t){!function(){var r=Xn,n=Zn.utf8,e=$n,o=Zn.bin,i=function(t,u){t.constructor==String?t=u&&"binary"===u.encoding?o.stringToBytes(t):n.stringToBytes(t):e(t)?t=Array.prototype.slice.call(t,0):Array.isArray(t)||t.constructor===Uint8Array||(t=t.toString());for(var c=r.bytesToWords(t),a=8*t.length,f=1732584193,s=-271733879,l=-1732584194,p=271733878,v=0;v<c.length;v++)c[v]=16711935&(c[v]<<8|c[v]>>>24)|4278255360&(c[v]<<24|c[v]>>>8);c[a>>>5]|=128<<a%32,c[14+(a+64>>>9<<4)]=a;var g=i._ff,y=i._gg,b=i._hh,h=i._ii;for(v=0;v<c.length;v+=16){var d=f,m=s,S=l,w=p;f=g(f,s,l,p,c[v+0],7,-680876936),p=g(p,f,s,l,c[v+1],12,-389564586),l=g(l,p,f,s,c[v+2],17,606105819),s=g(s,l,p,f,c[v+3],22,-1044525330),f=g(f,s,l,p,c[v+4],7,-176418897),p=g(p,f,s,l,c[v+5],12,1200080426),l=g(l,p,f,s,c[v+6],17,-1473231341),s=g(s,l,p,f,c[v+7],22,-45705983),f=g(f,s,l,p,c[v+8],7,1770035416),p=g(p,f,s,l,c[v+9],12,-1958414417),l=g(l,p,f,s,c[v+10],17,-42063),s=g(s,l,p,f,c[v+11],22,-1990404162),f=g(f,s,l,p,c[v+12],7,1804603682),p=g(p,f,s,l,c[v+13],12,-40341101),l=g(l,p,f,s,c[v+14],17,-1502002290),f=y(f,s=g(s,l,p,f,c[v+15],22,1236535329),l,p,c[v+1],5,-165796510),p=y(p,f,s,l,c[v+6],9,-1069501632),l=y(l,p,f,s,c[v+11],14,643717713),s=y(s,l,p,f,c[v+0],20,-373897302),f=y(f,s,l,p,c[v+5],5,-701558691),p=y(p,f,s,l,c[v+10],9,38016083),l=y(l,p,f,s,c[v+15],14,-660478335),s=y(s,l,p,f,c[v+4],20,-405537848),f=y(f,s,l,p,c[v+9],5,568446438),p=y(p,f,s,l,c[v+14],9,-1019803690),l=y(l,p,f,s,c[v+3],14,-187363961),s=y(s,l,p,f,c[v+8],20,1163531501),f=y(f,s,l,p,c[v+13],5,-1444681467),p=y(p,f,s,l,c[v+2],9,-51403784),l=y(l,p,f,s,c[v+7],14,1735328473),f=b(f,s=y(s,l,p,f,c[v+12],20,-1926607734),l,p,c[v+5],4,-378558),p=b(p,f,s,l,c[v+8],11,-2022574463),l=b(l,p,f,s,c[v+11],16,1839030562),s=b(s,l,p,f,c[v+14],23,-35309556),f=b(f,s,l,p,c[v+1],4,-1530992060),p=b(p,f,s,l,c[v+4],11,1272893353),l=b(l,p,f,s,c[v+7],16,-155497632),s=b(s,l,p,f,c[v+10],23,-1094730640),f=b(f,s,l,p,c[v+13],4,681279174),p=b(p,f,s,l,c[v+0],11,-358537222),l=b(l,p,f,s,c[v+3],16,-722521979),s=b(s,l,p,f,c[v+6],23,76029189),f=b(f,s,l,p,c[v+9],4,-640364487),p=b(p,f,s,l,c[v+12],11,-421815835),l=b(l,p,f,s,c[v+15],16,530742520),f=h(f,s=b(s,l,p,f,c[v+2],23,-995338651),l,p,c[v+0],6,-198630844),p=h(p,f,s,l,c[v+7],10,1126891415),l=h(l,p,f,s,c[v+14],15,-1416354905),s=h(s,l,p,f,c[v+5],21,-57434055),f=h(f,s,l,p,c[v+12],6,1700485571),p=h(p,f,s,l,c[v+3],10,-1894986606),l=h(l,p,f,s,c[v+10],15,-1051523),s=h(s,l,p,f,c[v+1],21,-2054922799),f=h(f,s,l,p,c[v+8],6,1873313359),p=h(p,f,s,l,c[v+15],10,-30611744),l=h(l,p,f,s,c[v+6],15,-1560198380),s=h(s,l,p,f,c[v+13],21,1309151649),f=h(f,s,l,p,c[v+4],6,-145523070),p=h(p,f,s,l,c[v+11],10,-1120210379),l=h(l,p,f,s,c[v+2],15,718787259),s=h(s,l,p,f,c[v+9],21,-343485551),f=f+d>>>0,s=s+m>>>0,l=l+S>>>0,p=p+w>>>0}return r.endian([f,s,l,p])};i._ff=function(t,r,n,e,o,i,u){var c=t+(r&n|~r&e)+(o>>>0)+u;return(c<<i|c>>>32-i)+r},i._gg=function(t,r,n,e,o,i,u){var c=t+(r&e|n&~e)+(o>>>0)+u;return(c<<i|c>>>32-i)+r},i._hh=function(t,r,n,e,o,i,u){var c=t+(r^n^e)+(o>>>0)+u;return(c<<i|c>>>32-i)+r},i._ii=function(t,r,n,e,o,i,u){var c=t+(n^(r|~e))+(o>>>0)+u;return(c<<i|c>>>32-i)+r},i._blocksize=16,i._digestsize=16,t.exports=function(t,n){if(null==t)throw new Error("Illegal argument "+t);var e=r.wordsToBytes(i(t,n));return n&&n.asBytes?e:n&&n.asString?o.bytesToString(e):r.bytesToHex(e)}}()}));function te(t){return"function"==typeof t}var re={},ne={},ee={};function oe(t){var r=t.invokeId,n=t.event,e=t.payload;if(r||n){e=r?{data:e}:e;for(var o=(r?ee[r]:ne[n])||[],i=0;i<o.length;i++){var u=o[i];try{u.callback(e)}catch(t){__appServiceSDK__.reportUncaughtError({info:t.toString(),stack:t.stack})}}}}function ie(t){if("string"==typeof t)try{t=JSON.parse(t)}catch(t){}for(var r=t.payload,n=t.event,e=re[n]||[],o=0;o<e.length;o++){var i=e[o];i.isSustain||(e.splice(o,1),o--);try{i.callback(r)}catch(t){__appServiceSDK__.reportUncaughtError({info:t.toString(),stack:t.stack})}}}var ue=function(t){var r=t.isSustain,n=void 0===r||r,e=t.method,o=t.callback,i=t.invokeId;if(o){var u={method:e,callback:o,isSustain:n};ee[i]?ee[i].push(u):ee[i]=[u]}},ce=DiminaServiceBridge&&te(DiminaServiceBridge.invoke),ae=DiminaServiceBridge&&te(DiminaServiceBridge.publish),fe={invoke:function(t){var r=t.method,n=t.module,e=void 0===n?"":n,o=t.data,i=t.invokeId,u=t.isSustain,c=void 0!==u&&u,a=t.callback;if(r){if(a&&(i||(i=Number(Math.random().toString().substr(3,13)+Date.now()).toString(36)),ue({invokeId:i,method:r,isSustain:c,callback:a})),ce)return DiminaServiceBridge.invoke(r,o,i,e);throw new Error("Service bridge invoke failed.")}},publish:function(t){var r=t.event,n=t.webViewId,e=t.data;if(r){if(!ae)throw new Error("Service bridge publish failed.");var o={data:e};DiminaServiceBridge.publish(JSON.stringify({event:r,payload:o}),n)}},on:function(t,r){var n=t.isSustain,e=void 0===n||n,o=t.method,i=t.callback,u=t.event;if(i=i||r){var c={method:o,callback:i,isSustain:e};ne[u]?ne[u].push(c):ne[u]=[c]}},onBridgeCb:ue,off:function(t){var r=t.event,n=t.callback;if(r){if(n&&!te(n))throw new Error("Error in off: callback should be function");if(n)for(var e=ne[r]||[],o=0;o<e.length;++o){(e[o]||{}).callback===n&&(e.splice(o,1),o--)}else ne[r]=[]}},subscribe:function(t,r){var n=t.event,e=t.isSustain,o=void 0===e||e,i=t.callback;if(i=i||r){var u={event:n,callback:i,isSustain:o};re[u.event]?re[u.event].push(u):re[u.event]=[u]}},clearAll:function(){re={},ee={},ne={}},invokeCallbackHandler:oe,subscribeHandler:ie};return DiminaServiceBridge&&(DiminaServiceBridge.invokeCallbackHandler=oe,DiminaServiceBridge.subscribeHandler=ie),fe}();


// ide 在全局注入的 变量
if (isDevTools) {
  didiJsBridge = new acquireLocalBridge({ from: 'AppService' })
}

var Reporter=function(){"use strict";function t(r){return t="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},t(r)}function r(){return r=Object.assign||function(t){for(var r=1;r<arguments.length;r++){var e=arguments[r];for(var n in e)Object.prototype.hasOwnProperty.call(e,n)&&(t[n]=e[n])}return t},r.apply(this,arguments)}var e="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function n(t,r,e){return t(e={path:r,exports:{},require:function(t,r){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==r&&e.path)}},e.exports),e.exports}var o,i,a=function(t){return t&&t.Math==Math&&t},u=a("object"==typeof globalThis&&globalThis)||a("object"==typeof window&&window)||a("object"==typeof self&&self)||a("object"==typeof e&&e)||function(){return this}()||Function("return this")(),c=function(t){try{return!!t()}catch(t){return!0}},f=!c((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),s=!c((function(){var t=function(){}.bind();return"function"!=typeof t||t.hasOwnProperty("prototype")})),p=Function.prototype.call,l=s?p.bind(p):function(){return p.apply(p,arguments)},y={}.propertyIsEnumerable,v=Object.getOwnPropertyDescriptor,g={f:v&&!y.call({1:2},1)?function(t){var r=v(this,t);return!!r&&r.enumerable}:y},m=function(t,r){return{enumerable:!(1&t),configurable:!(2&t),writable:!(4&t),value:r}},b=Function.prototype,d=b.bind,h=b.call,S=s&&d.bind(h,h),_=s?function(t){return t&&S(t)}:function(t){return t&&function(){return h.apply(t,arguments)}},w=_({}.toString),O=_("".slice),j=function(t){return O(w(t),8,-1)},P=Object,E=_("".split),N=c((function(){return!P("z").propertyIsEnumerable(0)}))?function(t){return"String"==j(t)?E(t,""):P(t)}:P,T=TypeError,I=function(t){if(null==t)throw T("Can't call method on "+t);return t},R=function(t){return N(I(t))},A=function(t){return"function"==typeof t},L=function(t){return"object"==typeof t?null!==t:A(t)},k=function(t){return A(t)?t:void 0},M=function(t,r){return arguments.length<2?k(u[t]):u[t]&&u[t][r]},C=_({}.isPrototypeOf),F=M("navigator","userAgent")||"",x=u.process,D=u.Deno,B=x&&x.versions||D&&D.version,z=B&&B.v8;z&&(i=(o=z.split("."))[0]>0&&o[0]<4?1:+(o[0]+o[1])),!i&&F&&(!(o=F.match(/Edge\/(\d+)/))||o[1]>=74)&&(o=F.match(/Chrome\/(\d+)/))&&(i=+o[1]);var G=i,J=!!Object.getOwnPropertySymbols&&!c((function(){var t=Symbol();return!String(t)||!(Object(t)instanceof Symbol)||!Symbol.sham&&G&&G<41})),U=J&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,V=Object,q=U?function(t){return"symbol"==typeof t}:function(t){var r=M("Symbol");return A(r)&&C(r.prototype,V(t))},W=String,X=TypeError,Y=function(t){if(A(t))return t;throw X(function(t){try{return W(t)}catch(t){return"Object"}}(t)+" is not a function")},$=TypeError,K=Object.defineProperty,H=function(t,r){try{K(u,t,{value:r,configurable:!0,writable:!0})}catch(e){u[t]=r}return r},Q="__core-js_shared__",Z=u[Q]||H(Q,{}),tt=n((function(t){(t.exports=function(t,r){return Z[t]||(Z[t]=void 0!==r?r:{})})("versions",[]).push({version:"3.24.1",mode:"global",copyright:"© 2014-2022 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.24.1/LICENSE",source:"https://github.com/zloirock/core-js"})})),rt=Object,et=function(t){return rt(I(t))},nt=_({}.hasOwnProperty),ot=Object.hasOwn||function(t,r){return nt(et(t),r)},it=0,at=Math.random(),ut=_(1..toString),ct=function(t){return"Symbol("+(void 0===t?"":t)+")_"+ut(++it+at,36)},ft=tt("wks"),st=u.Symbol,pt=st&&st.for,lt=U?st:st&&st.withoutSetter||ct,yt=function(t){if(!ot(ft,t)||!J&&"string"!=typeof ft[t]){var r="Symbol."+t;J&&ot(st,t)?ft[t]=st[t]:ft[t]=U&&pt?pt(r):lt(r)}return ft[t]},vt=TypeError,gt=yt("toPrimitive"),mt=function(t,r){if(!L(t)||q(t))return t;var e,n,o=null==(e=t[gt])?void 0:Y(e);if(o){if(void 0===r&&(r="default"),n=l(o,t,r),!L(n)||q(n))return n;throw vt("Can't convert object to primitive value")}return void 0===r&&(r="number"),function(t,r){var e,n;if("string"===r&&A(e=t.toString)&&!L(n=l(e,t)))return n;if(A(e=t.valueOf)&&!L(n=l(e,t)))return n;if("string"!==r&&A(e=t.toString)&&!L(n=l(e,t)))return n;throw $("Can't convert object to primitive value")}(t,r)},bt=function(t){var r=mt(t,"string");return q(r)?r:r+""},dt=u.document,ht=L(dt)&&L(dt.createElement),St=!f&&!c((function(){return 7!=Object.defineProperty((t="div",ht?dt.createElement(t):{}),"a",{get:function(){return 7}}).a;var t})),_t=Object.getOwnPropertyDescriptor,wt={f:f?_t:function(t,r){if(t=R(t),r=bt(r),St)try{return _t(t,r)}catch(t){}if(ot(t,r))return m(!l(g.f,t,r),t[r])}},Ot=f&&c((function(){return 42!=Object.defineProperty((function(){}),"prototype",{value:42,writable:!1}).prototype})),jt=String,Pt=TypeError,Et=function(t){if(L(t))return t;throw Pt(jt(t)+" is not an object")},Nt=TypeError,Tt=Object.defineProperty,It=Object.getOwnPropertyDescriptor,Rt="enumerable",At="configurable",Lt="writable",kt={f:f?Ot?function(t,r,e){if(Et(t),r=bt(r),Et(e),"function"==typeof t&&"prototype"===r&&"value"in e&&Lt in e&&!e.writable){var n=It(t,r);n&&n.writable&&(t[r]=e.value,e={configurable:At in e?e.configurable:n.configurable,enumerable:Rt in e?e.enumerable:n.enumerable,writable:!1})}return Tt(t,r,e)}:Tt:function(t,r,e){if(Et(t),r=bt(r),Et(e),St)try{return Tt(t,r,e)}catch(t){}if("get"in e||"set"in e)throw Nt("Accessors not supported");return"value"in e&&(t[r]=e.value),t}},Mt=f?function(t,r,e){return kt.f(t,r,m(1,e))}:function(t,r,e){return t[r]=e,t},Ct=Function.prototype,Ft=f&&Object.getOwnPropertyDescriptor,xt=ot(Ct,"name"),Dt={EXISTS:xt,PROPER:xt&&"something"===function(){}.name,CONFIGURABLE:xt&&(!f||f&&Ft(Ct,"name").configurable)},Bt=_(Function.toString);A(Z.inspectSource)||(Z.inspectSource=function(t){return Bt(t)});var zt,Gt,Jt,Ut=Z.inspectSource,Vt=u.WeakMap,qt=A(Vt)&&/native code/.test(Ut(Vt)),Wt=tt("keys"),Xt={},Yt="Object already initialized",$t=u.TypeError,Kt=u.WeakMap;if(qt||Z.state){var Ht=Z.state||(Z.state=new Kt),Qt=_(Ht.get),Zt=_(Ht.has),tr=_(Ht.set);zt=function(t,r){if(Zt(Ht,t))throw new $t(Yt);return r.facade=t,tr(Ht,t,r),r},Gt=function(t){return Qt(Ht,t)||{}},Jt=function(t){return Zt(Ht,t)}}else{var rr=function(t){return Wt[t]||(Wt[t]=ct(t))}("state");Xt[rr]=!0,zt=function(t,r){if(ot(t,rr))throw new $t(Yt);return r.facade=t,Mt(t,rr,r),r},Gt=function(t){return ot(t,rr)?t[rr]:{}},Jt=function(t){return ot(t,rr)}}var er={set:zt,get:Gt,has:Jt,enforce:function(t){return Jt(t)?Gt(t):zt(t,{})},getterFor:function(t){return function(r){var e;if(!L(r)||(e=Gt(r)).type!==t)throw $t("Incompatible receiver, "+t+" required");return e}}},nr=n((function(t){var r=Dt.CONFIGURABLE,e=er.enforce,n=er.get,o=Object.defineProperty,i=f&&!c((function(){return 8!==o((function(){}),"length",{value:8}).length})),a=String(String).split("String"),u=t.exports=function(t,n,u){"Symbol("===String(n).slice(0,7)&&(n="["+String(n).replace(/^Symbol\(([^)]*)\)/,"$1")+"]"),u&&u.getter&&(n="get "+n),u&&u.setter&&(n="set "+n),(!ot(t,"name")||r&&t.name!==n)&&(f?o(t,"name",{value:n,configurable:!0}):t.name=n),i&&u&&ot(u,"arity")&&t.length!==u.arity&&o(t,"length",{value:u.arity});try{u&&ot(u,"constructor")&&u.constructor?f&&o(t,"prototype",{writable:!1}):t.prototype&&(t.prototype=void 0)}catch(t){}var c=e(t);return ot(c,"source")||(c.source=a.join("string"==typeof n?n:"")),t};Function.prototype.toString=u((function(){return A(this)&&n(this).source||Ut(this)}),"toString")})),or=function(t,r,e,n){n||(n={});var o=n.enumerable,i=void 0!==n.name?n.name:r;if(A(e)&&nr(e,i,n),n.global)o?t[r]=e:H(r,e);else{try{n.unsafe?t[r]&&(o=!0):delete t[r]}catch(t){}o?t[r]=e:kt.f(t,r,{value:e,enumerable:!1,configurable:!n.nonConfigurable,writable:!n.nonWritable})}return t},ir=Math.ceil,ar=Math.floor,ur=Math.trunc||function(t){var r=+t;return(r>0?ar:ir)(r)},cr=function(t){var r=+t;return r!=r||0===r?0:ur(r)},fr=Math.max,sr=Math.min,pr=Math.min,lr=function(t){return(r=t.length)>0?pr(cr(r),9007199254740991):0;var r},yr=function(t){return function(r,e,n){var o,i=R(r),a=lr(i),u=function(t,r){var e=cr(t);return e<0?fr(e+r,0):sr(e,r)}(n,a);if(t&&e!=e){for(;a>u;)if((o=i[u++])!=o)return!0}else for(;a>u;u++)if((t||u in i)&&i[u]===e)return t||u||0;return!t&&-1}},vr={includes:yr(!0),indexOf:yr(!1)}.indexOf,gr=_([].push),mr=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"].concat("length","prototype"),br=Object.getOwnPropertyNames||function(t){return function(t,r){var e,n=R(t),o=0,i=[];for(e in n)!ot(Xt,e)&&ot(n,e)&&gr(i,e);for(;r.length>o;)ot(n,e=r[o++])&&(~vr(i,e)||gr(i,e));return i}(t,mr)},dr={f:br},hr={f:Object.getOwnPropertySymbols},Sr=_([].concat),_r=M("Reflect","ownKeys")||function(t){var r=dr.f(Et(t)),e=hr.f;return e?Sr(r,e(t)):r},wr=function(t,r,e){for(var n=_r(r),o=kt.f,i=wt.f,a=0;a<n.length;a++){var u=n[a];ot(t,u)||e&&ot(e,u)||o(t,u,i(r,u))}},Or=/#|\.prototype\./,jr=function(t,r){var e=Er[Pr(t)];return e==Tr||e!=Nr&&(A(r)?c(r):!!r)},Pr=jr.normalize=function(t){return String(t).replace(Or,".").toLowerCase()},Er=jr.data={},Nr=jr.NATIVE="N",Tr=jr.POLYFILL="P",Ir=jr,Rr=wt.f,Ar=Array.isArray||function(t){return"Array"==j(t)},Lr=TypeError,kr=function(t){if(t>9007199254740991)throw Lr("Maximum allowed index exceeded");return t},Mr=function(t,r,e){var n=bt(r);n in t?kt.f(t,n,m(0,e)):t[n]=e},Cr={};Cr[yt("toStringTag")]="z";var Fr="[object z]"===String(Cr),xr=yt("toStringTag"),Dr=Object,Br="Arguments"==j(function(){return arguments}()),zr=Fr?j:function(t){var r,e,n;return void 0===t?"Undefined":null===t?"Null":"string"==typeof(e=function(t,r){try{return t[r]}catch(t){}}(r=Dr(t),xr))?e:Br?j(r):"Object"==(n=j(r))&&A(r.callee)?"Arguments":n},Gr=function(){},Jr=[],Ur=M("Reflect","construct"),Vr=/^\s*(?:class|function)\b/,qr=_(Vr.exec),Wr=!Vr.exec(Gr),Xr=function(t){if(!A(t))return!1;try{return Ur(Gr,Jr,t),!0}catch(t){return!1}},Yr=function(t){if(!A(t))return!1;switch(zr(t)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return Wr||!!qr(Vr,Ut(t))}catch(t){return!0}};Yr.sham=!0;var $r,Kr=!Ur||c((function(){var t;return Xr(Xr.call)||!Xr(Object)||!Xr((function(){t=!0}))||t}))?Yr:Xr,Hr=yt("species"),Qr=Array,Zr=function(t,r){return new(function(t){var r;return Ar(t)&&(r=t.constructor,(Kr(r)&&(r===Qr||Ar(r.prototype))||L(r)&&null===(r=r[Hr]))&&(r=void 0)),void 0===r?Qr:r}(t))(0===r?0:r)},te=yt("species"),re=yt("isConcatSpreadable"),ee=G>=51||!c((function(){var t=[];return t[re]=!1,t.concat()[0]!==t})),ne=($r="concat",G>=51||!c((function(){var t=[];return(t.constructor={})[te]=function(){return{foo:1}},1!==t[$r](Boolean).foo}))),oe=function(t){if(!L(t))return!1;var r=t[re];return void 0!==r?!!r:Ar(t)};!function(t,r){var e,n,o,i,a,c=t.target,f=t.global,s=t.stat;if(e=f?u:s?u[c]||H(c,{}):(u[c]||{}).prototype)for(n in r){if(i=r[n],o=t.dontCallGetSet?(a=Rr(e,n))&&a.value:e[n],!Ir(f?n:c+(s?".":"#")+n,t.forced)&&void 0!==o){if(typeof i==typeof o)continue;wr(i,o)}(t.sham||o&&o.sham)&&Mt(i,"sham",!0),or(e,n,i,t)}}({target:"Array",proto:!0,arity:1,forced:!ee||!ne},{concat:function(t){var r,e,n,o,i,a=et(this),u=Zr(a,0),c=0;for(r=-1,n=arguments.length;r<n;r++)if(oe(i=-1===r?a:arguments[r]))for(o=lr(i),kr(c+o),e=0;e<o;e++,c++)e in i&&Mr(u,c,i[e]);else kr(c+1),Mr(u,c++,i);return u.length=c,u}});var ie=String,ae=TypeError,ue=Object.setPrototypeOf||("__proto__"in{}?function(){var t,r=!1,e={};try{(t=_(Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set))(e,[]),r=e instanceof Array}catch(t){}return function(e,n){return Et(e),function(t){if("object"==typeof t||A(t))return t;throw ae("Can't set "+ie(t)+" as a prototype")}(n),r?t(e,n):e.__proto__=n,e}}():void 0),ce=function(t,r,e){var n,o;return ue&&A(n=r.constructor)&&n!==e&&L(o=n.prototype)&&o!==e.prototype&&ue(t,o),t},fe=_(1..valueOf),se=String,pe=_("".replace),le="[\t\n\v\f\r                　\u2028\u2029\ufeff]",ye=RegExp("^"+le+le+"*"),ve=RegExp(le+le+"*$"),ge=function(t){return function(r){var e=function(t){if("Symbol"===zr(t))throw TypeError("Cannot convert a Symbol value to a string");return se(t)}(I(r));return 1&t&&(e=pe(e,ye,"")),2&t&&(e=pe(e,ve,"")),e}},me={start:ge(1),end:ge(2),trim:ge(3)},be=dr.f,de=wt.f,he=kt.f,Se=me.trim,_e="Number",we=u.Number,Oe=we.prototype,je=u.TypeError,Pe=_("".slice),Ee=_("".charCodeAt),Ne=function(t){var r=mt(t,"number");return"bigint"==typeof r?r:Te(r)},Te=function(t){var r,e,n,o,i,a,u,c,f=mt(t,"number");if(q(f))throw je("Cannot convert a Symbol value to a number");if("string"==typeof f&&f.length>2)if(f=Se(f),43===(r=Ee(f,0))||45===r){if(88===(e=Ee(f,2))||120===e)return NaN}else if(48===r){switch(Ee(f,1)){case 66:case 98:n=2,o=49;break;case 79:case 111:n=8,o=55;break;default:return+f}for(a=(i=Pe(f,2)).length,u=0;u<a;u++)if((c=Ee(i,u))<48||c>o)return NaN;return parseInt(i,n)}return+f};if(Ir(_e,!we(" 0o1")||!we("0b1")||we("+0x1"))){for(var Ie,Re=function(t){var r=arguments.length<1?0:we(Ne(t)),e=this;return C(Oe,e)&&c((function(){fe(e)}))?ce(Object(r),e,Re):r},Ae=f?be(we):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,isFinite,isInteger,isNaN,isSafeInteger,parseFloat,parseInt,fromString,range".split(","),Le=0;Ae.length>Le;Le++)ot(we,Ie=Ae[Le])&&!ot(Re,Ie)&&he(Re,Ie,de(we,Ie));Re.prototype=Oe,Oe.constructor=Re,or(u,_e,Re,{constructor:!0})}var ke,Me=function(){return Me=Object.assign||function(t){for(var r,e=1,n=arguments.length;e<n;e++)for(var o in r=arguments[e])Object.prototype.hasOwnProperty.call(r,o)&&(t[o]=r[o]);return t},Me.apply(this,arguments)},Ce=[],Fe=0,xe=(new Date).getTime();!function(t){t.pageLoad="pub_saga_page_load_bt",t.errorMessage="pub_saga_error_message_bt"}(ke||(ke={}));var De=!1,Be={},ze=function(){function e(){}return e.ddBridge=function(t,r){t&&t.event&&didiJsBridge.invoke({method:t.event,module:"DMServiceBridgeModule",data:t.data||{},isSustain:t.isSustain||!1,callback:r||function(r){(r=r.data).success?t.success&&t.success(r.data):t.fail&&t.fail({errMsg:r.errMsg}),t.complete&&t.complete()}})},e.reportNative=function(r,n){var o={};if(r){if(n)for(var i in n){var a=n[i];void 0===a||!a&&void 0!==a&&0!==a||(o[i]=n[i]),"object"===t(a)&&(o[i]=JSON.stringify(n[i]))}De?(o=e.formatReportParmas(Be,n),e.reportAnalytics(r,o)):e.ddBridge({event:"getSystemInfo",data:{},success:function(i){for(var a in i){var u=i[a];void 0===u||!u&&void 0!==u&&0!==u||(Be[a.toLowerCase()]=u),"object"===t(u)&&(Be[a.toLowerCase()]=JSON.stringify(u))}o=e.formatReportParmas(Be,n),e.reportAnalytics(r,o),De=!0}})}},e.reportAnalytics=function(t,r){e.ddBridge({event:"reportAnalytics",data:{eventName:t,data:r}})},e.traceBeginEvent=function(t,r){if(t&&r)try{var e={category:t,name:r,timeStamp:(new Date).getTime()};if(Ce.length>=1){var n=Ce.length-1;Fe=(new Date).getTime()-Ce[n].timeStamp}Ce.push(e)}catch(t){}},e.traceEndEvent=function(){if(Ce&&Ce.length)try{var t=Ce.pop(),r=(new Date).getTime(),n=r-t.timeStamp,o={category:"",name:"",timeStamp:r};Ce&&Ce.length&&(o=Ce[Ce.length-1]),e.reportNative("pub_saga_".concat(t.category,"_").concat(t.name,"_bt").toLowerCase(),{reportId:xe,start_time:t.timeStamp,end_time:r,take_up_time:n,take_begin_time:Fe,take_before_name:o.name,take_before_category:o.category})}catch(t){}},e.reportAppLaunchTime=function(t){void 0===t&&(t={app_launch_time:"",saga_launch:""}),t.app_launch_time&&(e.appLaunchTime=Number(t.app_launch_time)),t.saga_launch&&(e.sagaLaunchTime=Number(t.saga_launch))},e.pageLoadReport=function(t,r){var n=(new Date).getTime();e.reportNative("".concat(ke.pageLoad),{timetigger:n,path:t,webviewid:r,app_launch_time:n-(e.appLaunchTime||n),saga_launch_time:n-(e.sagaLaunchTime||n)})},e.errorReport=function(t){e.reportNative("".concat(ke.errorMessage),{key:t.key,type:t.type,error:t.error})},e.ravenReport=function(r,n,o){var i={};r&&(De?(i=e.formatReportParmas(Be,n),e.reportRavenNative(r,i,n,o)):e.ddBridge({event:"getSystemInfo",data:{},success:function(a){for(var u in a){var c=a[u];void 0===c||!c&&void 0!==c&&0!==c||(Be[u.toLowerCase()]=c),"object"===t(c)&&(Be[u.toLowerCase()]=JSON.stringify(c))}i=e.formatReportParmas(Be,n),e.reportRavenNative(r,i,n,o),De=!0}}))},e.formatReportParmas=function(n,o){var i={};if(o)for(var a in o){var u=o[a];void 0===u||!u&&void 0!==u&&0!==u||"fail"===a||(i[a]=o[a]),"object"===t(u)&&"fail"!==a&&(i[a]=JSON.stringify(o[a]))}return e.publicReportParams.jssdk_version=n.jssdkversion,e.publicReportParams.platform=n.platform,e.publicReportParams.brand="",e.publicReportParams.app_version=n.sdkversion,e.publicReportParams.applets_version=n.appversion,e.publicReportParams.app_id=n.appid,i=r(Me({},i),e.publicReportParams)},e.reportRavenNative=function(t,r,e,n){didiJsBridge.invoke({method:"traceRaven",data:{eventName:t,data:r||{}},callback:n||function(t){(t=t.data).success?e.success&&e.success(t.data):e.fail&&e.fail({errMsg:t.errMsg}),e.complete&&e.complete()}})},e.appLaunchTime=0,e.sagaLaunchTime=0,e.publicReportParams={jssdk_version:"",app_id:"",app_version:"",applets_version:"",platform:"",brand:"",user_info:""},e}();return ze}();


!function(){"use strict";var t="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function e(t,e,n){return t(n={path:e,exports:{},require:function(t,e){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==e&&n.path)}},n.exports),n.exports}var n,r,o=function(t){return t&&t.Math==Math&&t},i=o("object"==typeof globalThis&&globalThis)||o("object"==typeof window&&window)||o("object"==typeof self&&self)||o("object"==typeof t&&t)||function(){return this}()||Function("return this")(),a={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0},c=function(t){return"function"==typeof t},u=function(t){return"object"==typeof t?null!==t:c(t)},f=i.document,s=u(f)&&u(f.createElement),l=function(t){return s?f.createElement(t):{}},p=l("span").classList,d=p&&p.constructor&&p.constructor.prototype,v=d===Object.prototype?void 0:d,h=function(t){try{return!!t()}catch(t){return!0}},y=!h((function(){var t=function(){}.bind();return"function"!=typeof t||t.hasOwnProperty("prototype")})),g=Function.prototype,b=g.bind,m=g.call,_=y&&b.bind(m,m),S=y?function(t){return t&&_(t)}:function(t){return t&&function(){return m.apply(t,arguments)}},w=String,O=function(t){try{return w(t)}catch(t){return"Object"}},C=TypeError,j=function(t){if(c(t))return t;throw C(O(t)+" is not a function")},T=S(S.bind),E=function(t,e){return j(t),void 0===e?t:y?T(t,e):function(){return t.apply(e,arguments)}},P=S({}.toString),R=S("".slice),x=function(t){return R(P(t),8,-1)},A=Object,I=S("".split),L=h((function(){return!A("z").propertyIsEnumerable(0)}))?function(t){return"String"==x(t)?I(t,""):A(t)}:A,k=TypeError,F=function(t){if(null==t)throw k("Can't call method on "+t);return t},D=Object,M=function(t){return D(F(t))},N=Math.ceil,U=Math.floor,G=Math.trunc||function(t){var e=+t;return(e>0?U:N)(e)},V=function(t){var e=+t;return e!=e||0===e?0:G(e)},B=Math.min,W=function(t){return(e=t.length)>0?B(V(e),9007199254740991):0;var e},z=Array.isArray||function(t){return"Array"==x(t)},H=Object.defineProperty,q=function(t,e){try{H(i,t,{value:e,configurable:!0,writable:!0})}catch(n){i[t]=e}return e},J="__core-js_shared__",K=i[J]||q(J,{}),Y=e((function(t){(t.exports=function(t,e){return K[t]||(K[t]=void 0!==e?e:{})})("versions",[]).push({version:"3.24.1",mode:"global",copyright:"© 2014-2022 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.24.1/LICENSE",source:"https://github.com/zloirock/core-js"})})),X=S({}.hasOwnProperty),$=Object.hasOwn||function(t,e){return X(M(t),e)},Q=0,Z=Math.random(),tt=S(1..toString),et=function(t){return"Symbol("+(void 0===t?"":t)+")_"+tt(++Q+Z,36)},nt=function(t){return c(t)?t:void 0},rt=function(t,e){return arguments.length<2?nt(i[t]):i[t]&&i[t][e]},ot=rt("navigator","userAgent")||"",it=i.process,at=i.Deno,ct=it&&it.versions||at&&at.version,ut=ct&&ct.v8;ut&&(r=(n=ut.split("."))[0]>0&&n[0]<4?1:+(n[0]+n[1])),!r&&ot&&(!(n=ot.match(/Edge\/(\d+)/))||n[1]>=74)&&(n=ot.match(/Chrome\/(\d+)/))&&(r=+n[1]);var ft=r,st=!!Object.getOwnPropertySymbols&&!h((function(){var t=Symbol();return!String(t)||!(Object(t)instanceof Symbol)||!Symbol.sham&&ft&&ft<41})),lt=st&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,pt=Y("wks"),dt=i.Symbol,vt=dt&&dt.for,ht=lt?dt:dt&&dt.withoutSetter||et,yt=function(t){if(!$(pt,t)||!st&&"string"!=typeof pt[t]){var e="Symbol."+t;st&&$(dt,t)?pt[t]=dt[t]:pt[t]=lt&&vt?vt(e):ht(e)}return pt[t]},gt={};gt[yt("toStringTag")]="z";var bt="[object z]"===String(gt),mt=yt("toStringTag"),_t=Object,St="Arguments"==x(function(){return arguments}()),wt=bt?x:function(t){var e,n,r;return void 0===t?"Undefined":null===t?"Null":"string"==typeof(n=function(t,e){try{return t[e]}catch(t){}}(e=_t(t),mt))?n:St?x(e):"Object"==(r=x(e))&&c(e.callee)?"Arguments":r},Ot=S(Function.toString);c(K.inspectSource)||(K.inspectSource=function(t){return Ot(t)});var Ct=K.inspectSource,jt=function(){},Tt=[],Et=rt("Reflect","construct"),Pt=/^\s*(?:class|function)\b/,Rt=S(Pt.exec),xt=!Pt.exec(jt),At=function(t){if(!c(t))return!1;try{return Et(jt,Tt,t),!0}catch(t){return!1}},It=function(t){if(!c(t))return!1;switch(wt(t)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return xt||!!Rt(Pt,Ct(t))}catch(t){return!0}};It.sham=!0;var Lt=!Et||h((function(){var t;return At(At.call)||!At(Object)||!At((function(){t=!0}))||t}))?It:At,kt=yt("species"),Ft=Array,Dt=function(t,e){return new(function(t){var e;return z(t)&&(e=t.constructor,(Lt(e)&&(e===Ft||z(e.prototype))||u(e)&&null===(e=e[kt]))&&(e=void 0)),void 0===e?Ft:e}(t))(0===e?0:e)},Mt=S([].push),Nt=function(t){var e=1==t,n=2==t,r=3==t,o=4==t,i=6==t,a=7==t,c=5==t||i;return function(u,f,s,l){for(var p,d,v=M(u),h=L(v),y=E(f,s),g=W(h),b=0,m=l||Dt,_=e?m(u,g):n||a?m(u,0):void 0;g>b;b++)if((c||b in h)&&(d=y(p=h[b],b,v),t))if(e)_[b]=d;else if(d)switch(t){case 3:return!0;case 5:return p;case 6:return b;case 2:Mt(_,p)}else switch(t){case 4:return!1;case 7:Mt(_,p)}return i?-1:r||o?o:_}},Ut={forEach:Nt(0),map:Nt(1),filter:Nt(2),some:Nt(3),every:Nt(4),find:Nt(5),findIndex:Nt(6),filterReject:Nt(7)}.forEach,Gt=function(t,e){var n=[][t];return!!n&&h((function(){n.call(null,e||function(){return 1},1)}))}("forEach"),Vt=Gt?[].forEach:function(t){return Ut(this,t,arguments.length>1?arguments[1]:void 0)},Bt=!h((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),Wt=!Bt&&!h((function(){return 7!=Object.defineProperty(l("div"),"a",{get:function(){return 7}}).a})),zt=Bt&&h((function(){return 42!=Object.defineProperty((function(){}),"prototype",{value:42,writable:!1}).prototype})),Ht=String,qt=TypeError,Jt=function(t){if(u(t))return t;throw qt(Ht(t)+" is not an object")},Kt=Function.prototype.call,Yt=y?Kt.bind(Kt):function(){return Kt.apply(Kt,arguments)},Xt=S({}.isPrototypeOf),$t=Object,Qt=lt?function(t){return"symbol"==typeof t}:function(t){var e=rt("Symbol");return c(e)&&Xt(e.prototype,$t(t))},Zt=function(t,e){var n=t[e];return null==n?void 0:j(n)},te=TypeError,ee=TypeError,ne=yt("toPrimitive"),re=function(t,e){if(!u(t)||Qt(t))return t;var n,r=Zt(t,ne);if(r){if(void 0===e&&(e="default"),n=Yt(r,t,e),!u(n)||Qt(n))return n;throw ee("Can't convert object to primitive value")}return void 0===e&&(e="number"),function(t,e){var n,r;if("string"===e&&c(n=t.toString)&&!u(r=Yt(n,t)))return r;if(c(n=t.valueOf)&&!u(r=Yt(n,t)))return r;if("string"!==e&&c(n=t.toString)&&!u(r=Yt(n,t)))return r;throw te("Can't convert object to primitive value")}(t,e)},oe=function(t){var e=re(t,"string");return Qt(e)?e:e+""},ie=TypeError,ae=Object.defineProperty,ce=Object.getOwnPropertyDescriptor,ue="enumerable",fe="configurable",se="writable",le={f:Bt?zt?function(t,e,n){if(Jt(t),e=oe(e),Jt(n),"function"==typeof t&&"prototype"===e&&"value"in n&&se in n&&!n.writable){var r=ce(t,e);r&&r.writable&&(t[e]=n.value,n={configurable:fe in n?n.configurable:r.configurable,enumerable:ue in n?n.enumerable:r.enumerable,writable:!1})}return ae(t,e,n)}:ae:function(t,e,n){if(Jt(t),e=oe(e),Jt(n),Wt)try{return ae(t,e,n)}catch(t){}if("get"in n||"set"in n)throw ie("Accessors not supported");return"value"in n&&(t[e]=n.value),t}},pe=function(t,e){return{enumerable:!(1&t),configurable:!(2&t),writable:!(4&t),value:e}},de=Bt?function(t,e,n){return le.f(t,e,pe(1,n))}:function(t,e,n){return t[e]=n,t},ve=function(t){if(t&&t.forEach!==Vt)try{de(t,"forEach",Vt)}catch(e){t.forEach=Vt}};for(var he in a)a[he]&&ve(i[he]&&i[he].prototype);ve(v);var ye,ge=function(t){return L(F(t))},be=Math.max,me=Math.min,_e=function(t){return function(e,n,r){var o,i=ge(e),a=W(i),c=function(t,e){var n=V(t);return n<0?be(n+e,0):me(n,e)}(r,a);if(t&&n!=n){for(;a>c;)if((o=i[c++])!=o)return!0}else for(;a>c;c++)if((t||c in i)&&i[c]===n)return t||c||0;return!t&&-1}},Se={includes:_e(!0),indexOf:_e(!1)},we={},Oe=Se.indexOf,Ce=S([].push),je=function(t,e){var n,r=ge(t),o=0,i=[];for(n in r)!$(we,n)&&$(r,n)&&Ce(i,n);for(;e.length>o;)$(r,n=e[o++])&&(~Oe(i,n)||Ce(i,n));return i},Te=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],Ee=Object.keys||function(t){return je(t,Te)},Pe=Bt&&!zt?Object.defineProperties:function(t,e){Jt(t);for(var n,r=ge(e),o=Ee(e),i=o.length,a=0;i>a;)le.f(t,n=o[a++],r[n]);return t},Re={f:Pe},xe=rt("document","documentElement"),Ae=Y("keys"),Ie=function(t){return Ae[t]||(Ae[t]=et(t))},Le=Ie("IE_PROTO"),ke=function(){},Fe=function(t){return"<script>"+t+"</"+"script>"},De=function(t){t.write(Fe("")),t.close();var e=t.parentWindow.Object;return t=null,e},Me=function(){try{ye=new ActiveXObject("htmlfile")}catch(t){}var t,e;Me="undefined"!=typeof document?document.domain&&ye?De(ye):((e=l("iframe")).style.display="none",xe.appendChild(e),e.src=String("javascript:"),(t=e.contentWindow.document).open(),t.write(Fe("document.F=Object")),t.close(),t.F):De(ye);for(var n=Te.length;n--;)delete Me.prototype[Te[n]];return Me()};we[Le]=!0;var Ne=Object.create||function(t,e){var n;return null!==t?(ke.prototype=Jt(t),n=new ke,ke.prototype=null,n[Le]=t):n=Me(),void 0===e?n:Re.f(n,e)},Ue=le.f,Ge=yt("unscopables"),Ve=Array.prototype;null==Ve[Ge]&&Ue(Ve,Ge,{configurable:!0,value:Ne(null)});var Be,We,ze,He=function(t){Ve[Ge][t]=!0},qe={},Je=i.WeakMap,Ke=c(Je)&&/native code/.test(Ct(Je)),Ye="Object already initialized",Xe=i.TypeError,$e=i.WeakMap;if(Ke||K.state){var Qe=K.state||(K.state=new $e),Ze=S(Qe.get),tn=S(Qe.has),en=S(Qe.set);Be=function(t,e){if(tn(Qe,t))throw new Xe(Ye);return e.facade=t,en(Qe,t,e),e},We=function(t){return Ze(Qe,t)||{}},ze=function(t){return tn(Qe,t)}}else{var nn=Ie("state");we[nn]=!0,Be=function(t,e){if($(t,nn))throw new Xe(Ye);return e.facade=t,de(t,nn,e),e},We=function(t){return $(t,nn)?t[nn]:{}},ze=function(t){return $(t,nn)}}var rn,on,an,cn={set:Be,get:We,has:ze,enforce:function(t){return ze(t)?We(t):Be(t,{})},getterFor:function(t){return function(e){var n;if(!u(e)||(n=We(e)).type!==t)throw Xe("Incompatible receiver, "+t+" required");return n}}},un={}.propertyIsEnumerable,fn=Object.getOwnPropertyDescriptor,sn={f:fn&&!un.call({1:2},1)?function(t){var e=fn(this,t);return!!e&&e.enumerable}:un},ln=Object.getOwnPropertyDescriptor,pn={f:Bt?ln:function(t,e){if(t=ge(t),e=oe(e),Wt)try{return ln(t,e)}catch(t){}if($(t,e))return pe(!Yt(sn.f,t,e),t[e])}},dn=Function.prototype,vn=Bt&&Object.getOwnPropertyDescriptor,hn=$(dn,"name"),yn={EXISTS:hn,PROPER:hn&&"something"===function(){}.name,CONFIGURABLE:hn&&(!Bt||Bt&&vn(dn,"name").configurable)},gn=e((function(t){var e=yn.CONFIGURABLE,n=cn.enforce,r=cn.get,o=Object.defineProperty,i=Bt&&!h((function(){return 8!==o((function(){}),"length",{value:8}).length})),a=String(String).split("String"),u=t.exports=function(t,r,c){"Symbol("===String(r).slice(0,7)&&(r="["+String(r).replace(/^Symbol\(([^)]*)\)/,"$1")+"]"),c&&c.getter&&(r="get "+r),c&&c.setter&&(r="set "+r),(!$(t,"name")||e&&t.name!==r)&&(Bt?o(t,"name",{value:r,configurable:!0}):t.name=r),i&&c&&$(c,"arity")&&t.length!==c.arity&&o(t,"length",{value:c.arity});try{c&&$(c,"constructor")&&c.constructor?Bt&&o(t,"prototype",{writable:!1}):t.prototype&&(t.prototype=void 0)}catch(t){}var u=n(t);return $(u,"source")||(u.source=a.join("string"==typeof r?r:"")),t};Function.prototype.toString=u((function(){return c(this)&&r(this).source||Ct(this)}),"toString")})),bn=function(t,e,n,r){r||(r={});var o=r.enumerable,i=void 0!==r.name?r.name:e;if(c(n)&&gn(n,i,r),r.global)o?t[e]=n:q(e,n);else{try{r.unsafe?t[e]&&(o=!0):delete t[e]}catch(t){}o?t[e]=n:le.f(t,e,{value:n,enumerable:!1,configurable:!r.nonConfigurable,writable:!r.nonWritable})}return t},mn=Te.concat("length","prototype"),_n={f:Object.getOwnPropertyNames||function(t){return je(t,mn)}},Sn={f:Object.getOwnPropertySymbols},wn=S([].concat),On=rt("Reflect","ownKeys")||function(t){var e=_n.f(Jt(t)),n=Sn.f;return n?wn(e,n(t)):e},Cn=function(t,e,n){for(var r=On(e),o=le.f,i=pn.f,a=0;a<r.length;a++){var c=r[a];$(t,c)||n&&$(n,c)||o(t,c,i(e,c))}},jn=/#|\.prototype\./,Tn=function(t,e){var n=Pn[En(t)];return n==xn||n!=Rn&&(c(e)?h(e):!!e)},En=Tn.normalize=function(t){return String(t).replace(jn,".").toLowerCase()},Pn=Tn.data={},Rn=Tn.NATIVE="N",xn=Tn.POLYFILL="P",An=Tn,In=pn.f,Ln=function(t,e){var n,r,o,a,c,u=t.target,f=t.global,s=t.stat;if(n=f?i:s?i[u]||q(u,{}):(i[u]||{}).prototype)for(r in e){if(a=e[r],o=t.dontCallGetSet?(c=In(n,r))&&c.value:n[r],!An(f?r:u+(s?".":"#")+r,t.forced)&&void 0!==o){if(typeof a==typeof o)continue;Cn(a,o)}(t.sham||o&&o.sham)&&de(a,"sham",!0),bn(n,r,a,t)}},kn=!h((function(){function t(){}return t.prototype.constructor=null,Object.getPrototypeOf(new t)!==t.prototype})),Fn=Ie("IE_PROTO"),Dn=Object,Mn=Dn.prototype,Nn=kn?Dn.getPrototypeOf:function(t){var e=M(t);if($(e,Fn))return e[Fn];var n=e.constructor;return c(n)&&e instanceof n?n.prototype:e instanceof Dn?Mn:null},Un=yt("iterator"),Gn=!1;[].keys&&("next"in(an=[].keys())?(on=Nn(Nn(an)))!==Object.prototype&&(rn=on):Gn=!0);var Vn=null==rn||h((function(){var t={};return rn[Un].call(t)!==t}));Vn&&(rn={}),c(rn[Un])||bn(rn,Un,(function(){return this}));var Bn={IteratorPrototype:rn,BUGGY_SAFARI_ITERATORS:Gn},Wn=le.f,zn=yt("toStringTag"),Hn=function(t,e,n){t&&!n&&(t=t.prototype),t&&!$(t,zn)&&Wn(t,zn,{configurable:!0,value:e})},qn=Bn.IteratorPrototype,Jn=function(){return this},Kn=String,Yn=TypeError,Xn=Object.setPrototypeOf||("__proto__"in{}?function(){var t,e=!1,n={};try{(t=S(Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set))(n,[]),e=n instanceof Array}catch(t){}return function(n,r){return Jt(n),function(t){if("object"==typeof t||c(t))return t;throw Yn("Can't set "+Kn(t)+" as a prototype")}(r),e?t(n,r):n.__proto__=r,n}}():void 0),$n=yn.PROPER,Qn=yn.CONFIGURABLE,Zn=Bn.IteratorPrototype,tr=Bn.BUGGY_SAFARI_ITERATORS,er=yt("iterator"),nr="keys",rr="values",or="entries",ir=function(){return this},ar=function(t,e,n,r,o,i,a){!function(t,e,n,r){var o=e+" Iterator";t.prototype=Ne(qn,{next:pe(+!r,n)}),Hn(t,o,!1),qe[o]=Jn}(n,e,r);var u,f,s,l=function(t){if(t===o&&y)return y;if(!tr&&t in v)return v[t];switch(t){case nr:case rr:case or:return function(){return new n(this,t)}}return function(){return new n(this)}},p=e+" Iterator",d=!1,v=t.prototype,h=v[er]||v["@@iterator"]||o&&v[o],y=!tr&&h||l(o),g="Array"==e&&v.entries||h;if(g&&(u=Nn(g.call(new t)))!==Object.prototype&&u.next&&(Nn(u)!==Zn&&(Xn?Xn(u,Zn):c(u[er])||bn(u,er,ir)),Hn(u,p,!0)),$n&&o==rr&&h&&h.name!==rr&&(Qn?de(v,"name",rr):(d=!0,y=function(){return Yt(h,this)})),o)if(f={values:l(rr),keys:i?y:l(nr),entries:l(or)},a)for(s in f)(tr||d||!(s in v))&&bn(v,s,f[s]);else Ln({target:e,proto:!0,forced:tr||d},f);return v[er]!==y&&bn(v,er,y,{name:o}),qe[e]=y,f},cr=le.f,ur="Array Iterator",fr=cn.set,sr=cn.getterFor(ur),lr=ar(Array,"Array",(function(t,e){fr(this,{type:ur,target:ge(t),index:0,kind:e})}),(function(){var t=sr(this),e=t.target,n=t.kind,r=t.index++;return!e||r>=e.length?(t.target=void 0,{value:void 0,done:!0}):"keys"==n?{value:r,done:!1}:"values"==n?{value:e[r],done:!1}:{value:[r,e[r]],done:!1}}),"values"),pr=qe.Arguments=qe.Array;if(He("keys"),He("values"),He("entries"),Bt&&"values"!==pr.name)try{cr(pr,"name",{value:"values"})}catch(t){}var dr=bt?{}.toString:function(){return"[object "+wt(this)+"]"};bt||bn(Object.prototype,"toString",dr,{unsafe:!0});var vr,hr,yr,gr,br="process"==x(i.process),mr=yt("species"),_r=TypeError,Sr=TypeError,wr=yt("species"),Or=function(t,e){var n,r=Jt(t).constructor;return void 0===r||null==(n=Jt(r)[wr])?e:function(t){if(Lt(t))return t;throw Sr(O(t)+" is not a constructor")}(n)},Cr=Function.prototype,jr=Cr.apply,Tr=Cr.call,Er="object"==typeof Reflect&&Reflect.apply||(y?Tr.bind(jr):function(){return Tr.apply(jr,arguments)}),Pr=S([].slice),Rr=TypeError,xr=function(t,e){if(t<e)throw Rr("Not enough arguments");return t},Ar=/(?:ipad|iphone|ipod).*applewebkit/i.test(ot),Ir=i.setImmediate,Lr=i.clearImmediate,kr=i.process,Fr=i.Dispatch,Dr=i.Function,Mr=i.MessageChannel,Nr=i.String,Ur=0,Gr={},Vr="onreadystatechange";try{vr=i.location}catch(t){}var Br=function(t){if($(Gr,t)){var e=Gr[t];delete Gr[t],e()}},Wr=function(t){return function(){Br(t)}},zr=function(t){Br(t.data)},Hr=function(t){i.postMessage(Nr(t),vr.protocol+"//"+vr.host)};Ir&&Lr||(Ir=function(t){xr(arguments.length,1);var e=c(t)?t:Dr(t),n=Pr(arguments,1);return Gr[++Ur]=function(){Er(e,void 0,n)},hr(Ur),Ur},Lr=function(t){delete Gr[t]},br?hr=function(t){kr.nextTick(Wr(t))}:Fr&&Fr.now?hr=function(t){Fr.now(Wr(t))}:Mr&&!Ar?(gr=(yr=new Mr).port2,yr.port1.onmessage=zr,hr=E(gr.postMessage,gr)):i.addEventListener&&c(i.postMessage)&&!i.importScripts&&vr&&"file:"!==vr.protocol&&!h(Hr)?(hr=Hr,i.addEventListener("message",zr,!1)):hr=Vr in l("script")?function(t){xe.appendChild(l("script")).onreadystatechange=function(){xe.removeChild(this),Br(t)}}:function(t){setTimeout(Wr(t),0)});var qr,Jr,Kr,Yr,Xr,$r,Qr,Zr,to={set:Ir,clear:Lr},eo=/ipad|iphone|ipod/i.test(ot)&&void 0!==i.Pebble,no=/web0s(?!.*chrome)/i.test(ot),ro=pn.f,oo=to.set,io=i.MutationObserver||i.WebKitMutationObserver,ao=i.document,co=i.process,uo=i.Promise,fo=ro(i,"queueMicrotask"),so=fo&&fo.value;so||(qr=function(){var t,e;for(br&&(t=co.domain)&&t.exit();Jr;){e=Jr.fn,Jr=Jr.next;try{e()}catch(t){throw Jr?Yr():Kr=void 0,t}}Kr=void 0,t&&t.enter()},Ar||br||no||!io||!ao?!eo&&uo&&uo.resolve?((Qr=uo.resolve(void 0)).constructor=uo,Zr=E(Qr.then,Qr),Yr=function(){Zr(qr)}):br?Yr=function(){co.nextTick(qr)}:(oo=E(oo,i),Yr=function(){oo(qr)}):(Xr=!0,$r=ao.createTextNode(""),new io(qr).observe($r,{characterData:!0}),Yr=function(){$r.data=Xr=!Xr}));var lo=so||function(t){var e={fn:t,next:void 0};Kr&&(Kr.next=e),Jr||(Jr=e,Yr()),Kr=e},po=function(t){try{return{error:!1,value:t()}}catch(t){return{error:!0,value:t}}},vo=function(){this.head=null,this.tail=null};vo.prototype={add:function(t){var e={item:t,next:null};this.head?this.tail.next=e:this.head=e,this.tail=e},get:function(){var t=this.head;if(t)return this.head=t.next,this.tail===t&&(this.tail=null),t.item}};var ho=vo,yo=i.Promise,go="object"==typeof Deno&&Deno&&"object"==typeof Deno.version,bo=!go&&!br&&"object"==typeof window&&"object"==typeof document;yo&&yo.prototype;var mo,_o,So,wo=yt("species"),Oo=!1,Co=c(i.PromiseRejectionEvent),jo=An("Promise",(function(){var t=Ct(yo),e=t!==String(yo);if(!e&&66===ft)return!0;if(!ft||ft<51||!/native code/.test(t)){var n=new yo((function(t){t(1)})),r=function(t){t((function(){}),(function(){}))};if((n.constructor={})[wo]=r,!(Oo=n.then((function(){}))instanceof r))return!0}return!e&&(bo||go)&&!Co})),To={CONSTRUCTOR:jo,REJECTION_EVENT:Co,SUBCLASSING:Oo},Eo=function(t){var e,n;this.promise=new t((function(t,r){if(void 0!==e||void 0!==n)throw TypeError("Bad Promise constructor");e=t,n=r})),this.resolve=j(e),this.reject=j(n)},Po={f:function(t){return new Eo(t)}},Ro=to.set,xo="Promise",Ao=To.CONSTRUCTOR,Io=To.REJECTION_EVENT,Lo=To.SUBCLASSING,ko=cn.getterFor(xo),Fo=cn.set,Do=yo&&yo.prototype,Mo=yo,No=Do,Uo=i.TypeError,Go=i.document,Vo=i.process,Bo=Po.f,Wo=Bo,zo=!!(Go&&Go.createEvent&&i.dispatchEvent),Ho="unhandledrejection",qo=function(t){var e;return!(!u(t)||!c(e=t.then))&&e},Jo=function(t,e){var n,r,o,i=e.value,a=1==e.state,c=a?t.ok:t.fail,u=t.resolve,f=t.reject,s=t.domain;try{c?(a||(2===e.rejection&&Qo(e),e.rejection=1),!0===c?n=i:(s&&s.enter(),n=c(i),s&&(s.exit(),o=!0)),n===t.promise?f(Uo("Promise-chain cycle")):(r=qo(n))?Yt(r,n,u,f):u(n)):f(i)}catch(t){s&&!o&&s.exit(),f(t)}},Ko=function(t,e){t.notified||(t.notified=!0,lo((function(){for(var n,r=t.reactions;n=r.get();)Jo(n,t);t.notified=!1,e&&!t.rejection&&Xo(t)})))},Yo=function(t,e,n){var r,o;zo?((r=Go.createEvent("Event")).promise=e,r.reason=n,r.initEvent(t,!1,!0),i.dispatchEvent(r)):r={promise:e,reason:n},!Io&&(o=i["on"+t])?o(r):t===Ho&&function(t,e){var n=i.console;n&&n.error&&(1==arguments.length?n.error(t):n.error(t,e))}("Unhandled promise rejection",n)},Xo=function(t){Yt(Ro,i,(function(){var e,n=t.facade,r=t.value;if($o(t)&&(e=po((function(){br?Vo.emit("unhandledRejection",r,n):Yo(Ho,n,r)})),t.rejection=br||$o(t)?2:1,e.error))throw e.value}))},$o=function(t){return 1!==t.rejection&&!t.parent},Qo=function(t){Yt(Ro,i,(function(){var e=t.facade;br?Vo.emit("rejectionHandled",e):Yo("rejectionhandled",e,t.value)}))},Zo=function(t,e,n){return function(r){t(e,r,n)}},ti=function(t,e,n){t.done||(t.done=!0,n&&(t=n),t.value=e,t.state=2,Ko(t,!0))},ei=function(t,e,n){if(!t.done){t.done=!0,n&&(t=n);try{if(t.facade===e)throw Uo("Promise can't be resolved itself");var r=qo(e);r?lo((function(){var n={done:!1};try{Yt(r,e,Zo(ei,n,t),Zo(ti,n,t))}catch(e){ti(n,e,t)}})):(t.value=e,t.state=1,Ko(t,!1))}catch(e){ti({done:!1},e,t)}}};if(Ao&&(No=(Mo=function(t){!function(t,e){if(Xt(e,t))return t;throw _r("Incorrect invocation")}(this,No),j(t),Yt(mo,this);var e=ko(this);try{t(Zo(ei,e),Zo(ti,e))}catch(t){ti(e,t)}}).prototype,(mo=function(t){Fo(this,{type:xo,done:!1,notified:!1,parent:!1,reactions:new ho,rejection:!1,state:0,value:void 0})}).prototype=bn(No,"then",(function(t,e){var n=ko(this),r=Bo(Or(this,Mo));return n.parent=!0,r.ok=!c(t)||t,r.fail=c(e)&&e,r.domain=br?Vo.domain:void 0,0==n.state?n.reactions.add(r):lo((function(){Jo(r,n)})),r.promise})),_o=function(){var t=new mo,e=ko(t);this.promise=t,this.resolve=Zo(ei,e),this.reject=Zo(ti,e)},Po.f=Bo=function(t){return t===Mo||undefined===t?new _o(t):Wo(t)},c(yo)&&Do!==Object.prototype)){So=Do.then,Lo||bn(Do,"then",(function(t,e){var n=this;return new Mo((function(t,e){Yt(So,n,t,e)})).then(t,e)}),{unsafe:!0});try{delete Do.constructor}catch(t){}Xn&&Xn(Do,No)}Ln({global:!0,constructor:!0,wrap:!0,forced:Ao},{Promise:Mo}),Hn(Mo,xo,!1),function(t){var e=rt(t),n=le.f;Bt&&e&&!e[mr]&&n(e,mr,{configurable:!0,get:function(){return this}})}(xo);var ni=yt("iterator"),ri=Array.prototype,oi=yt("iterator"),ii=function(t){if(null!=t)return Zt(t,oi)||Zt(t,"@@iterator")||qe[wt(t)]},ai=TypeError,ci=function(t,e,n){var r,o;Jt(t);try{if(!(r=Zt(t,"return"))){if("throw"===e)throw n;return n}r=Yt(r,t)}catch(t){o=!0,r=t}if("throw"===e)throw n;if(o)throw r;return Jt(r),n},ui=TypeError,fi=function(t,e){this.stopped=t,this.result=e},si=fi.prototype,li=function(t,e,n){var r,o,i,a,c,u,f,s,l=n&&n.that,p=!(!n||!n.AS_ENTRIES),d=!(!n||!n.IS_RECORD),v=!(!n||!n.IS_ITERATOR),h=!(!n||!n.INTERRUPTED),y=E(e,l),g=function(t){return r&&ci(r,"normal",t),new fi(!0,t)},b=function(t){return p?(Jt(t),h?y(t[0],t[1],g):y(t[0],t[1])):h?y(t,g):y(t)};if(d)r=t.iterator;else if(v)r=t;else{if(!(o=ii(t)))throw ui(O(t)+" is not iterable");if(void 0!==(s=o)&&(qe.Array===s||ri[ni]===s)){for(i=0,a=W(t);a>i;i++)if((c=b(t[i]))&&Xt(si,c))return c;return new fi(!1)}r=function(t,e){var n=arguments.length<2?ii(t):e;if(j(n))return Jt(Yt(n,t));throw ai(O(t)+" is not iterable")}(t,o)}for(u=d?t.next:r.next;!(f=Yt(u,r)).done;){try{c=b(f.value)}catch(t){ci(r,"throw",t)}if("object"==typeof c&&c&&Xt(si,c))return c}return new fi(!1)},pi=yt("iterator"),di=!1;try{var vi=0,hi={next:function(){return{done:!!vi++}},return:function(){di=!0}};hi[pi]=function(){return this},Array.from(hi,(function(){throw 2}))}catch(t){}var yi=To.CONSTRUCTOR||!function(t,e){if(!e&&!di)return!1;var n=!1;try{var r={};r[pi]=function(){return{next:function(){return{done:n=!0}}}},t(r)}catch(t){}return n}((function(t){yo.all(t).then(void 0,(function(){}))}));Ln({target:"Promise",stat:!0,forced:yi},{all:function(t){var e=this,n=Po.f(e),r=n.resolve,o=n.reject,i=po((function(){var n=j(e.resolve),i=[],a=0,c=1;li(t,(function(t){var u=a++,f=!1;c++,Yt(n,e,t).then((function(t){f||(f=!0,i[u]=t,--c||r(i))}),o)})),--c||r(i)}));return i.error&&o(i.value),n.promise}});var gi=To.CONSTRUCTOR,bi=yo&&yo.prototype;if(Ln({target:"Promise",proto:!0,forced:gi,real:!0},{catch:function(t){return this.then(void 0,t)}}),c(yo)){var mi=rt("Promise").prototype.catch;bi.catch!==mi&&bn(bi,"catch",mi,{unsafe:!0})}Ln({target:"Promise",stat:!0,forced:yi},{race:function(t){var e=this,n=Po.f(e),r=n.reject,o=po((function(){var o=j(e.resolve);li(t,(function(t){Yt(o,e,t).then(n.resolve,r)}))}));return o.error&&r(o.value),n.promise}}),Ln({target:"Promise",stat:!0,forced:To.CONSTRUCTOR},{reject:function(t){var e=Po.f(this);return Yt(e.reject,void 0,t),e.promise}});var _i=To.CONSTRUCTOR;rt("Promise"),Ln({target:"Promise",stat:!0,forced:_i},{resolve:function(t){return function(t,e){if(Jt(t),u(e)&&e.constructor===t)return e;var n=Po.f(t);return(0,n.resolve)(e),n.promise}(this,t)}});var Si=String,wi=function(t){if("Symbol"===wt(t))throw TypeError("Cannot convert a Symbol value to a string");return Si(t)},Oi=S("".charAt),Ci=S("".charCodeAt),ji=S("".slice),Ti=function(t){return function(e,n){var r,o,i=wi(F(e)),a=V(n),c=i.length;return a<0||a>=c?t?"":void 0:(r=Ci(i,a))<55296||r>56319||a+1===c||(o=Ci(i,a+1))<56320||o>57343?t?Oi(i,a):r:t?ji(i,a,a+2):o-56320+(r-55296<<10)+65536}},Ei={codeAt:Ti(!1),charAt:Ti(!0)}.charAt,Pi="String Iterator",Ri=cn.set,xi=cn.getterFor(Pi);ar(String,"String",(function(t){Ri(this,{type:Pi,string:wi(t),index:0})}),(function(){var t,e=xi(this),n=e.string,r=e.index;return r>=n.length?{value:void 0,done:!0}:(t=Ei(n,r),e.index+=t.length,{value:t,done:!1})}));var Ai=yt("iterator"),Ii=yt("toStringTag"),Li=lr.values,ki=function(t,e){if(t){if(t[Ai]!==Li)try{de(t,Ai,Li)}catch(e){t[Ai]=Li}if(t[Ii]||de(t,Ii,e),a[e])for(var n in lr)if(t[n]!==lr[n])try{de(t,n,lr[n])}catch(e){t[n]=lr[n]}}};for(var Fi in a)ki(i[Fi]&&i[Fi].prototype,Fi);ki(v,"DOMTokenList");var Di=Foundation.env.isSubContext,Mi=Foundation.env.isSafeEnv,Ni=["env","appLaunchInfo","ext","wxAppInfo","debug","entryPagePath","envVersion","tabBar","pages","page","accountInfo","global","platform","system","appType","networkTimeout","navigateToMiniProgramAppIdList","plugins","extAppid","host","prerender"],Ui={};function Gi(t,e,n,r){Object.defineProperty(t,n,{configurable:!0,enumerable:!0,get:function(){if(n in e)return e[n];try{return"function"!=typeof r?r:r()}catch(t){return}},set:function(t){e[n]=t}})}var Vi=!0===__ddConfig.preload,Bi=!1,Wi=[],zi=[],Hi=Foundation.env.typeStr;function qi(t,e){try{Date.now(),t(e),Date.now()}catch(t){}}function Ji(t){zi.push(t)}function Ki(t){Bi?void 0!==__ddConfig&&qi(t,__ddConfig):"function"==typeof t&&Wi.push(t)}function Yi(t){t.tabBar&&t.tabBar.list&&t.tabBar.list.forEach((function(t){delete t.iconData,delete t.selectedIconData})),delete t.permission;var e=t.subPackages||t.subpackages;return e&&0<e.length&&(e.forEach((function(t){delete t.pages})),t.subPackages=t.subpackages=e),Bi&&(__libVersionInfo__.features&&__libVersionInfo__.features.pruneWxConfigByPage&&(Di||(__ddConfig._preloadRule=__ddConfig.preloadRule||{},__ddConfig._page=__ddConfig.page||{},delete __ddConfig.preloadRule,delete __ddConfig.page),__ddConfig.updatePage=function(t,e){var n;__ddConfig.page=__ddConfig.page||{},__ddConfig.page[t]=__ddConfig.page["".concat(t,".html")]=e,Ui["".concat(t,".html")]=(n=e,JSON.parse(JSON.stringify(n)))},__ddConfig.updatePreloadRule=function(t,e){__ddConfig.preloadRule=__ddConfig.preloadRule||{},__ddConfig.preloadRule[t]=e}),__ddConfig.page=__ddConfig.page||{}),t}function Xi(t){return t.onReady=Ki,t.beforeReady=Ji,Di||(t.preload=Vi),t.isReady=Bi,t.isSubContext=Di,t.envTag=Hi,t.isSafeContext=Mi,t.sdkVersion=t.SDKVersion=Foundation.env.SDKVersion,t.twoPhaseInject=!0,t.platform=Foundation.env.platform,t.brand||"ios"!==t.platform||(t.brand="iPhone"),"number"==typeof t.pixelRatio?t.devicePixelRatio=t.pixelRatio:"number"==typeof t.devicePixelRatio&&(t.pixelRatio=t.devicePixelRatio),t}function $i(){if(__ddConfig.onReadyStart=Date.now(),Wi.forEach((function(t){qi(t,__ddConfig)})),__ddConfig.onReadyEnd=Date.now(),Wi=[],!Mi){var t=__ddConfig,e={},n={};Ui=t.page||{},__libVersionInfo__.features&&__libVersionInfo__.features.pruneWxConfigByPage&&(Ui={});try{Gi(n,e,"deprecated",!0),Ni.forEach((function(r){if(r in t){var o=t[r];switch(r){case"page":Gi(n,e,r,Ui);break;case"env":Gi(n,e,r,(function(){return{USER_DATA_PATH:o.USER_DATA_PATH||""}}));break;case"accountInfo":Gi(n,e,r,{appId:o.appId,icon:o.icon,nickname:o.nickname});break;case"appLaunchInfo":Gi(n,e,r,(function(){return dd&&"function"==typeof dd.getLaunchOptionsSync?dd.getLaunchOptionsSync():{}}));break;case"wxAppInfo":Gi(n,e,r,{maxRequestConcurrent:o.maxRequestConcurrent,maxUploadConcurrent:o.maxUploadConcurrent,maxDownloadConcurrent:o.maxDownloadConcurrent,maxWorkerConcurrent:o.maxWorkerConcurrent,maxWebsocketConnect:o.maxWebsocketConnect});break;default:Gi(n,e,r,o)}}})),Foundation.setExportConfig(n)}catch(e){Foundation.setExportConfig(t)}}}function Qi(){void 0===__ddConfig||Bi||(Bi=!0,__ddConfig=Xi(__ddConfig),__ddConfig=Yi(__ddConfig),function(t){if(!zi.length)return t();var e=!1;setTimeout((function(){e||(e=!0,t())}),3e3),Promise.all(zi).catch((function(t){})).then((function(){e||(e=!0,t())})),zi=[]}($i))}function Zi(){Foundation.emitConfigReady(__ddConfig)}Foundation.env.isSubContext&&(Hi="SubContext"),__ddConfig=Xi(__ddConfig),__ddConfig=Yi(__ddConfig),Foundation.onConfigReady((function(){Qi()})),Di?__ddConfig.__readyHandler=Zi:Foundation.onLibraryReady(Zi)}();

var __appServiceSDK__=function(){"use strict";function e(t){return e="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},e(t)}function t(){return t=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},t.apply(this,arguments)}var n=function(){return this}();try{n=globalThis||new Function("return this")()}catch(t){"object"===("undefined"==typeof window?"undefined":e(window))&&(n=window)}var r=n,i="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function o(e,t,n){return e(n={path:t,exports:{},require:function(e,t){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==t&&n.path)}},n.exports),n.exports}var a,s,c=function(e){return e&&e.Math==Math&&e},u=c("object"==typeof globalThis&&globalThis)||c("object"==typeof window&&window)||c("object"==typeof self&&self)||c("object"==typeof i&&i)||function(){return this}()||Function("return this")(),f=function(e){try{return!!e()}catch(e){return!0}},d=!f((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),l=!f((function(){var e=function(){}.bind();return"function"!=typeof e||e.hasOwnProperty("prototype")})),p=Function.prototype.call,h=l?p.bind(p):function(){return p.apply(p,arguments)},y={}.propertyIsEnumerable,v=Object.getOwnPropertyDescriptor,g=v&&!y.call({1:2},1)?function(e){var t=v(this,e);return!!t&&t.enumerable}:y,m={f:g},b=function(e,t){return{enumerable:!(1&e),configurable:!(2&e),writable:!(4&e),value:t}},S=Function.prototype,w=S.bind,_=S.call,T=l&&w.bind(_,_),k=l?function(e){return e&&T(e)}:function(e){return e&&function(){return _.apply(e,arguments)}},M=k({}.toString),N=k("".slice),I=function(e){return N(M(e),8,-1)},O=Object,x=k("".split),P=f((function(){return!O("z").propertyIsEnumerable(0)}))?function(e){return"String"==I(e)?x(e,""):O(e)}:O,L=TypeError,C=function(e){if(null==e)throw L("Can't call method on "+e);return e},E=function(e){return P(C(e))},A=function(e){return"function"==typeof e},j=function(e){return"object"==typeof e?null!==e:A(e)},V=function(e){return A(e)?e:void 0},B=function(e,t){return arguments.length<2?V(u[e]):u[e]&&u[e][t]},R=k({}.isPrototypeOf),F=B("navigator","userAgent")||"",z=u.process,D=u.Deno,W=z&&z.versions||D&&D.version,U=W&&W.v8;U&&(s=(a=U.split("."))[0]>0&&a[0]<4?1:+(a[0]+a[1])),!s&&F&&(!(a=F.match(/Edge\/(\d+)/))||a[1]>=74)&&(a=F.match(/Chrome\/(\d+)/))&&(s=+a[1]);var q=s,J=!!Object.getOwnPropertySymbols&&!f((function(){var e=Symbol();return!String(e)||!(Object(e)instanceof Symbol)||!Symbol.sham&&q&&q<41})),G=J&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,H=Object,$=G?function(e){return"symbol"==typeof e}:function(e){var t=B("Symbol");return A(t)&&R(t.prototype,H(e))},Q=String,K=function(e){try{return Q(e)}catch(e){return"Object"}},X=TypeError,Y=function(e){if(A(e))return e;throw X(K(e)+" is not a function")},Z=function(e,t){var n=e[t];return null==n?void 0:Y(n)},ee=TypeError,te=Object.defineProperty,ne=function(e,t){try{te(u,e,{value:t,configurable:!0,writable:!0})}catch(n){u[e]=t}return t},re="__core-js_shared__",ie=u[re]||ne(re,{}),oe=o((function(e){(e.exports=function(e,t){return ie[e]||(ie[e]=void 0!==t?t:{})})("versions",[]).push({version:"3.24.1",mode:"global",copyright:"© 2014-2022 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.24.1/LICENSE",source:"https://github.com/zloirock/core-js"})})),ae=Object,se=function(e){return ae(C(e))},ce=k({}.hasOwnProperty),ue=Object.hasOwn||function(e,t){return ce(se(e),t)},fe=0,de=Math.random(),le=k(1..toString),pe=function(e){return"Symbol("+(void 0===e?"":e)+")_"+le(++fe+de,36)},he=oe("wks"),ye=u.Symbol,ve=ye&&ye.for,ge=G?ye:ye&&ye.withoutSetter||pe,me=function(e){if(!ue(he,e)||!J&&"string"!=typeof he[e]){var t="Symbol."+e;J&&ue(ye,e)?he[e]=ye[e]:he[e]=G&&ve?ve(t):ge(t)}return he[e]},be=TypeError,Se=me("toPrimitive"),we=function(e,t){if(!j(e)||$(e))return e;var n,r=Z(e,Se);if(r){if(void 0===t&&(t="default"),n=h(r,e,t),!j(n)||$(n))return n;throw be("Can't convert object to primitive value")}return void 0===t&&(t="number"),function(e,t){var n,r;if("string"===t&&A(n=e.toString)&&!j(r=h(n,e)))return r;if(A(n=e.valueOf)&&!j(r=h(n,e)))return r;if("string"!==t&&A(n=e.toString)&&!j(r=h(n,e)))return r;throw ee("Can't convert object to primitive value")}(e,t)},_e=function(e){var t=we(e,"string");return $(t)?t:t+""},Te=u.document,ke=j(Te)&&j(Te.createElement),Me=function(e){return ke?Te.createElement(e):{}},Ne=!d&&!f((function(){return 7!=Object.defineProperty(Me("div"),"a",{get:function(){return 7}}).a})),Ie=Object.getOwnPropertyDescriptor,Oe={f:d?Ie:function(e,t){if(e=E(e),t=_e(t),Ne)try{return Ie(e,t)}catch(e){}if(ue(e,t))return b(!h(m.f,e,t),e[t])}},xe=d&&f((function(){return 42!=Object.defineProperty((function(){}),"prototype",{value:42,writable:!1}).prototype})),Pe=String,Le=TypeError,Ce=function(e){if(j(e))return e;throw Le(Pe(e)+" is not an object")},Ee=TypeError,Ae=Object.defineProperty,je=Object.getOwnPropertyDescriptor,Ve="enumerable",Be="configurable",Re="writable",Fe={f:d?xe?function(e,t,n){if(Ce(e),t=_e(t),Ce(n),"function"==typeof e&&"prototype"===t&&"value"in n&&Re in n&&!n.writable){var r=je(e,t);r&&r.writable&&(e[t]=n.value,n={configurable:Be in n?n.configurable:r.configurable,enumerable:Ve in n?n.enumerable:r.enumerable,writable:!1})}return Ae(e,t,n)}:Ae:function(e,t,n){if(Ce(e),t=_e(t),Ce(n),Ne)try{return Ae(e,t,n)}catch(e){}if("get"in n||"set"in n)throw Ee("Accessors not supported");return"value"in n&&(e[t]=n.value),e}},ze=d?function(e,t,n){return Fe.f(e,t,b(1,n))}:function(e,t,n){return e[t]=n,e},De=Function.prototype,We=d&&Object.getOwnPropertyDescriptor,Ue=ue(De,"name"),qe={EXISTS:Ue,PROPER:Ue&&"something"===function(){}.name,CONFIGURABLE:Ue&&(!d||d&&We(De,"name").configurable)},Je=k(Function.toString);A(ie.inspectSource)||(ie.inspectSource=function(e){return Je(e)});var Ge,He,$e,Qe=ie.inspectSource,Ke=u.WeakMap,Xe=A(Ke)&&/native code/.test(Qe(Ke)),Ye=oe("keys"),Ze=function(e){return Ye[e]||(Ye[e]=pe(e))},et={},tt="Object already initialized",nt=u.TypeError,rt=u.WeakMap;if(Xe||ie.state){var it=ie.state||(ie.state=new rt),ot=k(it.get),at=k(it.has),st=k(it.set);Ge=function(e,t){if(at(it,e))throw new nt(tt);return t.facade=e,st(it,e,t),t},He=function(e){return ot(it,e)||{}},$e=function(e){return at(it,e)}}else{var ct=Ze("state");et[ct]=!0,Ge=function(e,t){if(ue(e,ct))throw new nt(tt);return t.facade=e,ze(e,ct,t),t},He=function(e){return ue(e,ct)?e[ct]:{}},$e=function(e){return ue(e,ct)}}var ut={set:Ge,get:He,has:$e,enforce:function(e){return $e(e)?He(e):Ge(e,{})},getterFor:function(e){return function(t){var n;if(!j(t)||(n=He(t)).type!==e)throw nt("Incompatible receiver, "+e+" required");return n}}},ft=o((function(e){var t=qe.CONFIGURABLE,n=ut.enforce,r=ut.get,i=Object.defineProperty,o=d&&!f((function(){return 8!==i((function(){}),"length",{value:8}).length})),a=String(String).split("String"),s=e.exports=function(e,r,s){"Symbol("===String(r).slice(0,7)&&(r="["+String(r).replace(/^Symbol\(([^)]*)\)/,"$1")+"]"),s&&s.getter&&(r="get "+r),s&&s.setter&&(r="set "+r),(!ue(e,"name")||t&&e.name!==r)&&(d?i(e,"name",{value:r,configurable:!0}):e.name=r),o&&s&&ue(s,"arity")&&e.length!==s.arity&&i(e,"length",{value:s.arity});try{s&&ue(s,"constructor")&&s.constructor?d&&i(e,"prototype",{writable:!1}):e.prototype&&(e.prototype=void 0)}catch(e){}var c=n(e);return ue(c,"source")||(c.source=a.join("string"==typeof r?r:"")),e};Function.prototype.toString=s((function(){return A(this)&&r(this).source||Qe(this)}),"toString")})),dt=function(e,t,n,r){r||(r={});var i=r.enumerable,o=void 0!==r.name?r.name:t;if(A(n)&&ft(n,o,r),r.global)i?e[t]=n:ne(t,n);else{try{r.unsafe?e[t]&&(i=!0):delete e[t]}catch(e){}i?e[t]=n:Fe.f(e,t,{value:n,enumerable:!1,configurable:!r.nonConfigurable,writable:!r.nonWritable})}return e},lt=Math.ceil,pt=Math.floor,ht=Math.trunc||function(e){var t=+e;return(t>0?pt:lt)(t)},yt=function(e){var t=+e;return t!=t||0===t?0:ht(t)},vt=Math.max,gt=Math.min,mt=function(e,t){var n=yt(e);return n<0?vt(n+t,0):gt(n,t)},bt=Math.min,St=function(e){return e>0?bt(yt(e),9007199254740991):0},wt=function(e){return St(e.length)},_t=function(e){return function(t,n,r){var i,o=E(t),a=wt(o),s=mt(r,a);if(e&&n!=n){for(;a>s;)if((i=o[s++])!=i)return!0}else for(;a>s;s++)if((e||s in o)&&o[s]===n)return e||s||0;return!e&&-1}},Tt={includes:_t(!0),indexOf:_t(!1)},kt=Tt.indexOf,Mt=k([].push),Nt=function(e,t){var n,r=E(e),i=0,o=[];for(n in r)!ue(et,n)&&ue(r,n)&&Mt(o,n);for(;t.length>i;)ue(r,n=t[i++])&&(~kt(o,n)||Mt(o,n));return o},It=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],Ot=It.concat("length","prototype"),xt={f:Object.getOwnPropertyNames||function(e){return Nt(e,Ot)}},Pt={f:Object.getOwnPropertySymbols},Lt=k([].concat),Ct=B("Reflect","ownKeys")||function(e){var t=xt.f(Ce(e)),n=Pt.f;return n?Lt(t,n(e)):t},Et=function(e,t,n){for(var r=Ct(t),i=Fe.f,o=Oe.f,a=0;a<r.length;a++){var s=r[a];ue(e,s)||n&&ue(n,s)||i(e,s,o(t,s))}},At=/#|\.prototype\./,jt=function(e,t){var n=Bt[Vt(e)];return n==Ft||n!=Rt&&(A(t)?f(t):!!t)},Vt=jt.normalize=function(e){return String(e).replace(At,".").toLowerCase()},Bt=jt.data={},Rt=jt.NATIVE="N",Ft=jt.POLYFILL="P",zt=jt,Dt=Oe.f,Wt=function(e,t){var n,r,i,o,a,s=e.target,c=e.global,f=e.stat;if(n=c?u:f?u[s]||ne(s,{}):(u[s]||{}).prototype)for(r in t){if(o=t[r],i=e.dontCallGetSet?(a=Dt(n,r))&&a.value:n[r],!zt(c?r:s+(f?".":"#")+r,e.forced)&&void 0!==i){if(typeof o==typeof i)continue;Et(o,i)}(e.sham||i&&i.sham)&&ze(o,"sham",!0),dt(n,r,o,e)}},Ut=function(e,t){var n=[][e];return!!n&&f((function(){n.call(null,t||function(){return 1},1)}))},qt=Tt.indexOf,Jt=k([].indexOf),Gt=!!Jt&&1/Jt([1],1,-0)<0,Ht=Ut("indexOf");Wt({target:"Array",proto:!0,forced:Gt||!Ht},{indexOf:function(e){var t=arguments.length>1?arguments[1]:void 0;return Gt?Jt(this,e,t)||0:qt(this,e,t)}});var $t={};$t[me("toStringTag")]="z";var Qt="[object z]"===String($t),Kt=me("toStringTag"),Xt=Object,Yt="Arguments"==I(function(){return arguments}()),Zt=Qt?I:function(e){var t,n,r;return void 0===e?"Undefined":null===e?"Null":"string"==typeof(n=function(e,t){try{return e[t]}catch(e){}}(t=Xt(e),Kt))?n:Yt?I(t):"Object"==(r=I(t))&&A(t.callee)?"Arguments":r},en=Qt?{}.toString:function(){return"[object "+Zt(this)+"]"};Qt||dt(Object.prototype,"toString",en,{unsafe:!0});var tn="process"==I(u.process),nn=String,rn=TypeError,on=Object.setPrototypeOf||("__proto__"in{}?function(){var e,t=!1,n={};try{(e=k(Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set))(n,[]),t=n instanceof Array}catch(e){}return function(n,r){return Ce(n),function(e){if("object"==typeof e||A(e))return e;throw rn("Can't set "+nn(e)+" as a prototype")}(r),t?e(n,r):n.__proto__=r,n}}():void 0),an=Fe.f,sn=me("toStringTag"),cn=function(e,t,n){e&&!n&&(e=e.prototype),e&&!ue(e,sn)&&an(e,sn,{configurable:!0,value:t})},un=me("species"),fn=function(e){var t=B(e),n=Fe.f;d&&t&&!t[un]&&n(t,un,{configurable:!0,get:function(){return this}})},dn=TypeError,ln=function(e,t){if(R(t,e))return e;throw dn("Incorrect invocation")},pn=function(){},hn=[],yn=B("Reflect","construct"),vn=/^\s*(?:class|function)\b/,gn=k(vn.exec),mn=!vn.exec(pn),bn=function(e){if(!A(e))return!1;try{return yn(pn,hn,e),!0}catch(e){return!1}},Sn=function(e){if(!A(e))return!1;switch(Zt(e)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return mn||!!gn(vn,Qe(e))}catch(e){return!0}};Sn.sham=!0;var wn,_n,Tn,kn,Mn=!yn||f((function(){var e;return bn(bn.call)||!bn(Object)||!bn((function(){e=!0}))||e}))?Sn:bn,Nn=TypeError,In=me("species"),On=function(e,t){var n,r=Ce(e).constructor;return void 0===r||null==(n=Ce(r)[In])?t:function(e){if(Mn(e))return e;throw Nn(K(e)+" is not a constructor")}(n)},xn=Function.prototype,Pn=xn.apply,Ln=xn.call,Cn="object"==typeof Reflect&&Reflect.apply||(l?Ln.bind(Pn):function(){return Ln.apply(Pn,arguments)}),En=k(k.bind),An=function(e,t){return Y(e),void 0===t?e:l?En(e,t):function(){return e.apply(t,arguments)}},jn=B("document","documentElement"),Vn=k([].slice),Bn=TypeError,Rn=function(e,t){if(e<t)throw Bn("Not enough arguments");return e},Fn=/(?:ipad|iphone|ipod).*applewebkit/i.test(F),zn=u.setImmediate,Dn=u.clearImmediate,Wn=u.process,Un=u.Dispatch,qn=u.Function,Jn=u.MessageChannel,Gn=u.String,Hn=0,$n={},Qn="onreadystatechange";try{wn=u.location}catch(e){}var Kn=function(e){if(ue($n,e)){var t=$n[e];delete $n[e],t()}},Xn=function(e){return function(){Kn(e)}},Yn=function(e){Kn(e.data)},Zn=function(e){u.postMessage(Gn(e),wn.protocol+"//"+wn.host)};zn&&Dn||(zn=function(e){Rn(arguments.length,1);var t=A(e)?e:qn(e),n=Vn(arguments,1);return $n[++Hn]=function(){Cn(t,void 0,n)},_n(Hn),Hn},Dn=function(e){delete $n[e]},tn?_n=function(e){Wn.nextTick(Xn(e))}:Un&&Un.now?_n=function(e){Un.now(Xn(e))}:Jn&&!Fn?(kn=(Tn=new Jn).port2,Tn.port1.onmessage=Yn,_n=An(kn.postMessage,kn)):u.addEventListener&&A(u.postMessage)&&!u.importScripts&&wn&&"file:"!==wn.protocol&&!f(Zn)?(_n=Zn,u.addEventListener("message",Yn,!1)):_n=Qn in Me("script")?function(e){jn.appendChild(Me("script")).onreadystatechange=function(){jn.removeChild(this),Kn(e)}}:function(e){setTimeout(Xn(e),0)});var er,tr,nr,rr,ir,or,ar,sr,cr={set:zn,clear:Dn},ur=/ipad|iphone|ipod/i.test(F)&&void 0!==u.Pebble,fr=/web0s(?!.*chrome)/i.test(F),dr=Oe.f,lr=cr.set,pr=u.MutationObserver||u.WebKitMutationObserver,hr=u.document,yr=u.process,vr=u.Promise,gr=dr(u,"queueMicrotask"),mr=gr&&gr.value;mr||(er=function(){var e,t;for(tn&&(e=yr.domain)&&e.exit();tr;){t=tr.fn,tr=tr.next;try{t()}catch(e){throw tr?rr():nr=void 0,e}}nr=void 0,e&&e.enter()},Fn||tn||fr||!pr||!hr?!ur&&vr&&vr.resolve?((ar=vr.resolve(void 0)).constructor=vr,sr=An(ar.then,ar),rr=function(){sr(er)}):tn?rr=function(){yr.nextTick(er)}:(lr=An(lr,u),rr=function(){lr(er)}):(ir=!0,or=hr.createTextNode(""),new pr(er).observe(or,{characterData:!0}),rr=function(){or.data=ir=!ir}));var br=mr||function(e){var t={fn:e,next:void 0};nr&&(nr.next=t),tr||(tr=t,rr()),nr=t},Sr=function(e){try{return{error:!1,value:e()}}catch(e){return{error:!0,value:e}}},wr=function(){this.head=null,this.tail=null};wr.prototype={add:function(e){var t={item:e,next:null};this.head?this.tail.next=t:this.head=t,this.tail=t},get:function(){var e=this.head;if(e)return this.head=e.next,this.tail===e&&(this.tail=null),e.item}};var _r=wr,Tr=u.Promise,kr="object"==typeof Deno&&Deno&&"object"==typeof Deno.version,Mr=!kr&&!tn&&"object"==typeof window&&"object"==typeof document;Tr&&Tr.prototype;var Nr,Ir,Or,xr=me("species"),Pr=!1,Lr=A(u.PromiseRejectionEvent),Cr=zt("Promise",(function(){var e=Qe(Tr),t=e!==String(Tr);if(!t&&66===q)return!0;if(!q||q<51||!/native code/.test(e)){var n=new Tr((function(e){e(1)})),r=function(e){e((function(){}),(function(){}))};if((n.constructor={})[xr]=r,!(Pr=n.then((function(){}))instanceof r))return!0}return!t&&(Mr||kr)&&!Lr})),Er={CONSTRUCTOR:Cr,REJECTION_EVENT:Lr,SUBCLASSING:Pr},Ar=function(e){var t,n;this.promise=new e((function(e,r){if(void 0!==t||void 0!==n)throw TypeError("Bad Promise constructor");t=e,n=r})),this.resolve=Y(t),this.reject=Y(n)},jr={f:function(e){return new Ar(e)}},Vr=cr.set,Br="Promise",Rr=Er.CONSTRUCTOR,Fr=Er.REJECTION_EVENT,zr=Er.SUBCLASSING,Dr=ut.getterFor(Br),Wr=ut.set,Ur=Tr&&Tr.prototype,qr=Tr,Jr=Ur,Gr=u.TypeError,Hr=u.document,$r=u.process,Qr=jr.f,Kr=Qr,Xr=!!(Hr&&Hr.createEvent&&u.dispatchEvent),Yr="unhandledrejection",Zr=function(e){var t;return!(!j(e)||!A(t=e.then))&&t},ei=function(e,t){var n,r,i,o=t.value,a=1==t.state,s=a?e.ok:e.fail,c=e.resolve,u=e.reject,f=e.domain;try{s?(a||(2===t.rejection&&oi(t),t.rejection=1),!0===s?n=o:(f&&f.enter(),n=s(o),f&&(f.exit(),i=!0)),n===e.promise?u(Gr("Promise-chain cycle")):(r=Zr(n))?h(r,n,c,u):c(n)):u(o)}catch(e){f&&!i&&f.exit(),u(e)}},ti=function(e,t){e.notified||(e.notified=!0,br((function(){for(var n,r=e.reactions;n=r.get();)ei(n,e);e.notified=!1,t&&!e.rejection&&ri(e)})))},ni=function(e,t,n){var r,i;Xr?((r=Hr.createEvent("Event")).promise=t,r.reason=n,r.initEvent(e,!1,!0),u.dispatchEvent(r)):r={promise:t,reason:n},!Fr&&(i=u["on"+e])?i(r):e===Yr&&function(e,t){var n=u.console;n&&n.error&&(1==arguments.length?n.error(e):n.error(e,t))}("Unhandled promise rejection",n)},ri=function(e){h(Vr,u,(function(){var t,n=e.facade,r=e.value;if(ii(e)&&(t=Sr((function(){tn?$r.emit("unhandledRejection",r,n):ni(Yr,n,r)})),e.rejection=tn||ii(e)?2:1,t.error))throw t.value}))},ii=function(e){return 1!==e.rejection&&!e.parent},oi=function(e){h(Vr,u,(function(){var t=e.facade;tn?$r.emit("rejectionHandled",t):ni("rejectionhandled",t,e.value)}))},ai=function(e,t,n){return function(r){e(t,r,n)}},si=function(e,t,n){e.done||(e.done=!0,n&&(e=n),e.value=t,e.state=2,ti(e,!0))},ci=function(e,t,n){if(!e.done){e.done=!0,n&&(e=n);try{if(e.facade===t)throw Gr("Promise can't be resolved itself");var r=Zr(t);r?br((function(){var n={done:!1};try{h(r,t,ai(ci,n,e),ai(si,n,e))}catch(t){si(n,t,e)}})):(e.value=t,e.state=1,ti(e,!1))}catch(t){si({done:!1},t,e)}}};if(Rr&&(Jr=(qr=function(e){ln(this,Jr),Y(e),h(Nr,this);var t=Dr(this);try{e(ai(ci,t),ai(si,t))}catch(e){si(t,e)}}).prototype,(Nr=function(e){Wr(this,{type:Br,done:!1,notified:!1,parent:!1,reactions:new _r,rejection:!1,state:0,value:void 0})}).prototype=dt(Jr,"then",(function(e,t){var n=Dr(this),r=Qr(On(this,qr));return n.parent=!0,r.ok=!A(e)||e,r.fail=A(t)&&t,r.domain=tn?$r.domain:void 0,0==n.state?n.reactions.add(r):br((function(){ei(r,n)})),r.promise})),Ir=function(){var e=new Nr,t=Dr(e);this.promise=e,this.resolve=ai(ci,t),this.reject=ai(si,t)},jr.f=Qr=function(e){return e===qr||undefined===e?new Ir(e):Kr(e)},A(Tr)&&Ur!==Object.prototype)){Or=Ur.then,zr||dt(Ur,"then",(function(e,t){var n=this;return new qr((function(e,t){h(Or,n,e,t)})).then(e,t)}),{unsafe:!0});try{delete Ur.constructor}catch(e){}on&&on(Ur,Jr)}Wt({global:!0,constructor:!0,wrap:!0,forced:Rr},{Promise:qr}),cn(qr,Br,!1),fn(Br);var ui={},fi=me("iterator"),di=Array.prototype,li=me("iterator"),pi=function(e){if(null!=e)return Z(e,li)||Z(e,"@@iterator")||ui[Zt(e)]},hi=TypeError,yi=function(e,t,n){var r,i;Ce(e);try{if(!(r=Z(e,"return"))){if("throw"===t)throw n;return n}r=h(r,e)}catch(e){i=!0,r=e}if("throw"===t)throw n;if(i)throw r;return Ce(r),n},vi=TypeError,gi=function(e,t){this.stopped=e,this.result=t},mi=gi.prototype,bi=function(e,t,n){var r,i,o,a,s,c,u,f,d=n&&n.that,l=!(!n||!n.AS_ENTRIES),p=!(!n||!n.IS_RECORD),y=!(!n||!n.IS_ITERATOR),v=!(!n||!n.INTERRUPTED),g=An(t,d),m=function(e){return r&&yi(r,"normal",e),new gi(!0,e)},b=function(e){return l?(Ce(e),v?g(e[0],e[1],m):g(e[0],e[1])):v?g(e,m):g(e)};if(p)r=e.iterator;else if(y)r=e;else{if(!(i=pi(e)))throw vi(K(e)+" is not iterable");if(void 0!==(f=i)&&(ui.Array===f||di[fi]===f)){for(o=0,a=wt(e);a>o;o++)if((s=b(e[o]))&&R(mi,s))return s;return new gi(!1)}r=function(e,t){var n=arguments.length<2?pi(e):t;if(Y(n))return Ce(h(n,e));throw hi(K(e)+" is not iterable")}(e,i)}for(c=p?e.next:r.next;!(u=h(c,r)).done;){try{s=b(u.value)}catch(e){yi(r,"throw",e)}if("object"==typeof s&&s&&R(mi,s))return s}return new gi(!1)},Si=me("iterator"),wi=!1;try{var _i=0,Ti={next:function(){return{done:!!_i++}},return:function(){wi=!0}};Ti[Si]=function(){return this},Array.from(Ti,(function(){throw 2}))}catch(e){}var ki=function(e,t){if(!t&&!wi)return!1;var n=!1;try{var r={};r[Si]=function(){return{next:function(){return{done:n=!0}}}},e(r)}catch(e){}return n},Mi=Er.CONSTRUCTOR||!ki((function(e){Tr.all(e).then(void 0,(function(){}))}));Wt({target:"Promise",stat:!0,forced:Mi},{all:function(e){var t=this,n=jr.f(t),r=n.resolve,i=n.reject,o=Sr((function(){var n=Y(t.resolve),o=[],a=0,s=1;bi(e,(function(e){var c=a++,u=!1;s++,h(n,t,e).then((function(e){u||(u=!0,o[c]=e,--s||r(o))}),i)})),--s||r(o)}));return o.error&&i(o.value),n.promise}});var Ni=Er.CONSTRUCTOR,Ii=Tr&&Tr.prototype;if(Wt({target:"Promise",proto:!0,forced:Ni,real:!0},{catch:function(e){return this.then(void 0,e)}}),A(Tr)){var Oi=B("Promise").prototype.catch;Ii.catch!==Oi&&dt(Ii,"catch",Oi,{unsafe:!0})}Wt({target:"Promise",stat:!0,forced:Mi},{race:function(e){var t=this,n=jr.f(t),r=n.reject,i=Sr((function(){var i=Y(t.resolve);bi(e,(function(e){h(i,t,e).then(n.resolve,r)}))}));return i.error&&r(i.value),n.promise}}),Wt({target:"Promise",stat:!0,forced:Er.CONSTRUCTOR},{reject:function(e){var t=jr.f(this);return h(t.reject,void 0,e),t.promise}});var xi=function(e,t){if(Ce(e),j(t)&&t.constructor===e)return t;var n=jr.f(e);return(0,n.resolve)(t),n.promise},Pi=Er.CONSTRUCTOR;B("Promise"),Wt({target:"Promise",stat:!0,forced:Pi},{resolve:function(e){return xi(this,e)}});var Li=function(){return Li=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e},Li.apply(this,arguments)};function Ci(e,t,n,r){return new(n||(n=Promise))((function(i,o){function a(e){try{c(r.next(e))}catch(e){o(e)}}function s(e){try{c(r.throw(e))}catch(e){o(e)}}function c(e){e.done?i(e.value):function(e){return e instanceof n?e:new n((function(t){t(e)}))}(e.value).then(a,s)}c((r=r.apply(e,t||[])).next())}))}function Ei(e,t){var n,r,i,o,a={label:0,sent:function(){if(1&i[0])throw i[1];return i[1]},trys:[],ops:[]};return o={next:s(0),throw:s(1),return:s(2)},"function"==typeof Symbol&&(o[Symbol.iterator]=function(){return this}),o;function s(o){return function(s){return function(o){if(n)throw new TypeError("Generator is already executing.");for(;a;)try{if(n=1,r&&(i=2&o[0]?r.return:o[0]?r.throw||((i=r.return)&&i.call(r),0):r.next)&&!(i=i.call(r,o[1])).done)return i;switch(r=0,i&&(o=[2&o[0],i.value]),o[0]){case 0:case 1:i=o;break;case 4:return a.label++,{value:o[1],done:!1};case 5:a.label++,r=o[1],o=[0];continue;case 7:o=a.ops.pop(),a.trys.pop();continue;default:if(!(i=a.trys,(i=i.length>0&&i[i.length-1])||6!==o[0]&&2!==o[0])){a=0;continue}if(3===o[0]&&(!i||o[1]>i[0]&&o[1]<i[3])){a.label=o[1];break}if(6===o[0]&&a.label<i[1]){a.label=i[1],i=o;break}if(i&&a.label<i[2]){a.label=i[2],a.ops.push(o);break}i[2]&&a.ops.pop(),a.trys.pop();continue}o=t.call(e,a)}catch(e){o=[6,e],r=0}finally{n=i=0}if(5&o[0])throw o[1];return{value:o[0]?o[1]:void 0,done:!0}}([o,s])}}}var Ai={customShare:{type:"async",event:"customShare",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},image:{type:["String"],ifMustNeed:!1,default:void 0,desc:"分享图片"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},showShareEntrance:{type:"async",event:"showShareEntrance",argsSize:1,agrs0Type:"Object",params:{buttons:{type:["Array"],ifMustNeed:!0,default:"",desc:"转发按钮名称列表"}}},hideShareEntrance:{type:"async",event:"hideShareEntrance",argsSize:0,agrs0Type:"any",params:null},shareWeixinTimeline:{type:"async",event:"shareWeixinTimeline",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"}}},shareWeixinAppmsg:{type:"async",event:"shareWeixinAppmsg",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareQqAppmsg:{type:"async",event:"shareQqAppmsg",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareQzone:{type:"async",event:"shareQzone",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareAlipayFriend:{type:"async",event:"shareAlipayFriend",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareAlipayLife:{type:"async",event:"shareAlipayLife",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareMessage:{type:"async",event:"shareMessage",argsSize:1,agrs0Type:"Object",params:{recipients:{type:["Array"],ifMustNeed:!1,default:[],desc:"收件人号码"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}},shareSinaWeibo:{type:"async",event:"shareSinaWeibo",argsSize:1,agrs0Type:"Object",params:{type:{type:["String"],ifMustNeed:!1,default:"text",desc:"类型"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"图片"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"分享的地址r"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"转发标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"内容"},ext:{type:["Object"],ifMustNeed:!1,default:{},desc:"ext配置"}}}},ji=Li(Li(Li(Li(Li(Li(Li(Li(Li(Li(Li(Li(Li(Li({},{getStorageSync:{type:"sync",event:"getStorageSync",argsSize:1,agrs0Type:"String",needReturn:!0,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"}}},setStorageSync:{type:"sync",event:"setStorageSync",argsSize:2,agrs0Type:"String",needReturn:!1,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"},data:{type:"any",ifMustNeed:!0,default:"",desc:"需要存储的内容"}}},removeStorageSync:{type:"sync",event:"removeStorageSync",argsSize:1,agrs0Type:"String",needReturn:!1,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"}}},removeStorage:{type:"async",event:"removeStorage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"}}},getStorageInfo:{type:"async",event:"getStorageInfo",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},getStorageInfoSync:{type:"sync",event:"getStorageInfoSync",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},setStorage:{type:"async",event:"setStorage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"},data:{type:"any",ifMustNeed:!0,default:"",desc:"需要存储的内容"}}},getStorage:{type:"async",event:"getStorage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{key:{type:["String"],ifMustNeed:!0,default:"",desc:"本地缓存中指定的key"}}},clearStorage:{type:"async",event:"clearStorage",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},setBackgroundFetchToken:{type:"async",event:"setBackgroundFetchToken",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{token:{type:["String"],ifMustNeed:!0,default:"",desc:"传给端上获取预加载数据的token"}}},getBackgroundFetchData:{type:"async",event:"getBackgroundFetchData",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{fetchType:{type:["String"],ifMustNeed:!0,defult:"",desc:"获取端上预加载的数据"}}}}),{getSystemInfo:{type:"async",event:"getSystemInfo",argsSize:0,agrs0Type:"any",params:null,usePromise:!0},getSystemInfoSync:{type:"sync",event:"getSystemInfoSync",argsSize:0,agrs0Type:"any",needReturn:!0,params:null},getAccountInfoSync:{type:"sync",event:"getAccountInfoSync",argsSize:0,agrs0Type:"any",needReturn:!0,params:null},getLaunchOptionsSync:{type:"sync",event:"getLaunchOptionsSync",argsSize:0,agrs0Type:"any",needReturn:!0,params:null},getNetworkType:{type:"async",event:"getNetworkType",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},authorize:{type:"async",event:"authorize",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{scope:{type:["String"],ifMustNeed:!0,default:"",desc:"需要获取权限的 scope"}}},businessAuthorize:{type:"async",event:"businessAuthorize",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{scope:{type:["String"],ifMustNeed:!0,default:"",desc:"需要获取权限的 scope"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"需要获取权限的 title"},icon:{type:["String"],ifMustNeed:!1,default:"",desc:"需要获取权限的 icon 仅支持difile格式"},subTitle:{type:["String"],ifMustNeed:!1,default:"",desc:"需要获取权限的 subTitle"},desc:{type:["String"],ifMustNeed:!1,default:"",desc:"需要获取权限的 desc"},showType:{type:["String"],ifMustNeed:!1,default:"bottom",desc:'需要获取权限的 showType ["bottom","center"]'}}},openSetting:{type:"async",event:"openSetting",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},getSetting:{type:"async",event:"getSetting",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},vibrateShort:{type:"async",event:"vibrateShort",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{type:{type:["String"],ifMustNeed:!0,default:"",desc:"震动强度类型，有效值为：heavy、medium、light"}}},vibrateLong:{type:"async",event:"vibrateLong",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},makePhoneCall:{type:"async",event:"makePhoneCall",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{phoneNumber:{type:["String"],ifMustNeed:!0,default:"",desc:"需要拨打的电话号码"}}},getClipboardData:{type:"async",event:"makePgetClipboardDatahoneCall",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},setClipboardData:{type:"async",event:"setClipboardData",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{data:{type:["String"],ifMustNeed:!0,default:"",desc:"剪贴板的内容"}}},getLocation:{type:"async",event:"getLocation",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{type:{type:["String"],ifMustNeed:!1,default:"wgs84",desc:"wgs84 返回 gps 坐标，gcj02 返回可用于 dd.openLocation 的坐标"},altitude:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"传入 true 会返回高度信息，由于获取高度需要较高精确度，会减慢接口返回速度"},isHighAccuracy:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"开启高精度定位"},highAccuracyExpireTime:{type:["Number"],ifMustNeed:!1,default:3e3,desc:"高精度定位超时时间(ms)，指定时间内返回最高精度，该值3000ms以上高精度定位才有效果"}}},openLocation:{type:"async",event:"openLocation",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{latitude:{type:["Number"],ifMustNeed:!0,default:"",desc:"纬度，范围为-90~90，负数表示南纬。使用 gcj02 国测局坐标系"},longitude:{type:["Number"],ifMustNeed:!0,default:"",desc:"经度，范围为-180~180，负数表示西经。使用 gcj02 国测局坐标系"},scale:{type:["Number"],ifMustNeed:!1,default:18,desc:"缩放比例，范围5~18"},name:{type:["String"],ifMustNeed:!1,default:"",desc:"位置名"},address:{type:["String"],ifMustNeed:!1,default:"",desc:"地址的详细说明"}}},choosePoi:{type:"async",event:"choosePoi",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},chooseLocation:{type:"async",event:"chooseLocation",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{latitude:{type:["Number"],ifMustNeed:!1,default:"",desc:"目标地纬度"},longitude:{type:["Number"],ifMustNeed:!1,default:"",desc:"目标地经度"}}},request:{type:"async",event:"request",agrs0Type:"Object",argsSize:1,params:{url:{type:["String"],ifMustNeed:!0,default:"",desc:"开发者服务器接口地址"},data:{type:["String","Object","ArrayBuffer"],ifMustNeed:!1,default:"",desc:"请求的参数"},header:{type:["Object"],ifMustNeed:!1,default:{"content-type":"application/json"},desc:"设置请求的 header，header 中不能设置 Referer。content-type 默认为 application/json"},timeout:{type:["Number"],ifMustNeed:!1,default:"",desc:"超时时间，单位为毫秒"},method:{type:["String"],ifMustNeed:!1,default:"GET",desc:"HTTP 请求方法"},dataType:{type:["String"],ifMustNeed:!1,default:"json",desc:"返回的数据格式"},responseType:{type:["String"],ifMustNeed:!1,default:"text",desc:"响应的数据类型"}}},startRecord:{type:"async",event:"startRecord",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},stopRecord:{type:"async",event:"stopRecord",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},startWifi:{type:"async",event:"startWifi",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},stopWifi:{type:"async",event:"stopWifi",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},getWifiList:{type:"async",event:"getWifiList",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},getConnectedWifi:{type:"async",event:"getConnectedWifi",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},closeDimina:{type:"async",event:"closeDimina",agrs0Type:"any",argsSize:0,usePromise:!0,params:null},showActionSheet:{type:"async",event:"showActionSheet",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{alertText:{type:["String"],ifMustNeed:!1,default:"",desc:"警示文案"},itemList:{type:["Array"],ifMustNeed:!0,default:"",desc:"按钮的文字数组，数组长度最大为 6"},itemColor:{type:["String"],ifMustNeed:!1,default:"#000000",desc:"按钮的文字颜色"}}},enableAlertBeforeUnload:{type:"async",event:"enableAlertBeforeUnload",agrs0Type:"Object",argsSize:1,params:{message:{type:["String"],ifMustNeed:!0,default:"",desc:"震动强度类型，有效值为：heavy、medium、light"}}},disableAlertBeforeUnload:{type:"async",event:"disableAlertBeforeUnload",agrs0Type:"any",argsSize:0,params:null},onMemoryWarning:{type:"monitor",event:"onMemoryWarning",eventManagerName:"onMemoryWarning",nativeEvent:"onMemoryWarningReceive",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"内存紧张时的回调函数"}}},offMemoryWarning:{type:"offMonitor",event:"offMemoryWarning",eventManagerName:"onMemoryWarning",nativeEvent:"onMemoryWarningReceive",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"内存紧张时的回调函数"}}},onNetworkStatusChange:{type:"monitor",event:"onNetworkStatusChange",eventManagerName:"onNetworkStatusChange",nativeEvent:"onNetworkStatusChange",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"监听网络状态变化事件"}}},offNetworkStatusChange:{type:"offMonitor",event:"offNetworkStatusChange",eventManagerName:"onNetworkStatusChange",nativeEvent:"onNetworkStatusChange",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"监听网络状态变化事件"}}},onGetWifiList:{type:"monitor",event:"onGetWifiList",eventManagerName:"onGetWifiList",nativeEvent:"onGetWifiList",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"获取到 Wi-Fi 列表数据事件的回调函数"}}},offGetWifiList:{type:"offMonitor",event:"offGetWifiList",eventManagerName:"onGetWifiList",nativeEvent:"onGetWifiList",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"获取到 Wi-Fi 列表数据事件的回调函数"}}},onWifiConnected:{type:"monitor",event:"onWifiConnected",eventManagerName:"onWifiConnected",nativeEvent:"onWifiConnected",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"连接上 Wi-Fi 的事件的回调函数"}}},offWifiConnected:{type:"offMonitor",event:"offWifiConnected",eventManagerName:"onWifiConnected",nativeEvent:"onWifiConnected",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"连接上 Wi-Fi 的事件的回调函数"}}},onLoginStatusChanged:{type:"monitor",event:"onLoginStatusChanged",eventManagerName:"notifyLoginStatusChanged",nativeEvent:"notifyLoginStatusChanged",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"登录状态变化时的回调函数"}}},offLoginStatusChanged:{type:"offMonitor",event:"offLoginStatusChanged",eventManagerName:"notifyLoginStatusChanged",nativeEvent:"notifyLoginStatusChanged",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"登录状态变化时的回调函数"}}},onUserCaptureScreen:{type:"monitor",event:"onUserCaptureScreen",eventManagerName:"onUserCaptureScreen",nativeEvent:"onUserCaptureScreen",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"用户主动截屏事件的回调函数"}}},offUserCaptureScreen:{type:"offMonitor",event:"offUserCaptureScreen",eventManagerName:"onUserCaptureScreen",nativeEvent:"onUserCaptureScreen",agrs0Type:"Function",argsSize:1,params:{callBack:{type:"Function",ifMustNeed:!0,default:function(){},desc:"用户主动截屏事件的回调函数"}}},showTabBar:{type:"async",event:"showTabBar",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{animation:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否需要动画效果"}}},hideTabBar:{type:"async",event:"hideTabBar",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{animation:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否需要动画效果"}}}}),{showLoading:{type:"async",event:"showLoading",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{title:{type:["String"],ifMustNeed:!0,default:"",desc:"提示的内容"},mask:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否显示透明蒙层，防止触摸穿透"}}},hideLoading:{type:"async",event:"hideLoading",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},showToast:{type:"async",event:"showToast",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{title:{type:["String"],ifMustNeed:!0,default:"",desc:"提示的内容"},icon:{type:["String"],ifMustNeed:!1,default:"success",desc:"图标"},image:{type:["String"],ifMustNeed:!1,default:"",desc:"自定义图标的本地路径，image 的优先级高于 icon"},duration:{type:["Number"],ifMustNeed:!1,default:1500,desc:"提示的延迟时间"},mask:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否显示透明蒙层，防止触摸穿透"}}},hideToast:{type:"async",event:"hideToast",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},showModal:{type:"async",event:"showModal",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{title:{type:["String"],ifMustNeed:!1,default:"",desc:"提示的标题"},content:{type:["String"],ifMustNeed:!1,default:"",desc:"提示的内容"},showCancel:{type:["Boolean"],ifMustNeed:!1,default:!0,desc:"是否显示取消按钮"},cancelText:{type:["String"],ifMustNeed:!1,default:"取消",desc:"取消按钮的文字，最多 4 个字符"},cancelColor:{type:["String"],ifMustNeed:!1,default:"#000000",desc:"取消按钮的文字颜色，必须是 16 进制格式的颜色字符串"},confirmText:{type:["String"],ifMustNeed:!1,default:"确定",desc:"确认按钮的文字，最多 4 个字符"},confirmColor:{type:["String"],ifMustNeed:!1,default:"#576B95",desc:"确认按钮的文字颜色，必须是 16 进制格式的颜色字符串"}}},setNavigationBarTitle:{type:"async",event:"setNavigationBarTitle",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{title:{type:["String"],ifMustNeed:!0,default:"",desc:"页面标题"}}},setNavigationBarColor:{type:"async",event:"setNavigationBarColor",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{frontColor:{type:["String"],ifMustNeed:!0,default:"",desc:"前景颜色值，包括按钮、标题、状态栏的颜色，仅支持 #ffffff 和 #000000"},backgroundColor:{type:["String"],ifMustNeed:!0,default:"",desc:"背景颜色值，有效值为十六进制颜色"},animation:{type:["Object"],ifMustNeed:!1,default:{},desc:"动画效果"}}},getMenuButtonBoundingClientRect:{type:"sync",event:"getMenuButtonBoundingClientRect",argsSize:0,agrs0Type:"any",needReturn:!0,params:null},setTabBarBadge:{type:"async",event:"setTabBarBadge",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{index:{type:["Number"],ifMustNeed:!0,default:0,desc:"tabBar 的哪一项，从左边算起"},text:{type:["String"],ifMustNeed:!0,default:"",desc:"显示的文本，超过 4 个字符则显示成 ..."}}},showCapsuleButton:{type:"async",event:"showCapsuleButton",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},hideCapsuleButton:{type:"async",event:"hideCapsuleButton",argsSize:0,agrs0Type:"any",usePromise:!0,params:null}}),{getImageInfo:{type:"async",event:"getImageInfo",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{src:{type:["String"],ifMustNeed:!0,default:"",desc:"图片的路径，支持网络路径、本地路径、代码包路径"}}},saveImageToPhotosAlbum:{type:"async",event:"saveImageToPhotosAlbum",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"图片文件路径，可以是临时文件路径或永久文件路径 (本地路径) ，不支持网络路径"}}},chooseImage:{type:"async",event:"chooseImage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{count:{type:["Number"],ifMustNeed:!1,default:9,desc:"最多可以选择的图片张数"},sizeType:{type:["Array"],ifMustNeed:!1,default:["original"],desc:"所选的图片的尺寸"},sourceType:{type:["Array"],ifMustNeed:!1,default:["album"],desc:"选择图片的来源"}}},scanCode:{type:"async",event:"scanCode",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{onlyFromCamera:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否只能从相机扫码，不允许从相册选择图片"},scanType:{type:["Array"],ifMustNeed:!1,default:["barCode","qrCode"],desc:"扫码类型"}}},previewImage:{type:"async",event:"previewImage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{urls:{type:["Array"],ifMustNeed:!0,default:"",desc:"需要预览的图片链接列表"},current:{type:["String"],ifMustNeed:!1,default:"",desc:"当前显示图片的链接"},showmenu:{type:["Boolean"],ifMustNeed:!1,default:!0,desc:"是否显示长按菜单"}}},compressImage:{type:"async",event:"compressImage",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{src:{type:["String"],ifMustNeed:!0,default:"",desc:"图片路径，图片的路径，支持本地路径、代码包路径"},quality:{type:["Number"],ifMustNeed:!1,default:80,desc:"压缩质量，范围0～100，数值越小，质量越低，压缩率越高（仅对jpg有效）。"}}}}),{getSavedFileInfo:{type:"async",event:"getSavedFileInfo",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"文件路径 (本地路径)"}}},getFileInfo:{type:"async",event:"getFileInfo",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"本地文件路径 (本地路径)"},digestAlgorithm:{type:["String"],ifMustNeed:!1,default:"md5",desc:"计算文件摘要的算法"}}},saveFile:{type:"async",event:"saveFile",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{tempFilePath:{type:["String"],ifMustNeed:!0,default:!1,desc:"需要保存的文件的临时路径 (本地路径)"}}},removeSavedFile:{type:"async",event:"removeSavedFile",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"需要删除的文件路径 (本地路径)"}}}}),{startPullDownRefresh:{type:"async",event:"startPullDownRefresh",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},stopPullDownRefresh:{type:"async",event:"stopPullDownRefresh",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},enablePullDownRefresh:{type:"async",event:"enablePullDownRefresh",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},disablePullDownRefresh:{type:"async",event:"disablePullDownRefresh",argsSize:0,agrs0Type:"any",usePromise:!0,params:null}}),Ai),{login:{type:"async",event:"login",argsSize:1,agrs0Type:"Object",params:{needLoginPage:{type:["Boolean"],ifMustNeed:!0,default:!1,desc:"needLoginPage"}}},passportLogin:{type:"async",event:"passportLogin",argsSize:0,agrs0Type:"any",params:null},loginAndShowLegalDialog:{type:"async",event:"loginAndShowLegalDialog",argsSize:1,agrs0Type:"Object",params:{scene:{type:["String"],ifMustNeed:!0,default:!1,desc:"场景值"}}},getLoginLegalInfo:{type:"async",event:"getLoginLegalInfo",argsSize:1,agrs0Type:"Object",params:{scene:{type:["String"],ifMustNeed:!0,default:!1,desc:"场景值"}}},getUserInfo:{type:"async",event:"getUserInfo",argsSize:0,agrs0Type:"any",params:null},logout:{type:"async",event:"logout",argsSize:0,agrs0Type:"any",params:null}}),{openBluetoothAdapter:{type:"async",event:"openBluetoothAdapter",argsSize:0,agrs0Type:"any",params:null,usePromise:!0},getBluetoothAdapterState:{type:"async",event:"getBluetoothAdapterState",argsSize:0,agrs0Type:"any",params:null,usePromise:!0},onBluetoothDeviceFound:{type:"async",event:"onBluetoothDeviceFound",isSustain:!0,argsSize:0,agrs0Type:"any",params:null},startBluetoothDevicesDiscovery:{type:"async",event:"startBluetoothDevicesDiscovery",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{services:{type:["Array"],ifMustNeed:!1,default:"",desc:"要搜索的蓝牙设备主 service 的 uuid 列表"},allowDuplicatesKey:{type:["Boolean"],ifMustNeed:!1,default:!1,desc:"是否允许重复上报同一设备"},interval:{type:["Number"],ifMustNeed:!1,default:0,desc:"上报设备的间隔"}}},onBluetoothAdapterStateChange:{type:"async",event:"onBluetoothAdapterStateChange",isSustain:!0,argsSize:0,agrs0Type:"any",params:null},stopBluetoothDevicesDiscovery:{type:"async",event:"stopBluetoothDevicesDiscovery",argsSize:0,agrs0Type:"any",params:null,usePromise:!0},createBLEConnection:{type:"async",event:"createBLEConnection",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"用于区分设备的 id"},timeout:{type:["Number"],ifMustNeed:!1,default:"",desc:"超时时间，单位ms，不填表示不会超时"}}},onBLEConnectionStateChange:{type:"async",event:"onBLEConnectionStateChange",isSustain:!0,argsSize:0,agrs0Type:"any",params:null},getBLEDeviceServices:{type:"async",event:"getBLEDeviceServices",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备id"}}},getBLEDeviceCharacteristics:{type:"async",event:"getBLEDeviceCharacteristics",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备 id"},serviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙服务 uuid，需要使用 getBLEDeviceServices 获取"}}},notifyBLECharacteristicValueChange:{type:"async",event:"notifyBLECharacteristicValueChange",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备 id"},serviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值对应服务的 uuid"},characteristicId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值的 uuid"},state:{type:["Boolean"],ifMustNeed:!0,default:"",desc:"是否启用 notify"}}},writeBLECharacteristicValue:{type:"async",event:"writeBLECharacteristicValue",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备 id"},serviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值对应服务的 uuid"},characteristicId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值的 uuid"},value:{type:["ArrayBuffer"],ifMustNeed:!0,default:"",desc:"蓝牙设备特征值对应的二进制值"}}},onBLECharacteristicValueChange:{type:"async",event:"onBLECharacteristicValueChange",isSustain:!0,argsSize:0,agrs0Type:"any",params:null},closeBluetoothAdapter:{type:"async",event:"closeBluetoothAdapter",argsSize:0,agrs0Type:"any",usePromise:!0,params:null},closeBLEConnection:{type:"async",event:"closeBLEConnection",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备id"}}},getConnectedBluetoothDevices:{type:"async",event:"getConnectedBluetoothDevices",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{services:{type:["Array"],ifMustNeed:!0,default:"",desc:"蓝牙设备主 service 的 uuid 列表"}}},getBluetoothDevices:{type:"async",event:"getBluetoothDevices",argsSize:0,agrs0Type:"any",params:null,usePromise:!0},readBLECharacteristicValue:{type:"async",event:"readBLECharacteristicValue",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{deviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙设备 id"},serviceId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值对应服务的 uuid"},characteristicId:{type:["String"],ifMustNeed:!0,default:"",desc:"蓝牙特征值的 uuid"}}}}),{hideKeyboard:{type:"async",event:"hideKeyboard",argsSize:0,agrs0Type:"any",usePromise:!0,params:null}}),{setScreenBrightness:{type:"async",event:"setScreenBrightness",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{value:{type:["Number"],ifMustNeed:!0,default:"",desc:"屏幕亮度值，范围 0 ~ 1。0 最暗，1 最亮"}}},setKeepScreenOn:{type:"async",event:"setKeepScreenOn",argsSize:1,agrs0Type:"Object",usePromise:!0,params:{keepScreenOn:{type:["Boolean"],ifMustNeed:!0,default:"",desc:"是否保持屏幕常亮"}}},getScreenBrightness:{type:"async",event:"getScreenBrightness",argsSize:0,agrs0Type:"any",usePromise:!0,params:null}}),{chooseContact:{type:"async",event:"chooseContact",agrs0Type:"any",argsSize:0,params:null},addPhoneContact:{type:"async",event:"addPhoneContact",agrs0Type:"Object",argsSize:1,usePromise:!0,params:{firstName:{type:["String"],ifMustNeed:!0,default:"",desc:"名字"},photoFilePath:{type:["String"],ifMustNeed:!1,default:"",desc:"头像本地文件路径"},nickName:{type:["String"],ifMustNeed:!1,default:"",desc:"昵称"},lastName:{type:["String"],ifMustNeed:!1,default:"",desc:"姓氏"},middleName:{type:["String"],ifMustNeed:!1,default:"",desc:"中间名"},remark:{type:["String"],ifMustNeed:!1,default:"",desc:"备注"},mobilePhoneNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"手机号"},weChatNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"微信号"},addressCountry:{type:["String"],ifMustNeed:!1,default:"",desc:"联系地址国家"},addressState:{type:["String"],ifMustNeed:!1,default:"",desc:"联系地址省份"},addressCity:{type:["String"],ifMustNeed:!1,default:"",desc:"联系地址城市"},addressStreet:{type:["String"],ifMustNeed:!1,default:"",desc:"联系地址街道"},addressPostalCode:{type:["String"],ifMustNeed:!1,default:"",desc:"联系地址邮政编码"},organization:{type:["String"],ifMustNeed:!1,default:"",desc:"公司"},title:{type:["String"],ifMustNeed:!1,default:"",desc:"职位"},workFaxNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"工作传真"},workPhoneNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"工作电话"},hostNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"公司电话"},email:{type:["String"],ifMustNeed:!1,default:"",desc:"电子邮件"},url:{type:["String"],ifMustNeed:!1,default:"",desc:"网站"},workAddressCountry:{type:["String"],ifMustNeed:!1,default:"",desc:"工作地址国家"},workAddressState:{type:["String"],ifMustNeed:!1,default:"",desc:"工作地址省份"},workAddressCity:{type:["String"],ifMustNeed:!1,default:"",desc:"工作地址城市"},workAddressStreet:{type:["String"],ifMustNeed:!1,default:"",desc:"工作地址街道"},workAddressPostalCode:{type:["String"],ifMustNeed:!1,default:"",desc:"工作地址邮政编码"},homeFaxNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅传真"},homePhoneNumber:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅电话"},homeAddressCountry:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅地址国家"},homeAddressState:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅地址省份"},homeAddressCity:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅地址城市"},homeAddressStreet:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅地址街道"},homeAddressPostalCode:{type:["String"],ifMustNeed:!1,default:"",desc:"住宅地址邮政编码"}}}}),{chooseVideo:{type:"async",event:"chooseVideo",agrs0Type:"Object",argsSize:1,params:{compressed:{type:["Boolean"],ifMustNeed:!1,default:!0,desc:"是否压缩所选择的视频文件"},maxDuration:{type:["Number"],ifMustNeed:!1,default:60,desc:"拍摄视频最长拍摄时间，单位秒"},camera:{type:["String"],ifMustNeed:!1,default:"back",desc:"默认拉起的是前置或者后置摄像头。部分 Android 手机下由于系统 ROM 不支持无法生效"},sourceType:{type:["Array"],ifMustNeed:!1,default:[],desc:"视频选择的来源"}}},getVideoInfo:{type:"async",event:"getVideoInfo",agrs0Type:"any",argsSize:1,params:{src:{type:["String"],ifMustNeed:!0,default:"",desc:"视频文件路径，可以是临时文件路径也可以是永久文件路径"}}},saveVideoToPhotosAlbum:{type:"async",event:"saveVideoToPhotosAlbum",agrs0Type:"Object",argsSize:1,params:{filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"视频文件路径，可以是临时文件路径也可以是永久文件路径 (本地路径)"}}},chooseMedia:{type:"async",event:"chooseMedia",agrs0Type:"Object",argsSize:1,params:{count:{type:["Number"],ifMustNeed:!1,default:9,desc:"最多可以选择的文件个数"},mediaType:{type:["Array"],ifMustNeed:!1,default:[],desc:"文件类型"},sourceType:{type:["Array"],ifMustNeed:!1,default:[],desc:"图片和视频选择的来源"},sizeType:{type:["Array"],ifMustNeed:!1,default:[],desc:"仅对mediaType为 image 时有效，是否压缩所选文件"},maxDuration:{type:["Number"],ifMustNeed:!1,default:10,desc:"拍摄视频最长拍摄时间，单位秒。时间范围为 3s 至 60s 之间。不限制相册。"},camera:{type:["String"],ifMustNeed:!1,default:"back",desc:"默认拉起的是前置或者后置摄像头。部分 Android 手机下由于系统 ROM 不支持无法生效"}}},compressVideo:{type:"async",event:"compressVideo",agrs0Type:"Object",argsSize:1,params:{src:{type:["String"],ifMustNeed:!0,default:"",desc:"视频文件路径，可以是临时文件路径也可以是永久文件路径"},quality:{type:["String"],ifMustNeed:!0,default:"",desc:"压缩质量"},bitrate:{type:["Number"],ifMustNeed:!0,default:0,desc:"码率，单位 kbps"},fps:{type:["Number"],ifMustNeed:!0,default:0,desc:"帧率"},resolution:{type:["Number"],ifMustNeed:!0,default:0,desc:"相对于原视频的分辨率比例，取值范围(0, 1]"}}}}),{registerLocalNotify:{type:"async",event:"registerLocalNotify",argsSize:1,agrs0Type:"Object",needReturn:!1,params:{notifyid:{type:["String"],ifMustNeed:!0,default:"",desc:"notifyid"},title:{type:["String"],ifMustNeed:!0,default:"",desc:"标题"},subtitle:{type:["String"],ifMustNeed:!1,default:"",desc:"副标题"},body:{type:["String"],ifMustNeed:!1,default:"",desc:"body"},badge:{type:["Number"],ifMustNeed:!1,default:"",desc:"badge"},year:{type:["Number"],ifMustNeed:!1,default:"",desc:"year"},month:{type:["Number"],ifMustNeed:!1,default:"",desc:"month"},day:{type:["Number"],ifMustNeed:!1,default:"",desc:"day"},hour:{type:["Number"],ifMustNeed:!1,default:"",desc:"hour"},minute:{type:["Number"],ifMustNeed:!1,default:"",desc:"minute"},second:{type:["Number"],ifMustNeed:!1,default:"",desc:"second"},repeats:{type:["Boolean"],ifMustNeed:!1,default:"",desc:"second"},attachmenturl:{type:["String"],ifMustNeed:!1,default:"",desc:"attachmenturl"}}},checkLocalNotify:{type:"async",event:"checkLocalNotify",argsSize:1,agrs0Type:"Object",needReturn:!1,params:null},removeLocalNotify:{type:"async",event:"removeLocalNotify",argsSize:1,agrs0Type:"Object",needReturn:!1,params:{notifyid:{type:["String"],ifMustNeed:!0,default:"",desc:"notifyid"}}}}),Vi=Array.isArray||function(e){return"Array"==I(e)},Bi=function(e,t,n){var r=_e(t);r in e?Fe.f(e,r,b(0,n)):e[r]=n},Ri=me("species"),Fi=function(e){return q>=51||!f((function(){var t=[];return(t.constructor={})[Ri]=function(){return{foo:1}},1!==t[e](Boolean).foo}))},zi=Fi("slice"),Di=me("species"),Wi=Array,Ui=Math.max;Wt({target:"Array",proto:!0,forced:!zi},{slice:function(e,t){var n,r,i,o=E(this),a=wt(o),s=mt(e,a),c=mt(void 0===t?a:t,a);if(Vi(o)&&(n=o.constructor,(Mn(n)&&(n===Wi||Vi(n.prototype))||j(n)&&null===(n=n[Di]))&&(n=void 0),n===Wi||void 0===n))return Vn(o,s,c);for(r=new(void 0===n?Wi:n)(Ui(c-s,0)),i=0;s<c;s++,i++)s in o&&Bi(r,i,o[s]);return r.length=i,r}});var qi=function(e,t,n){var r,i;return on&&A(r=t.constructor)&&r!==n&&j(i=r.prototype)&&i!==n.prototype&&on(e,i),e},Ji=k(1..valueOf),Gi=String,Hi=function(e){if("Symbol"===Zt(e))throw TypeError("Cannot convert a Symbol value to a string");return Gi(e)},$i="\t\n\v\f\r                　\u2028\u2029\ufeff",Qi=k("".replace),Ki="["+$i+"]",Xi=RegExp("^"+Ki+Ki+"*"),Yi=RegExp(Ki+Ki+"*$"),Zi=function(e){return function(t){var n=Hi(C(t));return 1&e&&(n=Qi(n,Xi,"")),2&e&&(n=Qi(n,Yi,"")),n}},eo={start:Zi(1),end:Zi(2),trim:Zi(3)},to=xt.f,no=Oe.f,ro=Fe.f,io=eo.trim,oo="Number",ao=u.Number,so=ao.prototype,co=u.TypeError,uo=k("".slice),fo=k("".charCodeAt),lo=function(e){var t=we(e,"number");return"bigint"==typeof t?t:po(t)},po=function(e){var t,n,r,i,o,a,s,c,u=we(e,"number");if($(u))throw co("Cannot convert a Symbol value to a number");if("string"==typeof u&&u.length>2)if(u=io(u),43===(t=fo(u,0))||45===t){if(88===(n=fo(u,2))||120===n)return NaN}else if(48===t){switch(fo(u,1)){case 66:case 98:r=2,i=49;break;case 79:case 111:r=8,i=55;break;default:return+u}for(a=(o=uo(u,2)).length,s=0;s<a;s++)if((c=fo(o,s))<48||c>i)return NaN;return parseInt(o,r)}return+u};if(zt(oo,!ao(" 0o1")||!ao("0b1")||ao("+0x1"))){for(var ho,yo=function(e){var t=arguments.length<1?0:ao(lo(e)),n=this;return R(so,n)&&f((function(){Ji(n)}))?qi(Object(t),n,yo):t},vo=d?to(ao):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,isFinite,isInteger,isNaN,isSafeInteger,parseFloat,parseInt,fromString,range".split(","),go=0;vo.length>go;go++)ue(ao,ho=vo[go])&&!ue(yo,ho)&&ro(yo,ho,no(ao,ho));yo.prototype=so,so.constructor=yo,dt(u,oo,yo,{constructor:!0})}var mo="undefined"!=typeof ArrayBuffer&&"undefined"!=typeof DataView,bo=function(e,t,n){for(var r in t)dt(e,r,t[r],n);return e},So=RangeError,wo=function(e){if(void 0===e)return 0;var t=yt(e),n=St(t);if(t!==n)throw So("Wrong length or index");return n},_o=Array,To=Math.abs,ko=Math.pow,Mo=Math.floor,No=Math.log,Io=Math.LN2,Oo=function(e,t,n){var r,i,o,a=_o(n),s=8*n-t-1,c=(1<<s)-1,u=c>>1,f=23===t?ko(2,-24)-ko(2,-77):0,d=e<0||0===e&&1/e<0?1:0,l=0;for((e=To(e))!=e||e===1/0?(i=e!=e?1:0,r=c):(r=Mo(No(e)/Io),e*(o=ko(2,-r))<1&&(r--,o*=2),(e+=r+u>=1?f/o:f*ko(2,1-u))*o>=2&&(r++,o/=2),r+u>=c?(i=0,r=c):r+u>=1?(i=(e*o-1)*ko(2,t),r+=u):(i=e*ko(2,u-1)*ko(2,t),r=0));t>=8;)a[l++]=255&i,i/=256,t-=8;for(r=r<<t|i,s+=t;s>0;)a[l++]=255&r,r/=256,s-=8;return a[--l]|=128*d,a},xo=function(e,t){var n,r=e.length,i=8*r-t-1,o=(1<<i)-1,a=o>>1,s=i-7,c=r-1,u=e[c--],f=127&u;for(u>>=7;s>0;)f=256*f+e[c--],s-=8;for(n=f&(1<<-s)-1,f>>=-s,s+=t;s>0;)n=256*n+e[c--],s-=8;if(0===f)f=1-a;else{if(f===o)return n?NaN:u?-1/0:1/0;n+=ko(2,t),f-=a}return(u?-1:1)*n*ko(2,f-t)},Po=!f((function(){function e(){}return e.prototype.constructor=null,Object.getPrototypeOf(new e)!==e.prototype})),Lo=Ze("IE_PROTO"),Co=Object,Eo=Co.prototype,Ao=Po?Co.getPrototypeOf:function(e){var t=se(e);if(ue(t,Lo))return t[Lo];var n=t.constructor;return A(n)&&t instanceof n?n.prototype:t instanceof Co?Eo:null},jo=Array,Vo=Math.max,Bo=function(e,t,n){for(var r=wt(e),i=mt(t,r),o=mt(void 0===n?r:n,r),a=jo(Vo(o-i,0)),s=0;i<o;i++,s++)Bi(a,s,e[i]);return a.length=s,a},Ro=xt.f,Fo=Fe.f,zo=qe.PROPER,Do=qe.CONFIGURABLE,Wo=ut.get,Uo=ut.set,qo="ArrayBuffer",Jo="DataView",Go="Wrong index",Ho=u.ArrayBuffer,$o=Ho,Qo=$o&&$o.prototype,Ko=u.DataView,Xo=Ko&&Ko.prototype,Yo=Object.prototype,Zo=u.Array,ea=u.RangeError,ta=k((function(e){for(var t=se(this),n=wt(t),r=arguments.length,i=mt(r>1?arguments[1]:void 0,n),o=r>2?arguments[2]:void 0,a=void 0===o?n:mt(o,n);a>i;)t[i++]=e;return t})),na=k([].reverse),ra=Oo,ia=xo,oa=function(e){return[255&e]},aa=function(e){return[255&e,e>>8&255]},sa=function(e){return[255&e,e>>8&255,e>>16&255,e>>24&255]},ca=function(e){return e[3]<<24|e[2]<<16|e[1]<<8|e[0]},ua=function(e){return ra(e,23,4)},fa=function(e){return ra(e,52,8)},da=function(e,t){Fo(e.prototype,t,{get:function(){return Wo(this)[t]}})},la=function(e,t,n,r){var i=wo(n),o=Wo(e);if(i+t>o.byteLength)throw ea(Go);var a=Wo(o.buffer).bytes,s=i+o.byteOffset,c=Bo(a,s,s+t);return r?c:na(c)},pa=function(e,t,n,r,i,o){var a=wo(n),s=Wo(e);if(a+t>s.byteLength)throw ea(Go);for(var c=Wo(s.buffer).bytes,u=a+s.byteOffset,f=r(+i),d=0;d<t;d++)c[u+d]=f[o?d:t-d-1]};if(mo){var ha=zo&&Ho.name!==qo;if(f((function(){Ho(1)}))&&f((function(){new Ho(-1)}))&&!f((function(){return new Ho,new Ho(1.5),new Ho(NaN),ha&&!Do})))ha&&Do&&ze(Ho,"name",qo);else{($o=function(e){return ln(this,Qo),new Ho(wo(e))}).prototype=Qo;for(var ya,va=Ro(Ho),ga=0;va.length>ga;)(ya=va[ga++])in $o||ze($o,ya,Ho[ya]);Qo.constructor=$o}on&&Ao(Xo)!==Yo&&on(Xo,Yo);var ma=new Ko(new $o(2)),ba=k(Xo.setInt8);ma.setInt8(0,2147483648),ma.setInt8(1,2147483649),!ma.getInt8(0)&&ma.getInt8(1)||bo(Xo,{setInt8:function(e,t){ba(this,e,t<<24>>24)},setUint8:function(e,t){ba(this,e,t<<24>>24)}},{unsafe:!0})}else Qo=($o=function(e){ln(this,Qo);var t=wo(e);Uo(this,{bytes:ta(Zo(t),0),byteLength:t}),d||(this.byteLength=t)}).prototype,Xo=(Ko=function(e,t,n){ln(this,Xo),ln(e,Qo);var r=Wo(e).byteLength,i=yt(t);if(i<0||i>r)throw ea("Wrong offset");if(i+(n=void 0===n?r-i:St(n))>r)throw ea("Wrong length");Uo(this,{buffer:e,byteLength:n,byteOffset:i}),d||(this.buffer=e,this.byteLength=n,this.byteOffset=i)}).prototype,d&&(da($o,"byteLength"),da(Ko,"buffer"),da(Ko,"byteLength"),da(Ko,"byteOffset")),bo(Xo,{getInt8:function(e){return la(this,1,e)[0]<<24>>24},getUint8:function(e){return la(this,1,e)[0]},getInt16:function(e){var t=la(this,2,e,arguments.length>1?arguments[1]:void 0);return(t[1]<<8|t[0])<<16>>16},getUint16:function(e){var t=la(this,2,e,arguments.length>1?arguments[1]:void 0);return t[1]<<8|t[0]},getInt32:function(e){return ca(la(this,4,e,arguments.length>1?arguments[1]:void 0))},getUint32:function(e){return ca(la(this,4,e,arguments.length>1?arguments[1]:void 0))>>>0},getFloat32:function(e){return ia(la(this,4,e,arguments.length>1?arguments[1]:void 0),23)},getFloat64:function(e){return ia(la(this,8,e,arguments.length>1?arguments[1]:void 0),52)},setInt8:function(e,t){pa(this,1,e,oa,t)},setUint8:function(e,t){pa(this,1,e,oa,t)},setInt16:function(e,t){pa(this,2,e,aa,t,arguments.length>2?arguments[2]:void 0)},setUint16:function(e,t){pa(this,2,e,aa,t,arguments.length>2?arguments[2]:void 0)},setInt32:function(e,t){pa(this,4,e,sa,t,arguments.length>2?arguments[2]:void 0)},setUint32:function(e,t){pa(this,4,e,sa,t,arguments.length>2?arguments[2]:void 0)},setFloat32:function(e,t){pa(this,4,e,ua,t,arguments.length>2?arguments[2]:void 0)},setFloat64:function(e,t){pa(this,8,e,fa,t,arguments.length>2?arguments[2]:void 0)}});cn($o,qo),cn(Ko,Jo);var Sa={ArrayBuffer:$o,DataView:Ko},wa="ArrayBuffer",_a=Sa.ArrayBuffer,Ta=u.ArrayBuffer;Wt({global:!0,constructor:!0,forced:Ta!==_a},{ArrayBuffer:_a}),fn(wa);var ka=Sa.ArrayBuffer,Ma=Sa.DataView,Na=Ma.prototype,Ia=k(ka.prototype.slice),Oa=k(Na.getUint8),xa=k(Na.setUint8),Pa=f((function(){return!new ka(2).slice(1,void 0).byteLength}));Wt({target:"ArrayBuffer",proto:!0,unsafe:!0,forced:Pa},{slice:function(e,t){if(Ia&&void 0===t)return Ia(Ce(this),e);for(var n=Ce(this).byteLength,r=mt(e,n),i=mt(void 0===t?n:t,n),o=new(On(this,ka))(St(i-r)),a=new Ma(this),s=new Ma(o),c=0;r<i;)xa(s,c++,Oa(a,r++));return o}});var La={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0},Ca=Me("span").classList,Ea=Ca&&Ca.constructor&&Ca.constructor.prototype,Aa=Ea===Object.prototype?void 0:Ea,ja=me("species"),Va=Array,Ba=function(e,t){return new(function(e){var t;return Vi(e)&&(t=e.constructor,(Mn(t)&&(t===Va||Vi(t.prototype))||j(t)&&null===(t=t[ja]))&&(t=void 0)),void 0===t?Va:t}(e))(0===t?0:t)},Ra=k([].push),Fa=function(e){var t=1==e,n=2==e,r=3==e,i=4==e,o=6==e,a=7==e,s=5==e||o;return function(c,u,f,d){for(var l,p,h=se(c),y=P(h),v=An(u,f),g=wt(y),m=0,b=d||Ba,S=t?b(c,g):n||a?b(c,0):void 0;g>m;m++)if((s||m in y)&&(p=v(l=y[m],m,h),e))if(t)S[m]=p;else if(p)switch(e){case 3:return!0;case 5:return l;case 6:return m;case 2:Ra(S,l)}else switch(e){case 4:return!1;case 7:Ra(S,l)}return o?-1:r||i?i:S}},za={forEach:Fa(0),map:Fa(1),filter:Fa(2),some:Fa(3),every:Fa(4),find:Fa(5),findIndex:Fa(6),filterReject:Fa(7)},Da=za.forEach,Wa=Ut("forEach")?[].forEach:function(e){return Da(this,e,arguments.length>1?arguments[1]:void 0)},Ua=function(e){if(e&&e.forEach!==Wa)try{ze(e,"forEach",Wa)}catch(t){e.forEach=Wa}};for(var qa in La)La[qa]&&Ua(u[qa]&&u[qa].prototype);Ua(Aa);var Ja=Object.keys||function(e){return Nt(e,It)},Ga=f((function(){Ja(1)}));Wt({target:"Object",stat:!0,forced:Ga},{keys:function(e){return Ja(se(e))}});var Ha=Object.prototype.toString;function $a(e){return Ha.call(e).slice(8,-1)}function Qa(e){return"Number"===$a(e)}function Ka(e){return"Object"===$a(e)}function Xa(e){return"function"==typeof e}function Ya(e,t){var n=e.params,r=$a(t[0]),i=e.argsSize,o=(e.agrs0Type,e.event,{});if(i>1||1===i&&"Object"!==r)for(var a=Object.keys(n),s=0;s<i;s++)o[a[s]]=t[s];else 1===i&&"Object"===r&&(o=t[0]);return e.params&&Object.keys(n).forEach((function(e){n[e].ifMustNeed;var t=$a(o[e]);e in o&&"any"!==n[e].type&&n[e].type.indexOf(t)})),o}function Za(e,t){var n={};return e&&Object.keys(e).forEach((function(r){"boolean"==typeof t[r]?n[r]=t[r]:n[r]=t[r]||e[r].default})),n}var es,ts=d&&!xe?Object.defineProperties:function(e,t){Ce(e);for(var n,r=E(t),i=Ja(t),o=i.length,a=0;o>a;)Fe.f(e,n=i[a++],r[n]);return e},ns={f:ts},rs=Ze("IE_PROTO"),is=function(){},os=function(e){return"<script>"+e+"</"+"script>"},as=function(e){e.write(os("")),e.close();var t=e.parentWindow.Object;return e=null,t},ss=function(){try{es=new ActiveXObject("htmlfile")}catch(e){}var e,t;ss="undefined"!=typeof document?document.domain&&es?as(es):((t=Me("iframe")).style.display="none",jn.appendChild(t),t.src=String("javascript:"),(e=t.contentWindow.document).open(),e.write(os("document.F=Object")),e.close(),e.F):as(es);for(var n=It.length;n--;)delete ss.prototype[It[n]];return ss()};et[rs]=!0;var cs=Object.create||function(e,t){var n;return null!==e?(is.prototype=Ce(e),n=new is,is.prototype=null,n[rs]=e):n=ss(),void 0===t?n:ns.f(n,t)},us=Fe.f,fs=me("unscopables"),ds=Array.prototype;null==ds[fs]&&us(ds,fs,{configurable:!0,value:cs(null)});var ls,ps,hs,ys=function(e){ds[fs][e]=!0},vs=me("iterator"),gs=!1;[].keys&&("next"in(hs=[].keys())?(ps=Ao(Ao(hs)))!==Object.prototype&&(ls=ps):gs=!0);var ms=null==ls||f((function(){var e={};return ls[vs].call(e)!==e}));ms&&(ls={}),A(ls[vs])||dt(ls,vs,(function(){return this}));var bs={IteratorPrototype:ls,BUGGY_SAFARI_ITERATORS:gs},Ss=bs.IteratorPrototype,ws=function(){return this},_s=qe.PROPER,Ts=qe.CONFIGURABLE,ks=bs.IteratorPrototype,Ms=bs.BUGGY_SAFARI_ITERATORS,Ns=me("iterator"),Is="keys",Os="values",xs="entries",Ps=function(){return this},Ls=function(e,t,n,r,i,o,a){!function(e,t,n,r){var i=t+" Iterator";e.prototype=cs(Ss,{next:b(+!r,n)}),cn(e,i,!1),ui[i]=ws}(n,t,r);var s,c,u,f=function(e){if(e===i&&v)return v;if(!Ms&&e in p)return p[e];switch(e){case Is:case Os:case xs:return function(){return new n(this,e)}}return function(){return new n(this)}},d=t+" Iterator",l=!1,p=e.prototype,y=p[Ns]||p["@@iterator"]||i&&p[i],v=!Ms&&y||f(i),g="Array"==t&&p.entries||y;if(g&&(s=Ao(g.call(new e)))!==Object.prototype&&s.next&&(Ao(s)!==ks&&(on?on(s,ks):A(s[Ns])||dt(s,Ns,Ps)),cn(s,d,!0)),_s&&i==Os&&y&&y.name!==Os&&(Ts?ze(p,"name",Os):(l=!0,v=function(){return h(y,this)})),i)if(c={values:f(Os),keys:o?v:f(Is),entries:f(xs)},a)for(u in c)(Ms||l||!(u in p))&&dt(p,u,c[u]);else Wt({target:t,proto:!0,forced:Ms||l},c);return p[Ns]!==v&&dt(p,Ns,v,{name:i}),ui[t]=v,c},Cs=Fe.f,Es="Array Iterator",As=ut.set,js=ut.getterFor(Es),Vs=Ls(Array,"Array",(function(e,t){As(this,{type:Es,target:E(e),index:0,kind:t})}),(function(){var e=js(this),t=e.target,n=e.kind,r=e.index++;return!t||r>=t.length?(e.target=void 0,{value:void 0,done:!0}):"keys"==n?{value:r,done:!1}:"values"==n?{value:t[r],done:!1}:{value:[r,t[r]],done:!1}}),"values"),Bs=ui.Arguments=ui.Array;if(ys("keys"),ys("values"),ys("entries"),d&&"values"!==Bs.name)try{Cs(Bs,"name",{value:"values"})}catch(e){}var Rs=k("".charAt),Fs=k("".charCodeAt),zs=k("".slice),Ds=function(e){return function(t,n){var r,i,o=Hi(C(t)),a=yt(n),s=o.length;return a<0||a>=s?e?"":void 0:(r=Fs(o,a))<55296||r>56319||a+1===s||(i=Fs(o,a+1))<56320||i>57343?e?Rs(o,a):r:e?zs(o,a,a+2):i-56320+(r-55296<<10)+65536}},Ws={codeAt:Ds(!1),charAt:Ds(!0)},Us=Ws.charAt,qs="String Iterator",Js=ut.set,Gs=ut.getterFor(qs);Ls(String,"String",(function(e){Js(this,{type:qs,string:Hi(e),index:0})}),(function(){var e,t=Gs(this),n=t.string,r=t.index;return r>=n.length?{value:void 0,done:!0}:(e=Us(n,r),t.index+=e.length,{value:e,done:!1})}));var Hs=xt.f,$s="object"==typeof window&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[],Qs={f:function(e){return $s&&"Window"==I(e)?function(e){try{return Hs(e)}catch(e){return Bo($s)}}(e):Hs(E(e))}},Ks=f((function(){if("function"==typeof ArrayBuffer){var e=new ArrayBuffer(8);Object.isExtensible(e)&&Object.defineProperty(e,"a",{value:8})}})),Xs=Object.isExtensible,Ys=f((function(){Xs(1)}))||Ks?function(e){return!!j(e)&&((!Ks||"ArrayBuffer"!=I(e))&&(!Xs||Xs(e)))}:Xs,Zs=!f((function(){return Object.isExtensible(Object.preventExtensions({}))})),ec=o((function(e){var t=Fe.f,n=!1,r=pe("meta"),i=0,o=function(e){t(e,r,{value:{objectID:"O"+i++,weakData:{}}})},a=e.exports={enable:function(){a.enable=function(){},n=!0;var e=xt.f,t=k([].splice),i={};i[r]=1,e(i).length&&(xt.f=function(n){for(var i=e(n),o=0,a=i.length;o<a;o++)if(i[o]===r){t(i,o,1);break}return i},Wt({target:"Object",stat:!0,forced:!0},{getOwnPropertyNames:Qs.f}))},fastKey:function(e,t){if(!j(e))return"symbol"==typeof e?e:("string"==typeof e?"S":"P")+e;if(!ue(e,r)){if(!Ys(e))return"F";if(!t)return"E";o(e)}return e[r].objectID},getWeakData:function(e,t){if(!ue(e,r)){if(!Ys(e))return!0;if(!t)return!1;o(e)}return e[r].weakData},onFreeze:function(e){return Zs&&n&&Ys(e)&&!ue(e,r)&&o(e),e}};et[r]=!0})),tc=function(e,t,n){var r=-1!==e.indexOf("Map"),i=-1!==e.indexOf("Weak"),o=r?"set":"add",a=u[e],s=a&&a.prototype,c=a,d={},l=function(e){var t=k(s[e]);dt(s,e,"add"==e?function(e){return t(this,0===e?0:e),this}:"delete"==e?function(e){return!(i&&!j(e))&&t(this,0===e?0:e)}:"get"==e?function(e){return i&&!j(e)?void 0:t(this,0===e?0:e)}:"has"==e?function(e){return!(i&&!j(e))&&t(this,0===e?0:e)}:function(e,n){return t(this,0===e?0:e,n),this})};if(zt(e,!A(a)||!(i||s.forEach&&!f((function(){(new a).entries().next()})))))c=n.getConstructor(t,e,r,o),ec.enable();else if(zt(e,!0)){var p=new c,h=p[o](i?{}:-0,1)!=p,y=f((function(){p.has(1)})),v=ki((function(e){new a(e)})),g=!i&&f((function(){for(var e=new a,t=5;t--;)e[o](t,t);return!e.has(-0)}));v||((c=t((function(e,t){ln(e,s);var n=qi(new a,e,c);return null!=t&&bi(t,n[o],{that:n,AS_ENTRIES:r}),n}))).prototype=s,s.constructor=c),(y||g)&&(l("delete"),l("has"),r&&l("get")),(g||h)&&l(o),i&&s.clear&&delete s.clear}return d[e]=c,Wt({global:!0,constructor:!0,forced:c!=a},d),cn(c,e),i||n.setStrong(c,e,r),c},nc=ec.getWeakData,rc=ut.set,ic=ut.getterFor,oc=za.find,ac=za.findIndex,sc=k([].splice),cc=0,uc=function(e){return e.frozen||(e.frozen=new fc)},fc=function(){this.entries=[]},dc=function(e,t){return oc(e.entries,(function(e){return e[0]===t}))};fc.prototype={get:function(e){var t=dc(this,e);if(t)return t[1]},has:function(e){return!!dc(this,e)},set:function(e,t){var n=dc(this,e);n?n[1]=t:this.entries.push([e,t])},delete:function(e){var t=ac(this.entries,(function(t){return t[0]===e}));return~t&&sc(this.entries,t,1),!!~t}};var lc,pc={getConstructor:function(e,t,n,r){var i=e((function(e,i){ln(e,o),rc(e,{type:t,id:cc++,frozen:void 0}),null!=i&&bi(i,e[r],{that:e,AS_ENTRIES:n})})),o=i.prototype,a=ic(t),s=function(e,t,n){var r=a(e),i=nc(Ce(t),!0);return!0===i?uc(r).set(t,n):i[r.id]=n,e};return bo(o,{delete:function(e){var t=a(this);if(!j(e))return!1;var n=nc(e);return!0===n?uc(t).delete(e):n&&ue(n,t.id)&&delete n[t.id]},has:function(e){var t=a(this);if(!j(e))return!1;var n=nc(e);return!0===n?uc(t).has(e):n&&ue(n,t.id)}}),bo(o,n?{get:function(e){var t=a(this);if(j(e)){var n=nc(e);return!0===n?uc(t).get(e):n?n[t.id]:void 0}},set:function(e,t){return s(this,e,t)}}:{add:function(e){return s(this,e,!0)}}),i}},hc=ut.enforce,yc=!u.ActiveXObject&&"ActiveXObject"in u,vc=function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}},gc=tc("WeakMap",vc,pc);if(Xe&&yc){lc=pc.getConstructor(vc,"WeakMap",!0),ec.enable();var mc=gc.prototype,bc=k(mc.delete),Sc=k(mc.has),wc=k(mc.get),_c=k(mc.set);bo(mc,{delete:function(e){if(j(e)&&!Ys(e)){var t=hc(this);return t.frozen||(t.frozen=new lc),bc(this,e)||t.frozen.delete(e)}return bc(this,e)},has:function(e){if(j(e)&&!Ys(e)){var t=hc(this);return t.frozen||(t.frozen=new lc),Sc(this,e)||t.frozen.has(e)}return Sc(this,e)},get:function(e){if(j(e)&&!Ys(e)){var t=hc(this);return t.frozen||(t.frozen=new lc),Sc(this,e)?wc(this,e):t.frozen.get(e)}return wc(this,e)},set:function(e,t){if(j(e)&&!Ys(e)){var n=hc(this);n.frozen||(n.frozen=new lc),Sc(this,e)?_c(this,e,t):n.frozen.set(e,t)}else _c(this,e,t);return this}})}var Tc=me("iterator"),kc=me("toStringTag"),Mc=Vs.values,Nc=function(e,t){if(e){if(e[Tc]!==Mc)try{ze(e,Tc,Mc)}catch(t){e[Tc]=Mc}if(e[kc]||ze(e,kc,t),La[t])for(var n in Vs)if(e[n]!==Vs[n])try{ze(e,n,Vs[n])}catch(t){e[n]=Vs[n]}}};for(var Ic in La)Nc(u[Ic]&&u[Ic].prototype,Ic);Nc(Aa,"DOMTokenList");var Oc=TypeError,xc=function(e){if(e>9007199254740991)throw Oc("Maximum allowed index exceeded");return e},Pc=me("isConcatSpreadable"),Lc=q>=51||!f((function(){var e=[];return e[Pc]=!1,e.concat()[0]!==e})),Cc=Fi("concat"),Ec=function(e){if(!j(e))return!1;var t=e[Pc];return void 0!==t?!!t:Vi(e)};Wt({target:"Array",proto:!0,arity:1,forced:!Lc||!Cc},{concat:function(e){var t,n,r,i,o,a=se(this),s=Ba(a,0),c=0;for(t=-1,r=arguments.length;t<r;t++)if(Ec(o=-1===t?a:arguments[t]))for(i=wt(o),xc(c+i),n=0;n<i;n++,c++)n in o&&Bi(s,c,o[n]);else xc(c+1),Bi(s,c++,o);return s.length=c,s}});var Ac=o((function(e,t){!function(t){var n=Object.hasOwnProperty,r=Array.isArray?Array.isArray:function(e){return"[object Array]"===Object.prototype.toString.call(e)},i="object"==typeof process&&"function"==typeof process.nextTick,o="function"==typeof Symbol,a="object"==typeof Reflect,s="function"==typeof setImmediate?setImmediate:setTimeout,c=o?a&&"function"==typeof Reflect.ownKeys?Reflect.ownKeys:function(e){var t=Object.getOwnPropertyNames(e);return t.push.apply(t,Object.getOwnPropertySymbols(e)),t}:Object.keys;function u(){this._events={},this._conf&&f.call(this,this._conf)}function f(e){e&&(this._conf=e,e.delimiter&&(this.delimiter=e.delimiter),e.maxListeners!==t&&(this._maxListeners=e.maxListeners),e.wildcard&&(this.wildcard=e.wildcard),e.newListener&&(this._newListener=e.newListener),e.removeListener&&(this._removeListener=e.removeListener),e.verboseMemoryLeak&&(this.verboseMemoryLeak=e.verboseMemoryLeak),e.ignoreErrors&&(this.ignoreErrors=e.ignoreErrors),this.wildcard&&(this.listenerTree={}))}function d(e,t){var n="(node) warning: possible EventEmitter memory leak detected. "+e+" listeners added. Use emitter.setMaxListeners() to increase limit.";if(this.verboseMemoryLeak&&(n+=" Event name: "+t+"."),"undefined"!=typeof process&&process.emitWarning){var r=new Error(n);r.name="MaxListenersExceededWarning",r.emitter=this,r.count=e,process.emitWarning(r)}else console.trace}var l=function(e,t,n){var r=arguments.length;switch(r){case 0:return[];case 1:return[e];case 2:return[e,t];case 3:return[e,t,n];default:for(var i=new Array(r);r--;)i[r]=arguments[r];return i}};function p(e,n){for(var r={},i=e.length,o=n?value.length:0,a=0;a<i;a++)r[e[a]]=a<o?n[a]:t;return r}function h(e,t,n){var r,i;if(this._emitter=e,this._target=t,this._listeners={},this._listenersCount=0,(n.on||n.off)&&(r=n.on,i=n.off),t.addEventListener?(r=t.addEventListener,i=t.removeEventListener):t.addListener?(r=t.addListener,i=t.removeListener):t.on&&(r=t.on,i=t.off),!r&&!i)throw Error("target does not implement any known event API");if("function"!=typeof r)throw TypeError("on method must be a function");if("function"!=typeof i)throw TypeError("off method must be a function");this._on=r,this._off=i;var o=e._observers;o?o.push(this):e._observers=[this]}function y(e,r,i,o){var a=Object.assign({},r);if(!e)return a;if("object"!=typeof e)throw TypeError("options must be an object");var s,c,u,f=Object.keys(e),d=f.length;function l(e){throw Error('Invalid "'+s+'" option value'+(e?". Reason: "+e:""))}for(var p=0;p<d;p++){if(s=f[p],!o&&!n.call(r,s))throw Error('Unknown "'+s+'" option');(c=e[s])!==t&&(u=i[s],a[s]=u?u(c,l):c)}return a}function v(e,t){return"function"==typeof e&&e.hasOwnProperty("prototype")||t("value must be a constructor"),e}function g(e){var t="value must be type of "+e.join("|"),n=e.length,r=e[0],i=e[1];return 1===n?function(e,n){if(typeof e===r)return e;n(t)}:2===n?function(e,n){var o=typeof e;if(o===r||o===i)return e;n(t)}:function(r,i){for(var o=typeof r,a=n;a-- >0;)if(o===e[a])return r;i(t)}}Object.assign(h.prototype,{subscribe:function(e,t,n){var r=this,i=this._target,o=this._emitter,a=this._listeners,s=function(){var r=l.apply(null,arguments),a={data:r,name:t,original:e};if(n){var s=n.call(i,a);!1!==s&&o.emit.apply(o,[a.name].concat(r))}else o.emit.apply(o,[t].concat(r))};if(a[e])throw Error("Event '"+e+"' is already listening");this._listenersCount++,o._newListener&&o._removeListener&&!r._onNewListener?(this._onNewListener=function(n){n===t&&null===a[e]&&(a[e]=s,r._on.call(i,e,s))},o.on("newListener",this._onNewListener),this._onRemoveListener=function(n){n===t&&!o.hasListeners(n)&&a[e]&&(a[e]=null,r._off.call(i,e,s))},a[e]=null,o.on("removeListener",this._onRemoveListener)):(a[e]=s,r._on.call(i,e,s))},unsubscribe:function(e){var t,n,r,i=this,o=this._listeners,a=this._emitter,s=this._off,u=this._target;if(e&&"string"!=typeof e)throw TypeError("event must be a string");function f(){i._onNewListener&&(a.off("newListener",i._onNewListener),a.off("removeListener",i._onRemoveListener),i._onNewListener=null,i._onRemoveListener=null);var e=w.call(a,i);a._observers.splice(e,1)}if(e){if(!(t=o[e]))return;s.call(u,e,t),delete o[e],--this._listenersCount||f()}else{for(r=(n=c(o)).length;r-- >0;)e=n[r],s.call(u,e,o[e]);this._listeners={},this._listenersCount=0,f()}}});var m=g(["function"]),b=g(["object","function"]);function S(e,t,n){var r,i,o,a=0,s=new e((function(c,u,f){function d(){i&&(i=null),a&&(clearTimeout(a),a=0)}n=y(n,{timeout:0,overload:!1},{timeout:function(e,t){return("number"!=typeof(e*=1)||e<0||!Number.isFinite(e))&&t("timeout must be a positive number"),e}}),r=!n.overload&&"function"==typeof e.prototype.cancel&&"function"==typeof f;var l=function(e){d(),c(e)},p=function(e){d(),u(e)};r?t(l,p,f):(i=[function(e){p(e||Error("canceled"))}],t(l,p,(function(e){if(o)throw Error("Unable to subscribe on cancel event asynchronously");if("function"!=typeof e)throw TypeError("onCancel callback must be a function");i.push(e)})),o=!0),n.timeout>0&&(a=setTimeout((function(){var e=Error("timeout");e.code="ETIMEDOUT",a=0,s.cancel(e),u(e)}),n.timeout))}));return r||(s.cancel=function(e){if(i){for(var t=i.length,n=1;n<t;n++)i[n](e);i[0](e),i=null}}),s}function w(e){var t=this._observers;if(!t)return-1;for(var n=t.length,r=0;r<n;r++)if(t[r]._target===e)return r;return-1}function _(e,t,n,r,i){if(!n)return null;if(0===r){var o=typeof t;if("string"===o){var a,s,u=0,f=0,d=this.delimiter,l=d.length;if(-1!==(s=t.indexOf(d))){a=new Array(5);do{a[u++]=t.slice(f,s),f=s+l}while(-1!==(s=t.indexOf(d,f)));a[u++]=t.slice(f),t=a,i=u}else t=[t],i=1}else"object"===o?i=t.length:(t=[t],i=1)}var p,h,y,v,g,m,b,S=null,w=t[r],T=t[r+1];if(r===i)n._listeners&&("function"==typeof n._listeners?(e&&e.push(n._listeners),S=[n]):(e&&e.push.apply(e,n._listeners),S=[n]));else{if("*"===w){for(s=(m=c(n)).length;s-- >0;)"_listeners"!==(p=m[s])&&(b=_(e,t,n[p],r+1,i))&&(S?S.push.apply(S,b):S=b);return S}if("**"===w){for((g=r+1===i||r+2===i&&"*"===T)&&n._listeners&&(S=_(e,t,n,i,i)),s=(m=c(n)).length;s-- >0;)"_listeners"!==(p=m[s])&&("*"===p||"**"===p?(n[p]._listeners&&!g&&(b=_(e,t,n[p],i,i))&&(S?S.push.apply(S,b):S=b),b=_(e,t,n[p],r,i)):b=_(e,t,n[p],p===T?r+2:r,i),b&&(S?S.push.apply(S,b):S=b));return S}n[w]&&(S=_(e,t,n[w],r+1,i))}if((h=n["*"])&&_(e,t,h,r+1,i),y=n["**"])if(r<i)for(y._listeners&&_(e,t,y,i,i),s=(m=c(y)).length;s-- >0;)"_listeners"!==(p=m[s])&&(p===T?_(e,t,y[p],r+2,i):p===w?_(e,t,y[p],r+1,i):((v={})[p]=y[p],_(e,t,{"**":v},r+1,i)));else y._listeners?_(e,t,y,i,i):y["*"]&&y["*"]._listeners&&_(e,t,y["*"],i,i);return S}function T(e,t,n){var r,i,o=0,a=0,s=this.delimiter,c=s.length;if("string"==typeof e)if(-1!==(r=e.indexOf(s))){i=new Array(5);do{i[o++]=e.slice(a,r),a=r+c}while(-1!==(r=e.indexOf(s,a)));i[o++]=e.slice(a)}else i=[e],o=1;else i=e,o=e.length;if(o>1)for(r=0;r+1<o;r++)if("**"===i[r]&&"**"===i[r+1])return;var u,f=this.listenerTree;for(r=0;r<o;r++)if(f=f[u=i[r]]||(f[u]={}),r===o-1)return f._listeners?("function"==typeof f._listeners&&(f._listeners=[f._listeners]),n?f._listeners.unshift(t):f._listeners.push(t),!f._listeners.warned&&this._maxListeners>0&&f._listeners.length>this._maxListeners&&(f._listeners.warned=!0,d.call(this,f._listeners.length,u))):f._listeners=t,!0;return!0}function k(e,t,n,r){for(var i,o,a,s,u=c(e),f=u.length,d=e._listeners;f-- >0;)i=e[o=u[f]],a="_listeners"===o?n:n?n.concat(o):[o],s=r||"symbol"==typeof o,d&&t.push(s?a:a.join(this.delimiter)),"object"==typeof i&&k.call(this,i,t,a,s);return t}function M(e){for(var t,n,r,i=c(e),o=i.length;o-- >0;)(t=e[n=i[o]])&&(r=!0,"_listeners"===n||M(t)||delete e[n]);return r}function N(e,t,n){this.emitter=e,this.event=t,this.listener=n}function I(e,n,r){if(!0===r)a=!0;else if(!1===r)o=!0;else{if(!r||"object"!=typeof r)throw TypeError("options should be an object or true");var o=r.async,a=r.promisify,c=r.nextTick,u=r.objectify}if(o||c||a){var f=n,d=n._origin||n;if(c&&!i)throw Error("process.nextTick is not supported");a===t&&(a="AsyncFunction"===n.constructor.name),n=function(){var e=arguments,t=this,n=this.event;return a?c?Promise.resolve():new Promise((function(e){s(e)})).then((function(){return t.event=n,f.apply(t,e)})):(c?process.nextTick:s)((function(){t.event=n,f.apply(t,e)}))},n._async=!0,n._origin=d}return[n,u?new N(this,e,n):this]}function O(e){this._events={},this._newListener=!1,this._removeListener=!1,this.verboseMemoryLeak=!1,f.call(this,e)}N.prototype.off=function(){return this.emitter.off(this.event,this.listener),this},O.EventEmitter2=O,O.prototype.listenTo=function(e,n,i){if("object"!=typeof e)throw TypeError("target musts be an object");var o=this;function a(t){if("object"!=typeof t)throw TypeError("events must be an object");var n,r=i.reducers,a=w.call(o,e);n=-1===a?new h(o,e,i):o._observers[a];for(var s,u=c(t),f=u.length,d="function"==typeof r,l=0;l<f;l++)s=u[l],n.subscribe(s,t[s]||s,d?r:r&&r[s])}return i=y(i,{on:t,off:t,reducers:t},{on:m,off:m,reducers:b}),r(n)?a(p(n)):a("string"==typeof n?p(n.split(/\s+/)):n),this},O.prototype.stopListeningTo=function(e,t){var n=this._observers;if(!n)return!1;var r,i=n.length,o=!1;if(e&&"object"!=typeof e)throw TypeError("target should be an object");for(;i-- >0;)r=n[i],e&&r._target!==e||(r.unsubscribe(t),o=!0);return o},O.prototype.delimiter=".",O.prototype.setMaxListeners=function(e){e!==t&&(this._maxListeners=e,this._conf||(this._conf={}),this._conf.maxListeners=e)},O.prototype.getMaxListeners=function(){return this._maxListeners},O.prototype.event="",O.prototype.once=function(e,t,n){return this._once(e,t,!1,n)},O.prototype.prependOnceListener=function(e,t,n){return this._once(e,t,!0,n)},O.prototype._once=function(e,t,n,r){return this._many(e,1,t,n,r)},O.prototype.many=function(e,t,n,r){return this._many(e,t,n,!1,r)},O.prototype.prependMany=function(e,t,n,r){return this._many(e,t,n,!0,r)},O.prototype._many=function(e,t,n,r,i){var o=this;if("function"!=typeof n)throw new Error("many only accepts instances of Function");function a(){return 0==--t&&o.off(e,a),n.apply(this,arguments)}return a._origin=n,this._on(e,a,r,i)},O.prototype.emit=function(){if(!this._events&&!this._all)return!1;this._events||u.call(this);var e,t,n,r,i,a,s=arguments[0],c=this.wildcard;if("newListener"===s&&!this._newListener&&!this._events.newListener)return!1;if(c&&(e=s,"newListener"!==s&&"removeListener"!==s&&"object"==typeof s)){if(n=s.length,o)for(r=0;r<n;r++)if("symbol"==typeof s[r]){a=!0;break}a||(s=s.join(this.delimiter))}var f,d=arguments.length;if(this._all&&this._all.length)for(r=0,n=(f=this._all.slice()).length;r<n;r++)switch(this.event=s,d){case 1:f[r].call(this,s);break;case 2:f[r].call(this,s,arguments[1]);break;case 3:f[r].call(this,s,arguments[1],arguments[2]);break;default:f[r].apply(this,arguments)}if(c)f=[],_.call(this,f,e,this.listenerTree,0,n);else{if("function"==typeof(f=this._events[s])){switch(this.event=s,d){case 1:f.call(this);break;case 2:f.call(this,arguments[1]);break;case 3:f.call(this,arguments[1],arguments[2]);break;default:for(t=new Array(d-1),i=1;i<d;i++)t[i-1]=arguments[i];f.apply(this,t)}return!0}f&&(f=f.slice())}if(f&&f.length){if(d>3)for(t=new Array(d-1),i=1;i<d;i++)t[i-1]=arguments[i];for(r=0,n=f.length;r<n;r++)switch(this.event=s,d){case 1:f[r].call(this);break;case 2:f[r].call(this,arguments[1]);break;case 3:f[r].call(this,arguments[1],arguments[2]);break;default:f[r].apply(this,t)}return!0}if(!this.ignoreErrors&&!this._all&&"error"===s)throw arguments[1]instanceof Error?arguments[1]:new Error("Uncaught, unspecified 'error' event.");return!!this._all},O.prototype.emitAsync=function(){if(!this._events&&!this._all)return!1;this._events||u.call(this);var e,t,n,r,i,a,s=arguments[0],c=this.wildcard;if("newListener"===s&&!this._newListener&&!this._events.newListener)return Promise.resolve([!1]);if(c&&(e=s,"newListener"!==s&&"removeListener"!==s&&"object"==typeof s)){if(r=s.length,o)for(i=0;i<r;i++)if("symbol"==typeof s[i]){t=!0;break}t||(s=s.join(this.delimiter))}var f,d=[],l=arguments.length;if(this._all)for(i=0,r=this._all.length;i<r;i++)switch(this.event=s,l){case 1:d.push(this._all[i].call(this,s));break;case 2:d.push(this._all[i].call(this,s,arguments[1]));break;case 3:d.push(this._all[i].call(this,s,arguments[1],arguments[2]));break;default:d.push(this._all[i].apply(this,arguments))}if(c?(f=[],_.call(this,f,e,this.listenerTree,0)):f=this._events[s],"function"==typeof f)switch(this.event=s,l){case 1:d.push(f.call(this));break;case 2:d.push(f.call(this,arguments[1]));break;case 3:d.push(f.call(this,arguments[1],arguments[2]));break;default:for(n=new Array(l-1),a=1;a<l;a++)n[a-1]=arguments[a];d.push(f.apply(this,n))}else if(f&&f.length){if(f=f.slice(),l>3)for(n=new Array(l-1),a=1;a<l;a++)n[a-1]=arguments[a];for(i=0,r=f.length;i<r;i++)switch(this.event=s,l){case 1:d.push(f[i].call(this));break;case 2:d.push(f[i].call(this,arguments[1]));break;case 3:d.push(f[i].call(this,arguments[1],arguments[2]));break;default:d.push(f[i].apply(this,n))}}else if(!this.ignoreErrors&&!this._all&&"error"===s)return arguments[1]instanceof Error?Promise.reject(arguments[1]):Promise.reject("Uncaught, unspecified 'error' event.");return Promise.all(d)},O.prototype.on=function(e,t,n){return this._on(e,t,!1,n)},O.prototype.prependListener=function(e,t,n){return this._on(e,t,!0,n)},O.prototype.onAny=function(e){return this._onAny(e,!1)},O.prototype.prependAny=function(e){return this._onAny(e,!0)},O.prototype.addListener=O.prototype.on,O.prototype._onAny=function(e,t){if("function"!=typeof e)throw new Error("onAny only accepts instances of Function");return this._all||(this._all=[]),t?this._all.unshift(e):this._all.push(e),this},O.prototype._on=function(e,n,r,i){if("function"==typeof e)return this._onAny(e,n),this;if("function"!=typeof n)throw new Error("on only accepts instances of Function");this._events||u.call(this);var o,a=this;return i!==t&&(n=(o=I.call(this,e,n,i))[0],a=o[1]),this._newListener&&this.emit("newListener",e,n),this.wildcard?(T.call(this,e,n,r),a):(this._events[e]?("function"==typeof this._events[e]&&(this._events[e]=[this._events[e]]),r?this._events[e].unshift(n):this._events[e].push(n),!this._events[e].warned&&this._maxListeners>0&&this._events[e].length>this._maxListeners&&(this._events[e].warned=!0,d.call(this,this._events[e].length,e))):this._events[e]=n,a)},O.prototype.off=function(e,t){if("function"!=typeof t)throw new Error("removeListener only takes instances of Function");var n,i=[];if(this.wildcard){var o="string"==typeof e?e.split(this.delimiter):e.slice();if(!(i=_.call(this,null,o,this.listenerTree,0)))return this}else{if(!this._events[e])return this;n=this._events[e],i.push({_listeners:n})}for(var a=0;a<i.length;a++){var s=i[a];if(n=s._listeners,r(n)){for(var c=-1,u=0,f=n.length;u<f;u++)if(n[u]===t||n[u].listener&&n[u].listener===t||n[u]._origin&&n[u]._origin===t){c=u;break}if(c<0)continue;return this.wildcard?s._listeners.splice(c,1):this._events[e].splice(c,1),0===n.length&&(this.wildcard?delete s._listeners:delete this._events[e]),this._removeListener&&this.emit("removeListener",e,t),this}(n===t||n.listener&&n.listener===t||n._origin&&n._origin===t)&&(this.wildcard?delete s._listeners:delete this._events[e],this._removeListener&&this.emit("removeListener",e,t))}return this.listenerTree&&M(this.listenerTree),this},O.prototype.offAny=function(e){var t,n=0,r=0;if(e&&this._all&&this._all.length>0){for(n=0,r=(t=this._all).length;n<r;n++)if(e===t[n])return t.splice(n,1),this._removeListener&&this.emit("removeListenerAny",e),this}else{if(t=this._all,this._removeListener)for(n=0,r=t.length;n<r;n++)this.emit("removeListenerAny",t[n]);this._all=[]}return this},O.prototype.removeListener=O.prototype.off,O.prototype.removeAllListeners=function(e){if(e===t)return!this._events||u.call(this),this;if(this.wildcard){var n,r=_.call(this,null,e,this.listenerTree,0);if(!r)return this;for(n=0;n<r.length;n++)r[n]._listeners=null;this.listenerTree&&M(this.listenerTree)}else this._events&&(this._events[e]=null);return this},O.prototype.listeners=function(e){var n,r,i,o,a,s=this._events;if(e===t){if(this.wildcard)throw Error("event name required for wildcard emitter");if(!s)return[];for(o=(n=c(s)).length,i=[];o-- >0;)"function"==typeof(r=s[n[o]])?i.push(r):i.push.apply(i,r);return i}if(this.wildcard){if(!(a=this.listenerTree))return[];var u=[],f="string"==typeof e?e.split(this.delimiter):e.slice();return _.call(this,u,f,a,0),u}return s&&(r=s[e])?"function"==typeof r?[r]:r:[]},O.prototype.eventNames=function(e){var t=this._events;return this.wildcard?k.call(this,this.listenerTree,[],null,e):t?c(t):[]},O.prototype.listenerCount=function(e){return this.listeners(e).length},O.prototype.hasListeners=function(e){if(this.wildcard){var n=[],r="string"==typeof e?e.split(this.delimiter):e.slice();return _.call(this,n,r,this.listenerTree,0),n.length>0}var i=this._events,o=this._all;return!!(o&&o.length||i&&(e===t?c(i).length:i[e]))},O.prototype.listenersAny=function(){return this._all?this._all:[]},O.prototype.waitFor=function(e,n){var r=this,i=typeof n;return"number"===i?n={timeout:n}:"function"===i&&(n={filter:n}),S((n=y(n,{timeout:0,filter:t,handleError:!1,Promise:Promise,overload:!1},{filter:m,Promise:v})).Promise,(function(t,i,o){function a(){var o=n.filter;if(!o||o.apply(r,arguments))if(r.off(e,a),n.handleError){var s=arguments[0];s?i(s):t(l.apply(null,arguments).slice(1))}else t(l.apply(null,arguments))}o((function(){r.off(e,a)})),r._on(e,a,!1)}),{timeout:n.timeout,overload:n.overload})};var x=O.prototype;Object.defineProperties(O,{defaultMaxListeners:{get:function(){return x._maxListeners},set:function(e){if("number"!=typeof e||e<0||Number.isNaN(e))throw TypeError("n must be a non-negative number");x._maxListeners=e},enumerable:!0},once:{value:function(e,t,n){return S((n=y(n,{Promise:Promise,timeout:0,overload:!1},{Promise:v})).Promise,(function(n,r,i){var o;if("function"==typeof e.addEventListener)return o=function(){n(l.apply(null,arguments))},i((function(){e.removeEventListener(t,o)})),void e.addEventListener(t,o,{once:!0});var a,s=function(){a&&e.removeListener("error",a),n(l.apply(null,arguments))};"error"!==t&&(a=function(n){e.removeListener(t,s),r(n)},e.once("error",a)),i((function(){a&&e.removeListener("error",a),e.removeListener(t,s)})),e.once(t,s)}),{timeout:n.timeout,overload:n.overload})},writable:!0,configurable:!0}}),Object.defineProperties(x,{_maxListeners:{value:10,writable:!0,configurable:!0},_observers:{value:null,writable:!0,configurable:!0}}),e.exports=O}()})),jc={f:me},Vc=u,Bc=Fe.f,Rc=function(e){var t=Vc.Symbol||(Vc.Symbol={});ue(t,e)||Bc(t,e,{value:jc.f(e)})},Fc=za.forEach,zc=Ze("hidden"),Dc="Symbol",Wc=ut.set,Uc=ut.getterFor(Dc),qc=Object.prototype,Jc=u.Symbol,Gc=Jc&&Jc.prototype,Hc=u.TypeError,$c=u.QObject,Qc=Oe.f,Kc=Fe.f,Xc=Qs.f,Yc=m.f,Zc=k([].push),eu=oe("symbols"),tu=oe("op-symbols"),nu=oe("wks"),ru=!$c||!$c.prototype||!$c.prototype.findChild,iu=d&&f((function(){return 7!=cs(Kc({},"a",{get:function(){return Kc(this,"a",{value:7}).a}})).a}))?function(e,t,n){var r=Qc(qc,t);r&&delete qc[t],Kc(e,t,n),r&&e!==qc&&Kc(qc,t,r)}:Kc,ou=function(e,t){var n=eu[e]=cs(Gc);return Wc(n,{type:Dc,tag:e,description:t}),d||(n.description=t),n},au=function(e,t,n){e===qc&&au(tu,t,n),Ce(e);var r=_e(t);return Ce(n),ue(eu,r)?(n.enumerable?(ue(e,zc)&&e[zc][r]&&(e[zc][r]=!1),n=cs(n,{enumerable:b(0,!1)})):(ue(e,zc)||Kc(e,zc,b(1,{})),e[zc][r]=!0),iu(e,r,n)):Kc(e,r,n)},su=function(e,t){Ce(e);var n=E(t),r=Ja(n).concat(du(n));return Fc(r,(function(t){d&&!h(cu,n,t)||au(e,t,n[t])})),e},cu=function(e){var t=_e(e),n=h(Yc,this,t);return!(this===qc&&ue(eu,t)&&!ue(tu,t))&&(!(n||!ue(this,t)||!ue(eu,t)||ue(this,zc)&&this[zc][t])||n)},uu=function(e,t){var n=E(e),r=_e(t);if(n!==qc||!ue(eu,r)||ue(tu,r)){var i=Qc(n,r);return!i||!ue(eu,r)||ue(n,zc)&&n[zc][r]||(i.enumerable=!0),i}},fu=function(e){var t=Xc(E(e)),n=[];return Fc(t,(function(e){ue(eu,e)||ue(et,e)||Zc(n,e)})),n},du=function(e){var t=e===qc,n=Xc(t?tu:E(e)),r=[];return Fc(n,(function(e){!ue(eu,e)||t&&!ue(qc,e)||Zc(r,eu[e])})),r};J||(Jc=function(){if(R(Gc,this))throw Hc("Symbol is not a constructor");var e=arguments.length&&void 0!==arguments[0]?Hi(arguments[0]):void 0,t=pe(e),n=function(e){this===qc&&h(n,tu,e),ue(this,zc)&&ue(this[zc],t)&&(this[zc][t]=!1),iu(this,t,b(1,e))};return d&&ru&&iu(qc,t,{configurable:!0,set:n}),ou(t,e)},Gc=Jc.prototype,dt(Gc,"toString",(function(){return Uc(this).tag})),dt(Jc,"withoutSetter",(function(e){return ou(pe(e),e)})),m.f=cu,Fe.f=au,ns.f=su,Oe.f=uu,xt.f=Qs.f=fu,Pt.f=du,jc.f=function(e){return ou(me(e),e)},d&&(Kc(Gc,"description",{configurable:!0,get:function(){return Uc(this).description}}),dt(qc,"propertyIsEnumerable",cu,{unsafe:!0}))),Wt({global:!0,constructor:!0,wrap:!0,forced:!J,sham:!J},{Symbol:Jc}),Fc(Ja(nu),(function(e){Rc(e)})),Wt({target:Dc,stat:!0,forced:!J},{useSetter:function(){ru=!0},useSimple:function(){ru=!1}}),Wt({target:"Object",stat:!0,forced:!J,sham:!d},{create:function(e,t){return void 0===t?cs(e):su(cs(e),t)},defineProperty:au,defineProperties:su,getOwnPropertyDescriptor:uu}),Wt({target:"Object",stat:!0,forced:!J},{getOwnPropertyNames:fu}),function(){var e=B("Symbol"),t=e&&e.prototype,n=t&&t.valueOf,r=me("toPrimitive");t&&!t[r]&&dt(t,r,(function(e){return h(n,this)}),{arity:1})}(),cn(Jc,Dc),et[zc]=!0;var lu=J&&!!Symbol.for&&!!Symbol.keyFor,pu=oe("string-to-symbol-registry"),hu=oe("symbol-to-string-registry");Wt({target:"Symbol",stat:!0,forced:!lu},{for:function(e){var t=Hi(e);if(ue(pu,t))return pu[t];var n=B("Symbol")(t);return pu[t]=n,hu[n]=t,n}});var yu=oe("symbol-to-string-registry");Wt({target:"Symbol",stat:!0,forced:!lu},{keyFor:function(e){if(!$(e))throw TypeError(K(e)+" is not a symbol");if(ue(yu,e))return yu[e]}});var vu=B("JSON","stringify"),gu=k(/./.exec),mu=k("".charAt),bu=k("".charCodeAt),Su=k("".replace),wu=k(1..toString),_u=/[\uD800-\uDFFF]/g,Tu=/^[\uD800-\uDBFF]$/,ku=/^[\uDC00-\uDFFF]$/,Mu=!J||f((function(){var e=B("Symbol")();return"[null]"!=vu([e])||"{}"!=vu({a:e})||"{}"!=vu(Object(e))})),Nu=f((function(){return'"\\udf06\\ud834"'!==vu("\udf06\ud834")||'"\\udead"'!==vu("\udead")})),Iu=function(e,t){var n=Vn(arguments),r=t;if((j(t)||void 0!==e)&&!$(e))return Vi(t)||(t=function(e,t){if(A(r)&&(t=h(r,this,e,t)),!$(t))return t}),n[1]=t,Cn(vu,null,n)},Ou=function(e,t,n){var r=mu(n,t-1),i=mu(n,t+1);return gu(Tu,e)&&!gu(ku,i)||gu(ku,e)&&!gu(Tu,r)?"\\u"+wu(bu(e,0),16):e};vu&&Wt({target:"JSON",stat:!0,arity:3,forced:Mu||Nu},{stringify:function(e,t,n){var r=Vn(arguments),i=Cn(Mu?Iu:vu,null,r);return Nu&&"string"==typeof i?Su(i,_u,Ou):i}});var xu=!J||f((function(){Pt.f(1)}));Wt({target:"Object",stat:!0,forced:xu},{getOwnPropertySymbols:function(e){var t=Pt.f;return t?t(se(e)):[]}});var Pu=Fe.f,Lu=u.Symbol,Cu=Lu&&Lu.prototype;if(d&&A(Lu)&&(!("description"in Cu)||void 0!==Lu().description)){var Eu={},Au=function(){var e=arguments.length<1||void 0===arguments[0]?void 0:Hi(arguments[0]),t=R(Cu,this)?new Lu(e):void 0===e?Lu():Lu(e);return""===e&&(Eu[t]=!0),t};Et(Au,Lu),Au.prototype=Cu,Cu.constructor=Au;var ju="Symbol(test)"==String(Lu("test")),Vu=k(Cu.toString),Bu=k(Cu.valueOf),Ru=/^Symbol\((.*)\)[^)]+$/,Fu=k("".replace),zu=k("".slice);Pu(Cu,"description",{configurable:!0,get:function(){var e=Bu(this),t=Vu(e);if(ue(Eu,e))return"";var n=ju?zu(t,7,-1):Fu(t,Ru,"$1");return""===n?void 0:n}}),Wt({global:!0,constructor:!0,forced:!0},{Symbol:Au})}Rc("iterator");var Du={},Wu=new Ac.EventEmitter2({maxListeners:20,newListener:!1}),Uu=new Ac.EventEmitter2({maxListeners:20,newListener:!1});function qu(e){var t=new WeakMap;return e=e[0].toUpperCase()+e.slice(1),Du[e]||(Du[e]={getGlobalListeners:function(){return Wu.listeners(e)},getInternalListeners:function(){return Uu.listeners(e)},emit:function(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];Uu.emit.apply(Uu,[e].concat(t)),Wu.emit.apply(Wu,[e].concat(t))},emitGlobal:function(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];Wu.emit.apply(Wu,[e].concat(t))},emitInternal:function(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];Uu.emit.apply(Uu,[e].concat(t))},internalOnMethod:function(t,n){void 0===n&&(n={}),Xa(t)&&(n.prepend?n.once?Uu.prependOnceListener(e,t):Uu.prependListener(e,t):n.once?Uu.once(e,t):Uu.on(e,t))},internalOffMethod:function(t){Xa(t)&&Uu.off(e,t)},onMethod:function(n){var r;(r=Xa(n)?n:null)&&(t.set(n,r),Wu.on(e,r))},offMethod:function(n){if(!n||Xa(n))if(n){var r=void 0;t.has(n)&&(r=t.get(n),t.delete(n)),Wu.off(e,r)}else t=new WeakMap,Wu.removeAllListeners(e)}}),Du[e]}function Ju(e){return!!Du[e]}var Gu=new Proxy({},{get:function(e,t){if(t in wh)return wh[t];if(t in ji){var n=ji[t];return function(){for(var e=[],r=0;r<arguments.length;r++)e[r]=arguments[r];var i=Ya(n,e),o=Za(n.params,i),a=n.isSustain;if("async"===n.type){var s=e[0],c=s||{},u=c.success,f=c.fail,d=c.complete;if(n.usePromise&&!(Xa(u)||Xa(f)||Xa(d)))return new Promise((function(e,n){Qu({isSustain:a,event:t,data:o,success:e,fail:n})}));"function"==typeof s?Qu({isSustain:a,event:t,data:o},s):Qu({isSustain:a,event:t,data:o,success:s&&s.success,fail:s&&s.fail,complete:s&&s.complete})}if("sync"===n.type){var l=Ku({isSustain:a,event:t,data:o});if(n.needReturn)return l}"monitor"===n.type&&Hu(Li(Li({},n),o)),"offMonitor"===n.type&&$u(Li(Li({},n),o))}}if(t in e)return e[t];throw new Error(t+" method 暂未实现")}}),Hu=function(e){Ju(e.eventManagerName)||didiJsBridge.on({event:e.nativeEvent},(function(t){qu(e.eventManagerName).emit(t.data)})),qu(e.eventManagerName).onMethod(e.callBack)},$u=function(e){Ju(e.eventManagerName)&&qu(e.eventManagerName).offMethod(e.callBack)},Qu=function(t,n){if(t&&t.event){didiJsBridge.invoke({method:t.event,data:t.data||{},isSustain:t.isSustain||!1,callback:(n?function(e){try{(e=e.data).success?n&&n(e.data):n&&n(e.message)}catch(e){throw e}}:"")||function(n){n=n.data;try{n.success?(n.data&&"object"===e(n.data)&&(n.data.errMsg=t.event+":ok"),t.success&&t.success(n.data)):t.fail&&t.fail({errMsg:n.errMsg})}catch(e){throw e}finally{t.complete&&t.complete()}}})}},Ku=function(e){if(e&&e.event)return didiJsBridge.invoke({method:e.event,data:e.data||{}})};didiJsBridge.on({event:"onCloseMiniProgram",isSustain:!0},(function(e){void 0===e&&(e={data:{}});var t=e.data;qu("onCloseMiniProgram").emit(t)}));var Xu=Tt.includes,Yu=f((function(){return!Array(1).includes()}));Wt({target:"Array",proto:!0,forced:Yu},{includes:function(e){return Xu(this,e,arguments.length>1?arguments[1]:void 0)}}),ys("includes");var Zu,ef,tf=function(){var e=Ce(this),t="";return e.hasIndices&&(t+="d"),e.global&&(t+="g"),e.ignoreCase&&(t+="i"),e.multiline&&(t+="m"),e.dotAll&&(t+="s"),e.unicode&&(t+="u"),e.unicodeSets&&(t+="v"),e.sticky&&(t+="y"),t},nf=u.RegExp,rf=f((function(){var e=nf("a","y");return e.lastIndex=2,null!=e.exec("abcd")})),of=rf||f((function(){return!nf("a","y").sticky})),af={BROKEN_CARET:rf||f((function(){var e=nf("^r","gy");return e.lastIndex=2,null!=e.exec("str")})),MISSED_STICKY:of,UNSUPPORTED_Y:rf},sf=u.RegExp,cf=f((function(){var e=sf(".","s");return!(e.dotAll&&e.exec("\n")&&"s"===e.flags)})),uf=u.RegExp,ff=f((function(){var e=uf("(?<a>b)","g");return"b"!==e.exec("b").groups.a||"bc"!=="b".replace(e,"$<a>c")})),df=ut.get,lf=oe("native-string-replace",String.prototype.replace),pf=RegExp.prototype.exec,hf=pf,yf=k("".charAt),vf=k("".indexOf),gf=k("".replace),mf=k("".slice),bf=(ef=/b*/g,h(pf,Zu=/a/,"a"),h(pf,ef,"a"),0!==Zu.lastIndex||0!==ef.lastIndex),Sf=af.BROKEN_CARET,wf=void 0!==/()??/.exec("")[1];(bf||wf||Sf||cf||ff)&&(hf=function(e){var t,n,r,i,o,a,s,c=this,u=df(c),f=Hi(e),d=u.raw;if(d)return d.lastIndex=c.lastIndex,t=h(hf,d,f),c.lastIndex=d.lastIndex,t;var l=u.groups,p=Sf&&c.sticky,y=h(tf,c),v=c.source,g=0,m=f;if(p&&(y=gf(y,"y",""),-1===vf(y,"g")&&(y+="g"),m=mf(f,c.lastIndex),c.lastIndex>0&&(!c.multiline||c.multiline&&"\n"!==yf(f,c.lastIndex-1))&&(v="(?: "+v+")",m=" "+m,g++),n=new RegExp("^(?:"+v+")",y)),wf&&(n=new RegExp("^"+v+"$(?!\\s)",y)),bf&&(r=c.lastIndex),i=h(pf,p?n:c,m),p?i?(i.input=mf(i.input,g),i[0]=mf(i[0],g),i.index=c.lastIndex,c.lastIndex+=i[0].length):c.lastIndex=0:bf&&i&&(c.lastIndex=c.global?i.index+i[0].length:r),wf&&i&&i.length>1&&h(lf,i[0],n,(function(){for(o=1;o<arguments.length-2;o++)void 0===arguments[o]&&(i[o]=void 0)})),i&&l)for(i.groups=a=cs(null),o=0;o<l.length;o++)a[(s=l[o])[0]]=i[s[1]];return i});var _f=hf;Wt({target:"RegExp",proto:!0,forced:/./.exec!==_f},{exec:_f});var Tf=me("species"),kf=RegExp.prototype,Mf=function(e,t,n,r){var i=me(e),o=!f((function(){var t={};return t[i]=function(){return 7},7!=""[e](t)})),a=o&&!f((function(){var t=!1,n=/a/;return"split"===e&&((n={}).constructor={},n.constructor[Tf]=function(){return n},n.flags="",n[i]=/./[i]),n.exec=function(){return t=!0,null},n[i](""),!t}));if(!o||!a||n){var s=k(/./[i]),c=t(i,""[e],(function(e,t,n,r,i){var a=k(e),c=t.exec;return c===_f||c===kf.exec?o&&!i?{done:!0,value:s(t,n,r)}:{done:!0,value:a(n,t,r)}:{done:!1}}));dt(String.prototype,e,c[0]),dt(kf,i,c[1])}r&&ze(kf[i],"sham",!0)},Nf=me("match"),If=function(e){var t;return j(e)&&(void 0!==(t=e[Nf])?!!t:"RegExp"==I(e))},Of=Ws.charAt,xf=function(e,t,n){return t+(n?Of(e,t).length:1)},Pf=TypeError,Lf=function(e,t){var n=e.exec;if(A(n)){var r=h(n,e,t);return null!==r&&Ce(r),r}if("RegExp"===I(e))return h(_f,e,t);throw Pf("RegExp#exec called on incompatible receiver")},Cf=af.UNSUPPORTED_Y,Ef=4294967295,Af=Math.min,jf=[].push,Vf=k(/./.exec),Bf=k(jf),Rf=k("".slice),Ff=!f((function(){var e=/(?:)/,t=e.exec;e.exec=function(){return t.apply(this,arguments)};var n="ab".split(e);return 2!==n.length||"a"!==n[0]||"b"!==n[1]}));Mf("split",(function(e,t,n){var r;return r="c"=="abbc".split(/(b)*/)[1]||4!="test".split(/(?:)/,-1).length||2!="ab".split(/(?:ab)*/).length||4!=".".split(/(.?)(.?)/).length||".".split(/()()/).length>1||"".split(/.?/).length?function(e,n){var r=Hi(C(this)),i=void 0===n?Ef:n>>>0;if(0===i)return[];if(void 0===e)return[r];if(!If(e))return h(t,r,e,i);for(var o,a,s,c=[],u=(e.ignoreCase?"i":"")+(e.multiline?"m":"")+(e.unicode?"u":"")+(e.sticky?"y":""),f=0,d=new RegExp(e.source,u+"g");(o=h(_f,d,r))&&!((a=d.lastIndex)>f&&(Bf(c,Rf(r,f,o.index)),o.length>1&&o.index<r.length&&Cn(jf,c,Bo(o,1)),s=o[0].length,f=a,c.length>=i));)d.lastIndex===o.index&&d.lastIndex++;return f===r.length?!s&&Vf(d,"")||Bf(c,""):Bf(c,Rf(r,f)),c.length>i?Bo(c,0,i):c}:"0".split(void 0,0).length?function(e,n){return void 0===e&&0===n?[]:h(t,this,e,n)}:t,[function(t,n){var i=C(this),o=null==t?void 0:Z(t,e);return o?h(o,t,i,n):h(r,Hi(i),t,n)},function(e,i){var o=Ce(this),a=Hi(e),s=n(r,o,a,i,r!==t);if(s.done)return s.value;var c=On(o,RegExp),u=o.unicode,f=(o.ignoreCase?"i":"")+(o.multiline?"m":"")+(o.unicode?"u":"")+(Cf?"g":"y"),d=new c(Cf?"^(?:"+o.source+")":o,f),l=void 0===i?Ef:i>>>0;if(0===l)return[];if(0===a.length)return null===Lf(d,a)?[a]:[];for(var p=0,h=0,y=[];h<a.length;){d.lastIndex=Cf?0:h;var v,g=Lf(d,Cf?Rf(a,h):a);if(null===g||(v=Af(St(d.lastIndex+(Cf?h:0)),a.length))===p)h=xf(a,h,u);else{if(Bf(y,Rf(a,p,h)),y.length===l)return y;for(var m=1;m<=g.length-1;m++)if(Bf(y,g[m]),y.length===l)return y;h=p=v}}return Bf(y,Rf(a,p)),y}]}),!Ff,Cf);var zf=TypeError,Df=function(e,t){if(!delete e[t])throw zf("Cannot delete property "+K(t)+" of "+K(e))},Wf=Fi("splice"),Uf=Math.max,qf=Math.min;Wt({target:"Array",proto:!0,forced:!Wf},{splice:function(e,t){var n,r,i,o,a,s,c=se(this),u=wt(c),f=mt(e,u),d=arguments.length;for(0===d?n=r=0:1===d?(n=0,r=u-f):(n=d-2,r=qf(Uf(yt(t),0),u-f)),xc(u+n-r),i=Ba(c,r),o=0;o<r;o++)(a=f+o)in c&&Bi(i,o,c[a]);if(i.length=r,n<r){for(o=f;o<u-r;o++)s=o+n,(a=o+r)in c?c[s]=c[a]:Df(c,s);for(o=u;o>u-r+n;o--)Df(c,o-1)}else if(n>r)for(o=u-r;o>f;o--)s=o+n-1,(a=o+r-1)in c?c[s]=c[a]:Df(c,s);for(o=0;o<n;o++)c[o+f]=arguments[o+2];return c.length=u-r+n,i}});var Jf=Fe.f,Gf=ec.fastKey,Hf=ut.set,$f=ut.getterFor,Qf={getConstructor:function(e,t,n,r){var i=e((function(e,i){ln(e,o),Hf(e,{type:t,index:cs(null),first:void 0,last:void 0,size:0}),d||(e.size=0),null!=i&&bi(i,e[r],{that:e,AS_ENTRIES:n})})),o=i.prototype,a=$f(t),s=function(e,t,n){var r,i,o=a(e),s=c(e,t);return s?s.value=n:(o.last=s={index:i=Gf(t,!0),key:t,value:n,previous:r=o.last,next:void 0,removed:!1},o.first||(o.first=s),r&&(r.next=s),d?o.size++:e.size++,"F"!==i&&(o.index[i]=s)),e},c=function(e,t){var n,r=a(e),i=Gf(t);if("F"!==i)return r.index[i];for(n=r.first;n;n=n.next)if(n.key==t)return n};return bo(o,{clear:function(){for(var e=a(this),t=e.index,n=e.first;n;)n.removed=!0,n.previous&&(n.previous=n.previous.next=void 0),delete t[n.index],n=n.next;e.first=e.last=void 0,d?e.size=0:this.size=0},delete:function(e){var t=this,n=a(t),r=c(t,e);if(r){var i=r.next,o=r.previous;delete n.index[r.index],r.removed=!0,o&&(o.next=i),i&&(i.previous=o),n.first==r&&(n.first=i),n.last==r&&(n.last=o),d?n.size--:t.size--}return!!r},forEach:function(e){for(var t,n=a(this),r=An(e,arguments.length>1?arguments[1]:void 0);t=t?t.next:n.first;)for(r(t.value,t.key,this);t&&t.removed;)t=t.previous},has:function(e){return!!c(this,e)}}),bo(o,n?{get:function(e){var t=c(this,e);return t&&t.value},set:function(e,t){return s(this,0===e?0:e,t)}}:{add:function(e){return s(this,e=0===e?0:e,e)}}),d&&Jf(o,"size",{get:function(){return a(this).size}}),i},setStrong:function(e,t,n){var r=t+" Iterator",i=$f(t),o=$f(r);Ls(e,t,(function(e,t){Hf(this,{type:r,target:e,state:i(e),kind:t,last:void 0})}),(function(){for(var e=o(this),t=e.kind,n=e.last;n&&n.removed;)n=n.previous;return e.target&&(e.last=n=n?n.next:e.state.first)?"keys"==t?{value:n.key,done:!1}:"values"==t?{value:n.value,done:!1}:{value:[n.key,n.value],done:!1}:(e.target=void 0,{value:void 0,done:!0})}),n?"entries":"values",!n,!0),fn(t)}};tc("Set",(function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}}),Qf);var Kf=za.map,Xf=Fi("map");Wt({target:"Array",proto:!0,forced:!Xf},{map:function(e){return Kf(this,e,arguments.length>1?arguments[1]:void 0)}});var Yf=Tr&&Tr.prototype,Zf=!!Tr&&f((function(){Yf.finally.call({then:function(){}},(function(){}))}));if(Wt({target:"Promise",proto:!0,real:!0,forced:Zf},{finally:function(e){var t=On(this,B("Promise")),n=A(e);return this.then(n?function(n){return xi(t,e()).then((function(){return n}))}:e,n?function(n){return xi(t,e()).then((function(){throw n}))}:e)}}),A(Tr)){var ed=B("Promise").prototype.finally;Yf.finally!==ed&&dt(Yf,"finally",ed,{unsafe:!0})}var td=function(){function e(t){this._promise=t,this.taskIds=[],null!==e.currentTask&&(e.currentTask.destroy(),e.currentTask=null),e.setCurrentTask(this),this.status=2,this.event=exparser.EventBus.create("App Route Callback")}return e.setCurrentTask=function(t){e.currentTask=t},e.getCurrentTask=function(){return e.currentTask},e.prototype.addTask=function(e){var t=this.event.add(e);this.taskIds.push(t)},e.prototype.clearTask=function(){for(var e=0,t=this.taskIds;e<t.length;e++){var n=t[e];this.event.remove(n)}this.taskIds.length=0},e.prototype.resolve=function(){this.status=0,this.event.call(void 0,[])},e.prototype.reject=function(){this.status=1},e.prototype.destroy=function(){var t=this;e.currentTask===this&&(e.currentTask=null),this.clearTask(),this.event=null,"Promise"===$a(this._promise)?Promise.race([Promise.resolve(),this._promise]).catch((function(e){})).finally((function(){return t._promise=null})):this._promise=null},Object.defineProperty(e.prototype,"resolved",{get:function(){return 0===this.status},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"rejected",{get:function(){return 1===this.status},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"pending",{get:function(){return 2===this.status},enumerable:!1,configurable:!0}),e.currentTask=null,e}(),nd=!1,rd="custom-tab-bar/index";function id(e,t,n){if(void 0===n&&(n=!1),n&&(t=function(e){if("string"!=typeof e)return e;var t=e.split("?"),n=t[0],r=t[1];return n+=".wxml",void 0!==r?n+"?"+r:n}(t)),0===t.indexOf("/"))return t.substr(1);if(0===t.indexOf("./"))return id(e,t.substr(2));for(var r=t.split("/"),i=r.length,o=0;o<i&&".."===r[o];)o+=1;r.splice(0,o);var a=0<e.length?e.split("/"):[];return o>a.length-1?r.join("/"):(a.splice(a.length-o-1,o+1),a.concat(r).join("/"))}function od(e){if(__routePackages__){if(Object.prototype.hasOwnProperty.call(__routePackages__,e))return __routePackages__[e];throw new Error("getPackageNameByRoute 未找到对应路由: "+e)}throw new Error("__routePackages__ not define.")}var ad=new Set;function sd(e){return ad.has(e)}function cd(e,t){t?ad.add(e):ad.has(e)&&ad.delete(e)}var ud=function(e,t){return Ci(this,void 0,void 0,(function(){var n;return Ei(this,(function(r){switch(r.label){case 0:return!1!==sd(e)?[3,2]:[4,new Promise((function(t,n){didiJsBridge.invoke({method:"loadJSFileToDataThread",data:{package:e},callback:function(r){r&&r.data&&r.data.success?(cd(e,!0),t()):n(r.data.errMsg||"loadJSFileToDataThread failed ("+e+").")}})}))];case 1:r.sent(),r.label=2;case 2:return __define__(e),(n=new Set).add(t),fd(t,n),function(e){if(!__ddConfig.tabBar||!0!==__ddConfig.tabBar.custom)return;!nd&&function(e){var t=__ddConfig.tabBar&&__ddConfig.tabBar.list;if(t instanceof Array&&(t=t.map((function(e){return e&&e.pagePath}))).indexOf(e)>=0)return!0;return!1}(e)&&(__ddRoute=rd,__ddRouteBegin=!0,__ddAppCurrentFile__=rd+".js",require(rd+".js"),nd=!0)}(t),globalThis._=void 0,[2,e]}}))}))};var fd=function t(n,r){var i=__ddAppCode__[n+".json"],o=__ddConfig.isLazyLoad;if("object"===e(i)&&i.usingComponents){var a=i.usingComponents,s=i.componentPlaceholder||[];Object.keys(a).forEach((function(e){if(!o||o&&!s[e]){var i=id(n,a[e]);r.has(i)||(r.add(i),t(i,r))}}))}__ddRoute=n,__ddRouteBegin=!0,__ddAppCurrentFile__=n+".js",require(n+".js")};var ld=!1;function pd(e,t,n){if(void 0===n&&(n=!1),n||!ld||globalThis.isBrowser){var r=id(__appServiceEngine__.getCurrentRoute(),e.split("?")[0]),i=od(r);ld=!0,function(e){return new Promise((function(t,n){didiJsBridge.invoke({method:"loadSubPackage",data:{package:e},callback:function(e){isDevTools&&"devtools"===__ddConfig.platform&&e&&t(),e&&e.data&&e.data.success?t():n(e.data.errMsg)}})}))}(i).then((function(){var e=new td;t(i),ud(i,r).then((function(){return e.resolve()})).catch((function(t){e.reject(),Reporter.errorReport({key:"service-error",type:"evaluateLogic",error:"[service-error]: evaluateLogic error: "+t}),Reporter.ravenReport("pub_saga_error_message_bt",{key:"service-error",type:"evaluateLogic",error:"[service-error]: evaluateLogic error: "+t,fail:function(e){}})})).finally((function(){e.clearTask(),ld=!1}))})).catch((function(e){ld=!1,Reporter.errorReport({key:"service-error",type:"loadSubpackageError",error:"[service-error]: load Subpackage error "+e}),Reporter.ravenReport("pub_saga_error_message_bt",{key:"service-error",type:"loadSubpackageError",error:"[service-error]: load Subpackage error "+e,fail:function(e){}})}))}}var hd=function(e){var t=e||{},n=t.delta,r=void 0===n?1:n,i=t.success,o=t.fail,a=t.complete;if(window.isBrowser)return window.parent.postMessage({event:"navigateBack",delta:r,openType:"navigateBack"},"*"),void qu("AppRoute").emit({openType:"navigateBack",webViewId:1});didiJsBridge.invoke({method:"navigateBack",data:{delta:r,openType:"navigateBack",stackId:currentStackId},callback:function(e){e&&e.data&&e.data.success?i&&i():o&&o(),a&&a();var t=+(e.data&&e.data.webViewId);qu("AppRoute").emit({openType:"navigateBack",webViewId:t})}})};function yd(){if(window.isBrowser)return{query:{}};var e=didiJsBridge.invoke({method:"getLaunchOptionsSync",data:{}});try{e="string"==typeof e?JSON.parse(e):e}catch(e){}return e||{}}function vd(){if(window.isBrowser)return{query:{}};var e=didiJsBridge.invoke({method:"getEnterOptionsSync",data:{stackId:currentStackId}});try{e="string"==typeof e?JSON.parse(e):e}catch(e){}return e||{}}didiJsBridge.on({event:"navigateBackNative"},(function(e){var t=+e.webViewId;qu("AppRoute").emit({openType:"navigateBack",webViewId:t})}));var gd=Math.floor,md=k("".charAt),bd=k("".replace),Sd=k("".slice),wd=/\$([$&'`]|\d{1,2}|<[^>]*>)/g,_d=/\$([$&'`]|\d{1,2})/g,Td=function(e,t,n,r,i,o){var a=n+e.length,s=r.length,c=_d;return void 0!==i&&(i=se(i),c=wd),bd(o,c,(function(o,c){var u;switch(md(c,0)){case"$":return"$";case"&":return e;case"`":return Sd(t,0,n);case"'":return Sd(t,a);case"<":u=i[Sd(c,1,-1)];break;default:var f=+c;if(0===f)return o;if(f>s){var d=gd(f/10);return 0===d?o:d<=s?void 0===r[d-1]?md(c,1):r[d-1]+md(c,1):o}u=r[f-1]}return void 0===u?"":u}))},kd=me("replace"),Md=Math.max,Nd=Math.min,Id=k([].concat),Od=k([].push),xd=k("".indexOf),Pd=k("".slice),Ld="$0"==="a".replace(/./,"$0"),Cd=!!/./[kd]&&""===/./[kd]("a","$0");Mf("replace",(function(e,t,n){var r=Cd?"$":"$0";return[function(e,n){var r=C(this),i=null==e?void 0:Z(e,kd);return i?h(i,e,r,n):h(t,Hi(r),e,n)},function(e,i){var o=Ce(this),a=Hi(e);if("string"==typeof i&&-1===xd(i,r)&&-1===xd(i,"$<")){var s=n(t,o,a,i);if(s.done)return s.value}var c=A(i);c||(i=Hi(i));var u=o.global;if(u){var f=o.unicode;o.lastIndex=0}for(var d=[];;){var l=Lf(o,a);if(null===l)break;if(Od(d,l),!u)break;""===Hi(l[0])&&(o.lastIndex=xf(a,St(o.lastIndex),f))}for(var p,h="",y=0,v=0;v<d.length;v++){for(var g=Hi((l=d[v])[0]),m=Md(Nd(yt(l.index),a.length),0),b=[],S=1;S<l.length;S++)Od(b,void 0===(p=l[S])?p:String(p));var w=l.groups;if(c){var _=Id([g],b,m,a);void 0!==w&&Od(_,w);var T=Hi(Cn(i,void 0,_))}else T=Td(g,a,m,b,w,i);m>=y&&(h+=Pd(a,y,m)+T,y=m+g.length)}return h+Pd(a,y)}]}),!!f((function(){var e=/./;return e.exec=function(){var e=[];return e.groups={a:"7"},e},"7"!=="".replace(e,"$<a>")}))||!Ld||Cd);var Ed={lastRoute:"",lastOpenType:"",query:{},runningStatus:"active",navigatorLock:!1,openUrlLock:!1,possessingBackgroundAudioPlayer:!1,webviewEventCallback:null,hanged:!1,appStatus:0,navigationBarTitleMap:{},currentWebviewId:void 0,lastRawQuery:null},Ad=function(e,t){var n=e.data;void 0===t&&(t=0),Bd.handleRewriteRoute(n)&&("appLaunch"!==n.openType&&"autoReLaunch"!==n.openType&&(n.path=function(e){return"string"==typeof e?-1!==e.indexOf("?")?e.replace(/\.html\?/,"?"):e.replace(/\.html$/,""):e}(n.path),n.webViewId=void 0!==n.webViewId?n.webViewId:t,Ed.lastRoute=n.path||"",Ed.lastRawQuery=n.query&&JSON.parse(JSON.stringify(n.query))||{},Ed.lastOpenType=n.openType),Ed.query=n.query,Ed.currentWebviewId=n.webViewId,didiJsBridge.publish({event:"onAppRoute",data:{},webViewId:n.webViewId}),qu("AppRoute").emit(n))},jd=qu("AppRoute").internalOnMethod,Vd=qu("AppRoute").internalOffMethod;didiJsBridge.on({event:"switchTabNotification"},(function(e){void 0===e&&(e={data:{toRoute:"",toWebViewId:"",query:{}}});var t=e.data,n=t.toRoute;0===n.indexOf("plugin://imPlugin")&&(n="__dimina__/empty/empty");var r=t.toIndex;t.fromNative&&__ddConfig&&__ddConfig.tabBar&&__ddConfig.tabBar.list&&__ddConfig.tabBar.list[r]&&tabBarTapList.push({index:r,pagePath:(__ddConfig.tabBar.list[r].pagePath||"").replace(/\.html$/,""),text:__ddConfig.tabBar.list[r].text}),Ad({data:{openType:"switchTab",path:n,webViewId:t.toWebViewId,query:t.query}})}));var Bd={launch:function(e,t){pd(e.url,(function(n){!function(e,t){didiJsBridge.invoke({method:"launch",data:{url:e.url,openType:e.openType,query:e.query,package:e.package,stackId:t}})}(Li(Li({},e),{package:n}),t)}),!0)},reLaunch:function(e){pd(e.url,(function(t){!function(e){var t=e.url,n=e.success,r=e.fail,i=e.complete;window.isBrowser?window.parent.postMessage({event:"reLaunch",route:t,openType:"reLaunch"},"*"):didiJsBridge.invoke({method:"reLaunch",data:{url:id(__appServiceEngine__.getCurrentRoute(),t),openType:"reLaunch",package:e.package,stackId:currentStackId},callback:function(e){e&&e.data&&e.data.success?n&&n():r&&r(),i&&i()}})}(Li(Li({},e),{package:t}))}))},navigateTo:function(e){pd(e.url,(function(t){!function(e){var t=e.url,n=e.success,r=e.fail,i=e.complete;globalThis.isBrowser?window.parent.postMessage({event:"navigateTo",route:t,openType:"navigateTo"},"*"):didiJsBridge.invoke({method:"navigateTo",data:{url:id(__appServiceEngine__.getCurrentRoute(),t),openType:"navigateTo",package:e.package,stackId:currentStackId},callback:function(e){e&&e.data&&e.data.success?n&&n():r&&r(),i&&i()}})}(Li(Li({},e),{package:t}))}))},redirectTo:function(e){pd(e.url,(function(t){!function(e){var t=e.url,n=e.success,r=e.fail,i=e.complete;window.isBrowser?window.parent.postMessage({event:"redirectTo",route:id(__appServiceEngine__.getCurrentRoute(),t),openType:"redirectTo"},"*"):didiJsBridge.invoke({method:"redirectTo",data:{url:id(__appServiceEngine__.getCurrentRoute(),t),openType:"redirectTo",package:e.package,stackId:currentStackId},callback:function(e){e&&e.data&&e.data.success?n&&n():r&&r(),i&&i()}})}(Li(Li({},e),{package:t}))}))},handleRewriteRoute:function(e){if(["dismissPip","navigateBack"].includes(e.openType))return!1;if(!e.notFound)return!0;if(/^[-_+a-z]+:\/\//i.test(e.rawPath))try{return didiJsBridge.invoke({method:"rewriteRoute",data:{},webViewId:"",invokeId:""}),!0}catch(e){return!1}return!1},navigateBack:hd,switchTab:function(e){pd(e.url,(function(t){!function(e){var t=e.url,n=e.success,r=e.fail;if(window.isBrowser){var i=t.split("?"),o=i[0];return 2===i.length&&(o=o+"&"+i[1]),void window.parent.postMessage({event:"switchTab",route:id(__appServiceEngine__.getCurrentRoute(),o),openType:"switchTab"},"*")}didiJsBridge.invoke({method:"switchTab",data:{url:t,openType:"switchTab",package:e.package,stackId:currentStackId},callback:function(e){e&&e.data&&e.data.success?n&&n():r&&r()}})}(Li(Li({},e),{package:t}))}))},navigateToMiniProgram:function(e){if(!e.appId)return e.fail&&e.fail("缺少appId"),void(e.complete&&e.complete());Qu({event:"navigateToMiniProgram",data:{appId:e.appId,path:e.path,extraData:e.extraData,envVersion:e.envVersion||"release"},success:e.success,fail:e.fail,complete:e.complete})},navigateToDimina:function(e){if(!e.appId)return e.fail&&e.fail("缺少appId"),void(e.complete&&e.complete());Qu({event:"navigateToDimina",data:{appId:e.appId,path:e.path,extraData:e.extraData,remoteUrl:e.remoteUrl||"",hasCapsuleButton:e.hasCapsuleButton||!1},success:e.success,fail:e.fail,complete:e.complete})}};didiJsBridge.subscribe({event:"H5navigateTo"},(function(e){!e||e.data,Bd.navigateTo(e.data.params)})),didiJsBridge.subscribe({event:"H5navigateBack"},(function(e){!e||e.data,Bd.navigateBack(e.data.params)})),didiJsBridge.subscribe({event:"H5redirectTo"},(function(e){!e||e.data,Bd.redirectTo(e.data.params)})),didiJsBridge.subscribe({event:"H5switchTab"},(function(e){!e||e.data,Bd.switchTab(e.data.params)})),didiJsBridge.subscribe({event:"H5reLaunch"},(function(e){!e||e.data,Bd.reLaunch(e.data.params)})),didiJsBridge.subscribe({event:"H5goSuperAppTab"},(function(){Rd()})),didiJsBridge.subscribe({event:"H5openLocation"},(function(e){var t;void 0===(t=e.data)&&(t={latitude:0,longitude:0}),Qu({event:"openLocation",data:{latitude:t.latitude,longitude:t.longitude,scale:t.scale||18,name:t.name,address:t.address},success:t.success,fail:t.fail,complete:t.complete})}));var Rd=function(){var e,t,n,r=(vd().query||{}).fromDidiTabbar||!1;"string"==typeof r&&(r="true"===r),r?(void 0===n&&(n={}),Qu({event:"closeDimina",data:{},success:n.success,fail:n.fail,complete:n.complete})):(e=!1,(t=__appServiceEngine__.getCurrentPagesByDomain(""))&&t.length&&t[0].route.indexOf("pages/index/index")>-1&&(e=!0),hd(e?{delta:10}:{delta:10,success:function(){Bd.redirectTo({url:"/pages/index/index"})}}))},Fd=eo.trim,zd=u.parseInt,Dd=u.Symbol,Wd=Dd&&Dd.iterator,Ud=/^[+-]?0x/i,qd=k(Ud.exec),Jd=8!==zd($i+"08")||22!==zd($i+"0x16")||Wd&&!f((function(){zd(Object(Wd))}))?function(e,t){var n=Fd(Hi(e));return zd(n,t>>>0||(qd(Ud,n)?16:10))}:zd;Wt({global:!0,forced:parseInt!=Jd},{parseInt:Jd});var Gd=RegExp.prototype,Hd=qe.PROPER,$d="toString",Qd=RegExp.prototype.toString,Kd=f((function(){return"/a/b"!=Qd.call({source:"a",flags:"b"})})),Xd=Hd&&Qd.name!=$d;(Kd||Xd)&&dt(RegExp.prototype,$d,(function(){var e=Ce(this),t=Hi(e.source),n=Hi(function(e){var t=e.flags;return void 0!==t||"flags"in Gd||ue(e,"flags")||!R(Gd,e)?t:h(tf,e)}(e));return"/"+t+"/"+n}),{unsafe:!0});var Yd=eo.trim,Zd=k("".charAt),el=u.parseFloat,tl=u.Symbol,nl=tl&&tl.iterator,rl=1/el($i+"-0")!=-1/0||nl&&!f((function(){el(Object(nl))}))?function(e){var t=Yd(Hi(e)),n=el(t);return 0===n&&"-"==Zd(t,0)?-0:n}:el;Wt({global:!0,forced:parseFloat!=rl},{parseFloat:rl});var il,ol=TypeError,al=function(e){if(If(e))throw ol("The method doesn't accept regular expressions");return e},sl=me("match"),cl=Oe.f,ul=k("".endsWith),fl=k("".slice),dl=Math.min,ll=function(e){var t=/./;try{"/./"[e](t)}catch(n){try{return t[sl]=!1,"/./"[e](t)}catch(e){}}return!1}("endsWith"),pl=!(ll||(il=cl(String.prototype,"endsWith"),!il||il.writable));Wt({target:"String",proto:!0,forced:!pl&&!ll},{endsWith:function(e){var t=Hi(C(this));al(e);var n=arguments.length>1?arguments[1]:void 0,r=t.length,i=void 0===n?r:dl(St(n),r),o=Hi(e);return ul?ul(t,o,i):fl(t,i-o.length,i)===o}});var hl,yl={aliceblue:"#f0f8ff",antiquewhite:"#faebd7",aqua:"#00ffff",aquamarine:"#7fffd4",azure:"#f0ffff",beige:"#f5f5dc",bisque:"#ffe4c4",black:"#000000",blanchedalmond:"#ffebcd",blue:"#0000ff",blueviolet:"#8a2be2",brown:"#a52a2a",burlywood:"#deb887",cadetblue:"#5f9ea0",chartreuse:"#7fff00",chocolate:"#d2691e",coral:"#ff7f50",cornflowerblue:"#6495ed",cornsilk:"#fff8dc",crimson:"#dc143c",cyan:"#00ffff",darkblue:"#00008b",darkcyan:"#008b8b",darkgoldenrod:"#b8860b",darkgray:"#a9a9a9",darkgrey:"#a9a9a9",darkgreen:"#006400",darkkhaki:"#bdb76b",darkmagenta:"#8b008b",darkolivegreen:"#556b2f",darkorange:"#ff8c00",darkorchid:"#9932cc",darkred:"#8b0000",darksalmon:"#e9967a",darkseagreen:"#8fbc8f",darkslateblue:"#483d8b",darkslategray:"#2f4f4f",darkslategrey:"#2f4f4f",darkturquoise:"#00ced1",darkviolet:"#9400d3",deeppink:"#ff1493",deepskyblue:"#00bfff",dimgray:"#696969",dimgrey:"#696969",dodgerblue:"#1e90ff",firebrick:"#b22222",floralwhite:"#fffaf0",forestgreen:"#228b22",fuchsia:"#ff00ff",gainsboro:"#dcdcdc",ghostwhite:"#f8f8ff",gold:"#ffd700",goldenrod:"#daa520",gray:"#808080",grey:"#808080",green:"#008000",greenyellow:"#adff2f",honeydew:"#f0fff0",hotpink:"#ff69b4",indianred:"#cd5c5c",indigo:"#4b0082",ivory:"#fffff0",khaki:"#f0e68c",lavender:"#e6e6fa",lavenderblush:"#fff0f5",lawngreen:"#7cfc00",lemonchiffon:"#fffacd",lightblue:"#add8e6",lightcoral:"#f08080",lightcyan:"#e0ffff",lightgoldenrodyellow:"#fafad2",lightgray:"#d3d3d3",lightgrey:"#d3d3d3",lightgreen:"#90ee90",lightpink:"#ffb6c1",lightsalmon:"#ffa07a",lightseagreen:"#20b2aa",lightskyblue:"#87cefa",lightslategray:"#778899",lightslategrey:"#778899",lightsteelblue:"#b0c4de",lightyellow:"#ffffe0",lime:"#00ff00",limegreen:"#32cd32",linen:"#faf0e6",magenta:"#ff00ff",maroon:"#800000",mediumaquamarine:"#66cdaa",mediumblue:"#0000cd",mediumorchid:"#ba55d3",mediumpurple:"#9370db",mediumseagreen:"#3cb371",mediumslateblue:"#7b68ee",mediumspringgreen:"#00fa9a",mediumturquoise:"#48d1cc",mediumvioletred:"#c71585",midnightblue:"#191970",mintcream:"#f5fffa",mistyrose:"#ffe4e1",moccasin:"#ffe4b5",navajowhite:"#ffdead",navy:"#000080",oldlace:"#fdf5e6",olive:"#808000",olivedrab:"#6b8e23",orange:"#ffa500",orangered:"#ff4500",orchid:"#da70d6",palegoldenrod:"#eee8aa",palegreen:"#98fb98",paleturquoise:"#afeeee",palevioletred:"#db7093",papayawhip:"#ffefd5",peachpuff:"#ffdab9",peru:"#cd853f",pink:"#ffc0cb",plum:"#dda0dd",powderblue:"#b0e0e6",purple:"#800080",rebeccapurple:"#663399",red:"#ff0000",rosybrown:"#bc8f8f",royalblue:"#4169e1",saddlebrown:"#8b4513",salmon:"#fa8072",sandybrown:"#f4a460",seagreen:"#2e8b57",seashell:"#fff5ee",sienna:"#a0522d",silver:"#c0c0c0",skyblue:"#87ceeb",slateblue:"#6a5acd",slategray:"#708090",slategrey:"#708090",snow:"#fffafa",springgreen:"#00ff7f",steelblue:"#4682b4",tan:"#d2b48c",teal:"#008080",thistle:"#d8bfd8",tomato:"#ff6347",turquoise:"#40e0d0",violet:"#ee82ee",wheat:"#f5deb3",white:"#ffffff",whitesmoke:"#f5f5f5",yellow:"#ffff00",yellowgreen:"#9acd32",transparent:"#00000000"};function vl(e,t,n,r){void 0===n&&(n=""),void 0===r&&(r="");var i="canvas_"+e+"_"+t+"_"+n+"_";return r&&r!==__virtualDOM__.getRootNodeId(e)&&(i+=r),i}function gl(e,t,n){return void 0===n&&(n={}),Ku({event:t+"Canvas",data:Li({canvasId:e},n)})}function ml(e){return parseInt(e,16)}function bl(e){var t=Number(Math.min(hl.MAX_COLOR_VALUE,Math.max(Math.round(parseFloat(e)),hl.MIN_COLOR_VALUE))).toString(16);return 1===t.length&&(t="0"+t),t}function Sl(e){return Math.min(hl.MAX_COLOR_VALUE,Math.max(parseFloat(e),hl.MIN_COLOR_VALUE))}function wl(e){var t=e.slice(0,3).map((function(e){return""+Math.round(e)}));if(4===e.length){var n=e[3].toFixed(3).replace(/0+$/g,"");n.endsWith(".")&&(n="0"),t.push(n)}return t}!function(e){e[e.MAX_COLOR_VALUE=255]="MAX_COLOR_VALUE",e[e.MIN_COLOR_VALUE=0]="MIN_COLOR_VALUE"}(hl||(hl={}));var _l={};function Tl(e,t){t?_l[e]&&delete _l[e].nodeId:delete _l[e]}qu("skiaCanvasLoadFontFace");var kl={},Ml=1;didiJsBridge.subscribe({event:"pageScrollDone"},(function(e){var t=e.data,n=void 0===t?{}:t;if(n.callBackId>0&&kl[n.callBackId]){var r=kl[n.callBackId];delete kl[n.callBackId],n.success?"function"==typeof r.success&&r.success():"function"==typeof r.fail&&r.fail(),"function"==typeof r.complete&&r.complete()}}));var Nl,Il=za.filter,Ol=Fi("filter");Wt({target:"Array",proto:!0,forced:!Ol},{filter:function(e){return Il(this,e,arguments.length>1?arguments[1]:void 0)}});var xl=function(){function e(){this.entryList=new Ll}return e.prototype.createObserver=function(e){var t=this,n=new Pl(e);return didiJsBridge.on({event:"performanceEntries",isSustain:!0},(function(e){var r,i;if(e){var o=(null===(r=null==e?void 0:e.data)||void 0===r?void 0:r.entryList)&&JSON.parse(null===(i=null==e?void 0:e.data)||void 0===i?void 0:i.entryList)||[];o&&(t.entryList.push(o),n.notify(o))}})),n},e.prototype.getEntries=function(){return this.entryList.getEntries()},e.prototype.getEntriesByName=function(e,t){return this.entryList.getEntriesByName(e,t)},e.prototype.getEntriesByType=function(e){return this.entryList.getEntriesByType(e)},e.prototype.setBufferSize=function(){},e}(),Pl=function(){function e(e){this.entryTypes=[],this.callback=e}return e.prototype.observe=function(e){this.connected=!0,this.entryTypes=e.entryTypes},e.prototype.notify=function(e){var t=this;if(this.connected){var n=new Ll;n.push(e.filter((function(e){var n=!1;return t.entryTypes&&t.entryTypes.length>0&&t.entryTypes.forEach((function(t){e.entryType===t&&(n=!0)})),n}))),this.callback(n)}},e.prototype.disconnect=function(){this.connected=!1},e}(),Ll=function(){function e(){this._list=[]}return e.prototype.push=function(e){this._list=this._list.concat(e)},e.prototype.getEntriesByName=function(e,t){return this._entryFilter(e,t)},e.prototype.getEntriesByType=function(e){return this._entryFilter(null,e)},e.prototype._entryFilter=function(e,t){return this._list.filter((function(n){return(!e||e===n.name)&&(!t||t===n.entryType)}))},e.prototype.getEntries=function(){return this._list},e}();function Cl(e,t){for(var n=e.split("."),r=t.split("."),i=Math.max(n.length,r.length);n.length<i;)n.push("0");for(;r.length<i;)r.push("0");for(var o=0;o<i;o++){var a=parseInt(n[o]),s=parseInt(r[o]);if(a>s)return 1;if(a<s)return-1}return 0}var El,Al,jl={"image.webp":{version:"1.4.0",dmVersion:"1.0.0"},view:{version:"1.0.0",dmVersion:"1.0.0"},text:{version:"1.0.0",dmVersion:"1.0.0"},image:{version:"1.0.0",dmVersion:"1.0.0"},label:{version:"1.0.0",dmVersion:"1.0.0"},input:{version:"1.0.0",dmVersion:"1.0.0"},textarea:{version:"1.0.0",dmVersion:"1.0.0"},form:{version:"1.0.0",dmVersion:"1.0.0"},button:{version:"1.0.0",dmVersion:"1.0.0"},"rich-text":{version:"1.0.0",dmVersion:"1.0.0"},swiper:{version:"1.0.0",dmVersion:"1.0.0"},picker:{version:"1.0.0",dmVersion:"1.0.0"},"swiper-item":{version:"1.0.0",dmVersion:"1.0.0"},navigator:{version:"1.0.0",dmVersion:"1.0.0"},radio:{version:"1.0.0",dmVersion:"1.0.0"},"radio-group":{version:"1.0.0",dmVersion:"1.0.0"},switch:{version:"1.0.0",dmVersion:"1.0.0"},slider:{version:"1.0.0",dmVersion:"1.0.0"},"scroll-view":{version:"1.0.0",dmVersion:"1.0.0"},map:{version:"1.0.0",dmVersion:"1.0.0"},"functional-map":{version:"1.0.0",dmVersion:"1.0.0"},"cover-view":{version:"1.0.0",dmVersion:"1.0.0"},checkbox:{version:"1.0.0",dmVersion:"1.0.0"},"checkbox-group":{version:"1.0.0",dmVersion:"1.0.0"},"web-view":{version:"1.0.0",dmVersion:"1.0.0"},"movable-area":{version:"1.0.0",dmVersion:"1.0.0"},"movable-view":{version:"1.0.0",dmVersion:"1.0.0"},nextTick:{version:"1.0.0",dmVersion:"1.0.0"},createAnimation:{version:"1.0.0",dmVersion:"1.0.0"},createSelectorQuery:{version:"1.0.0",dmVersion:"1.0.0"},createIntersectionObserver:{version:"1.0.0",dmVersion:"1.0.0"},createMediaQueryObserver:{version:"1.0.0",dmVersion:"1.0.0"},onAppHide:{version:"1.0.0",dmVersion:"1.0.0"},startPullDownRefresh:{version:"1.0.0",dmVersion:"1.0.0"},stopPullDownRefresh:{version:"1.0.0",dmVersion:"1.0.0"},enablePullDownRefresh:{version:"1.0.0",dmVersion:"1.0.0"},disablePullDownRefresh:{version:"1.0.0",dmVersion:"1.0.0"},navigateTo:{version:"1.0.0",dmVersion:"1.0.0"},redirectTo:{version:"1.0.0",dmVersion:"1.0.0"},navigateBack:{version:"1.0.0",dmVersion:"1.0.0"},switchTab:{version:"1.0.0",dmVersion:"1.0.0"},reLaunch:{version:"1.0.0",dmVersion:"1.0.0"},launch:{version:"1.0.0",dmVersion:"1.0.0"},getRealRoute:{version:"1.0.0",dmVersion:"1.0.0"},getLocalFilePath:{version:"1.0.0",dmVersion:"1.0.0"},getStorageSync:{version:"1.0.0",dmVersion:"1.0.0"},setStorageSync:{version:"1.0.0",dmVersion:"1.0.0"},removeStorageSync:{version:"1.0.0",dmVersion:"1.0.0"},removeStorage:{version:"1.0.0",dmVersion:"1.0.0"},getStorageInfo:{version:"1.0.0",dmVersion:"1.0.0"},setStorage:{version:"1.0.0",dmVersion:"1.0.0"},clearStorage:{version:"1.0.0",dmVersion:"1.0.0"},setBackgroundFetchToken:{version:"1.12.0",dmVersion:"1.3.0"},getBackgroundFetchData:{version:"1.12.0",dmVersion:"1.3.0"},showLoading:{version:"1.0.0",dmVersion:"1.0.0"},hideLoading:{version:"1.0.0",dmVersion:"1.0.0"},showToast:{version:"1.0.0",dmVersion:"1.0.0"},showModal:{version:"1.0.0",dmVersion:"1.0.0"},getImageInfo:{version:"1.0.0",dmVersion:"1.0.0"},getSystemInfo:{version:"1.0.0",dmVersion:"1.0.0"},getSystemInfoSync:{version:"1.0.0",dmVersion:"1.0.0"},setNavigationBarTitle:{version:"1.0.0",dmVersion:"1.0.0"},saveImageToPhotosAlbum:{version:"1.0.0",dmVersion:"1.0.0"},request:{version:"1.0.0",dmVersion:"1.0.0"},RequestTask:{version:"2.9.0",dmVersion:"1.7.6"},getLocation:{version:"1.0.0",dmVersion:"1.0.0"},getLaunchOptionsSync:{version:"1.0.0",dmVersion:"1.0.0"},chooseImage:{version:"1.0.0",dmVersion:"1.0.0"},scanCode:{version:"1.0.0",dmVersion:"1.0.0"},makePhoneCall:{version:"1.0.0",dmVersion:"1.0.0"},getSavedFileInfo:{version:"1.0.0",dmVersion:"1.0.0"},downloadFile:{version:"1.0.0",dmVersion:"1.0.0"},DownloadTask:{version:"2.11.0",dmVersion:"1.7.6"},getFileInfo:{version:"1.0.0",dmVersion:"1.0.0"},saveFile:{version:"1.0.0",dmVersion:"1.0.0"},removeSavedFile:{version:"1.0.0",dmVersion:"1.0.0"},uploadFile:{version:"1.0.0",dmVersion:"1.0.0"},UploadTask:{version:"2.9.0",dmVersion:"1.7.6"},setClipboardData:{version:"1.0.0",dmVersion:"1.0.0"},getClipboardData:{version:"1.0.0",dmVersion:"1.0.0"},getFileSystemManager:{version:"1.0.0",dmVersion:"1.0.0"},onAppRoute:{version:"1.0.0",dmVersion:"1.0.0"},canIUse:{version:"1.0.0",dmVersion:"1.0.0"},getUpdateManager:{version:"1.0.0",dmVersion:"1.0.0"},reportEvent:{version:"11.0.0",dmVersion:"11.0.0"},reportAnalytics:{version:"1.0.0",dmVersion:"1.0.0"},navigateToMiniProgram:{version:"1.0.0",dmVersion:"1.0.0"},authorize:{version:"1.14.0",dmVersion:"1.3.0"},openSetting:{version:"1.0.0",dmVersion:"1.0.0"},getSetting:{version:"1.0.0",dmVersion:"1.0.0"},setNavigationBarColor:{version:"1.0.0",dmVersion:"1.0.0"},customShare:{version:"1.0.0",dmVersion:"1.0.0"},showShareEntrance:{version:"1.0.0",dmVersion:"1.0.0"},hideShareEntrance:{version:"1.0.0",dmVersion:"1.0.0"},shareWeixinAppmsg:{version:"1.0.0",dmVersion:"1.0.0"},shareWeixinTimeline:{version:"1.0.0",dmVersion:"1.0.0"},shareMessage:{version:"1.0.0",dmVersion:"1.0.0"},getMenuButtonBoundingClientRect:{version:"1.0.0",dmVersion:"1.0.0"},pageScrollTo:{version:"1.0.0",dmVersion:"1.0.0"},previewImage:{version:"1.0.0",dmVersion:"1.0.0"},requestPayment:{version:"1.0.0",dmVersion:"1.0.0"},extBridge:{version:"1.0.0",dmVersion:"1.0.0"},setTabBarBadge:{version:"1.0.0",dmVersion:"1.0.0"},openLocation:{version:"1.0.0",dmVersion:"1.0.0"},showCapsuleButton:{version:"1.0.0",dmVersion:"1.0.0"},hideCapsuleButton:{version:"1.0.0",dmVersion:"1.0.0"},triggerGC:{version:"1.0.0",dmVersion:"1.0.0"},vibrateShort:{version:"1.0.0",dmVersion:"1.0.0"},vibrateLong:{version:"2.8.0",dmVersion:"1.7.0"},onMemoryWarning:{version:"1.0.0",dmVersion:"1.0.0"},offMemoryWarning:{version:"1.0.0",dmVersion:"1.0.0"},closeDimina:{version:"1.0.0",dmVersion:"1.0.0"},getNetworkType:{version:"1.0.0",dmVersion:"1.0.0"},onNetworkStatusChange:{version:"1.0.0",dmVersion:"1.0.0"},offNetworkStatusChange:{version:"1.0.0",dmVersion:"1.0.0"},loginNotifition:{version:"1.0.0",dmVersion:"1.0.0"},logout:{version:"1.0.0",dmVersion:"1.0.0"},login:{version:"1.0.0",dmVersion:"1.0.0"},passportLogin:{version:"1.0.0",dmVersion:"1.0.0"},businessAuthorize:{version:"2.1.0",dmVersion:"1.4.0"},onUnhandledRejection:{version:"1.0.0",dmVersion:"1.4.3"},offUnhandledRejection:{version:"1.0.0",dmVersion:"1.4.3"},setScreenBrightness:{version:"2.8.0",dmVersion:"1.7.0"},setKeepScreenOn:{version:"2.8.0",dmVersion:"1.7.0"},onUserCaptureScreen:{version:"2.8.0",dmVersion:"1.7.0"},offUserCaptureScreen:{version:"2.8.0",dmVersion:"1.7.0"},getScreenBrightness:{version:"2.8.0",dmVersion:"1.7.0"},startRecord:{version:"2.8.0",dmVersion:"1.7.0"},stopRecord:{version:"2.8.0",dmVersion:"1.7.0"},startWifi:{version:"2.8.0",dmVersion:"1.7.0"},stopWifi:{version:"2.8.0",dmVersion:"1.7.0"},getWifiList:{version:"2.8.0",dmVersion:"1.7.0"},onGetWifiList:{version:"2.8.0",dmVersion:"1.7.0"},offGetWifiList:{version:"2.8.0",dmVersion:"1.7.0"},getConnectedWifi:{version:"2.8.0",dmVersion:"1.7.0"},onWifiConnected:{version:"2.8.0",dmVersion:"1.7.0"},offWifiConnected:{version:"2.8.0",dmVersion:"1.7.0"},showActionSheet:{version:"2.8.0",dmVersion:"1.7.0"},enableAlertBeforeUnload:{version:"2.8.0",dmVersion:"1.7.0"},disableAlertBeforeUnload:{version:"2.8.0",dmVersion:"1.7.0"},getAccountInfoSync:{version:"2.6.0",dmVersion:"1.6.0"},chooseContact:{version:"2.11.0",dmVersion:"1.8.0"},addPhoneContact:{version:"2.11.0",dmVersion:"1.8.0"},chooseVideo:{version:"2.13.0",dmVersion:"1.9.0"},getVideoInfo:{version:"2.13.0",dmVersion:"1.9.0"},saveVideoToPhotosAlbum:{version:"2.13.0",dmVersion:"1.9.0"},chooseMedia:{version:"2.13.0",dmVersion:"1.9.0"},compressVideo:{version:"2.13.0",dmVersion:"1.9.0"},showTabBar:{version:"2.8.0",dmVersion:"1.6.2"},hideTabBar:{version:"2.8.0",dmVersion:"1.6.2"},setTabBarStyle:{version:"10000.0.0",dmVersion:"10000.0.0"},getPerformance:{version:"2.11.0",dmVersion:"1.8.0"},choosePoi:{version:"3.0.0",dmVersion:"1.8.0"},chooseLocation:{version:"3.0.0",dmVersion:"1.8.0"},shareQqAppmsg:{version:"10000.0.0",dmVersion:"10000.0.0"},shareQzone:{version:"10000.0.0",dmVersion:"10000.0.0"},shareAlipayFriend:{version:"10000.0.0",dmVersion:"10000.0.0"},shareAlipayLife:{version:"10000.0.0",dmVersion:"10000.0.0"},shareSinaWeibo:{version:"10000.0.0",dmVersion:"10000.0.0"},requestSubscribeMessage:{version:"10000.0.0",dmVersion:"10000.0.0"},getRealtimeLogManager:{version:"10000.0.0",dmVersion:"10000.0.0"},openBusinessView:{version:"10000.0.0",dmVersion:"10000.0.0"},registerLocalNotify:{version:"2.13.0",dmVersion:"1.9.0"},checkLocalNotify:{version:"2.13.0",dmVersion:"1.9.0"},removeLocalNotify:{version:"2.13.0",dmVersion:"1.9.0"},reportUncaughtError:{version:"2.21.0",dmVersion:"1.14.0"},loginAndShowLegalDialog:{version:"2.23.0",dmVersion:"1.18.0"},getLoginLegalInfo:{version:"2.23.0",dmVersion:"1.18.0"}},Vl=function(e){if(!jl[e])return!1;if(!El||!Al){var t=dd.getSystemInfoSync();El=(null==t?void 0:t.SDKVersion)||"10.0.0",Al=(null==t?void 0:t.jssdkVersion)||"10.0.0"}var n=Cl(El,jl[e].version),r=Cl(Al,jl[e].dmVersion);return n>=0&&r>=0},Bl=function(t,n){var r={};if(t){if(n)for(var i in n){var o=n[i];void 0===o||!o&&void 0!==o&&0!==o||(r[i]=n[i]),"object"===e(o)&&(r[i]=JSON.stringify(n[i]))}Qu({event:"reportAnalytics",data:{eventName:""+t,data:Li({},r)},success:n&&n.success,fail:n&&n.fail,complete:n&&n.complete})}},Rl=function(e,t){e&&Qu({event:"traceServiceCoreDotting",data:{eventName:""+e,data:Li({},t)}})},Fl=function(e,t){if(void 0===t&&(t=!1),Rl("app_error",{info:e,isError:!0}),Wl("tech_saga_app_err",{err_info:e,err_type:1}),!t){var n=__appServiceEngine__.getApp();n&&n.onError&&n.onError(e)}},zl=[],Dl=0;function Wl(e,t){"reportMiniProgram"!==t.apiName&&Qu({event:"reportMiniProgram",data:{eventName:""+e,data:Li({},t)}})}var Ul=function(e){Qu({event:"fileSystemReadFile",data:{filePath:e.filePath,encoding:e.encoding},success:e.success,fail:e.fail,complete:e.complete})},ql=function(e,t){return Ku({event:"fileSystemReadFileSync",data:{filePath:e,encoding:t}}).data},Jl=function(e){Qu({event:"fileSystemWriteFile",data:{filePath:e.filePath,data:e.data,encoding:e.encoding},success:e.success,fail:e.fail,complete:e.complete})},Gl=function(e,t,n){return Ku({event:"fileSystemWriteFileSync",data:{filePath:e,data:t,encoding:n}}).data},Hl=null,$l=[],Ql=null;function Kl(){var e=$l;$l=[],Ql=null;for(var t=0;t<e.length;t++)e[t]()}var Xl=TypeError,Yl=function(e){return function(t,n,r,i){Y(n);var o=se(t),a=P(o),s=wt(o),c=e?s-1:0,u=e?-1:1;if(r<2)for(;;){if(c in a){i=a[c],c+=u;break}if(c+=u,e?c<0:s<=c)throw Xl("Reduce of empty array with no initial value")}for(;e?c>=0:s>c;c+=u)c in a&&(i=n(i,a[c],c,o));return i}},Zl={left:Yl(!1),right:Yl(!0)}.left,ep=Ut("reduce");Wt({target:"Array",proto:!0,forced:!ep||!tn&&q>79&&q<83},{reduce:function(e){var t=arguments.length;return Zl(this,e,t,t>1?arguments[1]:void 0)}});var tp=function(){function e(e){void 0===e&&(e={}),this.actions=[],this.currentTransform={},this.currentStepAnimates=[],this.option={transition:{duration:void 0!==e.duration?e.duration:400,timingFunction:void 0!==e.timingFunction?e.timingFunction:"linear",delay:void 0!==e.delay?e.delay:0},transformOrigin:e.transformOrigin||"50% 50% 0"}}return e.prototype.export=function(){var e=this.actions;return this.actions=[],{actions:e}},e.prototype.step=function(e){void 0===e&&(e={});for(var t=this,n=0,r=this.currentStepAnimates;n<r.length;n++){var i=r[n];"style"===i.type?this.currentTransform[i.type+"."+i.args[0]]=i:this.currentTransform[i.type]=i}return this.actions.push({animates:Object.keys(this.currentTransform).reduce((function(e,n){return[].concat.apply([],function(){for(var e=0,t=0,n=arguments.length;t<n;t++)e+=arguments[t].length;var r=Array(e),i=0;for(t=0;t<n;t++)for(var o=arguments[t],a=0,s=o.length;a<s;a++,i++)r[i]=o[a];return r}(e,[[t.currentTransform[n]]]))}),[]),option:{transformOrigin:void 0!==e.transformOrigin?e.transformOrigin:this.option.transformOrigin,transition:{duration:void 0!==e.duration?e.duration:this.option.transition.duration,timingFunction:void 0!==e.timingFunction?e.timingFunction:this.option.transition.timingFunction,delay:void 0!==e.delay?e.delay:this.option.transition.delay}}}),this.currentStepAnimates=[],this},e.prototype.matrix=function(e,t,n,r,i,o){return void 0===e&&(e=1),void 0===t&&(t=0),void 0===n&&(n=0),void 0===r&&(r=1),void 0===i&&(i=1),void 0===o&&(o=1),this.currentStepAnimates.push({type:"matrix",args:[e,t,n,r,i,o]}),this},e.prototype.matrix3d=function(e,t,n,r,i,o,a,s,c,u,f,d,l,p,h,y){return void 0===e&&(e=1),void 0===t&&(t=0),void 0===n&&(n=0),void 0===r&&(r=0),void 0===i&&(i=0),void 0===o&&(o=1),void 0===a&&(a=0),void 0===s&&(s=0),void 0===c&&(c=0),void 0===u&&(u=0),void 0===f&&(f=1),void 0===d&&(d=0),void 0===l&&(l=0),void 0===p&&(p=0),void 0===h&&(h=0),void 0===y&&(y=1),this.currentStepAnimates.push({type:"matrix3d",args:[e,t,n,r,i,o,a,s,c,u,f,d,l,p,h,y]}),this},e.prototype.rotate=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"rotate",args:[e]}),this},e.prototype.rotate3d=function(e,t,n,r){return void 0===e&&(e=0),void 0===t&&(t=0),void 0===n&&(n=0),void 0===r&&(r=0),this.currentStepAnimates.push({type:"rotate3d",args:[e,t,n,r]}),this},e.prototype.rotateX=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"rotateX",args:[e]}),this},e.prototype.rotateY=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"rotateY",args:[e]}),this},e.prototype.rotateZ=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"rotateZ",args:[e]}),this},e.prototype.scale=function(e,t){return void 0===e&&(e=1),void 0===t&&(t=1),this.currentStepAnimates.push({type:"scale",args:[e,t]}),this},e.prototype.scale3d=function(e,t,n){return void 0===e&&(e=1),void 0===t&&(t=1),void 0===n&&(n=1),this.currentStepAnimates.push({type:"scale3d",args:[e,t,n]}),this},e.prototype.scaleX=function(e){return void 0===e&&(e=1),this.currentStepAnimates.push({type:"scaleX",args:[e]}),this},e.prototype.scaleY=function(e){return void 0===e&&(e=1),this.currentStepAnimates.push({type:"scaleY",args:[e]}),this},e.prototype.scaleZ=function(e){return void 0===e&&(e=1),this.currentStepAnimates.push({type:"scaleZ",args:[e]}),this},e.prototype.skew=function(e,t){return void 0===e&&(e=0),void 0===t&&(t=0),this.currentStepAnimates.push({type:"skew",args:[e,t]}),this},e.prototype.skewX=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"skewX",args:[e]}),this},e.prototype.skewY=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"skewY",args:[e]}),this},e.prototype.translate=function(e,t){return void 0===e&&(e=0),void 0===t&&(t=0),this.currentStepAnimates.push({type:"translate",args:[e,t]}),this},e.prototype.translate3d=function(e,t,n){return void 0===e&&(e=0),void 0===t&&(t=0),void 0===n&&(n=0),this.currentStepAnimates.push({type:"translate3d",args:[e,t,n]}),this},e.prototype.translateX=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"translateX",args:[e]}),this},e.prototype.translateY=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"translateY",args:[e]}),this},e.prototype.translateZ=function(e){return void 0===e&&(e=0),this.currentStepAnimates.push({type:"translateZ",args:[e]}),this},e.prototype.opacity=function(e){return this.currentStepAnimates.push({type:"style",args:["opacity",e]}),this},e.prototype.backgroundColor=function(e){return this.currentStepAnimates.push({type:"style",args:["background-color",e]}),this},e.prototype.width=function(e){return Qa(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["width",e]}),this},e.prototype.height=function(e){return Qa(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["height",e]}),this},e.prototype.left=function(e){return Qa(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["left",e]}),this},e.prototype.right=function(e){return Qa(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["right",e]}),this},e.prototype.top=function(e){return Qa(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["top",e]}),this},e.prototype.bottom=function(e){return Qa(e)&&(e+="px"),this.currentStepAnimates.push({type:"style",args:["bottom",e]}),this},e}();var np=function(){function e(e,t,n,r){this._selectorQuery=e,this._component=t,this._selector=n,this._single=r}return e.prototype.fields=function(e,t){return this._selectorQuery._push(this._selector,this._component,this._single,e,t),this._selectorQuery},e.prototype.boundingClientRect=function(e){return this.fields({id:!0,dataset:!0,rect:!0,size:!0},e)},e.prototype.scrollOffset=function(e){return this.fields({id:!0,dataset:!0,scrollOffset:!0},e)},e.prototype.context=function(e){return this.fields({context:!0},e)},e.prototype.node=function(e){return this.fields({node:!0},e)},e}(),rp=function(){function e(){this.width=0,this.height=0,this.src="",this.path=null,this.onload=void 0,this.onerror=void 0,this._onload=void 0,this._onerror=void 0,this._complete=!1,this._status=null,this._sendTime=null,Object.defineProperty(this,"onload",{set:function(e){e&&"function"==typeof e?(this._onload=e,this._complete&&this._status&&(this._complete=!1,e())):this._onload=void 0},get:function(){return this._onload}}),Object.defineProperty(this,"onerror",{set:function(e){e&&"function"==typeof e?(this._onerror=e,this._complete&&!1===this._status&&(this._complete=!1,e())):this._onerror=void 0},get:function(){return this._onerror}}),Object.defineProperty(this,"src",{set:function(e){this._src=e,this.checkImageValid(e,""+Date.now())},get:function(){return this._src}})}return e.prototype.checkImageValid=function(e,t){var n=this;this._complete=!1,this._status=null,this._sendTime=t,Qu({event:"getImageInfo",data:{src:e}},(function(e){n._sendTime===t&&(n._complete=!0,n.dealCheckResult(e))}))},e.prototype.dealCheckResult=function(e){var t=e.width,n=e.height,r=e.path,i=!!t&&!!n&&!!r;this._status=i,this.width=t||0,this.height=n||0,this.path=r||null,i&&this._onload?this._onload():!i&&this._onerror&&this._onerror()},e}(),ip=["shadowBlur","shadowOffsetX","shadowOffsetY","lineCap","lineJoin","lineWidth","miterLimit","font","textAlign","textBaseline","direction"],op=["fillStyle","strokeStyle","shadowColor"],ap=[{key:"clearRect",params:["x","y","width","height"],extParams:[]},{key:"fillRect",params:["x","y","width","height"],extParams:[]},{key:"strokeRect",params:["x","y","width","height"],extParams:[]},{key:"fillText",params:["text","x","y"],extParams:["maxWidth"]},{key:"strokeText",params:["text","x","y"],extParams:["maxWidth"]},{key:"measureText",params:["text"],extParams:[]},{key:"beginPath",params:[],extParams:[]},{key:"closePath",params:[],extParams:[]},{key:"moveTo",params:["x","y"],extParams:[]},{key:"lineTo",params:["x","y"],extParams:[]},{key:"bezierCurveTo",params:["cp1x","cp1y","cp2x","cp2y","x","y"],extParams:[]},{key:"quadraticCurveTo",params:["cpx","cpy","x","y"],extParams:[]},{key:"arc",params:["x","y","radius","startAngle","endAngle"],extParams:["anticlockwise"]},{key:"rect",params:["x","y","width","height"],extParams:[]},{key:"fill",params:[],extParams:[]},{key:"stroke",params:[],extParams:[]},{key:"clip",params:[],extParams:[]},{key:"rotate",params:["angle"],extParams:[]},{key:"scale",params:["x","y"],extParams:[]},{key:"translate",params:["x","y"],extParams:[]},{key:"transform",params:["a","b","c","d","e","f"],extParams:[]},{key:"setTransform",params:["a","b","c","d","e","f"],extParams:[]},{key:"save",params:[],extParams:[]},{key:"restore",params:[],extParams:[]}],sp=function(){function e(e){var t=this;this.viewId=e,ip.forEach((function(e){Object.defineProperty(t,e,{set:function(n){var r;gl(t.viewId,e,((r={})[e]=n,r))},get:function(){return gl(t.viewId,e)}})})),op.forEach((function(e){Object.defineProperty(t,"_"+e,{value:"#000000",writable:!0}),Object.defineProperty(t,e,{set:function(n){var r,i=function(e){if("string"==typeof e){if(e=e.toLowerCase().replace(/\s+/g,""),/^#([0-9|a-f]{6})$/.test(e))return e;if(/^#([0-9|a-f]{8})$/.test(e))return"ff"===e.slice(7)?e.slice(0,7):wl([ml(e.slice(1,3)),ml(e.slice(3,5)),ml(e.slice(5,7)),ml(e.slice(7))/hl.MAX_COLOR_VALUE]);if(/^#([0-9|a-f]{3,4})$/.test(e)){var t=e.slice(1,2),n=e.slice(2,3),r=e.slice(3,4),i=void 0;return 4===e.length||"f"===(i=e.slice(4))?"#"+t+t+n+n+r+r:wl([ml(t+t),ml(n+n),ml(r+r),ml(i+i)/hl.MAX_COLOR_VALUE])}if(/^rgb[a]?\(((-|\+?)\d+(\.\d+)?,){2,3}(-|\+?)\d+(\.\d+)?\)$/.test(e)){var o=e.split(",");return t=o[0].split("(")[1],n=o[1],r=o[2],"rgba"===e.slice(0,4)&&o[3]&&(i=Sl(o[3].split(")")[0]))<1?wl([Sl(t),Sl(n),Sl(r),i]):"#"+bl(t)+bl(n)+bl(r)}if(yl[e])return yl[e]}return null}(n);i&&(Array.isArray(i)?(t["_"+e]="rgba("+i.join(", ")+")",i="#"+bl(""+parseFloat(i[3])*hl.MAX_COLOR_VALUE)+bl(i[0])+bl(i[1])+bl(i[2])):t["_"+e]=i,gl(t.viewId,e,((r={})[e]=i,r)))},get:function(){return t["_"+e]}})})),ap.forEach((function(e){var n=e.key,r=e.params,i=e.extParams;t[n]=function(){for(var e=[],o=0;o<arguments.length;o++)e[o]=arguments[o];var a={},s=e.length,c=r.length;if(s<c)throw new TypeError("Failed to execute '"+n+"' on 'CanvasRenderingContext2D': "+r.length+" arguments required, but only "+e.length+" present.");for(var u=i.length,f=0;f<c;f++)a[r[f]]=e[f];if(s>c)for(f=0;f<u;f++)a[i[f]]=e[f+c];return gl(t.viewId,n,a)}}))}return e.prototype.drawImage=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];if(!(e instanceof rp))throw new TypeError("Failed to execute 'drawImage' on 'CanvasRenderingContext2D': image must be created by canvas.");if(![2,4,8].includes(t.length))throw new TypeError("Failed to execute 'drawImage' on 'CanvasRenderingContext2D': Overload resolution failed.");if(e.path){var r={src:e.path},i=void 0,o=void 0,a=void 0,s=void 0;2===t.length||4===t.length?(i=t[0],o=t[1],a=t[2]||null,s=t[3]||null):(r.sx=t[0],r.sy=t[1],r.sWidth=t[2],r.sHeight=t[3],i=t[4],o=t[5],a=t[6],s=t[7]),r.dx=i,r.dy=o,a&&(r.dWidth=a,r.dHeight=s),gl(this.viewId,"drawImage",r)}},e}(),cp=function(){function e(e,t){var n=this;this._width=300,this._height=150,this._webViewId=e,this._nodeId=t,this.canvasRef=null,Object.defineProperty(this,"width",{get:function(){return n._width},set:function(e){e=up(e),n._width=e,gl(n._nodeId,"width",{width:e})}}),Object.defineProperty(this,"height",{get:function(){return n._height},set:function(e){e=up(e),n._height=e,gl(n._nodeId,"height",{height:e})}})}return e.prototype.getContext=function(e){if(!this.canvasRef&&"2d"===e){var t=gl(this._nodeId,"getContext",{type:"2d"});if(!(null==t?void 0:t.canvasId))return null;this.canvasRef=new sp(this._nodeId)}return this.canvasRef},e.prototype.createImage=function(){return new rp},e.prototype.createImageData=function(){},e.prototype.createPath2D=function(){},e.prototype.requestAnimationFrame=function(){},e.prototype.cancelAnimationFrame=function(){},e.prototype.toDataURL=function(e,t){return void 0===e&&(e="image/png"),gl(this._nodeId,"toDataURL",{type:e,encoderOptions:t})},e}();function up(e){try{var t=Math.abs(parseInt(e));return isNaN(t)?0:t}catch(e){return 0}}tc("Map",(function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}}),Qf);var fp=function(){function e(e){this.lottieId="",this.src="",this._onDataReady=void 0,this._onDataFailed=void 0,this._complete=!1,this._status=null,this._sendTime=null,this.onCompletionCallbackLottie=null,this.lottieId=e,Object.defineProperty(this,"src",{set:function(e){this._src=e,this.srcLottie(e,""+Date.now())},get:function(){return this._src}})}return e.prototype.onDataReady=function(e){e&&"function"==typeof e?(this._onDataReady=e,this._complete&&this._status&&(this._complete=!1,e())):this._onDataReady=void 0},e.prototype.onDataFailed=function(e){e&&"function"==typeof e?(this._onDataFailed=e,this._complete&&!1===this._status&&(this._complete=!1,e())):this._onDataFailed=void 0},e.prototype.srcLottie=function(e,t){var n=this;this._complete=!1,this._status=null,this._sendTime=t,Qu({event:"srcLottie",data:{src:e,lottieId:this.lottieId},success:function(){n._sendTime===t&&(n._complete=!0,n._status=!0,n._onDataReady&&n._onDataReady())},fail:function(e){n._sendTime===t&&(n._complete=!0,n._status=!1,n._onDataFailed&&n._onDataFailed(e.data))}})},e.prototype.setLoopLottie=function(e){Qu({event:"setLoopLottie",data:{isLoop:e,lottieId:this.lottieId}})},e.prototype.playAnimationLottie=function(){Qu({event:"playAnimationLottie",data:{lottieId:this.lottieId}})},e.prototype.cancelAnimationLottie=function(){Qu({event:"cancelAnimationLottie",data:{lottieId:this.lottieId}})},e.prototype.setOnCompletionCallbackLottie=function(e){var t=this;this.onCompletionCallbackLottie&&didiJsBridge.off({event:"onCompletionCallbackLottie",callback:this.onCompletionCallbackLottie}),"function"==typeof e&&(this.onCompletionCallbackLottie=function(n){var r;(null===(r=n.data)||void 0===r?void 0:r.lottieId)===t.lottieId&&e()},didiJsBridge.on({event:"onCompletionCallbackLottie",callback:this.onCompletionCallbackLottie}))},e}(),dp=new Map;function lp(e,t,n,r){if(e)if(Array.isArray(e))e.forEach((function(e){return lp(e,t,n)}));else{var i=e.nodeIs;if(i){var o=e.nodeId;"dd-canvas"===i&&o?e.node=function(e,t){if("2d"===t){var n=function(e,t){var n,r=vl(e,t);return(null===(n=_l[e])||void 0===n?void 0:n[r])||null}(Ed.currentWebviewId,e);return n||(n=new cp(Ed.currentWebviewId,e),function(e,t,n){var r=vl(e,t);_l[e]?_l[e][r]=n:_l[e]={id:n}}(Ed.currentWebviewId,e,n),n)}}(o,e.nodeCanvasType):"dd-lottie"===i&&o&&(e.node=(a=o,dp.has(a)||dp.set(a,new fp(a)),dp.get(a))),delete e.nodeIs,delete e.nodeId,delete e.nodeCanvasType,e.node&&"function"==typeof e.node._onReady&&n.push(new Promise((function(t){return e.node._onReady(t)})))}}var a}var pp={},hp={};function yp(e,t){return pp[t]||(pp[t]=function(e){return function(){function t(e){if(e&&e.page)this._component=this._defaultComponent=e.page,this._webViewId=this._defaultComponent.__ddWebViewId__;else{var t=__appServiceEngine__.getCurrentPagesByDomain("");this._defaultComponent=t[t.length-1],this._component=null,this._webViewId=null}this._queue=[],this._queueCb=[]}return t.prototype.in=function(e){return null===this._webViewId?(this._webViewId=e.__ddWebViewId__,this._component=e):this._webViewId!==e.__ddWebViewId__||(this._component=e),this},t.prototype.select=function(e){return new np(this,this._component,e,!0)},t.prototype.selectAll=function(e){return new np(this,this._component,e,!1)},t.prototype.selectViewport=function(){return new np(this,0,"",!0)},t.prototype._push=function(t,n,r,i,o){null===this._webViewId&&(this._webViewId=this._defaultComponent?this._defaultComponent.__ddWebViewId__:void 0);var a=e?"":__virtualDOM__.getRootNodeId(this._webViewId),s=null!=n?0===n?0:n.__ddExparserNodeId__:a;this._queue.push({component:s,selector:t,single:r,fields:i}),this._queueCb.push(o||null)},t.prototype.exec=function(t){var n=this,r=this,i=this._webViewId,o={pluginId:e,queue:this._queue},a=function(e){return Ci(n,void 0,void 0,(function(){var n,i,o,a=this;return Ei(this,(function(s){switch(s.label){case 0:return n=this._queueCb,i=[],o=[],e.forEach((function(e,t){lp(e,a._component,o),Xa(n[t])&&i.push((function(){n[t].call(r,e)}))})),Xa(t)&&i.push((function(){t.call(r,e)})),o.length?[4,Promise.all(o)]:[3,2];case 1:s.sent(),s.label=2;case 2:return i.forEach((function(e){return e()})),[2]}}))}))};if(null!=i)var s=__virtualDOM__.requestViewInfo("selectorQuery",o,i,(function(e){a&&(__virtualDOM__.endViewInfoCallback(i,s),a&&a(e))}))},t}()}(t)),new pp[t](e)}function vp(e,t,n){return hp[n]||(hp[n]=function(e){return function(){function t(e,t){if(this._component=e,this._options=t,this._relativeInfo=[],this._observerId=null,this._disconnected=!1,this._component)this._webViewId=this._component.__ddWebViewId__;else{var n=__appServiceEngine__.getCurrentPagesByDomain("");n.length&&(this._webViewId=n[n.length-1].__ddWebViewId__)}}return t.requestViewInfo=function(e,t,n){var r=__virtualDOM__.requestViewInfo("intersection",t,e,(function(t){t.reqEnd&&__virtualDOM__.endViewInfoCallback(e,r),n&&!t.reqEnd&&n(t)}))},t.prototype.relativeTo=function(e,t){if(null!==this._observerId)throw new Error('Relative nodes cannot be added after "observe" call in IntersectionObserver');return this._relativeInfo.push({selector:e,margins:t}),this},t.prototype.relativeToViewport=function(e){if(null!==this._observerId)throw new Error('Relative nodes cannot be added after "observe" call in IntersectionObserver');return this._relativeInfo.push({selector:null,margins:e}),this},t.prototype.observe=function(n,r){var i=this;if(null!==this._observerId)throw new Error('"observe" call can be only called once in IntersectionObserver');this._observerId="";var o=this._component;t.requestViewInfo(this._webViewId,{type:"addIntersectionObserver",pluginId:e,nodeId:o?o.__ddExparserNodeId__:__virtualDOM__.getRootNodeId(this._webViewId),targetSelector:n,relativeInfo:this._relativeInfo,options:this._options},(function(e){i._disconnected||(e.observerId&&(i._observerId=e.observerId),e.info&&r.call(i,e.info))}))},t.prototype.disconnect=function(){t.requestViewInfo(this._webViewId,{type:"removeIntersectionObserver",observerId:this._observerId}),this._disconnected=!0},t}()}(n)),new hp[n](e,t)}var gp=qu("AppHide").internalOnMethod;function mp(e,t,n){var r={event:e,data:t,webViewId:n};didiJsBridge.publish(r)}function bp(e,t){didiJsBridge.subscribe({event:e},(function(e){var n=e.data,r=void 0===n?{}:n,i=e.webViewId;Xa(t)&&t(r,i)}))}qu("AppHide").internalOffMethod;var Sp=!1;var wp=new Ac.EventEmitter2;didiJsBridge.on({event:"onUpdateStatusChange"},(function(e){var t=e&&e.data&&e.data.event||"";wp.emit(t,e)}));var _p,Tp,kp=null,Mp=[];function Np(){Mp.forEach((function(e){"function"==typeof e&&e(_p)})),Mp.length=0}wp.on("updating",(function(){_p={hasUpdate:!0},Np()})),wp.on("noupdate",(function(){_p={hasUpdate:!1},Np()}));var Ip,Op=[],xp=!1;wp.on("updateready",(function(e){xp=!0,Tp={strategy:e.data.strategy},Op.forEach((function(e){"function"==typeof e&&e(Tp)})),Op.length=0}));var Pp=[];wp.on("updatefail",(function(){Ip={},Pp.forEach((function(e){"function"==typeof e&&e(Ip)})),Pp.length=0}));var Lp,Cp={src:"",startTime:0,paused:!0,currentTime:0,duration:0,obeyMuteSwitch:!0,volume:1,autoplay:!1,loop:!1,buffered:0,referrerPolicy:""},Ep=new Map,Ap=function(){function e(e){this.src=e.src,this.startTime=e.startTime,this.paused=e.paused,this.currentTime=e.currentTime,this.duration=e.duration,this.obeyMuteSwitch=e.obeyMuteSwitch,this.volume=e.volume,this.autoplay=e.autoplay,this.loop=e.loop,this.buffered=e.buffered,this.referrerPolicy=e.referrerPolicy}return e.prototype.play=function(){Qu({event:"audioInstancePlay",data:{audioId:Lp,src:this.src,paused:!1,startTime:this.startTime,currentTime:this.currentTime,duration:this.duration,obeyMuteSwitch:this.obeyMuteSwitch,volume:this.volume,autoplay:this.autoplay,loop:this.loop,buffered:this.buffered}})},e.prototype.stop=function(){Qu({event:"audioInstanceStop",data:{audioId:Lp,src:this.src,paused:this.paused,startTime:this.startTime,currentTime:this.currentTime,duration:this.duration,obeyMuteSwitch:this.obeyMuteSwitch,volume:this.volume,autoplay:this.autoplay,loop:this.loop,buffered:this.buffered}})},e.prototype.destroy=function(){Ep.clear()},e.prototype.onPlay=function(e){this.onPlayFuncs=e},e.prototype.onStop=function(e){this.onStopFuncs=e},e.prototype.onEnded=function(e){this.onEndedFuncs=e},e}();didiJsBridge.on({event:"audioInstanceStateChanged"},(function(e){var t=e.data,n=t.audioId,r=t.emitFunctionName,i=Ep.get(n);i&&i[r+"Funcs"]()}));var jp=new Map;didiJsBridge.on({event:"bindanimationend",callback:function(e){var t=e.data||{},n="string"==typeof t?JSON.parse(t):t,r=n.markerId&&jp.get(n.markerId);r&&"function"==typeof r&&r(n)}});var Vp=function(){function e(e,t){this.mapId=e,this.that=t}return e.prototype.setCenterOffset=function(e){void 0===e&&(e={}),e.mapId=this.mapId,Qu({event:"setCenterOffset",data:e,success:e.success,fail:e.fail,complete:e.complete})},e.prototype.includePoints=function(e){void 0===e&&(e={}),e.mapId=this.mapId,Qu({event:"includePoints",data:e,success:e.success,fail:e.fail,complete:e.complete})},e.prototype.getCenterLocation=function(e){void 0===e&&(e={}),e.mapId=this.mapId,Qu({event:"getCenterLocation",data:e,success:e.success,fail:e.fail,complete:e.complete})},e.prototype.moveToLocation=function(e){void 0===e&&(e={}),e.mapId=this.mapId,Qu({event:"moveToLocation",data:e,success:e.success,fail:e.fail,complete:e.complete})},e.prototype.translateMarker=function(e){void 0===e&&(e={}),e.mapId=this.mapId,Qu({event:"translateMarker",data:e,success:e.success,fail:e.fail,complete:e.complete});var t=e.animationEnd;t&&"function"==typeof t&&jp.set(e.markerId,t)},e.prototype.getScale=function(e){void 0===e&&(e={}),e.mapId=this.mapId,Qu({event:"getScale",data:e,success:e.success,fail:e.fail,complete:e.complete})},e}();var Bp=function(){function t(){}return t.prototype.takePhoto=function(e){var t=e.quality,n=void 0===t?"normal":t,r=e.success,i=e.fail,o=e.complete;Qu({event:"takePhotoCamera",data:{quality:n},success:r,fail:i,complete:o})},t.prototype.setZoom=function(t){var n=t.zoom,r=t.success,i=t.fail,o=t.complete;if("number"!=typeof n)throw new Error("CameraContext.setZoom:fail parameter error: parameter.zoom should be Number instead of "+e(n)+";");Qu({event:"setZoomCamera",data:{zoom:n},success:r,fail:i,complete:o})},t.prototype.startRecord=function(e){var t=e.success,n=e.fail,r=e.complete;Qu({event:"startRecordCamera",success:t,fail:n,complete:r})},t.prototype.stopRecord=function(e){var t=e.compressed,n=void 0!==t&&t,r=e.success,i=e.fail,o=e.complete;Qu({event:"stopRecordCamera",data:{compressed:n},success:r,fail:i,complete:o})},t}();var Rp="";function Fp(e){return e||null}function zp(e,t,n,r){var i=["then","catch","always"].reduce((function(e,t){return e[t]=function(n){return e[t]=n,e},e}),{}),o=new XMLHttpRequest,a=function(e,t,n){if("get"!==n.toLowerCase()||!t)return e;var r=function(e){return Wp(e)?Up(e):e}(t),i=e.indexOf("?")>-1?"&":"?";return e+i+r}(t,n,e);return o.open(e,a,!0),o.withCredentials=r.hasOwnProperty("withCredentials"),function(e,t,n){(function(e){return Object.keys(e).some((function(e){return"content-type"===e.toLowerCase()}))})(t=t||{})||(t["Content-Type"]=Wp(n)?"application/json":"application/x-www-form-urlencoded");if("application/x-www-form-urlencoded"===t["Content-Type"]||"application/x-www-form-urlencoded"===t["content-type"]){if(Wp(n)){for(var r in n)Rp=Rp+r+"="+n[r]+"&";Rp=Rp.substr(0,Rp.length-1)}}else Rp=Wp(n)?JSON.stringify(n):n;Object.keys(t).forEach((function(n){t[n]&&e.setRequestHeader(n,t[n])}))}(o,r.headers,n),o.addEventListener("readystatechange",function(e,t){return function n(){t.readyState===t.DONE&&(t.removeEventListener("readystatechange",n,!1),e.always.apply(e,Dp(t)),t.status>=200&&t.status<300?e.then.apply(e,Dp(t)):e.catch.apply(e,Dp(t)))}}(i,o),!1),o.send(Rp),i.abort=function(){return o.abort()},i}function Dp(e){var t;try{t=JSON.parse(e.responseText)}catch(n){t=e.responseText}return[t,e]}function Wp(e){return"[object Object]"===Object.prototype.toString.call(e)}function Up(t,n){return Object.keys(t).map((function(r){if(t.hasOwnProperty(r)&&void 0!==t[r]){var i=t[r];return r=n?n+"["+r+"]":r,null!==i&&"object"===e(i)?Up(i,r):qp(r)+"="+qp(i)}})).filter(Boolean).join("&")}function qp(e){return encodeURIComponent(e)}function Jp(e,t){this.eventMap=new Map,this.callbackMap=new WeakMap,this.originalCallbackMap=new WeakMap,this.type=e,this.surround=t,this.on=function(e,t){var n,r;Xa(t)&&(n=t,this.surround&&(r=t,"at"+this.type+e+"callback function",n=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];try{return r.apply(void 0,e)}catch(e){return}},this.callbackMap.set(t,n),this.originalCallbackMap.set(n,t),this.eventMap.has(e)?this.eventMap.get(e).add(n):this.eventMap.set(e,new Set([n]))))},this.off=function(e,t){var n,r=this,i=this.eventMap.get(e);i&&("function"!=typeof t?(i.forEach((function(e){var t=r.originalCallbackMap.get(e);r.callbackMap.delete(t),r.originalCallbackMap.delete(e)})),i.clear()):this.surround?(n=this.callbackMap.get(t),i.delete(n),this.callbackMap.delete(t),this.originalCallbackMap.delete(n)):i.delete(t))},this.emit=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];this.eventMap.has(e)&&new Set(this.eventMap.get(e)).forEach((function(e){return e.apply(void 0,t)}))},this.removeAllListeners=function(e){this.off(e)}}var Gp="pending",Hp="then",$p="catch",Qp=function(){function e(e){if(this._status=Gp,this._return=void 0,this._processors=[],"function"!=typeof e)throw new TypeError("Promise resolver is not a function");var t=this;try{e((function(e){t._status===Gp&&(t._status=Hp,t._return=e,t._consume())}),(function(e){t._status===Gp&&(t._status=$p,t._return=e,t._consume())}))}catch(e){}}return e.prototype._consume=function(){if(this._status!==Gp){for(var e=this._processors.shift();e&&e.type!==this._status;)e=this._processors.shift();if(e)try{this._return=e.func(this._return),this._status=Hp}catch(e){this._return=e,this._status=$p}finally{this._consume()}}},e.prototype.then=function(e){return this._processors.push({func:e,type:Hp}),this._consume(),this},e.prototype.catch=function(e){return this._processors.push({func:e,type:$p}),this._consume(),this},e.prototype.resolve=function(t){return new e((function(e){return e(t)}))},e.prototype.reject=function(t){return new e((function(){throw t}))},e}(),Kp={currentTaskCount:0,maxTaskCount:10,taskQueue:[],functionName:"",taskIdMap:{}},Xp={};function Yp(e,n){var r=Xp[e]?Xp[e]:Kp;didiJsBridge.on({event:"on"+e+"TaskStateChange"},(function(t){!function(e,t){var n=e.taskId,r=e.state,i=e.data;rh.emit(""+t+n+r,i),("success"===r||"fail"===r)&&(rh.emit(""+t+n+"complete",i),--Xp[t].currentTaskCount,Xp[t].taskQueue.length>0&&Xp[t].taskQueue.shift().item.createTask(),delete Xp[t].taskIdMap[""+t+n])}(t&&t.data,e)})),Xp[e]=t(r,n)}Yp("Request",{maxTaskCount:10,functionName:"request"}),Yp("Download",{maxTaskCount:10,functionName:"downloadFile"}),Yp("Upload",{maxTaskCount:10,functionName:"uploadFile"});var Zp=new WeakMap,eh=new WeakMap,th=new WeakMap,nh=0,rh=new Jp("netWork",!0),ih=function(){function e(e){var t=this,n=e.taskType;++nh,Xp[n].taskIdMap[""+n+nh]=this,eh.set(this,n),th.set(this,e),this.promise=new Qp((function(e,n){t.resolve=e,t.reject=n})),Xp[n].currentTaskCount>=Xp[n].maxTaskCount?Xp[n].taskQueue.push({id:""+n+nh,item:this}):this.createTask()}return e.prototype.createTask=function(){var e=this,t=th.get(this),n=eh.get(this),r={url:t.url,data:t.data,header:t.header,dataType:t.dataType,responseType:t.responseType,method:t.method,timeout:t.timeout,filePath:t.filePath,formData:t.formData,name:t.name};"Request"===n&&(r.dataType||(r.dataType="json"),r.responseType||(r.responseType="text"),r.method||(r.method="GET"));var i=""+n+nh;Qu({event:"create"+n+"Task",data:{taskId:i,options:r},success:function(){Zp.set(e,""+i),Xp[n].taskIdMap[i].resolve()},fail:function(e){Xp[n].taskIdMap[i].reject(e)}}),this.promise.then((function(){e.createTaskSuccess()})).catch((function(t){e.createTaskFail(t)}))},e.prototype.createTaskSuccess=function(){var e=eh.get(this),t=Zp.get(this),n=th.get(this);rh.on(""+e+t+"success",(function(e){n&&n.success&&"function"==typeof n.success&&n.success(e)})),rh.on(""+e+t+"fail",(function(e){n&&n.fail&&"function"==typeof n.fail&&n.fail(e)})),rh.on(""+e+t+"complete",(function(e){n&&n.complete&&"function"==typeof n.complete&&n.complete(e)}))},e.prototype.createTaskFail=function(e){var t=th.get(this);t&&t.fail&&"function"==typeof t.fail&&t.fail(e),t&&t.complete&&"function"==typeof t.complete&&t.complete(e)},e.prototype.abort=function(){var e=this;this.promise.then((function(){var t=eh.get(e);Qu({event:"operate"+t+"Task",data:{operationType:"abort",taskId:Zp.get(e),extra:{}},success:function(){},fail:function(e){}})}))},e.prototype.onProgressUpdate=function(e){var t=this;Zp.get(this)?rh.on(""+eh.get(this)+Zp.get(this)+"progressUpdate",e):this.promise.then((function(){rh.on(""+eh.get(t)+Zp.get(t)+"progressUpdate",e)}))},e.prototype.offProgressUpdate=function(e){rh.off(""+eh.get(this)+Zp.get(this)+"progressUpdate",e)},e}();var oh,ah={type:"async",event:"downloadFile",argsSize:1,agrs0Type:"Object",params:{url:{type:["String"],ifMustNeed:!0,default:"",desc:"下载资源的url"},header:{type:["Object"],ifMustNeed:!1,default:{},desc:"HTTP 请求的 Header，Header 中不能设置 Referer"},timeout:{type:["Number"],ifMustNeed:!1,default:"",desc:"超时时间，单位为毫秒"},filePath:{type:["String"],ifMustNeed:!1,default:"",desc:"指定文件下载后存储的路径 (本地路径)"}}},sh={type:"async",event:"uploadFile",argsSize:1,agrs0Type:"Object",params:{url:{type:["String"],ifMustNeed:!0,default:"",desc:"开发者服务器地址"},filePath:{type:["String"],ifMustNeed:!0,default:"",desc:"要上传文件资源的路径 (本地路径)"},name:{type:["String"],ifMustNeed:!0,default:"",desc:"文件对应的 key，开发者在服务端可以通过这个 key 获取文件的二进制内容"},header:{type:["Object"],ifMustNeed:!1,default:{},desc:"HTTP 请求 Header，Header 中不能设置 Referer"},formData:{type:["Object"],ifMustNeed:!1,default:{},desc:"HTTP 请求中其他额外的 form data"},timeout:{type:["Number"],ifMustNeed:!1,default:"",desc:"超时时间，单位为毫秒"}}},ch=function(e){if(void 0===e&&(e={url:""}),window.isBrowser){var t=(n={method:e.method||"GET",data:e.data,url:e.url,headers:e.header,timeout:e.timeout,dataType:e.dataType||"json",responseType:e.responseType||"text"},Rp="",(n=n||{}).baseUrl=n.baseUrl||"",n.method&&n.url?zp(n.method,n.baseUrl+n.url,Fp(n.data),n):["get","post","put","delete"].reduce((function(e,t){return e[t]=function(e,r){return zp(t,n.baseUrl+e,Fp(r),n)},e}),{}));t.then((function(t){e.success({data:t})}))}else{var n;Qu({event:"request",data:{url:e.url,data:e.data,header:e.header,timeout:e.timeout,method:e.method||"GET",dataType:e.dataType||"json",responseType:e.responseType||"text"},success:e.success,fail:e.fail,complete:e.complete})}},uh="2.11.0",fh=new Jp("socket-task",!0),dh=0,lh=new WeakMap,ph={};didiJsBridge.on({event:"onSocketStateChange"},(function(e){var t=e.data,n=t.state,r=t.taskId,i=t.data;"open"===n&&(yh.currentTaskCount++,ph[r].readyState=1),fh.emit(""+r+n,i),"close"===n&&(yh.currentTaskCount--,ph[r].readyState=3,fh.removeAllListeners(r+"open"),fh.removeAllListeners(r+"close"),fh.removeAllListeners(r+"message"),fh.removeAllListeners(r+"error"))}));var hh=new WeakMap,yh=function(){function e(){}return e.connectSocket=function(t){if(t&&t.url&&(r=t.url,/^(ws|wss):\/\/.*/i.test(r))){t.header&&"[Object object]"===Object.prototype.toString.call(t.header)||delete t.header,0===t.timeout&&delete t.timeout;try{var n=new vh(t);return n&&3!==n.readyState&&hh.set(e.currentTask,n),n}catch(e){}}var r},e.closeSocket=function(){var t=hh.get(e.currentTask);t&&3!==t.readyState&&t.close()},e.sendSocketMessage=function(t){hh.get(e.currentTask).send(t)},e.onSocketOpen=function(t){t||(t=function(){});var n=hh.get(e.currentTask);fh.on(n.taskId+"open",t)},e.onSocketClose=function(t){t||(t=function(){});var n=hh.get(e.currentTask);fh.on(n.taskId+"close",t)},e.onSocketMessage=function(t){t||(t=function(){});var n=hh.get(e.currentTask);fh.on(n.taskId+"message",t)},e.onSocketError=function(t){t||(t=function(){});var n=hh.get(e.currentTask);fh.on(n.taskId+"error",t)},e.currentTask={},e.currentTaskCount=0,e}(),vh=function(){function e(e){this.readyState=0;var t="web-socket"+dh++;lh.set(this,t),ph[t]=this,yh.currentTaskCount>=2?e.fail({errMsg:"exceed max task count"}):Qu({event:"createSocketTask",data:{taskId:t,options:{url:e.url,header:e.header,protocols:e.protocols,tcpNoDelay:e.tcpNoDelay,perMessageDeflate:e.perMessageDeflate,timeout:e.timeout}},success:function(n){Ka(n)||(n={errMsg:"operateSocketTask:ok"}),n.errMsg=n.errMsg.replace("createSocketTask","connectSocket"),n.socketTaskId=t,e.success&&e.success(n)},fail:function(t){e.fail&&e.fail(t)},complete:function(){e.complete&&e.complete()}})}return e.prototype.close=function(e){var t=this;this.readyState>1||(e.code&&(1e3!==e.code||e.code>=3e3&&e.code<=4999)?e&&e.fail&&e.fail({errMsg:"closeSocket:fail Failed to execute 'close' on 'WebSocket': The code must be either 1000, or between 3000 and 4999. "+e.code+" is neither."}):(this.readyState=2,Qu({event:"operateSocketTask",data:{operationType:"close",taskId:lh.get(this),extra:{code:e.code||1e3,reason:e.reason}},success:function(n){Ka(n)||(n={errMsg:"operateSocketTask:ok"}),yh.currentTaskCount--,t.readyState=3,n.errMsg=n.errMsg.replace("operateSocketTask","closeSocket"),e.success&&e.success(n)},fail:function(t){e.fail&&e.fail(t)},complete:function(){e.complete&&e.complete()}})))},e.prototype.send=function(e){if(1===this.readyState)Qu({event:"operateSocketTask",data:{operationType:"send",taskId:lh.get(this),extra:{data:e.data||""}},success:function(t){Ka(t)||(t={errMsg:"operateSocketTask:ok"}),t.errMsg=t.errMsg.replace("operateSocketTask","sendSocketMessage"),e.success&&e.success(t)},fail:function(t){e.fail&&e.fail(t)}});else{if(!e.fail)throw new Error("SocketTask.send:fail SocketTask.readyState is not OPEN");e.fail({errMsg:"SocketTask.send:fail SocketTask.readyState is not OPEN"})}},e.prototype.onClose=function(e){var t=this;e||(e=function(){});var n=lh.get(this);fh.on(n+"close",(function(){t.readyState=3,e()}))},e.prototype.onError=function(e){e||(e=function(){});var t=lh.get(this);fh.on(t+"error",e)},e.prototype.onMessage=function(e){e||(e=function(){});var t=lh.get(this);fh.on(t+"message",e)},e.prototype.onOpen=function(e){e||(e=function(){});var t=lh.get(this);fh.on(t+"open",e)},e}();var gh,mh,bh={downloadFile:function(e){void 0===e&&(e={url:""});var t=Ya(ah,[e]);if(Cl((null==(oh=oh||dd.getSystemInfoSync())?void 0:oh.SDKVersion)||"10.0.0",uh)>=0)return new ih(Li({taskType:"Download"},t));!function(e){Qu({event:"downloadFile",data:{url:e.url,header:e.header,timeout:e.timeout,filePath:e.filePath},success:e.success,fail:e.fail,complete:e.complete})}(t)},request:function(e){if(void 0===e&&(e={url:""}),Cl((null==(oh=oh||dd.getSystemInfoSync())?void 0:oh.SDKVersion)||"10.0.0",uh)>=0)return new ih(Li({taskType:"Request"},e));ch(e)},uploadFile:function(e){var t=Ya(sh,[e]);if(Cl((null==(oh=oh||dd.getSystemInfoSync())?void 0:oh.SDKVersion)||"10.0.0",uh)>=0)return new ih(Li({taskType:"Upload"},t));!function(e){Qu({event:"uploadFile",data:{url:e.url,filePath:e.filePath,name:e.name,header:e.header,formData:e.formData,timeout:e.timeout},success:e.success,fail:e.fail,complete:e.complete})}(t)},connectSocket:function(e){return yh.connectSocket(e)},onSocketOpen:function(e){yh.onSocketOpen(e)},closeSocket:function(){yh.closeSocket()},sendSocketMessage:function(e){yh.sendSocketMessage(e)},onSocketClose:function(e){yh.onSocketClose(e)},onSocketMessage:function(e){yh.onSocketMessage(e)},onSocketError:function(e){yh.onSocketError(e)},nextTick:function(e){Xa(e)&&($l.push(e),Ql||(Ql=setTimeout(Kl,0)))},createAnimation:function(e){return void 0===e&&(e={}),new tp(e)},createSelectorQuery:function(e){return yp(e,"")},createIntersectionObserver:function(e,t){return vp(e,t,"")},createMediaQueryObserver:function(){return null},getLaunchOptionsSync:yd,getEnterOptionsSync:vd,onAppHide:gp,navigateTo:Bd.navigateTo,redirectTo:Bd.redirectTo,navigateBack:Bd.navigateBack,switchTab:Bd.switchTab,reLaunch:Bd.reLaunch,launch:Bd.launch,getRealRoute:id,getLocalFilePath:function(e,t){return new Promise((function(n,r){didiJsBridge.invoke({method:"getLocalFilePath",data:{package:e,path:t},callback:function(i){i&&i.data&&i.data.success?n(i.data.data.path):r(i.data.errMsg||"getLocalFilePath failed ("+e+" - "+t+").")}})}))},getFileSystemManager:function(){return{readFile:Ul,readFileSync:ql,writeFileSync:Gl,writeFile:Jl}},onAppRoute:jd,canIUse:Vl,getUpdateManager:function(){return kp||(kp={onCheckForUpdate:function(e){_p?"function"==typeof e&&e(_p):Mp.push(e)},onUpdateReady:function(e){xp?"function"==typeof e&&e(Tp):Op.push(e)},onUpdateFailed:function(e){Ip?"function"==typeof e&&e(Ip):Pp.push(e)},applyUpdate:function(){xp&&Qu({event:"applyUpdate"})}})},getRealtimeLogManager:function(){return{info:function(){},warn:function(){},error:function(){},setFilterMsg:function(){},addFilterMsg:function(){},in:function(){}}},openBusinessView:function(){return!1},reportAnalytics:function(e,t){Bl(e,t)},navigateToMiniProgram:Bd.navigateToMiniProgram,navigateToDimina:Bd.navigateToDimina,requestSubscribeMessage:function(e){return e.sucssess&&e.success(),{}},loginNotifition:function(e){didiJsBridge.on({event:"loginNotifition"},(function(t){e&&e(t.data||{})}))},shareQqAppmsg:function(e){Qu({event:"shareQqAppmsg",data:{type:e.type||"text",icon:e.icon,image:e.image,url:e.url,title:e.title,content:e.content,ext:e.ext},success:e.success,fail:e.fail,complete:e.complete})},shareQzone:function(e){Qu({event:"shareQzone",data:{type:e.type||"text",icon:e.icon,image:e.image,url:e.url,title:e.title,content:e.content,ext:e.ext},success:e.success,fail:e.fail,complete:e.complete})},shareAlipayFriend:function(e){Qu({event:"shareAlipayFriend",data:{type:e.type||"text",icon:e.icon,image:e.image,url:e.url,title:e.title,content:e.content,ext:e.ext},success:e.success,fail:e.fail,complete:e.complete})},shareAlipayLife:function(e){Qu({event:"shareAlipayLife",data:{type:e.type||"text",icon:e.icon,image:e.image,url:e.url,title:e.title,content:e.content,ext:e.ext},success:e.success,fail:e.fail,complete:e.complete})},shareSinaWeibo:function(e){Qu({event:"shareSinaWeibo",data:{type:e.type||"text",icon:e.icon,image:e.image,url:e.url,title:e.title,content:e.content,ext:e.ext},success:e.success,fail:e.fail,complete:e.complete})},getPerformance:function(){return Nl||(Nl=new xl),Nl},pageScrollTo:function(e){var t=__appServiceEngine__.getCurrentPagesByDomain(""),n=t[t.length-1].__ddWebViewId__;e.page&&(e.page.__ddWebViewId__||e.page.__wxWebviewId__)&&(n=e.page.__ddWebViewId__||e.page.__wxWebviewId__);var r={};for(var i in e)"function"==typeof e[i]&&(r[i]=e[i],delete e[i]);e.callBackId=Ml,kl[Ml]=r,Ml++,didiJsBridge.publish({event:"pageScrollTo",data:e,webViewId:n})},requestPayment:function(e){if(!e.isTrip&&!e.outTradeId)return e.fail&&e.fail("缺少outTradeId"),void(e.complete&&e.complete());for(var t={},n=0,r=["isTrip","oid","sid","bid","appId","domain","isOnline","mOfflineURL","outToken","ext_info","bizContent","sign","signType","terminalId","orderId"];n<r.length;n++){var i=r[n];void 0!==e[i]&&(t[i]=e[i])}Qu({event:"requestPayment",data:Li({outTradeId:e.outTradeId},t),success:e.success,fail:e.fail,complete:e.complete})},skiaCanvasRemove:Tl,extBridge:function(e,t){e&&e.event&&e.module&&didiJsBridge.invoke({module:e.module,method:e.event,data:e.data||{},isSustain:e.isSustain||!1,callback:t||function(t){(t=t.data).success?e.success&&e.success(t.data):e.fail&&e.fail({errMsg:t.errMsg}),e.complete&&e.complete()}})},extOnBridge:function(e){var t=e.event,n=e.module,r=e.callBack;if(n&&"DMServiceBridgeModule"!==n&&t&&r){var i=n+"_"+t;Hu({eventManagerName:i,nativeEvent:i,callBack:r})}},extOffBridge:function(e){var t=e.event,n=e.module,r=e.callBack;if(n&&"DMServiceBridgeModule"!==n&&t){var i=n+"_"+t;$u({eventManagerName:i,nativeEvent:i,callBack:r})}},triggerGC:function(){if(!Sp){Sp=!0;for(var e={},t=0;t<1e5;t++)e[t]=[];e=null,new Promise((function(e){e(!0)})).then((function(){})).catch((function(){})).finally((function(){return Sp&&(Sp=!1)}))}},goSuperAppTab:Rd,onCloseMiniProgram:function(e){qu("onCloseMiniProgram").internalOnMethod(e)},exitMiniProgram:function(e){void 0===e&&(e={}),Qu({event:"exitMiniProgram",data:{},success:e.success,fail:e.fail,complete:e.complete})},createInnerAudioContext:function(){var e=new Ap(Cp);Lp=Number(Math.random().toString().substr(3,13)+Date.now()).toString(36);var t=new Proxy(e,{get:function(e,t){return e[t]},set:function(e,t,n){var r;return Qu({event:"updateAudioInstanceState",data:(r={audioId:Lp},r[t]=n,r)}),e[t]=n,!0}});return Ep.set(Lp,t),t},createMapContext:function(e,t){return new Vp(e,t)},createCameraContext:function(){return new Bp},emitUnhandledRejection:function(e){Hl||(Hl=qu("unhandledRejection")),Hl&&Hl.emit(e);var t=e.reason;if(t instanceof Error)__appServiceSDK__.reportUncaughtError({info:"Uncaught (in promise) "+t.toString(),stack:t.stack,isPromise:!0}),(n=__appServiceEngine__.getApp())&&n.onUnhandledRejection&&n.onUnhandledRejection(e);else if("string"==typeof t&&t.length>0){var n;__appServiceSDK__.reportUncaughtError({info:"Uncaught (in promise) "+t,isPromise:!0}),(n=__appServiceEngine__.getApp())&&n.onUnhandledRejection&&n.onUnhandledRejection(e)}},onUnhandledRejection:function(e){Hl||(Hl=qu("unhandledRejection")),Hl.onMethod(e)},offUnhandledRejection:function(e){Hl&&Hl.offMethod(e)},reportEvent:function(e){didiJsBridge.invoke({method:"reportEvent",data:Li({},e)})}},Sh={openSetting:function(e){void 0===e&&(e={}),Qu({event:"openSetting",data:{},success:e&&e.success,fail:e&&e.fail,complete:e&&e.complete})},showToast:function(e){Qu({event:"showToast",data:{title:e.title,icon:e.icon,image:e.image,duration:e.duration||1500,mask:e.mask||!1},success:e.success,fail:e.fail,complete:e.complete})},hideToast:function(e){void 0===e&&(e={}),Qu({event:"hideToast",data:{},success:e.success,fail:e.fail,complete:e.complete})},showModal:function(e){window.isBrowser?window.confirm(e.content)?e.success({confirm:!0}):e.fail({confirm:!1}):Qu({event:"showModal",data:{title:e.title,content:e.content,showCancel:void 0===e.showCancel||e.showCancel,cancelText:e.cancelText||"取消",cancelColor:e.cancelColor||"#000000",confirmText:e.confirmText||"确定",confirmColor:e.confirmColor||"#576B95"},success:e.success,fail:e.fail,complete:e.complete})},navigateTo:Bd.navigateTo,redirectTo:Bd.redirectTo,navigateBack:Bd.navigateBack,switchTab:Bd.switchTab,reLaunch:Bd.reLaunch};bp("invokeAppServiceMethod",(function(e){e.name in Sh&&Sh[e.name].apply(void 0,e.args)})),bp("skiaCanvasRemove",(function(e){var t=e.viewId;Tl(e.webViewId,t)})),gh="noTargetApiCall",mh=function(e){var t=e||{},n=t.module,i=void 0===n?"未知模块":n,o=t.method,a="Native模块"+i+"里没有"+(void 0===o?"未知api":o)+"此Api，请联系Native同学查看";r&&r.vConsoleLog&&r.vConsoleLog(3,a)},didiJsBridge.on({event:gh},(function(e){var t=e.data,n=void 0===t?{}:t,r=e.webViewId;Xa(mh)&&mh(n,r)}));var wh=bh,_h={vdSync:function(e,t){mp("vdSync",{data:e,webViewId:t},t)},vdSyncBatch:function(e,t){mp("vdSyncBatch",{data:e,webViewId:t},t)},onVdSync:function(e){bp("vdSync",(function(t){var n=t.data,r=t.webViewId;e(n,r)}))},onVdSyncBatch:function(e){bp("vdSyncBatch",(function(t){var n=t.data,r=t.webViewId;e(n,r)}))}};var Th=qu("onAppRouteDone").internalOnMethod,kh=qu("onAppRouteDone").internalOffMethod,Mh=0,Nh=[];jd((function e(t){var n={};"appLaunch"===t.openType&&(n=yd(),qu("onAppShow").emitInternal(n),Vd(e))}));var Ih=qu("AppEnterForeground"),Oh=qu("onAppShow");didiJsBridge.on({event:"onAppEnterForeground"},(function(e){Oh.emit(e)})),didiJsBridge.subscribe({event:"onPageReload"},(function(e){void 0===e&&(e={data:{path:"",webViewId:-1,query:{}}});var t=e.data;qu("onPageReload").emit({path:t.path,webViewId:t.webViewId,query:t.query})})),didiJsBridge.on({event:"onPullDownRefresh"},(function(){qu("onPullDownRefresh").emit()}));var xh=qu("onPullDownRefresh").internalOnMethod,Ph=qu("onPullDownRefresh").internalOffMethod,Lh={proxySDK:Gu,dd:wh,_createSelectorQuery:yp,_createIntersectionObserver:vp,_virtualDOMTunnel:_h,_getPackageDirByRoute:od,getLaunchOptionsSync:yd,getEnterOptionsSync:vd,pluginInfos:{},onAppRouteDone:Th,offAppRouteDone:kh,invokeWebviewMethod:function(e,t,n,r){void 0===t&&(t={});var i=Mh++;Nh[i]=r,mp&&mp("invokeWebviewMethod",{name:e,args:t,callbackId:i},void 0===n?Ed.currentWebviewId:n),bp&&bp("callbackWebviewMethod",(function(e){var t=e.callbackId;r=Nh[t],delete Nh[t],r&&r(e.res)}))},onAppRoute:jd,onAppRouteInit:Ad,offAppRoute:Vd,onAppShow:qu("onAppShow").onMethod,onAppEnterForeground:function(){return Ih.internalOnMethod},emitIsloatedAppShow:function(e){!function(e){qu("onAppShow").emitGlobal(e)}(e)},onAppHide:gp,traceEvent:function(e){didiJsBridge.invoke({method:"traceEvent",data:Li({},e)})},onAppEnterBackground:function(){didiJsBridge.on({event:"onAppEnterBackground"},(function(){qu("AppHide").emit()}))},onCallMethodFromWxs:function(e){bp("vdCallComponentMethodForWxs",e)},onPageReload:qu("onPageReload").internalOnMethod,offPageReload:qu("onPageReload").internalOffMethod,onPullDownRefresh:xh,offPullDownRefresh:Ph,installPackageByRoute:pd,RouteTask:td,getPackageLoadStatus:sd,setPackageLoadStatus:cd,requireByRoute:fd,traceBeginEvent:function(e,t){if(e&&t)try{var n={category:e,name:t,timeStamp:(new Date).getTime()};if(zl.length>=1){var r=zl.length-1;Dl=(new Date).getTime()-zl[r].timeStamp}zl.push(n)}catch(e){}},traceEndEvent:function(){if(zl&&zl.length)try{var e=zl.pop(),t=(new Date).getTime(),n=t-e.timeStamp,r=zl[zl.length-1];Bl(("pub_saga_"+e.category+"_"+e.name+"_bt").toLowerCase(),{start_time:e.timeStamp,end_time:t,take_up_time:n,take_begin_time:Dl,take_before_name:r.name,take_before_category:r.category})}catch(e){}},reportNative:Bl,traceCoreDotting:Rl,reportToMiniBackend:Wl,reportUncaughtError:function(e){if(e){var t=(e.info||"")+"\n"+(e.stack||"");if(Vl("reportUncaughtError")){var n=__appServiceEngine__.getApp();return Qu({event:"reportUncaughtError",data:Li(Li({},e),{appId:null==n?void 0:n.__appId__})}),void(e.isPromise||e.disableAppError||n&&n.onError&&n.onError(t))}Fl(t,e.isPromise)}}};return Lh}();

var dd = __appServiceSDK__.dd;

var exparser=function(){"use strict";var e=function(e){try{return!!e()}catch(e){return!0}},t=!e((function(){var e=function(){}.bind();return"function"!=typeof e||e.hasOwnProperty("prototype")})),r=Function.prototype,n=r.bind,i=r.call,o=t&&n.bind(i,i),a=t?function(e){return e&&o(e)}:function(e){return e&&function(){return i.apply(e,arguments)}},s=a({}.toString),l=a("".slice),u=function(e){return l(s(e),8,-1)},c=Object,d=a("".split),f=e((function(){return!c("z").propertyIsEnumerable(0)}))?function(e){return"String"==u(e)?d(e,""):c(e)}:c,_=TypeError,p=function(e){if(null==e)throw _("Can't call method on "+e);return e},h=function(e){return f(p(e))},v="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function g(e,t,r){return e(r={path:t,exports:{},require:function(e,t){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==t&&r.path)}},r.exports),r.exports}var y,m,b=function(e){return e&&e.Math==Math&&e},E=b("object"==typeof globalThis&&globalThis)||b("object"==typeof window&&window)||b("object"==typeof self&&self)||b("object"==typeof v&&v)||function(){return this}()||Function("return this")(),w=Object.defineProperty,O=function(e,t){try{w(E,e,{value:t,configurable:!0,writable:!0})}catch(r){E[e]=t}return t},A="__core-js_shared__",C=E[A]||O(A,{}),S=g((function(e){(e.exports=function(e,t){return C[e]||(C[e]=void 0!==t?t:{})})("versions",[]).push({version:"3.24.1",mode:"global",copyright:"© 2014-2022 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.24.1/LICENSE",source:"https://github.com/zloirock/core-js"})})),T=Object,N=function(e){return T(p(e))},x=a({}.hasOwnProperty),I=Object.hasOwn||function(e,t){return x(N(e),t)},R=0,L=Math.random(),M=a(1..toString),k=function(e){return"Symbol("+(void 0===e?"":e)+")_"+M(++R+L,36)},P=function(e){return"function"==typeof e},j=function(e){return P(e)?e:void 0},D=function(e,t){return arguments.length<2?j(E[e]):E[e]&&E[e][t]},B=D("navigator","userAgent")||"",F=E.process,U=E.Deno,G=F&&F.versions||U&&U.version,H=G&&G.v8;H&&(m=(y=H.split("."))[0]>0&&y[0]<4?1:+(y[0]+y[1])),!m&&B&&(!(y=B.match(/Edge\/(\d+)/))||y[1]>=74)&&(y=B.match(/Chrome\/(\d+)/))&&(m=+y[1]);var V,z=m,$=!!Object.getOwnPropertySymbols&&!e((function(){var e=Symbol();return!String(e)||!(Object(e)instanceof Symbol)||!Symbol.sham&&z&&z<41})),Y=$&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,W=S("wks"),Z=E.Symbol,J=Z&&Z.for,K=Y?Z:Z&&Z.withoutSetter||k,q=function(e){if(!I(W,e)||!$&&"string"!=typeof W[e]){var t="Symbol."+e;$&&I(Z,e)?W[e]=Z[e]:W[e]=Y&&J?J(t):K(t)}return W[e]},X=function(e){return"object"==typeof e?null!==e:P(e)},Q=String,ee=TypeError,te=function(e){if(X(e))return e;throw ee(Q(e)+" is not an object")},re=!e((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),ne=re&&e((function(){return 42!=Object.defineProperty((function(){}),"prototype",{value:42,writable:!1}).prototype})),ie=E.document,oe=X(ie)&&X(ie.createElement),ae=function(e){return oe?ie.createElement(e):{}},se=!re&&!e((function(){return 7!=Object.defineProperty(ae("div"),"a",{get:function(){return 7}}).a})),le=Function.prototype.call,ue=t?le.bind(le):function(){return le.apply(le,arguments)},ce=a({}.isPrototypeOf),de=Object,fe=Y?function(e){return"symbol"==typeof e}:function(e){var t=D("Symbol");return P(t)&&ce(t.prototype,de(e))},_e=String,pe=function(e){try{return _e(e)}catch(e){return"Object"}},he=TypeError,ve=function(e){if(P(e))return e;throw he(pe(e)+" is not a function")},ge=function(e,t){var r=e[t];return null==r?void 0:ve(r)},ye=TypeError,me=TypeError,be=q("toPrimitive"),Ee=function(e,t){if(!X(e)||fe(e))return e;var r,n=ge(e,be);if(n){if(void 0===t&&(t="default"),r=ue(n,e,t),!X(r)||fe(r))return r;throw me("Can't convert object to primitive value")}return void 0===t&&(t="number"),function(e,t){var r,n;if("string"===t&&P(r=e.toString)&&!X(n=ue(r,e)))return n;if(P(r=e.valueOf)&&!X(n=ue(r,e)))return n;if("string"!==t&&P(r=e.toString)&&!X(n=ue(r,e)))return n;throw ye("Can't convert object to primitive value")}(e,t)},we=function(e){var t=Ee(e,"string");return fe(t)?t:t+""},Oe=TypeError,Ae=Object.defineProperty,Ce=Object.getOwnPropertyDescriptor,Se="enumerable",Te="configurable",Ne="writable",xe=re?ne?function(e,t,r){if(te(e),t=we(t),te(r),"function"==typeof e&&"prototype"===t&&"value"in r&&Ne in r&&!r.writable){var n=Ce(e,t);n&&n.writable&&(e[t]=r.value,r={configurable:Te in r?r.configurable:n.configurable,enumerable:Se in r?r.enumerable:n.enumerable,writable:!1})}return Ae(e,t,r)}:Ae:function(e,t,r){if(te(e),t=we(t),te(r),se)try{return Ae(e,t,r)}catch(e){}if("get"in r||"set"in r)throw Oe("Accessors not supported");return"value"in r&&(e[t]=r.value),e},Ie={f:xe},Re=Math.ceil,Le=Math.floor,Me=Math.trunc||function(e){var t=+e;return(t>0?Le:Re)(t)},ke=function(e){var t=+e;return t!=t||0===t?0:Me(t)},Pe=Math.max,je=Math.min,De=function(e,t){var r=ke(e);return r<0?Pe(r+t,0):je(r,t)},Be=Math.min,Fe=function(e){return e>0?Be(ke(e),9007199254740991):0},Ue=function(e){return Fe(e.length)},Ge=function(e){return function(t,r,n){var i,o=h(t),a=Ue(o),s=De(n,a);if(e&&r!=r){for(;a>s;)if((i=o[s++])!=i)return!0}else for(;a>s;s++)if((e||s in o)&&o[s]===r)return e||s||0;return!e&&-1}},He={includes:Ge(!0),indexOf:Ge(!1)},Ve={},ze=He.indexOf,$e=a([].push),Ye=function(e,t){var r,n=h(e),i=0,o=[];for(r in n)!I(Ve,r)&&I(n,r)&&$e(o,r);for(;t.length>i;)I(n,r=t[i++])&&(~ze(o,r)||$e(o,r));return o},We=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],Ze=Object.keys||function(e){return Ye(e,We)},Je=re&&!ne?Object.defineProperties:function(e,t){te(e);for(var r,n=h(t),i=Ze(t),o=i.length,a=0;o>a;)Ie.f(e,r=i[a++],n[r]);return e},Ke={f:Je},qe=D("document","documentElement"),Xe=S("keys"),Qe=function(e){return Xe[e]||(Xe[e]=k(e))},et=Qe("IE_PROTO"),tt=function(){},rt=function(e){return"<script>"+e+"</"+"script>"},nt=function(e){e.write(rt("")),e.close();var t=e.parentWindow.Object;return e=null,t},it=function(){try{V=new ActiveXObject("htmlfile")}catch(e){}var e,t;it="undefined"!=typeof document?document.domain&&V?nt(V):((t=ae("iframe")).style.display="none",qe.appendChild(t),t.src=String("javascript:"),(e=t.contentWindow.document).open(),e.write(rt("document.F=Object")),e.close(),e.F):nt(V);for(var r=We.length;r--;)delete it.prototype[We[r]];return it()};Ve[et]=!0;var ot=Object.create||function(e,t){var r;return null!==e?(tt.prototype=te(e),r=new tt,tt.prototype=null,r[et]=e):r=it(),void 0===t?r:Ke.f(r,t)},at=Ie.f,st=q("unscopables"),lt=Array.prototype;null==lt[st]&&at(lt,st,{configurable:!0,value:ot(null)});var ut=function(e){lt[st][e]=!0},ct={},dt=a(Function.toString);P(C.inspectSource)||(C.inspectSource=function(e){return dt(e)});var ft,_t,pt,ht=C.inspectSource,vt=E.WeakMap,gt=P(vt)&&/native code/.test(ht(vt)),yt=function(e,t){return{enumerable:!(1&e),configurable:!(2&e),writable:!(4&e),value:t}},mt=re?function(e,t,r){return Ie.f(e,t,yt(1,r))}:function(e,t,r){return e[t]=r,e},bt="Object already initialized",Et=E.TypeError,wt=E.WeakMap;if(gt||C.state){var Ot=C.state||(C.state=new wt),At=a(Ot.get),Ct=a(Ot.has),St=a(Ot.set);ft=function(e,t){if(Ct(Ot,e))throw new Et(bt);return t.facade=e,St(Ot,e,t),t},_t=function(e){return At(Ot,e)||{}},pt=function(e){return Ct(Ot,e)}}else{var Tt=Qe("state");Ve[Tt]=!0,ft=function(e,t){if(I(e,Tt))throw new Et(bt);return t.facade=e,mt(e,Tt,t),t},_t=function(e){return I(e,Tt)?e[Tt]:{}},pt=function(e){return I(e,Tt)}}var Nt,xt,It,Rt={set:ft,get:_t,has:pt,enforce:function(e){return pt(e)?_t(e):ft(e,{})},getterFor:function(e){return function(t){var r;if(!X(t)||(r=_t(t)).type!==e)throw Et("Incompatible receiver, "+e+" required");return r}}},Lt={}.propertyIsEnumerable,Mt=Object.getOwnPropertyDescriptor,kt={f:Mt&&!Lt.call({1:2},1)?function(e){var t=Mt(this,e);return!!t&&t.enumerable}:Lt},Pt=Object.getOwnPropertyDescriptor,jt=re?Pt:function(e,t){if(e=h(e),t=we(t),se)try{return Pt(e,t)}catch(e){}if(I(e,t))return yt(!ue(kt.f,e,t),e[t])},Dt={f:jt},Bt=Function.prototype,Ft=re&&Object.getOwnPropertyDescriptor,Ut=I(Bt,"name"),Gt={EXISTS:Ut,PROPER:Ut&&"something"===function(){}.name,CONFIGURABLE:Ut&&(!re||re&&Ft(Bt,"name").configurable)},Ht=g((function(t){var r=Gt.CONFIGURABLE,n=Rt.enforce,i=Rt.get,o=Object.defineProperty,a=re&&!e((function(){return 8!==o((function(){}),"length",{value:8}).length})),s=String(String).split("String"),l=t.exports=function(e,t,i){"Symbol("===String(t).slice(0,7)&&(t="["+String(t).replace(/^Symbol\(([^)]*)\)/,"$1")+"]"),i&&i.getter&&(t="get "+t),i&&i.setter&&(t="set "+t),(!I(e,"name")||r&&e.name!==t)&&(re?o(e,"name",{value:t,configurable:!0}):e.name=t),a&&i&&I(i,"arity")&&e.length!==i.arity&&o(e,"length",{value:i.arity});try{i&&I(i,"constructor")&&i.constructor?re&&o(e,"prototype",{writable:!1}):e.prototype&&(e.prototype=void 0)}catch(e){}var l=n(e);return I(l,"source")||(l.source=s.join("string"==typeof t?t:"")),e};Function.prototype.toString=l((function(){return P(this)&&i(this).source||ht(this)}),"toString")})),Vt=function(e,t,r,n){n||(n={});var i=n.enumerable,o=void 0!==n.name?n.name:t;if(P(r)&&Ht(r,o,n),n.global)i?e[t]=r:O(t,r);else{try{n.unsafe?e[t]&&(i=!0):delete e[t]}catch(e){}i?e[t]=r:Ie.f(e,t,{value:r,enumerable:!1,configurable:!n.nonConfigurable,writable:!n.nonWritable})}return e},zt=We.concat("length","prototype"),$t=Object.getOwnPropertyNames||function(e){return Ye(e,zt)},Yt={f:$t},Wt={f:Object.getOwnPropertySymbols},Zt=a([].concat),Jt=D("Reflect","ownKeys")||function(e){var t=Yt.f(te(e)),r=Wt.f;return r?Zt(t,r(e)):t},Kt=function(e,t,r){for(var n=Jt(t),i=Ie.f,o=Dt.f,a=0;a<n.length;a++){var s=n[a];I(e,s)||r&&I(r,s)||i(e,s,o(t,s))}},qt=/#|\.prototype\./,Xt=function(t,r){var n=er[Qt(t)];return n==rr||n!=tr&&(P(r)?e(r):!!r)},Qt=Xt.normalize=function(e){return String(e).replace(qt,".").toLowerCase()},er=Xt.data={},tr=Xt.NATIVE="N",rr=Xt.POLYFILL="P",nr=Xt,ir=Dt.f,or=function(e,t){var r,n,i,o,a,s=e.target,l=e.global,u=e.stat;if(r=l?E:u?E[s]||O(s,{}):(E[s]||{}).prototype)for(n in t){if(o=t[n],i=e.dontCallGetSet?(a=ir(r,n))&&a.value:r[n],!nr(l?n:s+(u?".":"#")+n,e.forced)&&void 0!==i){if(typeof o==typeof i)continue;Kt(o,i)}(e.sham||i&&i.sham)&&mt(o,"sham",!0),Vt(r,n,o,e)}},ar=!e((function(){function e(){}return e.prototype.constructor=null,Object.getPrototypeOf(new e)!==e.prototype})),sr=Qe("IE_PROTO"),lr=Object,ur=lr.prototype,cr=ar?lr.getPrototypeOf:function(e){var t=N(e);if(I(t,sr))return t[sr];var r=t.constructor;return P(r)&&t instanceof r?r.prototype:t instanceof lr?ur:null},dr=q("iterator"),fr=!1;[].keys&&("next"in(It=[].keys())?(xt=cr(cr(It)))!==Object.prototype&&(Nt=xt):fr=!0);var _r=null==Nt||e((function(){var e={};return Nt[dr].call(e)!==e}));_r&&(Nt={}),P(Nt[dr])||Vt(Nt,dr,(function(){return this}));var pr={IteratorPrototype:Nt,BUGGY_SAFARI_ITERATORS:fr},hr=Ie.f,vr=q("toStringTag"),gr=function(e,t,r){e&&!r&&(e=e.prototype),e&&!I(e,vr)&&hr(e,vr,{configurable:!0,value:t})},yr=pr.IteratorPrototype,mr=function(){return this},br=String,Er=TypeError,wr=Object.setPrototypeOf||("__proto__"in{}?function(){var e,t=!1,r={};try{(e=a(Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set))(r,[]),t=r instanceof Array}catch(e){}return function(r,n){return te(r),function(e){if("object"==typeof e||P(e))return e;throw Er("Can't set "+br(e)+" as a prototype")}(n),t?e(r,n):r.__proto__=n,r}}():void 0),Or=Gt.PROPER,Ar=Gt.CONFIGURABLE,Cr=pr.IteratorPrototype,Sr=pr.BUGGY_SAFARI_ITERATORS,Tr=q("iterator"),Nr="keys",xr="values",Ir="entries",Rr=function(){return this},Lr=function(e,t,r,n,i,o,a){!function(e,t,r,n){var i=t+" Iterator";e.prototype=ot(yr,{next:yt(+!n,r)}),gr(e,i,!1),ct[i]=mr}(r,t,n);var s,l,u,c=function(e){if(e===i&&h)return h;if(!Sr&&e in _)return _[e];switch(e){case Nr:case xr:case Ir:return function(){return new r(this,e)}}return function(){return new r(this)}},d=t+" Iterator",f=!1,_=e.prototype,p=_[Tr]||_["@@iterator"]||i&&_[i],h=!Sr&&p||c(i),v="Array"==t&&_.entries||p;if(v&&(s=cr(v.call(new e)))!==Object.prototype&&s.next&&(cr(s)!==Cr&&(wr?wr(s,Cr):P(s[Tr])||Vt(s,Tr,Rr)),gr(s,d,!0)),Or&&i==xr&&p&&p.name!==xr&&(Ar?mt(_,"name",xr):(f=!0,h=function(){return ue(p,this)})),i)if(l={values:c(xr),keys:o?h:c(Nr),entries:c(Ir)},a)for(u in l)(Sr||f||!(u in _))&&Vt(_,u,l[u]);else or({target:t,proto:!0,forced:Sr||f},l);return _[Tr]!==h&&Vt(_,Tr,h,{name:i}),ct[t]=h,l},Mr=Ie.f,kr="Array Iterator",Pr=Rt.set,jr=Rt.getterFor(kr),Dr=Lr(Array,"Array",(function(e,t){Pr(this,{type:kr,target:h(e),index:0,kind:t})}),(function(){var e=jr(this),t=e.target,r=e.kind,n=e.index++;return!t||n>=t.length?(e.target=void 0,{value:void 0,done:!0}):"keys"==r?{value:n,done:!1}:"values"==r?{value:t[n],done:!1}:{value:[n,t[n]],done:!1}}),"values"),Br=ct.Arguments=ct.Array;if(ut("keys"),ut("values"),ut("entries"),re&&"values"!==Br.name)try{Mr(Br,"name",{value:"values"})}catch(e){}var Fr="undefined"!=typeof ArrayBuffer&&"undefined"!=typeof DataView,Ur=function(e,t,r){for(var n in t)Vt(e,n,t[n],r);return e},Gr=TypeError,Hr=function(e,t){if(ce(t,e))return e;throw Gr("Incorrect invocation")},Vr=RangeError,zr=function(e){if(void 0===e)return 0;var t=ke(e),r=Fe(t);if(t!==r)throw Vr("Wrong length or index");return r},$r=Array,Yr=Math.abs,Wr=Math.pow,Zr=Math.floor,Jr=Math.log,Kr=Math.LN2,qr=function(e,t,r){var n,i,o,a=$r(r),s=8*r-t-1,l=(1<<s)-1,u=l>>1,c=23===t?Wr(2,-24)-Wr(2,-77):0,d=e<0||0===e&&1/e<0?1:0,f=0;for((e=Yr(e))!=e||e===1/0?(i=e!=e?1:0,n=l):(n=Zr(Jr(e)/Kr),e*(o=Wr(2,-n))<1&&(n--,o*=2),(e+=n+u>=1?c/o:c*Wr(2,1-u))*o>=2&&(n++,o/=2),n+u>=l?(i=0,n=l):n+u>=1?(i=(e*o-1)*Wr(2,t),n+=u):(i=e*Wr(2,u-1)*Wr(2,t),n=0));t>=8;)a[f++]=255&i,i/=256,t-=8;for(n=n<<t|i,s+=t;s>0;)a[f++]=255&n,n/=256,s-=8;return a[--f]|=128*d,a},Xr=function(e,t){var r,n=e.length,i=8*n-t-1,o=(1<<i)-1,a=o>>1,s=i-7,l=n-1,u=e[l--],c=127&u;for(u>>=7;s>0;)c=256*c+e[l--],s-=8;for(r=c&(1<<-s)-1,c>>=-s,s+=t;s>0;)r=256*r+e[l--],s-=8;if(0===c)c=1-a;else{if(c===o)return r?NaN:u?-1/0:1/0;r+=Wr(2,t),c-=a}return(u?-1:1)*r*Wr(2,c-t)},Qr=function(e){for(var t=N(this),r=Ue(t),n=arguments.length,i=De(n>1?arguments[1]:void 0,r),o=n>2?arguments[2]:void 0,a=void 0===o?r:De(o,r);a>i;)t[i++]=e;return t},en=function(e,t,r){var n=we(t);n in e?Ie.f(e,n,yt(0,r)):e[n]=r},tn=Array,rn=Math.max,nn=function(e,t,r){for(var n=Ue(e),i=De(t,n),o=De(void 0===r?n:r,n),a=tn(rn(o-i,0)),s=0;i<o;i++,s++)en(a,s,e[i]);return a.length=s,a},on=Yt.f,an=Ie.f,sn=Gt.PROPER,ln=Gt.CONFIGURABLE,un=Rt.get,cn=Rt.set,dn="ArrayBuffer",fn="DataView",_n="Wrong index",pn=E.ArrayBuffer,hn=pn,vn=hn&&hn.prototype,gn=E.DataView,yn=gn&&gn.prototype,mn=Object.prototype,bn=E.Array,En=E.RangeError,wn=a(Qr),On=a([].reverse),An=qr,Cn=Xr,Sn=function(e){return[255&e]},Tn=function(e){return[255&e,e>>8&255]},Nn=function(e){return[255&e,e>>8&255,e>>16&255,e>>24&255]},xn=function(e){return e[3]<<24|e[2]<<16|e[1]<<8|e[0]},In=function(e){return An(e,23,4)},Rn=function(e){return An(e,52,8)},Ln=function(e,t){an(e.prototype,t,{get:function(){return un(this)[t]}})},Mn=function(e,t,r,n){var i=zr(r),o=un(e);if(i+t>o.byteLength)throw En(_n);var a=un(o.buffer).bytes,s=i+o.byteOffset,l=nn(a,s,s+t);return n?l:On(l)},kn=function(e,t,r,n,i,o){var a=zr(r),s=un(e);if(a+t>s.byteLength)throw En(_n);for(var l=un(s.buffer).bytes,u=a+s.byteOffset,c=n(+i),d=0;d<t;d++)l[u+d]=c[o?d:t-d-1]};if(Fr){var Pn=sn&&pn.name!==dn;if(e((function(){pn(1)}))&&e((function(){new pn(-1)}))&&!e((function(){return new pn,new pn(1.5),new pn(NaN),Pn&&!ln})))Pn&&ln&&mt(pn,"name",dn);else{(hn=function(e){return Hr(this,vn),new pn(zr(e))}).prototype=vn;for(var jn,Dn=on(pn),Bn=0;Dn.length>Bn;)(jn=Dn[Bn++])in hn||mt(hn,jn,pn[jn]);vn.constructor=hn}wr&&cr(yn)!==mn&&wr(yn,mn);var Fn=new gn(new hn(2)),Un=a(yn.setInt8);Fn.setInt8(0,2147483648),Fn.setInt8(1,2147483649),!Fn.getInt8(0)&&Fn.getInt8(1)||Ur(yn,{setInt8:function(e,t){Un(this,e,t<<24>>24)},setUint8:function(e,t){Un(this,e,t<<24>>24)}},{unsafe:!0})}else vn=(hn=function(e){Hr(this,vn);var t=zr(e);cn(this,{bytes:wn(bn(t),0),byteLength:t}),re||(this.byteLength=t)}).prototype,yn=(gn=function(e,t,r){Hr(this,yn),Hr(e,vn);var n=un(e).byteLength,i=ke(t);if(i<0||i>n)throw En("Wrong offset");if(i+(r=void 0===r?n-i:Fe(r))>n)throw En("Wrong length");cn(this,{buffer:e,byteLength:r,byteOffset:i}),re||(this.buffer=e,this.byteLength=r,this.byteOffset=i)}).prototype,re&&(Ln(hn,"byteLength"),Ln(gn,"buffer"),Ln(gn,"byteLength"),Ln(gn,"byteOffset")),Ur(yn,{getInt8:function(e){return Mn(this,1,e)[0]<<24>>24},getUint8:function(e){return Mn(this,1,e)[0]},getInt16:function(e){var t=Mn(this,2,e,arguments.length>1?arguments[1]:void 0);return(t[1]<<8|t[0])<<16>>16},getUint16:function(e){var t=Mn(this,2,e,arguments.length>1?arguments[1]:void 0);return t[1]<<8|t[0]},getInt32:function(e){return xn(Mn(this,4,e,arguments.length>1?arguments[1]:void 0))},getUint32:function(e){return xn(Mn(this,4,e,arguments.length>1?arguments[1]:void 0))>>>0},getFloat32:function(e){return Cn(Mn(this,4,e,arguments.length>1?arguments[1]:void 0),23)},getFloat64:function(e){return Cn(Mn(this,8,e,arguments.length>1?arguments[1]:void 0),52)},setInt8:function(e,t){kn(this,1,e,Sn,t)},setUint8:function(e,t){kn(this,1,e,Sn,t)},setInt16:function(e,t){kn(this,2,e,Tn,t,arguments.length>2?arguments[2]:void 0)},setUint16:function(e,t){kn(this,2,e,Tn,t,arguments.length>2?arguments[2]:void 0)},setInt32:function(e,t){kn(this,4,e,Nn,t,arguments.length>2?arguments[2]:void 0)},setUint32:function(e,t){kn(this,4,e,Nn,t,arguments.length>2?arguments[2]:void 0)},setFloat32:function(e,t){kn(this,4,e,In,t,arguments.length>2?arguments[2]:void 0)},setFloat64:function(e,t){kn(this,8,e,Rn,t,arguments.length>2?arguments[2]:void 0)}});gr(hn,dn),gr(gn,fn);var Gn={ArrayBuffer:hn,DataView:gn},Hn={};Hn[q("toStringTag")]="z";var Vn="[object z]"===String(Hn),zn=q("toStringTag"),$n=Object,Yn="Arguments"==u(function(){return arguments}()),Wn=Vn?u:function(e){var t,r,n;return void 0===e?"Undefined":null===e?"Null":"string"==typeof(r=function(e,t){try{return e[t]}catch(e){}}(t=$n(e),zn))?r:Yn?u(t):"Object"==(n=u(t))&&P(t.callee)?"Arguments":n},Zn=function(){},Jn=[],Kn=D("Reflect","construct"),qn=/^\s*(?:class|function)\b/,Xn=a(qn.exec),Qn=!qn.exec(Zn),ei=function(e){if(!P(e))return!1;try{return Kn(Zn,Jn,e),!0}catch(e){return!1}},ti=function(e){if(!P(e))return!1;switch(Wn(e)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return Qn||!!Xn(qn,ht(e))}catch(e){return!0}};ti.sham=!0;var ri=!Kn||e((function(){var e;return ei(ei.call)||!ei(Object)||!ei((function(){e=!0}))||e}))?ti:ei,ni=TypeError,ii=function(e){if(ri(e))return e;throw ni(pe(e)+" is not a constructor")},oi=q("species"),ai=function(e,t){var r,n=te(e).constructor;return void 0===n||null==(r=te(n)[oi])?t:ii(r)},si=Gn.ArrayBuffer,li=Gn.DataView,ui=li.prototype,ci=a(si.prototype.slice),di=a(ui.getUint8),fi=a(ui.setUint8),_i=e((function(){return!new si(2).slice(1,void 0).byteLength}));or({target:"ArrayBuffer",proto:!0,unsafe:!0,forced:_i},{slice:function(e,t){if(ci&&void 0===t)return ci(te(this),e);for(var r=te(this).byteLength,n=De(e,r),i=De(void 0===t?r:t,r),o=new(ai(this,si))(Fe(i-n)),a=new li(this),s=new li(o),l=0;n<i;)fi(s,l++,di(a,n++));return o}});var pi=Vn?{}.toString:function(){return"[object "+Wn(this)+"]"};Vn||Vt(Object.prototype,"toString",pi,{unsafe:!0});var hi=q("iterator"),vi=!1;try{var gi=0,yi={next:function(){return{done:!!gi++}},return:function(){vi=!0}};yi[hi]=function(){return this},Array.from(yi,(function(){throw 2}))}catch(e){}var mi,bi,Ei,wi=function(e,t){if(!t&&!vi)return!1;var r=!1;try{var n={};n[hi]=function(){return{next:function(){return{done:r=!0}}}},e(n)}catch(e){}return r},Oi=Ie.f,Ai=Rt.enforce,Ci=Rt.get,Si=E.Int8Array,Ti=Si&&Si.prototype,Ni=E.Uint8ClampedArray,xi=Ni&&Ni.prototype,Ii=Si&&cr(Si),Ri=Ti&&cr(Ti),Li=Object.prototype,Mi=E.TypeError,ki=q("toStringTag"),Pi=k("TYPED_ARRAY_TAG"),ji="TypedArrayConstructor",Di=Fr&&!!wr&&"Opera"!==Wn(E.opera),Bi=!1,Fi={Int8Array:1,Uint8Array:1,Uint8ClampedArray:1,Int16Array:2,Uint16Array:2,Int32Array:4,Uint32Array:4,Float32Array:4,Float64Array:8},Ui={BigInt64Array:8,BigUint64Array:8},Gi=function(e){var t=cr(e);if(X(t)){var r=Ci(t);return r&&I(r,ji)?r.TypedArrayConstructor:Gi(t)}},Hi=function(e){if(!X(e))return!1;var t=Wn(e);return I(Fi,t)||I(Ui,t)};for(mi in Fi)(Ei=(bi=E[mi])&&bi.prototype)?Ai(Ei).TypedArrayConstructor=bi:Di=!1;for(mi in Ui)(Ei=(bi=E[mi])&&bi.prototype)&&(Ai(Ei).TypedArrayConstructor=bi);if((!Di||!P(Ii)||Ii===Function.prototype)&&(Ii=function(){throw Mi("Incorrect invocation")},Di))for(mi in Fi)E[mi]&&wr(E[mi],Ii);if((!Di||!Ri||Ri===Li)&&(Ri=Ii.prototype,Di))for(mi in Fi)E[mi]&&wr(E[mi].prototype,Ri);if(Di&&cr(xi)!==Ri&&wr(xi,Ri),re&&!I(Ri,ki))for(mi in Bi=!0,Oi(Ri,ki,{get:function(){return X(this)?this[Pi]:void 0}}),Fi)E[mi]&&mt(E[mi],Pi,mi);var Vi={NATIVE_ARRAY_BUFFER_VIEWS:Di,TYPED_ARRAY_TAG:Bi&&Pi,aTypedArray:function(e){if(Hi(e))return e;throw Mi("Target is not a typed array")},aTypedArrayConstructor:function(e){if(P(e)&&(!wr||ce(Ii,e)))return e;throw Mi(pe(e)+" is not a typed array constructor")},exportTypedArrayMethod:function(e,t,r,n){if(re){if(r)for(var i in Fi){var o=E[i];if(o&&I(o.prototype,e))try{delete o.prototype[e]}catch(r){try{o.prototype[e]=t}catch(e){}}}Ri[e]&&!r||Vt(Ri,e,r?t:Di&&Ti[e]||t,n)}},exportTypedArrayStaticMethod:function(e,t,r){var n,i;if(re){if(wr){if(r)for(n in Fi)if((i=E[n])&&I(i,e))try{delete i[e]}catch(e){}if(Ii[e]&&!r)return;try{return Vt(Ii,e,r?t:Di&&Ii[e]||t)}catch(e){}}for(n in Fi)!(i=E[n])||i[e]&&!r||Vt(i,e,t)}},getTypedArrayConstructor:Gi,isView:function(e){if(!X(e))return!1;var t=Wn(e);return"DataView"===t||I(Fi,t)||I(Ui,t)},isTypedArray:Hi,TypedArray:Ii,TypedArrayPrototype:Ri},zi=Vi.NATIVE_ARRAY_BUFFER_VIEWS,$i=E.ArrayBuffer,Yi=E.Int8Array,Wi=!zi||!e((function(){Yi(1)}))||!e((function(){new Yi(-1)}))||!wi((function(e){new Yi,new Yi(null),new Yi(1.5),new Yi(e)}),!0)||e((function(){return 1!==new Yi(new $i(2),1,void 0).length})),Zi=Math.floor,Ji=Number.isInteger||function(e){return!X(e)&&isFinite(e)&&Zi(e)===e},Ki=RangeError,qi=RangeError,Xi=function(e,t){var r=function(e){var t=ke(e);if(t<0)throw Ki("The argument can't be less than 0");return t}(e);if(r%t)throw qi("Wrong offset");return r},Qi=a(a.bind),eo=function(e,r){return ve(e),void 0===r?e:t?Qi(e,r):function(){return e.apply(r,arguments)}},to=q("iterator"),ro=function(e){if(null!=e)return ge(e,to)||ge(e,"@@iterator")||ct[Wn(e)]},no=TypeError,io=function(e,t){var r=arguments.length<2?ro(e):t;if(ve(r))return te(ue(r,e));throw no(pe(e)+" is not iterable")},oo=q("iterator"),ao=Array.prototype,so=function(e){return void 0!==e&&(ct.Array===e||ao[oo]===e)},lo=Vi.aTypedArrayConstructor,uo=function(e){var t,r,n,i,o,a,s=ii(this),l=N(e),u=arguments.length,c=u>1?arguments[1]:void 0,d=void 0!==c,f=ro(l);if(f&&!so(f))for(a=(o=io(l,f)).next,l=[];!(i=ue(a,o)).done;)l.push(i.value);for(d&&u>2&&(c=eo(c,arguments[2])),r=Ue(l),n=new(lo(s))(r),t=0;r>t;t++)n[t]=d?c(l[t],t):l[t];return n},co=Array.isArray||function(e){return"Array"==u(e)},fo=q("species"),_o=Array,po=function(e,t){return new(function(e){var t;return co(e)&&(t=e.constructor,(ri(t)&&(t===_o||co(t.prototype))||X(t)&&null===(t=t[fo]))&&(t=void 0)),void 0===t?_o:t}(e))(0===t?0:t)},ho=a([].push),vo=function(e){var t=1==e,r=2==e,n=3==e,i=4==e,o=6==e,a=7==e,s=5==e||o;return function(l,u,c,d){for(var _,p,h=N(l),v=f(h),g=eo(u,c),y=Ue(v),m=0,b=d||po,E=t?b(l,y):r||a?b(l,0):void 0;y>m;m++)if((s||m in v)&&(p=g(_=v[m],m,h),e))if(t)E[m]=p;else if(p)switch(e){case 3:return!0;case 5:return _;case 6:return m;case 2:ho(E,_)}else switch(e){case 4:return!1;case 7:ho(E,_)}return o?-1:n||i?i:E}},go={forEach:vo(0),map:vo(1),filter:vo(2),some:vo(3),every:vo(4),find:vo(5),findIndex:vo(6),filterReject:vo(7)},yo=q("species"),mo=function(e){var t=D(e),r=Ie.f;re&&t&&!t[yo]&&r(t,yo,{configurable:!0,get:function(){return this}})},bo=function(e,t,r){var n,i;return wr&&P(n=t.constructor)&&n!==r&&X(i=n.prototype)&&i!==r.prototype&&wr(e,i),e},Eo=g((function(e){var t=Yt.f,r=go.forEach,n=Rt.get,i=Rt.set,o=Rt.enforce,a=Ie.f,s=Dt.f,l=Math.round,u=E.RangeError,c=Gn.ArrayBuffer,d=c.prototype,f=Gn.DataView,_=Vi.NATIVE_ARRAY_BUFFER_VIEWS,p=Vi.TYPED_ARRAY_TAG,h=Vi.TypedArray,v=Vi.TypedArrayPrototype,g=Vi.aTypedArrayConstructor,y=Vi.isTypedArray,m="BYTES_PER_ELEMENT",b="Wrong length",w=function(e,t){g(e);for(var r=0,n=t.length,i=new e(n);n>r;)i[r]=t[r++];return i},O=function(e,t){a(e,t,{get:function(){return n(this)[t]}})},A=function(e){var t;return ce(d,e)||"ArrayBuffer"==(t=Wn(e))||"SharedArrayBuffer"==t},C=function(e,t){return y(e)&&!fe(t)&&t in e&&Ji(+t)&&t>=0},S=function(e,t){return t=we(t),C(e,t)?yt(2,e[t]):s(e,t)},T=function(e,t,r){return t=we(t),!(C(e,t)&&X(r)&&I(r,"value"))||I(r,"get")||I(r,"set")||r.configurable||I(r,"writable")&&!r.writable||I(r,"enumerable")&&!r.enumerable?a(e,t,r):(e[t]=r.value,e)};re?(_||(Dt.f=S,Ie.f=T,O(v,"buffer"),O(v,"byteOffset"),O(v,"byteLength"),O(v,"length")),or({target:"Object",stat:!0,forced:!_},{getOwnPropertyDescriptor:S,defineProperty:T}),e.exports=function(e,s,d){var g=e.match(/\d+$/)[0]/8,O=e+(d?"Clamped":"")+"Array",C="get"+e,S="set"+e,T=E[O],N=T,x=N&&N.prototype,I={},R=function(e,t){a(e,t,{get:function(){return function(e,t){var r=n(e);return r.view[C](t*g+r.byteOffset,!0)}(this,t)},set:function(e){return function(e,t,r){var i=n(e);d&&(r=(r=l(r))<0?0:r>255?255:255&r),i.view[S](t*g+i.byteOffset,r,!0)}(this,t,e)},enumerable:!0})};_?Wi&&(N=s((function(e,t,r,n){return Hr(e,x),bo(X(t)?A(t)?void 0!==n?new T(t,Xi(r,g),n):void 0!==r?new T(t,Xi(r,g)):new T(t):y(t)?w(N,t):ue(uo,N,t):new T(zr(t)),e,N)})),wr&&wr(N,h),r(t(T),(function(e){e in N||mt(N,e,T[e])})),N.prototype=x):(N=s((function(e,t,r,n){Hr(e,x);var o,a,s,l=0,d=0;if(X(t)){if(!A(t))return y(t)?w(N,t):ue(uo,N,t);o=t,d=Xi(r,g);var _=t.byteLength;if(void 0===n){if(_%g)throw u(b);if((a=_-d)<0)throw u(b)}else if((a=Fe(n)*g)+d>_)throw u(b);s=a/g}else s=zr(t),o=new c(a=s*g);for(i(e,{buffer:o,byteOffset:d,byteLength:a,length:s,view:new f(o)});l<s;)R(e,l++)})),wr&&wr(N,h),x=N.prototype=ot(v)),x.constructor!==N&&mt(x,"constructor",N),o(x).TypedArrayConstructor=N,p&&mt(x,p,O);var L=N!=T;I[O]=N,or({global:!0,constructor:!0,forced:L,sham:!_},I),m in N||mt(N,m,g),m in x||mt(x,m,g),mo(O)}):e.exports=function(){}}));Eo("Uint16",(function(e){return function(t,r,n){return e(this,t,r,n)}}));var wo=TypeError,Oo=function(e,t){if(!delete e[t])throw wo("Cannot delete property "+pe(t)+" of "+pe(e))},Ao=Math.min,Co=[].copyWithin||function(e,t){var r=N(this),n=Ue(r),i=De(e,n),o=De(t,n),a=arguments.length>2?arguments[2]:void 0,s=Ao((void 0===a?n:De(a,n))-o,n-i),l=1;for(o<i&&i<o+s&&(l=-1,o+=s-1,i+=s-1);s-- >0;)o in r?r[i]=r[o]:Oo(r,i),i+=l,o+=l;return r},So=a(Co),To=Vi.aTypedArray;(0,Vi.exportTypedArrayMethod)("copyWithin",(function(e,t){return So(To(this),e,t,arguments.length>2?arguments[2]:void 0)}));var No=go.every,xo=Vi.aTypedArray;(0,Vi.exportTypedArrayMethod)("every",(function(e){return No(xo(this),e,arguments.length>1?arguments[1]:void 0)}));var Io=TypeError,Ro=function(e){var t=Ee(e,"number");if("number"==typeof t)throw Io("Can't convert number to bigint");return BigInt(t)},Lo=Vi.aTypedArray,Mo=Vi.exportTypedArrayMethod,ko=a("".slice);Mo("fill",(function(e){var t=arguments.length;Lo(this);var r="Big"===ko(Wn(this),0,3)?Ro(e):+e;return ue(Qr,this,r,t>1?arguments[1]:void 0,t>2?arguments[2]:void 0)}),e((function(){var e=0;return new Int8Array(2).fill({valueOf:function(){return e++}}),1!==e})));var Po=Vi.aTypedArrayConstructor,jo=Vi.getTypedArrayConstructor,Do=function(e){return Po(ai(e,jo(e)))},Bo=function(e,t){return function(e,t){for(var r=0,n=Ue(t),i=new e(n);n>r;)i[r]=t[r++];return i}(Do(e),t)},Fo=go.filter,Uo=Vi.aTypedArray;(0,Vi.exportTypedArrayMethod)("filter",(function(e){var t=Fo(Uo(this),e,arguments.length>1?arguments[1]:void 0);return Bo(this,t)}));var Go=go.find,Ho=Vi.aTypedArray;(0,Vi.exportTypedArrayMethod)("find",(function(e){return Go(Ho(this),e,arguments.length>1?arguments[1]:void 0)}));var Vo=go.findIndex,zo=Vi.aTypedArray;(0,Vi.exportTypedArrayMethod)("findIndex",(function(e){return Vo(zo(this),e,arguments.length>1?arguments[1]:void 0)}));var $o=go.forEach,Yo=Vi.aTypedArray;(0,Vi.exportTypedArrayMethod)("forEach",(function(e){$o(Yo(this),e,arguments.length>1?arguments[1]:void 0)}));var Wo=He.includes,Zo=Vi.aTypedArray;(0,Vi.exportTypedArrayMethod)("includes",(function(e){return Wo(Zo(this),e,arguments.length>1?arguments[1]:void 0)}));var Jo=He.indexOf,Ko=Vi.aTypedArray;(0,Vi.exportTypedArrayMethod)("indexOf",(function(e){return Jo(Ko(this),e,arguments.length>1?arguments[1]:void 0)}));var qo=q("iterator"),Xo=E.Uint8Array,Qo=a(Dr.values),ea=a(Dr.keys),ta=a(Dr.entries),ra=Vi.aTypedArray,na=Vi.exportTypedArrayMethod,ia=Xo&&Xo.prototype,oa=!e((function(){ia[qo].call([1])})),aa=!!ia&&ia.values&&ia[qo]===ia.values&&"values"===ia.values.name,sa=function(){return Qo(ra(this))};na("entries",(function(){return ta(ra(this))}),oa),na("keys",(function(){return ea(ra(this))}),oa),na("values",sa,oa||!aa,{name:"values"}),na(qo,sa,oa||!aa,{name:"values"});var la=Vi.aTypedArray,ua=Vi.exportTypedArrayMethod,ca=a([].join);ua("join",(function(e){return ca(la(this),e)}));var da=Function.prototype,fa=da.apply,_a=da.call,pa="object"==typeof Reflect&&Reflect.apply||(t?_a.bind(fa):function(){return _a.apply(fa,arguments)}),ha=function(t,r){var n=[][t];return!!n&&e((function(){n.call(null,r||function(){return 1},1)}))},va=Math.min,ga=[].lastIndexOf,ya=!!ga&&1/[1].lastIndexOf(1,-0)<0,ma=ha("lastIndexOf"),ba=ya||!ma?function(e){if(ya)return pa(ga,this,arguments)||0;var t=h(this),r=Ue(t),n=r-1;for(arguments.length>1&&(n=va(n,ke(arguments[1]))),n<0&&(n=r+n);n>=0;n--)if(n in t&&t[n]===e)return n||0;return-1}:ga,Ea=Vi.aTypedArray;(0,Vi.exportTypedArrayMethod)("lastIndexOf",(function(e){var t=arguments.length;return pa(ba,Ea(this),t>1?[e,arguments[1]]:[e])}));var wa=go.map,Oa=Vi.aTypedArray;(0,Vi.exportTypedArrayMethod)("map",(function(e){return wa(Oa(this),e,arguments.length>1?arguments[1]:void 0,(function(e,t){return new(Do(e))(t)}))}));var Aa=TypeError,Ca=function(e){return function(t,r,n,i){ve(r);var o=N(t),a=f(o),s=Ue(o),l=e?s-1:0,u=e?-1:1;if(n<2)for(;;){if(l in a){i=a[l],l+=u;break}if(l+=u,e?l<0:s<=l)throw Aa("Reduce of empty array with no initial value")}for(;e?l>=0:s>l;l+=u)l in a&&(i=r(i,a[l],l,o));return i}},Sa={left:Ca(!1),right:Ca(!0)},Ta=Sa.left,Na=Vi.aTypedArray;(0,Vi.exportTypedArrayMethod)("reduce",(function(e){var t=arguments.length;return Ta(Na(this),e,t,t>1?arguments[1]:void 0)}));var xa=Sa.right,Ia=Vi.aTypedArray;(0,Vi.exportTypedArrayMethod)("reduceRight",(function(e){var t=arguments.length;return xa(Ia(this),e,t,t>1?arguments[1]:void 0)}));var Ra=Vi.aTypedArray,La=Vi.exportTypedArrayMethod,Ma=Math.floor;La("reverse",(function(){for(var e,t=this,r=Ra(t).length,n=Ma(r/2),i=0;i<n;)e=t[i],t[i++]=t[--r],t[r]=e;return t}));var ka=a([].slice),Pa=Vi.aTypedArray;(0,Vi.exportTypedArrayMethod)("slice",(function(e,t){for(var r=ka(Pa(this),e,t),n=Do(this),i=0,o=r.length,a=new n(o);o>i;)a[i]=r[i++];return a}),e((function(){new Int8Array(1).slice()})));var ja=go.some,Da=Vi.aTypedArray;(0,Vi.exportTypedArrayMethod)("some",(function(e){return ja(Da(this),e,arguments.length>1?arguments[1]:void 0)}));var Ba=Math.floor,Fa=function(e,t){var r=e.length,n=Ba(r/2);return r<8?Ua(e,t):Ga(e,Fa(nn(e,0,n),t),Fa(nn(e,n),t),t)},Ua=function(e,t){for(var r,n,i=e.length,o=1;o<i;){for(n=o,r=e[o];n&&t(e[n-1],r)>0;)e[n]=e[--n];n!==o++&&(e[n]=r)}return e},Ga=function(e,t,r,n){for(var i=t.length,o=r.length,a=0,s=0;a<i||s<o;)e[a+s]=a<i&&s<o?n(t[a],r[s])<=0?t[a++]:r[s++]:a<i?t[a++]:r[s++];return e},Ha=Fa,Va=B.match(/firefox\/(\d+)/i),za=!!Va&&+Va[1],$a=/MSIE|Trident/.test(B),Ya=B.match(/AppleWebKit\/(\d+)\./),Wa=!!Ya&&+Ya[1],Za=Vi.aTypedArray,Ja=Vi.exportTypedArrayMethod,Ka=E.Uint16Array,qa=Ka&&a(Ka.prototype.sort),Xa=!(!qa||e((function(){qa(new Ka(2),null)}))&&e((function(){qa(new Ka(2),{})}))),Qa=!!qa&&!e((function(){if(z)return z<74;if(za)return za<67;if($a)return!0;if(Wa)return Wa<602;var e,t,r=new Ka(516),n=Array(516);for(e=0;e<516;e++)t=e%4,r[e]=515-e,n[e]=e-2*t+3;for(qa(r,(function(e,t){return(e/4|0)-(t/4|0)})),e=0;e<516;e++)if(r[e]!==n[e])return!0}));Ja("sort",(function(e){return void 0!==e&&ve(e),Qa?qa(this,e):Ha(Za(this),function(e){return function(t,r){return void 0!==e?+e(t,r)||0:r!=r?-1:t!=t?1:0===t&&0===r?1/t>0&&1/r<0?1:-1:t>r}}(e))}),!Qa||Xa);var es=E.Int8Array,ts=Vi.aTypedArray,rs=Vi.exportTypedArrayMethod,ns=[].toLocaleString,is=!!es&&e((function(){ns.call(new es(1))}));rs("toLocaleString",(function(){return pa(ns,is?ka(ts(this)):ts(this),ka(arguments))}),e((function(){return[1,2].toLocaleString()!=new es([1,2]).toLocaleString()}))||!e((function(){es.prototype.toLocaleString.call([1,2])})));var os=Vi.exportTypedArrayMethod,as=E.Uint8Array,ss=as&&as.prototype||{},ls=[].toString,us=a([].join);e((function(){ls.call({})}))&&(ls=function(){return us(this)});var cs=ss.toString!=ls;os("toString",ls,cs);var ds=q("species"),fs=function(t){return z>=51||!e((function(){var e=[];return(e.constructor={})[ds]=function(){return{foo:1}},1!==e[t](Boolean).foo}))},_s=fs("slice"),ps=q("species"),hs=Array,vs=Math.max;or({target:"Array",proto:!0,forced:!_s},{slice:function(e,t){var r,n,i,o=h(this),a=Ue(o),s=De(e,a),l=De(void 0===t?a:t,a);if(co(o)&&(r=o.constructor,(ri(r)&&(r===hs||co(r.prototype))||X(r)&&null===(r=r[ps]))&&(r=void 0),r===hs||void 0===r))return ka(o,s,l);for(n=new(void 0===r?hs:r)(vs(l-s,0)),i=0;s<l;s++,i++)s in o&&en(n,i,o[s]);return n.length=i,n}}),Eo("Int32",(function(e){return function(t,r,n){return e(this,t,r,n)}}));var gs=function(e,t){return gs=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&(e[r]=t[r])},gs(e,t)};function ys(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function r(){this.constructor=e}gs(e,t),e.prototype=null===t?Object.create(t):(r.prototype=t.prototype,new r)}function ms(){for(var e=0,t=0,r=arguments.length;t<r;t++)e+=arguments[t].length;var n=Array(e),i=0;for(t=0;t<r;t++)for(var o=arguments[t],a=0,s=o.length;a<s;a++,i++)n[i]=o[a];return n}var bs="ArrayBuffer",Es=Gn.ArrayBuffer,ws=E.ArrayBuffer;or({global:!0,constructor:!0,forced:ws!==Es},{ArrayBuffer:Es}),mo(bs),Eo("Int8",(function(e){return function(t,r,n){return e(this,t,r,n)}})),Eo("Uint8",(function(e){return function(t,r,n){return e(this,t,r,n)}})),Eo("Int16",(function(e){return function(t,r,n){return e(this,t,r,n)}})),Eo("Uint32",(function(e){return function(t,r,n){return e(this,t,r,n)}})),Eo("Float32",(function(e){return function(t,r,n){return e(this,t,r,n)}})),Eo("Float64",(function(e){return function(t,r,n){return e(this,t,r,n)}}));var Os,As,Cs,Ss,Ts,Ns,xs,Is,Rs,Ls,Ms=new ArrayBuffer(1114112);Os={Math:Math,Int8Array:Int8Array,Uint8Array:Uint8Array,Int16Array:Int16Array,Uint16Array:Uint16Array,Int32Array:Int32Array,Uint32Array:Uint32Array,Float32Array:Float32Array,Float64Array:Float64Array,NaN:NaN,Infinity:1/0},As=Ms,Cs=new Os.Int8Array(As),new Os.Int16Array(As),Ss=new Os.Int32Array(As),Ts=new Os.Uint8Array(As),Ns=new Os.Uint16Array(As),xs=new Os.Uint32Array(As),new Os.Float32Array(As),new Os.Float64Array(As),Is=Os.Math.imul,Os.Math.fround,Os.Math.abs,Rs=Os.Math.clz32,Os.Math.min,Os.Math.max,Os.Math.floor,Os.Math.ceil,Os.Math.sqrt,Os.NaN,Os.Infinity,Ls=1048576;var ks={memory:Object.create(Object.prototype,{grow:{value:Hs},buffer:{get:function(){return As}}}),rust_calloc:Bs,rust_free:function(e){Ps(e|=0)},llparser_create:function(e,t,r){return 0|(n=e|=0,i=t|=0,o=r|=0,Ls=a=Ls-32|0,Ss[28+a>>2]=n,Ss[24+a>>2]=i,Ss[20+a>>2]=o,i=Ss[28+(n=a)>>2]?Ss[28+a>>2]:256,Ss[n+28>>2]=i,i=Ss[24+(n=a)>>2]?Ss[24+a>>2]:256,Ss[n+24>>2]=i,i=Ss[20+(n=a)>>2]?Ss[20+a>>2]:256,Ss[n+20>>2]=i,l=Bs(((((((Is(Ss[24+(s=a)>>2],140)+52|0)+Is(Ss[20+a>>2],44)|0)+(Ss[24+a>>2]<<9)|0)+(Ss[24+a>>2]<<9)|0)+Is(Ss[20+a>>2],Ss[24+a>>2]<<3)|0)+(Ss[28+a>>2]<<1)|0)+(Ss[28+a>>2]<<3)|0,1),Ss[16+s>>2]=l,Ss[Ss[16+a>>2]+12>>2]=Ss[28+a>>2],Ss[Ss[16+a>>2]+16>>2]=Ss[24+a>>2],Ss[Ss[16+a>>2]+20>>2]=Ss[20+a>>2],Ss[Ss[16+a>>2]+4>>2]=0,Ss[Ss[16+a>>2]>>2]=0,Ss[Ss[16+a>>2]+8>>2]=0,Ss[12+a>>2]=Ss[16+a>>2]+52,Ss[Ss[16+a>>2]+24>>2]=Ss[12+a>>2],Ss[12+a>>2]=Ss[12+a>>2]+Is(Ss[24+a>>2],140),Ss[Ss[16+a>>2]+28>>2]=Ss[12+a>>2],Ss[12+a>>2]=Ss[12+a>>2]+Is(Ss[20+a>>2],44),Ss[Ss[16+a>>2]+32>>2]=Ss[12+a>>2],Ss[12+a>>2]=Ss[12+a>>2]+(Ss[24+a>>2]<<9),Ss[Ss[16+a>>2]+36>>2]=Ss[12+a>>2],Ss[12+a>>2]=Ss[12+a>>2]+(Ss[24+a>>2]<<9),Ss[Ss[16+a>>2]+40>>2]=Ss[12+a>>2],Ss[12+a>>2]=Ss[12+a>>2]+Is(Ss[20+a>>2],Ss[24+a>>2]<<3),Ss[Ss[16+a>>2]+44>>2]=Ss[12+a>>2],Ss[12+a>>2]=Ss[12+a>>2]+(Ss[28+a>>2]<<1),Ss[Ss[16+a>>2]+48>>2]=Ss[12+a>>2],Ls=32+a|0,Ss[16+a>>2]);var n,i,o,a,s,l},llparser_destroy:function(e){var t,r;t=e|=0,Ls=r=Ls-16|0,Ss[12+r>>2]=t,Ps(Ss[12+r>>2]),Ls=16+r|0},llparser_create_descriptor:function(e,t){return 0|(r=e|=0,n=t|=0,Ss[12+(i=Ls-16|0)>>2]=r,Ss[8+i>>2]=n,n=Ss[Ss[12+i>>2]+24>>2],o=Ss[12+i>>2],r=Ss[o+4>>2],Ss[o+4>>2]=r+1,Ss[4+i>>2]=n+Is(r,140),Ss[Ss[4+i>>2]+4>>2]=Ss[8+i>>2]?1:0,Ss[4+i>>2]);var r,n,i,o},llparser_descriptor_set_all:function(e){var t;e|=0,Ss[12+(t=Ls-16|0)>>2]=e,Ss[Ss[12+t>>2]+4>>2]=-1,Cs[Ss[12+t>>2]+135|0]=1},llparser_descriptor_set_nil:function(e){var t;e|=0,Ss[12+(t=Ls-16|0)>>2]=e,Ss[Ss[12+t>>2]+4>>2]=-2,Cs[Ss[12+t>>2]+8|0]=1},llparser_descriptor_add_char:function(e,t){var r,n,i;r=e|=0,n=t|=0,Ss[12+(i=Ls-16|0)>>2]=r,Ss[8+i>>2]=n,Cs[Ss[8+i>>2]+(Ss[12+i>>2]+8|0)|0]=1},llparser_descriptor_add_range:function(e,t,r){!function(e,t,r){var n;for(Ss[12+(n=Ls-16|0)>>2]=e,Ss[8+n>>2]=t,Ss[4+n>>2]=r,Ss[n>>2]=Ss[8+n>>2];!(Ss[n>>2]>Ss[4+n>>2]);)Cs[Ss[n>>2]+(Ss[12+n>>2]+8|0)|0]=1,Ss[n>>2]=Ss[n>>2]+1}(e|=0,t|=0,r|=0)},llparser_descriptor_revert:function(e){!function(e){var t;for(Ss[12+(t=Ls-16|0)>>2]=e,Ss[8+t>>2]=1;!(127<=Ss[8+t>>2]);)Cs[Ss[8+t>>2]+(Ss[12+t>>2]+8|0)|0]=1&(0!=Ts[Ss[8+t>>2]+(Ss[12+t>>2]+8|0)|0]^-1),Ss[8+t>>2]=Ss[8+t>>2]+1}(e|=0)},llparser_add_rule:function(e,t,r,n,i,o,a,s,l,u,c,d){return 0|(f=e|=0,_=t|=0,p=r|=0,h=n|=0,v=i|=0,g=o|=0,y=a|=0,m=s|=0,b=l|=0,E=u|=0,w=c|=0,O=d|=0,Ls=A=Ls+-64|0,Ss[60+A>>2]=f,Ss[56+A>>2]=_,Ss[52+A>>2]=p,Ss[48+A>>2]=h,Ss[44+A>>2]=v,Ss[40+A>>2]=g,Ss[36+A>>2]=y,Ss[32+A>>2]=m,Ss[28+A>>2]=b,Ss[24+A>>2]=E,Ss[20+A>>2]=w,Ss[16+A>>2]=O,_=Ss[Ss[60+A>>2]+28>>2],p=Ss[60+A>>2],f=Ss[p>>2],Ss[p>>2]=f+1,Ss[12+A>>2]=_+Is(f,44),Ss[Ss[12+A>>2]>>2]=Ss[52+A>>2],Ss[Ss[12+A>>2]+4>>2]=Ss[48+A>>2],0<Ss[48+A>>2]&&(Ss[Ss[12+A>>2]+8>>2]=Ss[44+A>>2]),1<Ss[48+A>>2]&&(Ss[Ss[12+A>>2]+12>>2]=Ss[40+A>>2]),2<Ss[48+A>>2]&&(Ss[Ss[12+A>>2]+16>>2]=Ss[36+A>>2]),3<Ss[48+A>>2]&&(Ss[Ss[12+A>>2]+20>>2]=Ss[32+A>>2]),4<Ss[48+A>>2]&&(Ss[Ss[12+A>>2]+24>>2]=Ss[28+A>>2]),5<Ss[48+A>>2]&&(Ss[Ss[12+A>>2]+28>>2]=Ss[24+A>>2]),6<Ss[48+A>>2]&&(Ss[Ss[12+A>>2]+32>>2]=Ss[20+A>>2]),7<Ss[48+A>>2]&&(Ss[Ss[12+A>>2]+36>>2]=Ss[16+A>>2]),Ss[Ss[12+A>>2]+40>>2]=Ss[56+A>>2],0<Ss[48+A>>2]&&(C=Ss[60+A>>2],S=Ss[12+A>>2],T=Ss[52+A>>2],Ss[28+(N=Ls-32|0)>>2]=C,Ss[24+N>>2]=S,Ss[20+N>>2]=T,Ss[16+N>>2]=(Ss[20+N>>2]-Ss[Ss[28+N>>2]+24>>2]|0)/140,1==Ss[Ss[20+N>>2]+4>>2]&&(S=Ss[Ss[28+N>>2]+40>>2],T=Ss[28+N>>2],C=Ss[T+8>>2],Ss[T+8>>2]=C+1,Ss[12+N>>2]=S+(C<<3),Ss[Ss[12+N>>2]>>2]=Ss[24+N>>2],Ss[Ss[12+N>>2]+4>>2]=Ss[Ss[20+N>>2]+136>>2],Ss[Ss[20+N>>2]+136>>2]=Ss[12+N>>2])),Ls=64+A|0,Ss[12+A>>2]);var f,_,p,h,v,g,y,m,b,E,w,O,A,C,S,T,N},llparser_prepare:function(e){!function(e){var t;for(Ls=t=Ls-32|0,Ss[28+t>>2]=e,Ss[24+t>>2]=0;!(Ss[24+t>>2]>=Ss[Ss[28+t>>2]+4>>2]);)Ss[20+t>>2]=Ss[Ss[28+t>>2]+24>>2]+Is(Ss[24+t>>2],140),1==Ss[Ss[20+t>>2]+4>>2]&&function e(t,r,n,i,o){var a;if(Ls=a=Ls-48|0,Ss[44+a>>2]=t,Ss[40+a>>2]=r,Ss[36+a>>2]=n,Ss[32+a>>2]=i,Ss[28+a>>2]=o,Ss[Ss[40+a>>2]>>2]!=Ss[36+a>>2])for(Ss[Ss[40+a>>2]>>2]=Ss[36+a>>2],Ss[24+a>>2]=Ss[Ss[40+a>>2]+136>>2],Ss[20+a>>2]=1&(0!=Ss[28+a>>2]^-1^-1);Ss[24+a>>2];){for(Ss[20+a>>2]||(Ss[28+a>>2]=Ss[24+a>>2]),Ss[16+a>>2]=Ss[Ss[Ss[24+a>>2]>>2]+8>>2],1==Ss[Ss[16+a>>2]+4>>2]&&e(Ss[44+a>>2],Ss[16+a>>2],Ss[36+a>>2],Ss[32+a>>2],Ss[28+a>>2]),Ss[12+a>>2]=0;!(128<=Ss[12+a>>2]);)Ts[Ss[12+a>>2]+(Ss[16+a>>2]+8|0)|0]&&(xs[Ss[28+a>>2]>>2]>=xs[Ss[32+a>>2]+(Ss[12+a>>2]<<2)>>2]&&Ss[Ss[32+a>>2]+(Ss[12+a>>2]<<2)>>2]||(Ss[Ss[32+a>>2]+(Ss[12+a>>2]<<2)>>2]=Ss[Ss[28+a>>2]>>2])),Ss[12+a>>2]=Ss[12+a>>2]+1;Ss[24+a>>2]=Ss[Ss[24+a>>2]+4>>2]}Ls=48+a|0}(Ss[28+t>>2],Ss[20+t>>2],Ss[20+t>>2],Ss[Ss[28+t>>2]+32>>2]+(Ss[24+t>>2]<<9)|0,0),Ss[24+t>>2]=Ss[24+t>>2]+1;for(Ss[16+t>>2]=0;!(Ss[16+t>>2]>=Ss[Ss[28+t>>2]+4>>2]);)Ss[12+t>>2]=Ss[Ss[28+t>>2]+24>>2]+Is(Ss[16+t>>2],140),1==Ss[Ss[12+t>>2]+4>>2]&&(Ss[Ss[12+t>>2]>>2]=0,function(e,t,r,n){var i;for(Ss[44+(i=Ls-48|0)>>2]=e,Ss[40+i>>2]=t,Ss[36+i>>2]=r,Ss[32+i>>2]=n,Ss[28+i>>2]=Ss[Ss[40+i>>2]+136>>2];Ss[28+i>>2];){if(Ss[24+i>>2]=Ss[Ss[Ss[28+i>>2]>>2]+8>>2],Ss[24+i>>2]==Ss[40+i>>2])for(Ss[20+i>>2]=Ss[Ss[Ss[28+i>>2]>>2]+12>>2],Ss[16+i>>2]=0;!(128<=Ss[16+i>>2]);){e:{if(1!=Ss[Ss[20+i>>2]+4>>2]){if(!Ts[Ss[16+i>>2]+(Ss[20+i>>2]+8|0)|0])break e}else if(Ss[12+i>>2]=Ss[Ss[44+i>>2]+32>>2]+((Ss[20+i>>2]-Ss[Ss[44+i>>2]+24>>2]|0)/140<<9),!Ss[Ss[12+i>>2]+(Ss[16+i>>2]<<2)>>2])break e;xs[Ss[28+i>>2]>>2]>=xs[Ss[32+i>>2]+(Ss[16+i>>2]<<2)>>2]&&Ss[Ss[32+i>>2]+(Ss[16+i>>2]<<2)>>2]||(Ss[Ss[32+i>>2]+(Ss[16+i>>2]<<2)>>2]=Ss[Ss[28+i>>2]>>2])}Ss[16+i>>2]=Ss[16+i>>2]+1}Ss[28+i>>2]=Ss[Ss[28+i>>2]+4>>2]}}(Ss[28+t>>2],Ss[12+t>>2],Ss[12+t>>2],Ss[Ss[28+t>>2]+36>>2]+(Ss[16+t>>2]<<9)|0)),Ss[16+t>>2]=Ss[16+t>>2]+1;Ls=32+t|0}(e|=0)},llparser_parse:function(e,t){return 0|(r=e|=0,n=t|=0,Ls=i=Ls-32|0,Ss[24+i>>2]=r,Ss[20+i>>2]=n,Ss[16+i>>2]=0,Ss[12+i>>2]=0,a=function e(t,r,n,i,o,a,s){var l,u=0,c=0;Ls=l=Ls-96|0,Ss[88+l>>2]=t,Ss[84+l>>2]=r,Ss[80+l>>2]=n,Ss[76+l>>2]=i,Ss[72+l>>2]=o,Ss[68+l>>2]=a,Ss[64+l>>2]=s,Ss[60+l>>2]=Ns[Ss[80+l>>2]+(Ss[Ss[76+l>>2]>>2]<<1)>>1],128<=xs[60+l>>2]&&(Ss[60+l>>2]=1);e:if(Ss[Ss[72+l>>2]>>2]>(Ss[64+l>>2]-4|0))Ss[92+l>>2]=-1;else if(1==Ss[Ss[84+l>>2]+4>>2])if(Ss[56+l>>2]=Ss[Ss[76+l>>2]>>2],Ss[52+l>>2]=Ss[Ss[72+l>>2]>>2],Ss[48+l>>2]=0,Ss[44+l>>2]=0,Ss[40+l>>2]=Ss[Ss[88+l>>2]+32>>2]+((Ss[84+l>>2]-Ss[Ss[88+l>>2]+24>>2]|0)/140<<9),Ss[36+l>>2]=0,!Ss[Ss[40+l>>2]+(Ss[60+l>>2]<<2)>>2]|xs[60+l>>2]<=0|127<=xs[60+l>>2]?!Ss[60+l>>2]|!Ss[Ss[40+l>>2]+508>>2]?Ss[Ss[40+l>>2]>>2]&&(Ss[36+l>>2]=Ss[Ss[40+l>>2]>>2]):Ss[36+l>>2]=Ss[Ss[40+l>>2]+508>>2]:Ss[36+l>>2]=Ss[Ss[40+l>>2]+(Ss[60+l>>2]<<2)>>2],Ss[36+l>>2]){for(Ss[68+l>>2]||Ss[Ss[36+l>>2]+40>>2]||(Ss[48+l>>2]=Ss[Ss[72+l>>2]>>2],t=Ss[72+l>>2],Ss[t>>2]=Ss[t>>2]+2),Ss[32+l>>2]=0;Ss[32+l>>2]<Ss[Ss[36+l>>2]+4>>2];){if(Ss[28+l>>2]=Ss[68+l>>2],Ss[68+l>>2]||!Ss[Ss[36+l>>2]+40>>2]|Ss[Ss[36+l>>2]+40>>2]==(Ss[32+l>>2]+65536|0)||(Ss[28+l>>2]=1),c=e(Ss[88+(u=l)>>2],Ss[(Ss[36+l>>2]+8|0)+(Ss[32+l>>2]<<2)>>2],Ss[80+l>>2],Ss[76+l>>2],Ss[72+l>>2],Ss[28+l>>2],Ss[64+l>>2]),Ss[u+24>>2]=c,Ss[24+l>>2]<0){Ss[92+l>>2]=-1;break e}Ss[68+l>>2]|Ss[Ss[36+l>>2]+40>>2]!=(Ss[32+l>>2]+65536|0)||(Ss[44+l>>2]=Ss[24+l>>2]),Ss[32+l>>2]=Ss[32+l>>2]+1}for(Ss[68+l>>2]||(Ss[Ss[36+l>>2]+40>>2]?1==Ss[Ss[36+l>>2]+40>>2]&&(r=Ss[56+l>>2],n=Ss[Ss[88+l>>2]+48>>2],i=Ss[72+l>>2],t=Ss[i>>2],Ss[i>>2]=t+1,Ss[n+(t<<2)>>2]=r,Ss[44+l>>2]=Ss[Ss[72+l>>2]>>2],r=Ss[Ss[76+l>>2]>>2],n=Ss[Ss[88+l>>2]+48>>2],i=Ss[72+l>>2],t=Ss[i>>2],Ss[i>>2]=t+1,Ss[n+(t<<2)>>2]=r):(Ss[Ss[Ss[88+l>>2]+48>>2]+(Ss[48+l>>2]<<2)>>2]=0-Ss[36+l>>2],Ss[Ss[Ss[88+l>>2]+48>>2]+(Ss[48+l>>2]+1<<2)>>2]=Ss[Ss[36+l>>2]+4>>2],Ss[44+l>>2]=Ss[48+l>>2]+1));;){if(Ss[Ss[72+l>>2]>>2]>(Ss[64+l>>2]-4|0)){Ss[92+l>>2]=-1;break e}if(Ss[20+l>>2]=Ss[Ss[88+l>>2]+36>>2]+((Ss[84+l>>2]-Ss[Ss[88+l>>2]+24>>2]|0)/140<<9),Ss[16+l>>2]=0,Ss[60+l>>2]=Ns[Ss[80+l>>2]+(Ss[Ss[76+l>>2]>>2]<<1)>>1],128<=xs[60+l>>2]&&(Ss[60+l>>2]=1),!Ss[Ss[20+l>>2]+(Ss[60+l>>2]<<2)>>2]|xs[60+l>>2]<=0|127<=xs[60+l>>2]?!Ss[60+l>>2]|!Ss[Ss[20+l>>2]+508>>2]||(Ss[16+l>>2]=Ss[Ss[20+l>>2]+508>>2]):Ss[16+l>>2]=Ss[Ss[20+l>>2]+(Ss[60+l>>2]<<2)>>2],!Ss[16+l>>2])break;for(Ss[68+l>>2]||(Ss[Ss[16+l>>2]+40>>2]?65536!=Ss[Ss[16+l>>2]+40>>2]&&(Ss[Ss[72+l>>2]>>2]=Ss[52+l>>2]):(Ss[Ss[Ss[88+l>>2]+48>>2]+(Ss[44+l>>2]<<2)>>2]=(0-Ss[Ss[Ss[88+l>>2]+48>>2]+(Ss[44+l>>2]<<2)>>2]|0)-1,Ss[48+l>>2]=Ss[Ss[72+l>>2]>>2],t=Ss[72+l>>2],Ss[t>>2]=Ss[t>>2]+2)),Ss[12+l>>2]=1;Ss[12+l>>2]<Ss[Ss[16+l>>2]+4>>2];){if(Ss[8+l>>2]=Ss[68+l>>2],Ss[68+l>>2]||!Ss[Ss[16+l>>2]+40>>2]|Ss[Ss[16+l>>2]+40>>2]==(Ss[12+l>>2]+65536|0)||(Ss[8+l>>2]=1),c=e(Ss[88+(u=l)>>2],Ss[(Ss[16+l>>2]+8|0)+(Ss[12+l>>2]<<2)>>2],Ss[80+l>>2],Ss[76+l>>2],Ss[72+l>>2],Ss[8+l>>2],Ss[64+l>>2]),Ss[u+4>>2]=c,Ss[4+l>>2]<0){Ss[92+l>>2]=-1;break e}Ss[68+l>>2]|Ss[Ss[16+l>>2]+40>>2]!=(Ss[12+l>>2]+65536|0)||(Ss[44+l>>2]=Ss[4+l>>2]),Ss[12+l>>2]=Ss[12+l>>2]+1}Ss[68+l>>2]||(Ss[Ss[16+l>>2]+40>>2]?1==Ss[Ss[16+l>>2]+40>>2]&&(r=Ss[56+l>>2],n=Ss[Ss[88+l>>2]+48>>2],i=Ss[72+l>>2],t=Ss[i>>2],Ss[i>>2]=t+1,Ss[n+(t<<2)>>2]=r,Ss[44+l>>2]=Ss[Ss[72+l>>2]>>2],r=Ss[Ss[76+l>>2]>>2],n=Ss[Ss[88+l>>2]+48>>2],i=Ss[72+l>>2],t=Ss[i>>2],Ss[i>>2]=t+1,Ss[n+(t<<2)>>2]=r):(Ss[Ss[Ss[88+l>>2]+48>>2]+(Ss[48+l>>2]<<2)>>2]=0-Ss[16+l>>2],Ss[Ss[Ss[88+l>>2]+48>>2]+(Ss[48+l>>2]+1<<2)>>2]=Ss[Ss[16+l>>2]+4>>2],Ss[44+l>>2]=Ss[48+l>>2]+1))}Ss[92+l>>2]=Ss[44+l>>2]}else Ss[92+l>>2]=-1;else{if(Ss[60+l>>2]&&(-1==Ss[Ss[84+l>>2]+4>>2]&&(t=Ss[76+l>>2],Ss[t>>2]=Ss[t>>2]+1),!Ss[Ss[84+l>>2]+4>>2])){if(!Ts[Ss[60+l>>2]+(Ss[84+l>>2]+8|0)|0]){Ss[92+l>>2]=-1;break e}t=Ss[76+l>>2],Ss[t>>2]=Ss[t>>2]+1}Ss[68+l>>2]||(r=Ss[Ss[76+l>>2]>>2],n=Ss[Ss[84+l>>2]+4>>2],i=Ss[Ss[88+l>>2]+48>>2],o=Ss[72+l>>2],t=Ss[o>>2],Ss[o>>2]=t+1,Ss[i+(t<<2)>>2]=r-(-2==(0|n)?0:1),r=Ss[Ss[76+l>>2]>>2],n=Ss[Ss[88+l>>2]+48>>2],i=Ss[72+l>>2],t=Ss[i>>2],Ss[i>>2]=t+1,Ss[n+(t<<2)>>2]=r),Ss[92+l>>2]=Ss[Ss[72+l>>2]>>2]-1}return Ls=96+l|0,Ss[92+l>>2]}(Ss[24+(o=i)>>2],Ss[20+i>>2],Ss[Ss[24+i>>2]+44>>2],12+i|0,16+i|0,0,Ss[Ss[24+i>>2]+12>>2]<<1),Ss[8+o>>2]=a,r=Ss[Ss[24+i>>2]+48>>2],n=Ss[16+i>>2],Ss[16+i>>2]=n+1,Ss[r+(n<<2)>>2]=-1,r=Ss[Ss[24+i>>2]+48>>2],n=Ss[16+i>>2],Ss[16+i>>2]=n+1,Ss[r+(n<<2)>>2]=0,Ns[Ss[Ss[24+i>>2]+44>>2]+(Ss[12+i>>2]<<1)>>1]|Ss[8+i>>2]<0?Ss[28+i>>2]=Ss[12+i>>2]+1:Ss[28+i>>2]=0,Ls=32+i|0,Ss[28+i>>2]);var r,n,i,o,a},llparser_get_input_buffer:function(e){var t;return e|=0,Ss[12+(t=Ls-16|0)>>2]=e,Ss[Ss[12+t>>2]+44>>2]},llparser_get_result:function(e){var t;return e|=0,Ss[12+(t=Ls-16|0)>>2]=e,Ss[Ss[12+t>>2]+48>>2]},wasm_main:Fs,__wbindgen_start:Fs};function Ps(e){var t=0,r=0,n=0,i=0,o=0,a=0,s=0;r=(t=e+-8|0)+(e=-8&(i=Ss[e+-4>>2]))|0;e:{t:{r:{n:{i:if(!(1&i)){if(!(3&i))break n;if(e=(i=Ss[t>>2])+e|0,(0|(t=t-i|0))==Ss[262246]){if(3!=(3&Ss[r+4>>2]))break i;return Ss[262244]=e,Ss[r+4>>2]=-2&Ss[r+4>>2],Ss[t+4>>2]=1|e,Ss[e+t>>2]=e,0}256<=i>>>0?Ds(t):(0|(n=Ss[t+8>>2]))==(0|(o=Ss[t+12>>2]))?(a=1048576,s=Ss[262144]&Gs(i>>>3),Ss[a>>2]=s):(Ss[n+12>>2]=o,Ss[o+8>>2]=n)}if(2&(i=Ss[r+4>>2]))Ss[r+4>>2]=-2&i,Ss[t+4>>2]=1|e,Ss[e+t>>2]=e;else{i:{if(Ss[262247]!=(0|r)){if((0|r)!=Ss[262246])break i;return Ss[262246]=t,e=Ss[262244]+e|0,Ss[262244]=e,Ss[t+4>>2]=1|e,Ss[e+t>>2]=e,0}if(Ss[262247]=t,e=Ss[262245]+e|0,Ss[262245]=e,Ss[t+4>>2]=1|e,(0|t)==Ss[262246]&&(Ss[262244]=0,Ss[262246]=0),(r=Ss[262254])>>>0>=e>>>0)break n;if(!(e=Ss[262247]))break n;o:if(!((i=Ss[262245])>>>0<41))for(t=1049e3;;){if((n=Ss[t>>2])+Ss[t+4>>2]>>>0>e>>>0&&n>>>0<=e>>>0)break o;if(!(t=Ss[t+8>>2]))break}if(n=4095,e=Ss[262252]){for(t=0;t=t+1|0,e=Ss[e+8>>2];);n=4095<t>>>0?t:4095}if(Ss[262256]=n,i>>>0<=r>>>0)break n;return Ss[262254]=-1,0}if(e=(n=-8&i)+e|0,256<=n>>>0?Ds(r):(0|(n=Ss[r+12>>2]))==(0|(r=Ss[r+8>>2]))?(a=1048576,s=Ss[262144]&Gs(i>>>3),Ss[a>>2]=s):(Ss[r+12>>2]=n,Ss[n+8>>2]=r),Ss[t+4>>2]=1|e,Ss[e+t>>2]=e,Ss[262246]==(0|t)){Ss[262244]=e;break n}}if(e>>>0<256)break r;if(js(t,e),e=Ss[262256]+-1|0,!(Ss[262256]=e)){if(e=Ss[262252])break t;e=4095;break e}}return}return e=1048584+((r=e>>>3)<<3)|0,i=Ss[262144],r=1<<(31&r),n=Ss[e+8>>2],i&r||(Ss[262144]=r|i,n=e),r=n,Ss[e+8>>2]=t,Ss[r+12>>2]=t,Ss[t+12>>2]=e,Ss[t+8>>2]=r,0}for(t=0;t=t+1|0,e=Ss[e+8>>2];);e=4095<t>>>0?t:4095}Ss[262256]=e}function js(e,t){var r=0,n=0,i=0,o=0;Ss[e+16>>2]=0,r=Ss[(i=e)+20>>2]=0,(n=t>>>8)&&(r=31,16777215<t>>>0||(r=62+((t>>>(6-(n=Rs(n))&31)&1)-(n<<1)|0)|0)),i=1048848+((Ss[i+28>>2]=r)<<2)|0;e:{t:{r:{n:{if((o=Ss[262145])&(n=1<<(31&r))){if(n=Ss[i>>2],(-8&Ss[n+4>>2])!=(0|t))break n;r=n;break r}Ss[262145]=n|o,Ss[i>>2]=e,Ss[e+24>>2]=i;break e}for(i=t<<(31==(0|r)?0:25-(r>>>1)&31);;){if(!(r=Ss[(o=16+((i>>>29&4)+n|0)|0)>>2]))break t;if(i<<=1,(-8&Ss[(n=r)+4>>2])==(0|t))break}}return t=Ss[r+8>>2],Ss[t+12>>2]=e,Ss[r+8>>2]=e,Ss[e+24>>2]=0,Ss[e+12>>2]=r,Ss[e+8>>2]=t,0}Ss[o>>2]=e,Ss[e+24>>2]=n}Ss[e+12>>2]=e,Ss[e+8>>2]=e}function Ds(e){var t=0,r=0,n=0,i=0,o=0,a=0,s=Ss[e+24>>2];e:{t:{if((0|e)==(0|(t=Ss[e+12>>2]))){if(n=Ss[(t=e+20|0)>>2],r=Ss[(n?20:16)+e>>2])break t;t=0;break e}r=Ss[e+8>>2],Ss[r+12>>2]=t,Ss[t+8>>2]=r;break e}for(n=n?t:e+16|0;i=n,(r=Ss[(n=(t=r)+20|0)>>2])||(n=t+16|0,r=Ss[t+16>>2]),r;);Ss[i>>2]=0}e:if(s){r=1048848+(Ss[e+28>>2]<<2)|0;t:{if((0|e)==Ss[r>>2]){if(Ss[r>>2]=t)break t;return o=1048580,a=Ss[262145]&Gs(Ss[e+28>>2]),Ss[o>>2]=a,0}if(!(Ss[(Ss[s+16>>2]==(0|e)?16:20)+s>>2]=t))break e}Ss[t+24>>2]=s,(r=Ss[e+16>>2])&&(Ss[t+16>>2]=r,Ss[r+24>>2]=t),(e=Ss[e+20>>2])&&(Ss[t+20>>2]=e,Ss[e+24>>2]=t)}}function Bs(e,t){return 0|(!(n=function(e){var t=0,r=0,n=0,i=0,o=0,a=0,s=0,l=0,u=0,c=0,d=0;e:{t:{r:{if(245<=e>>>0){if(4294901709<=e>>>0)break t;if(i=-8&(e=e+11|0),!(l=Ss[262145]))break r;r=0-i|0,s=0,(e>>>=8)&&(s=31,16777215<i>>>0||(s=62+((i>>>(6-(e=Rs(e))&31)&1)-(e<<1)|0)|0));n:{i:{if(e=Ss[1048848+(s<<2)>>2]){for(o=i<<(31==(0|s)?0:25-(s>>>1)&31);;){if(!((a=-8&Ss[e+4>>2])>>>0<i>>>0||(a=a-i|0)>>>0>=r>>>0||(n=e,r=a))){r=0;break i}if(a=Ss[e+20>>2],e=Ss[16+((o>>>29&4)+e|0)>>2],t=a&&(0|a)!=(0|e)?a:t,o<<=1,!e)break}if(t){e=t;break i}if(n)break n}if(!(e=((n=0)-(e=2<<(31&s))|e)&l))break r;if(!(e=Ss[1048848+(Us(e&0-e)<<2)>>2]))break r}for(;n=(a=(o=(t=-8&Ss[e+4>>2])-i|0)>>>0<r>>>0&i>>>0<=t>>>0)?e:n,r=a?o:r,e=(t=Ss[e+16>>2])||Ss[e+20>>2];);if(!n)break r}if(r>>>0>=(e=Ss[262244])-i>>>0&&i>>>0<=e>>>0)break r;Ds(n);n:if(16<=r>>>0){if(Ss[n+4>>2]=3|i,Ss[4+(t=n+i|0)>>2]=1|r,256<=(Ss[t+r>>2]=r)>>>0){js(t,r);break n}e=1048584+((r>>>=3)<<3)|0,o=Ss[262144],r=1<<(31&r),s=Ss[e+8>>2],o&r||(Ss[262144]=r|o,s=e),r=s,Ss[e+8>>2]=t,Ss[r+12>>2]=t,Ss[t+12>>2]=e,Ss[t+8>>2]=r}else e=r+i|0,Ss[n+4>>2]=3|e,Ss[4+(e=e+n|0)>>2]=1|Ss[e+4>>2];return n+8|0}n:{i:{if(!(3&(e=(t=Ss[262144])>>>(n=31&(r=(i=e>>>0<11?16:e+11&-8)>>>3))))){if(i>>>0<=xs[262244])break r;if(e)break i;if(!(e=Ss[262145]))break r;for(t=Ss[1048848+(Us(e&0-e)<<2)>>2],r=(-8&Ss[t+4>>2])-i|0,o=t;;){if(!(e=Ss[t+16>>2])&&!(e=Ss[t+20>>2]))break n;r=(t=(n=(-8&Ss[e+4>>2])-i|0)>>>0<r>>>0)?n:r,o=t?e:o,t=e}}r=(e=Ss[1048592+(a=(n=r+(1&(-1^e))|0)<<3)>>2])+8|0,(0|(o=Ss[e+8>>2]))==(0|(a=a+1048584|0))?(d=Gs(n)&t,Ss[(c=1048576)>>2]=d):(Ss[o+12>>2]=a,Ss[a+8>>2]=o),t=n<<3,Ss[e+4>>2]=3|t,Ss[4+(e=e+t|0)>>2]=1|Ss[e+4>>2];break t}return n=Us(0-(e=(r=e<<n)&(0-(e=2<<n)|e))&e),e=Ss[1048592+(o=n<<3)>>2],(0|(r=Ss[e+8>>2]))==(0|(o=o+1048584|0))?(d=Gs(n)&t,Ss[(c=1048576)>>2]=d):(Ss[r+12>>2]=o,Ss[o+8>>2]=r),o=e+8|0,Ss[e+4>>2]=3|i,r=(t=n<<3)-i|0,Ss[4+(a=e+i|0)>>2]=1|r,Ss[e+t>>2]=r,(e=Ss[262244])&&(e=1048584+((n=e>>>3)<<3)|0,t=Ss[262246],i=Ss[262144],n=1<<(31&n),s=Ss[e+8>>2],i&n||(Ss[262144]=n|i,s=e),n=s,Ss[e+8>>2]=t,Ss[n+12>>2]=t,Ss[t+12>>2]=e,Ss[t+8>>2]=n),Ss[262246]=a,Ss[262244]=r,o}return Ds(o),16<=r>>>0?(Ss[o+4>>2]=3|i,Ss[4+(a=i+o|0)>>2]=1|r,Ss[r+a>>2]=r,(e=Ss[262244])&&(e=1048584+((n=e>>>3)<<3)|0,t=Ss[262246],i=Ss[262144],n=1<<(31&n),s=Ss[e+8>>2],i&n||(Ss[262144]=n|i,s=e),n=s,Ss[e+8>>2]=t,Ss[n+12>>2]=t,Ss[t+12>>2]=e,Ss[t+8>>2]=n),Ss[262246]=a,Ss[262244]=r):(e=r+i|0,Ss[o+4>>2]=3|e,Ss[4+(e=e+o|0)>>2]=1|Ss[e+4>>2]),o+8|0}r:{n:{i:{o:{if((t=Ss[262244])>>>0<i>>>0){if((e=Ss[262245])>>>0>i>>>0)break e;if(-1==((r=0)|(t=Hs((e=i+65583|0)>>>16))))break t;if(!(n=t<<16))break t;if(e=(o=-65536&e)+Ss[262248]|0,Ss[262248]=e,t=Ss[262249],Ss[262249]=e>>>0<t>>>0?t:e,!(r=Ss[262247]))break o;for(e=1049e3;;){if((0|n)==((t=Ss[e>>2])+(a=Ss[e+4>>2])|0))break i;if(!(e=Ss[e+8>>2]))break}break n}return e=Ss[262246],(n=t-i|0)>>>0<=15?(Ss[262246]=0,Ss[262244]=0,Ss[e+4>>2]=3|t,i=4+(t=e+t|0)|0,r=1|Ss[t+4>>2]):(Ss[262244]=n,r=e+i|0,Ss[262246]=r,Ss[r+4>>2]=1|n,Ss[e+t>>2]=n,r=3|i,i=e+4|0),Ss[i>>2]=r,e+8|0}for((e=Ss[262255])>>>0<=n>>>0&&e||(Ss[262255]=n),e=0,Ss[262256]=4095,Ss[262251]=o,Ss[262250]=n,Ss[262253]=0;t=e+1048584|0,Ss[e+1048592>>2]=t,Ss[e+1048596>>2]=t,256!=(0|(e=e+8|0)););Ss[262247]=n,e=o+-40|0,Ss[262245]=e,Ss[n+4>>2]=1|e,Ss[4+(e+n|0)>>2]=40,Ss[262254]=2097152;break r}if(!(Ss[e+12>>2]|n>>>0<=r>>>0|r>>>0<t>>>0)){Ss[e+4>>2]=o+a,t=(e=Ss[262247])+15&-8,Ss[262247]=t+-8,r=8+((n=o+Ss[262245]|0)+(e-t|0)|0)|0,Ss[262245]=r,Ss[t+-4>>2]=1|r,Ss[4+(e+n|0)>>2]=40,Ss[262254]=2097152;break r}}e=Ss[262255],Ss[262255]=e>>>0<n>>>0?e:n,t=n+o|0,e=1049e3;n:{for(;(0|t)!=Ss[e>>2];)if(!(e=Ss[e+8>>2]))break n;if(!Ss[e+12>>2]){Ss[e>>2]=n,Ss[e+4>>2]=o+Ss[e+4>>2],Ss[n+4>>2]=3|i,o=n+i|0,i=(t-n|0)-i|0;i:{o:{if((0|t)!=Ss[262247]){if(Ss[262246]==(0|t))break o;if(1==(3&(e=Ss[t+4>>2]))&&(256<=(r=-8&e)>>>0?Ds(t):(0|(a=Ss[t+12>>2]))==(0|(s=Ss[t+8>>2]))?(c=1048576,d=Ss[262144]&Gs(e>>>3),Ss[c>>2]=d):(Ss[s+12>>2]=a,Ss[a+8>>2]=s),i=r+i|0,t=t+r|0),Ss[t+4>>2]=-2&Ss[t+4>>2],Ss[o+4>>2]=1|i,256<=(Ss[i+o>>2]=i)>>>0){js(o,i);break i}e=1048584+((t=i>>>3)<<3)|0,r=Ss[262144],t=1<<(31&t),s=Ss[e+8>>2],r&t||(Ss[262144]=t|r,s=e),r=s,Ss[e+8>>2]=o,Ss[r+12>>2]=o,Ss[o+12>>2]=e,Ss[o+8>>2]=r;break i}Ss[262247]=o,e=Ss[262245]+i|0,Ss[262245]=e,Ss[o+4>>2]=1|e;break i}Ss[262246]=o,e=Ss[262244]+i|0,Ss[262244]=e,Ss[o+4>>2]=1|e,Ss[e+o>>2]=e}return n+8|0}}for(e=1049e3;!((t=Ss[e>>2])>>>0<=r>>>0&&(a=t+Ss[e+4>>2]|0)>>>0>r>>>0);)e=Ss[e+8>>2];for(Ss[262247]=n,e=o+-40|0,Ss[262245]=e,Ss[n+4>>2]=1|e,Ss[4+(e+n|0)>>2]=40,Ss[262254]=2097152,Ss[(t=(e=(a+-32&-8)-8|0)>>>0<r+16>>>0?r:e)+4>>2]=27,e=Ss[262250],s=Ss[262251],u=Ss[262253],Ss[(l=t+16|0)>>2]=Ss[262252],Ss[l+4>>2]=u,Ss[t+8>>2]=e,Ss[t+12>>2]=s,Ss[262251]=o,Ss[262250]=n,Ss[262252]=t+8,e=t+28|(Ss[262253]=0);Ss[e>>2]=7,a>>>0>(e=e+4|0)>>>0;);(0|t)!=(0|r)&&(Ss[t+4>>2]=-2&Ss[t+4>>2],e=t-r|0,Ss[r+4>>2]=1|e,256<=(Ss[t>>2]=e)>>>0?js(r,e):(e=1048584+((t=e>>>3)<<3)|0,n=Ss[262144],t=1<<(31&t),s=Ss[e+8>>2],n&t||(Ss[262144]=t|n,s=e),t=s,Ss[e+8>>2]=r,Ss[t+12>>2]=r,Ss[r+12>>2]=e,Ss[r+8>>2]=t))}if(r=0,!((e=Ss[262245])>>>0<=i>>>0))break e}return r}return t=e-i|0,Ss[262245]=t,n=(e=Ss[262247])+i|0,Ss[262247]=n,Ss[n+4>>2]=1|t,Ss[e+4>>2]=3|i,e+8|0}(r=Is(e|=0,t|=0)))|!(3&Ts[n+-4|0])||function(e,t){if(t)for(;e=e+1|(Cs[0|e]=0),t=t+-1|0;);}(n,r),n);var r,n}function Fs(){}function Us(e){return e?31-Rs(e+-1^e)|0:32}function Gs(e){var t;return(-1>>>(t=31&e)&-2)<<t|(-1<<(e=0-e&31)&-2)>>>e}function Hs(e){e|=0;var t,r,n=0|As.byteLength/65536,i=n+e|0;return n<i&&i<65536&&(t=new ArrayBuffer(Is(i,65536)),(r=new Os.Int8Array(t)).set(Cs),Cs=r,Cs=new Os.Int8Array(t),new Os.Int16Array(t),Ss=new Os.Int32Array(t),Ts=new Os.Uint8Array(t),Ns=new Os.Uint16Array(t),xs=new Os.Uint32Array(t),new Os.Float32Array(t),new Os.Float64Array(t),As=t),n}var Vs=ks,zs=function(){function e(){}return e.create=function(t,r,n){void 0===n&&(n=16384);var i={},o=new e;o._llp=Vs.llparser_create(n,128,128);var a=o._llp,s={ALL:Vs.llparser_create_descriptor(a,0),NULL:Vs.llparser_create_descriptor(a,0)};for(var l in Vs.llparser_descriptor_set_all(s.ALL),Vs.llparser_descriptor_set_nil(s.NULL),t){var u=a;s[l]=Vs.llparser_create_descriptor(u,1)}for(var l in t)for(var c=t[l],d=s[l],f=0;f<c.length;f++){for(var _=c[f].id,p=c[f].states,h=[],v=0;v<p.length;v++){var g=p[v];s[g]||(s[g]=function(e,t){for(var r=Vs.llparser_create_descriptor(e,0),n="^"===t[0],i=+n;i<t.length;i++){var o=t.charCodeAt(i),a=t.charCodeAt(i+2);"-"===t[i+1]&&o<=a?(Vs.llparser_descriptor_add_range(r,o,a),i+=2):Vs.llparser_descriptor_add_char(r,o)}return n&&Vs.llparser_descriptor_revert(r),r}(a,g)),h.push(s[g])}var y=0;"_raw"===_?y=1:"_jump"===_?y=65536:"_blank"===_&&(y=65537);var m=Vs.llparser_add_rule.apply(Vs,ms([a,y,d,h.length],h));0===y&&(i[m]=r[_])}return Vs.llparser_prepare(a),o._inputPtr=Vs.llparser_get_input_buffer(a),o._resultPtr=Vs.llparser_get_result(a),o._stateIdMap=s,o._ruleCbMap=i,o._charCountLimit=n,o},e.prototype.parse=function(e,t){var r=Date.now();!function(e,t,r,n){for(var i=n>e.length?e.length:n,o=0;o<i;o++)t[r+o]=e.charCodeAt(o);t[r+i]=0}(t,new Uint16Array(Vs.memory.buffer),this._inputPtr>>1,this._charCountLimit),$s.copyIn=$s.copyIn+Date.now()-r,r=Date.now();var n=Vs.llparser_parse(this._llp,this._stateIdMap[e]);if($s.parse=$s.parse+Date.now()-r,r=Date.now(),n)throw new Error("Parsing failed at character position "+(n-1)+' near "'+t.slice(n-20,n)+'"');var i=function(e,t,r,n,i){for(var o=[],a={i:0,r:0,n:!1,cc:-1,c:[]},s=a,l=i.pos,u=!1,c=!1,d=!1;;){var f=t[l],_=t[l+1];if(_<0?(c=!0,_=-_-1):c=!1,f>=0){d=!0;var p=r.slice(f,_);s.c.push(p),u=c}else{if(-1===f&&0===_)break;d=!1;var h={i:s.c.length-(u?1:0),r:-f,n:c,cc:_,c:[]};if(u){var v=s.c.length-1,g=s.c[v];h.c.push(g),s.c[v]=h}else s.c.push(h);o.push(s),s=h,u=!1}if(!d||!u)for(;s.c.length===s.cc;){if(u=s.n,(h=o.pop()).c[s.i]=n[s.r].call(e,s.c),s=h,u)break}l+=2}return a.c[0]}(this,new Int32Array(Vs.memory.buffer),t,this._ruleCbMap,{pos:this._resultPtr>>2});return $s.constructOut=$s.constructOut+Date.now()-r,i},e.stats={all:0,copyIn:0,parse:0,constructOut:0},e}(),$s=zs.stats,Ys=String,Ws=function(e){if("Symbol"===Wn(e))throw TypeError("Cannot convert a Symbol value to a string");return Ys(e)},Zs=function(){var e=te(this),t="";return e.hasIndices&&(t+="d"),e.global&&(t+="g"),e.ignoreCase&&(t+="i"),e.multiline&&(t+="m"),e.dotAll&&(t+="s"),e.unicode&&(t+="u"),e.unicodeSets&&(t+="v"),e.sticky&&(t+="y"),t},Js=RegExp.prototype,Ks=function(e){var t=e.flags;return void 0!==t||"flags"in Js||I(e,"flags")||!ce(Js,e)?t:ue(Zs,e)},qs=Gt.PROPER,Xs="toString",Qs=RegExp.prototype.toString,el=e((function(){return"/a/b"!=Qs.call({source:"a",flags:"b"})})),tl=qs&&Qs.name!=Xs;(el||tl)&&Vt(RegExp.prototype,Xs,(function(){var e=te(this);return"/"+Ws(e.source)+"/"+Ws(Ks(e))}),{unsafe:!0});var rl=TypeError,nl=function(e){if(e>9007199254740991)throw rl("Maximum allowed index exceeded");return e},il=fs("splice"),ol=Math.max,al=Math.min;or({target:"Array",proto:!0,forced:!il},{splice:function(e,t){var r,n,i,o,a,s,l=N(this),u=Ue(l),c=De(e,u),d=arguments.length;for(0===d?r=n=0:1===d?(r=0,n=u-c):(r=d-2,n=al(ol(ke(t),0),u-c)),nl(u+r-n),i=po(l,n),o=0;o<n;o++)(a=c+o)in l&&en(i,o,l[a]);if(i.length=n,r<n){for(o=c;o<u-n;o++)s=o+r,(a=o+n)in l?l[s]=l[a]:Oo(l,s);for(o=u;o>u-n+r;o--)Oo(l,o-1)}else if(r>n)for(o=u-n;o>c;o--)s=o+r-1,(a=o+n-1)in l?l[s]=l[a]:Oo(l,s);for(o=0;o<r;o++)l[o+c]=arguments[o+2];return l.length=u-n+r,i}});var sl={renderingMode:"native",lazyRegistration:!1,publicProperties:!1,classPrefix:"",availability:null,domain:"//",writeOnly:!1,allowInWriteOnly:!0,addGlobalClass:!1,templateEngine:null,multipleSlots:!1,reflectToAttributes:!0,writeFieldsToNode:!0,writeIdToDOM:!1,separateInnerData:!1,innerDataExclude:null,listenerChangeLifeTimes:!1,randomizeTagName:!1,virtualHost:!1,throwGlobalError:!1,writeExtraInfoToAttr:!0,documentBackend:"undefined"!=typeof window&&"undefined"!=typeof document?"dom":"none",hasDOMBackend:!("undefined"==typeof window||"undefined"==typeof document)};function ll(e){return ll="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},ll(e)}function ul(e){return"[object Object]"===Object.prototype.toString.call(e)}function cl(e){return"[object String]"===Object.prototype.toString.call(e)}function dl(e){return"[object Number]"===Object.prototype.toString.call(e)}function fl(e){return e&&("[object Function]"===Object.prototype.toString.call(e)||"function"==typeof e)}function _l(e){return Array.isArray?Array.isArray(e):"[object Array]"===Object.prototype.toString.call(e)}var pl={element:null,component:null,freeTemplateEngine:null,textNode:null,nativeNode:null,virtualNode:null},hl=function(e){pl.element=e,hl=null},vl=function(e){pl.component=e,vl=null},gl=function(e){pl.freeTemplateEngine=e,gl=null},yl=function(e){pl.textNode=e,yl=null},ml=function(e){pl.nativeNode=e,ml=null},bl=function(e){pl.virtualNode=e,bl=null};function El(){return pl.component}function wl(e){return e instanceof pl.element}function Ol(e){return e instanceof pl.component}function Al(e){return e instanceof pl.textNode}var Cl=function(){function e(e){this._arr=[],this._index=0,this._type=e}return e.getGlobalErrorInstance=function(){return e.instance||(e.instance=e.create()),e.instance},e.create=function(t){return new e(t)},e.addGlobalErrorListener=function(t){return e.getGlobalErrorInstance().add(t)},e.removeGlobalErrorListener=function(t){return e.getGlobalErrorInstance().remove(t)},e.safeCallback=function(t,r,n,i,o){try{return r.apply(n,i)}catch(u){__appServiceSDK__.reportUncaughtError({info:u.toString(),stack:u.stack});var a=e.getGlobalErrorInstance(),s="[Exparser] [Error] [Component] "+(t||"Error Listener")+" Error @ ";n&&n.is&&(s+=n.is),s+="#"+(r.name||"(anonymous)"),Ol(o)&&o.triggerLifeTime("error",[u]);var l={message:s,type:t,element:n,method:r,args:i};if((!l.type||a.call(null,[u,l]))&&sl.throwGlobalError)throw u}},e.prototype.add=function(e){var t=this._index++;return this._arr.push({id:t,func:e}),t},e.prototype.remove=function(e){for(var t=this._arr,r=fl(e),n=0,i=t.length,o=void 0;n<i;n++)if(o=t[n],(r?o.func:o.id)===e)return t.splice(n,1),o.func;return null},e.prototype.call=function(t,r,n){for(var i=!1,o=0,a=this._arr;o<a.length;o++){var s=a[o];!1===e.safeCallback(this._type,s.func,t,r,n)&&(i=!0)}if(i)return!1},e.prototype.destroy=function(){for(var e=0;e<this._arr.length;e++)this._arr[e].func=void 0,this._arr[e]=null;this._arr.length=0},Object.defineProperty(e.prototype,"empty",{get:function(){return 0===this._arr.length},enumerable:!1,configurable:!0}),e}(),Sl=a("".charAt),Tl=a("".charCodeAt),Nl=a("".slice),xl=function(e){return function(t,r){var n,i,o=Ws(p(t)),a=ke(r),s=o.length;return a<0||a>=s?e?"":void 0:(n=Tl(o,a))<55296||n>56319||a+1===s||(i=Tl(o,a+1))<56320||i>57343?e?Sl(o,a):n:e?Nl(o,a,a+2):i-56320+(n-55296<<10)+65536}},Il={codeAt:xl(!1),charAt:xl(!0)},Rl=Il.charAt,Ll="String Iterator",Ml=Rt.set,kl=Rt.getterFor(Ll);Lr(String,"String",(function(e){Ml(this,{type:Ll,string:Ws(e),index:0})}),(function(){var e,t=kl(this),r=t.string,n=t.index;return n>=r.length?{value:void 0,done:!0}:(e=Rl(r,n),t.index+=e.length,{value:e,done:!1})}));var Pl=Yt.f,jl="object"==typeof window&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[],Dl={f:function(e){return jl&&"Window"==u(e)?function(e){try{return Pl(e)}catch(e){return nn(jl)}}(e):Pl(h(e))}},Bl=e((function(){if("function"==typeof ArrayBuffer){var e=new ArrayBuffer(8);Object.isExtensible(e)&&Object.defineProperty(e,"a",{value:8})}})),Fl=Object.isExtensible,Ul=e((function(){Fl(1)}))||Bl?function(e){return!!X(e)&&((!Bl||"ArrayBuffer"!=u(e))&&(!Fl||Fl(e)))}:Fl,Gl=!e((function(){return Object.isExtensible(Object.preventExtensions({}))})),Hl=g((function(e){var t=Ie.f,r=!1,n=k("meta"),i=0,o=function(e){t(e,n,{value:{objectID:"O"+i++,weakData:{}}})},s=e.exports={enable:function(){s.enable=function(){},r=!0;var e=Yt.f,t=a([].splice),i={};i[n]=1,e(i).length&&(Yt.f=function(r){for(var i=e(r),o=0,a=i.length;o<a;o++)if(i[o]===n){t(i,o,1);break}return i},or({target:"Object",stat:!0,forced:!0},{getOwnPropertyNames:Dl.f}))},fastKey:function(e,t){if(!X(e))return"symbol"==typeof e?e:("string"==typeof e?"S":"P")+e;if(!I(e,n)){if(!Ul(e))return"F";if(!t)return"E";o(e)}return e[n].objectID},getWeakData:function(e,t){if(!I(e,n)){if(!Ul(e))return!0;if(!t)return!1;o(e)}return e[n].weakData},onFreeze:function(e){return Gl&&r&&Ul(e)&&!I(e,n)&&o(e),e}};Ve[n]=!0})),Vl=function(e,t,r){var n,i;te(e);try{if(!(n=ge(e,"return"))){if("throw"===t)throw r;return r}n=ue(n,e)}catch(e){i=!0,n=e}if("throw"===t)throw r;if(i)throw n;return te(n),r},zl=TypeError,$l=function(e,t){this.stopped=e,this.result=t},Yl=$l.prototype,Wl=function(e,t,r){var n,i,o,a,s,l,u,c=r&&r.that,d=!(!r||!r.AS_ENTRIES),f=!(!r||!r.IS_RECORD),_=!(!r||!r.IS_ITERATOR),p=!(!r||!r.INTERRUPTED),h=eo(t,c),v=function(e){return n&&Vl(n,"normal",e),new $l(!0,e)},g=function(e){return d?(te(e),p?h(e[0],e[1],v):h(e[0],e[1])):p?h(e,v):h(e)};if(f)n=e.iterator;else if(_)n=e;else{if(!(i=ro(e)))throw zl(pe(e)+" is not iterable");if(so(i)){for(o=0,a=Ue(e);a>o;o++)if((s=g(e[o]))&&ce(Yl,s))return s;return new $l(!1)}n=io(e,i)}for(l=f?e.next:n.next;!(u=ue(l,n)).done;){try{s=g(u.value)}catch(e){Vl(n,"throw",e)}if("object"==typeof s&&s&&ce(Yl,s))return s}return new $l(!1)},Zl=Hl.getWeakData,Jl=Rt.set,Kl=Rt.getterFor,ql=go.find,Xl=go.findIndex,Ql=a([].splice),eu=0,tu=function(e){return e.frozen||(e.frozen=new ru)},ru=function(){this.entries=[]},nu=function(e,t){return ql(e.entries,(function(e){return e[0]===t}))};ru.prototype={get:function(e){var t=nu(this,e);if(t)return t[1]},has:function(e){return!!nu(this,e)},set:function(e,t){var r=nu(this,e);r?r[1]=t:this.entries.push([e,t])},delete:function(e){var t=Xl(this.entries,(function(t){return t[0]===e}));return~t&&Ql(this.entries,t,1),!!~t}};var iu,ou={getConstructor:function(e,t,r,n){var i=e((function(e,i){Hr(e,o),Jl(e,{type:t,id:eu++,frozen:void 0}),null!=i&&Wl(i,e[n],{that:e,AS_ENTRIES:r})})),o=i.prototype,a=Kl(t),s=function(e,t,r){var n=a(e),i=Zl(te(t),!0);return!0===i?tu(n).set(t,r):i[n.id]=r,e};return Ur(o,{delete:function(e){var t=a(this);if(!X(e))return!1;var r=Zl(e);return!0===r?tu(t).delete(e):r&&I(r,t.id)&&delete r[t.id]},has:function(e){var t=a(this);if(!X(e))return!1;var r=Zl(e);return!0===r?tu(t).has(e):r&&I(r,t.id)}}),Ur(o,r?{get:function(e){var t=a(this);if(X(e)){var r=Zl(e);return!0===r?tu(t).get(e):r?r[t.id]:void 0}},set:function(e,t){return s(this,e,t)}}:{add:function(e){return s(this,e,!0)}}),i}},au=Rt.enforce,su=!E.ActiveXObject&&"ActiveXObject"in E,lu=function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}},uu=function(t,r,n){var i=-1!==t.indexOf("Map"),o=-1!==t.indexOf("Weak"),s=i?"set":"add",l=E[t],u=l&&l.prototype,c=l,d={},f=function(e){var t=a(u[e]);Vt(u,e,"add"==e?function(e){return t(this,0===e?0:e),this}:"delete"==e?function(e){return!(o&&!X(e))&&t(this,0===e?0:e)}:"get"==e?function(e){return o&&!X(e)?void 0:t(this,0===e?0:e)}:"has"==e?function(e){return!(o&&!X(e))&&t(this,0===e?0:e)}:function(e,r){return t(this,0===e?0:e,r),this})};if(nr(t,!P(l)||!(o||u.forEach&&!e((function(){(new l).entries().next()})))))c=n.getConstructor(r,t,i,s),Hl.enable();else if(nr(t,!0)){var _=new c,p=_[s](o?{}:-0,1)!=_,h=e((function(){_.has(1)})),v=wi((function(e){new l(e)})),g=!o&&e((function(){for(var e=new l,t=5;t--;)e[s](t,t);return!e.has(-0)}));v||((c=r((function(e,t){Hr(e,u);var r=bo(new l,e,c);return null!=t&&Wl(t,r[s],{that:r,AS_ENTRIES:i}),r}))).prototype=u,u.constructor=c),(h||g)&&(f("delete"),f("has"),i&&f("get")),(g||p)&&f(s),o&&u.clear&&delete u.clear}return d[t]=c,or({global:!0,constructor:!0,forced:c!=l},d),gr(c,t),o||n.setStrong(c,t,i),c}("WeakMap",lu,ou);if(gt&&su){iu=ou.getConstructor(lu,"WeakMap",!0),Hl.enable();var cu=uu.prototype,du=a(cu.delete),fu=a(cu.has),_u=a(cu.get),pu=a(cu.set);Ur(cu,{delete:function(e){if(X(e)&&!Ul(e)){var t=au(this);return t.frozen||(t.frozen=new iu),du(this,e)||t.frozen.delete(e)}return du(this,e)},has:function(e){if(X(e)&&!Ul(e)){var t=au(this);return t.frozen||(t.frozen=new iu),fu(this,e)||t.frozen.has(e)}return fu(this,e)},get:function(e){if(X(e)&&!Ul(e)){var t=au(this);return t.frozen||(t.frozen=new iu),fu(this,e)?_u(this,e):t.frozen.get(e)}return _u(this,e)},set:function(e,t){if(X(e)&&!Ul(e)){var r=au(this);r.frozen||(r.frozen=new iu),fu(this,e)?pu(this,e,t):r.frozen.set(e,t)}else pu(this,e,t);return this}})}var hu={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0},vu=ae("span").classList,gu=vu&&vu.constructor&&vu.constructor.prototype,yu=gu===Object.prototype?void 0:gu,mu=q("iterator"),bu=q("toStringTag"),Eu=Dr.values,wu=function(e,t){if(e){if(e[mu]!==Eu)try{mt(e,mu,Eu)}catch(t){e[mu]=Eu}if(e[bu]||mt(e,bu,t),hu[t])for(var r in Dr)if(e[r]!==Dr[r])try{mt(e,r,Dr[r])}catch(t){e[r]=Dr[r]}}};for(var Ou in hu)wu(E[Ou]&&E[Ou].prototype,Ou);function Au(e,t){if(function(e){return"object"===ll(e)}(e)&&null!==e){var r=t?t.get(e):void 0;if(void 0!==r)return r;if(_l(e)){r=[],t&&t.set(e,r);for(var n=0,i=e.length;n<i;++n)r[n]=Au(e[n],t)}else for(var o in r={},t&&t.set(e,r),e)Cu.call(e,o)&&(r[o]=Au(e[o],t));return r}if("symbol"!==ll(e))return e}wu(yu,"DOMTokenList");var Cu=Object.prototype.hasOwnProperty;function Su(e){return Au(e,new WeakMap)}var Tu=Object.freeze({__proto__:null,hasOwnProperty:Cu,deepCopy:Su}),Nu=He.indexOf,xu=a([].indexOf),Iu=!!xu&&1/xu([1],1,-0)<0,Ru=ha("indexOf");function Lu(e,t,r,n){for(var i=wl(e)?e.collectMarks():{},o=[],a=[],s=e,l=e;l;){if(s!==l&&(o.push(e),e=l,a.push(i),i=wl(e)?e.collectMarks():{}),s=l.parentNode,!1===n(l,e,i))return;if(l.__ddHost){if(r)break;e=o.pop()||l.__ddHost,i=a.pop()||(wl(e)?e.collectMarks():{}),s=l=l.__ddHost}else l=!wl(l)||r?l.parentNode:l.__ddSlotParent}}or({target:"Array",proto:!0,forced:Iu||!Ru},{indexOf:function(e){var t=arguments.length>1?arguments[1]:void 0;return Iu?xu(this,e,t)||0:Nu(this,e,t)}});var Mu=function(){function e(){}return e.setInitTimeStamp=function(t){return void 0===t&&(t=Date.now()),e.initTimeStamp=t},e.getInitTimeStamp=function(){return e.initTimeStamp},e.create=function(t,r,n){void 0===n&&(n={});var i=n.originalEvent,o=n.extraFields,a=void 0===o?{}:o,s=n.bubbles,l=n.composed,u=n.capturePhase,c=Date.now()-e.initTimeStamp,d=new e;for(var f in d.currentTarget=null,d.type=t,d.timeStamp=c,d.mark=null,d.detail=r,d.bubbles=!!s,d.composed=!!l,d.__originalEvent=i,d.__hasCapture=!!u,d.__stopped=!1,d.__dispatched=!1,a)d[f]=a[f];return d},e.dispatchEvent=function(e,t){if(t&&!t.__dispatched){t.__dispatched=!0,e.__ddElement&&e.__ddHost!==e.__ddElement&&wl((e=e.__ddElement).shadowRoot)&&(e=e.shadowRoot),t.target=wl(e)?e.__methodCaller:e;var r=t.type,n=!t.composed;if(t.__hasCapture){var i=[];Lu(e,0,n,(function(e,t,n){return e.__ddCaptureEvents&&e.__ddCaptureEvents[r]&&i.push([e,t,n]),!0}));for(var o=i.length-1;o>=0;o--){var a=i[o],s=a[0],l=a[1],u=a[2];t.target=wl(l)?l.__methodCaller:l,t.mark=u;var c=s.__ddCaptureMutated&&s.__ddCaptureMutated[r];if(f(s.__ddCaptureEvents[r],c,s),t.__stopped)break}}if(t.target=wl(e)?e.__methodCaller:e,!t.__stopped){var d=!t.bubbles;Lu(e,0,n,(function(e,n,i){t.target=wl(n)?n.__methodCaller:n,t.mark=i;var o=e.__ddMutated&&e.__ddMutated[r];return e.__ddEvents&&e.__ddEvents[r]&&f(e.__ddEvents[r],o,e),!d&&!t.__stopped}))}}function f(e,r,n){if(!(r&&r.length&&t.mutatedMarked())){var i=t.currentTarget=wl(n)?n.__methodCaller:n,o=e.call(i,[t],Ol(n)?n:void 0);r&&r.length&&t.mutatedMarked(),!1===o&&(t.__originalEvent&&t.__originalEvent.preventDefault(),t.__stopped=!0)}}},e.triggerEvent=function(t,r,n,i){e.dispatchEvent(t,e.create(r,n,i))},e.addListenerToElement=function(e,t,r,n){var i,o=n&&n.mutated;if(o){var a=r;r=function(e){for(var t=[],r=1;r<arguments.length;r++)t[r-1]=arguments[r];if(!e.mutatedMarked())return a.apply(this,ms([e],t))}}return n&&(n.useCapture||n.capture)?(e.__ddCaptureEvents||(e.__ddCaptureEvents=Object.create(null)),e.__ddCaptureEvents[t]||(e.__ddCaptureEvents[t]=Cl.create("Event Listener")),i=e.__ddCaptureEvents[t].add(r),o&&(e.__ddCaptureMutated||(e.__ddCaptureMutated=Object.create(null)),e.__ddCaptureMutated[t]||(e.__ddCaptureMutated[t]=[]),e.__ddCaptureMutated[t].push(i))):(e.__ddEvents||(e.__ddEvents=Object.create(null)),e.__ddEvents[t]||(e.__ddEvents[t]=Cl.create("Event Listener")),i=e.__ddEvents[t].add(r),o&&(e.__ddMutated||(e.__ddMutated=Object.create(null)),e.__ddMutated[t]||(e.__ddMutated[t]=[]),e.__ddMutated[t].push(i))),Ol(e)&&e.__componentOptions.listenerChangeLifeTimes&&e.triggerLifeTime("listenerChanged",[!0,t,r,n]),i},e.removeListenerFromElement=function(e,t,r,n){var i,o;n&&(n.useCapture||n.capture)?(e.__ddCaptureEvents&&e.__ddCaptureEvents[t]&&(i=e.__ddCaptureEvents[t].remove(r)),e.__ddCaptureMutated&&e.__ddCaptureMutated[t]&&-1!==(o=e.__ddCaptureMutated[t].indexOf(r))&&e.__ddCaptureMutated[t].splice(o,1)):(e.__ddEvents&&e.__ddEvents[t]&&(i=e.__ddEvents[t].remove(r)),e.__ddMutated&&e.__ddMutated[t]&&-1!==(o=e.__ddMutated[t].indexOf(r))&&e.__ddMutated[t].splice(o,1)),i&&Ol(e)&&e.__componentOptions.listenerChangeLifeTimes&&e.triggerLifeTime("listenerChanged",[!1,t,i,n])},e.prototype.preventDefault=function(){this.__originalEvent&&this.__originalEvent.preventDefault()},e.prototype.stopPropagation=function(){this.__stopped=!0},e.prototype.isStopped=function(){return!!this.__stopped},e.prototype.markMutated=function(){this.__mutatedMarked=!0},e.prototype.mutatedMarked=function(){return!!this.__mutatedMarked},e.initTimeStamp=Date.now(),e}(),ku=E.RegExp,Pu=e((function(){var e=ku("a","y");return e.lastIndex=2,null!=e.exec("abcd")})),ju=Pu||e((function(){return!ku("a","y").sticky})),Du={BROKEN_CARET:Pu||e((function(){var e=ku("^r","gy");return e.lastIndex=2,null!=e.exec("str")})),MISSED_STICKY:ju,UNSUPPORTED_Y:Pu},Bu=E.RegExp,Fu=e((function(){var e=Bu(".","s");return!(e.dotAll&&e.exec("\n")&&"s"===e.flags)})),Uu=E.RegExp,Gu=e((function(){var e=Uu("(?<a>b)","g");return"b"!==e.exec("b").groups.a||"bc"!=="b".replace(e,"$<a>c")})),Hu=Rt.get,Vu=S("native-string-replace",String.prototype.replace),zu=RegExp.prototype.exec,$u=zu,Yu=a("".charAt),Wu=a("".indexOf),Zu=a("".replace),Ju=a("".slice),Ku=function(){var e=/a/,t=/b*/g;return ue(zu,e,"a"),ue(zu,t,"a"),0!==e.lastIndex||0!==t.lastIndex}(),qu=Du.BROKEN_CARET,Xu=void 0!==/()??/.exec("")[1];(Ku||Xu||qu||Fu||Gu)&&($u=function(e){var t,r,n,i,o,a,s,l=this,u=Hu(l),c=Ws(e),d=u.raw;if(d)return d.lastIndex=l.lastIndex,t=ue($u,d,c),l.lastIndex=d.lastIndex,t;var f=u.groups,_=qu&&l.sticky,p=ue(Zs,l),h=l.source,v=0,g=c;if(_&&(p=Zu(p,"y",""),-1===Wu(p,"g")&&(p+="g"),g=Ju(c,l.lastIndex),l.lastIndex>0&&(!l.multiline||l.multiline&&"\n"!==Yu(c,l.lastIndex-1))&&(h="(?: "+h+")",g=" "+g,v++),r=new RegExp("^(?:"+h+")",p)),Xu&&(r=new RegExp("^"+h+"$(?!\\s)",p)),Ku&&(n=l.lastIndex),i=ue(zu,_?r:l,g),_?i?(i.input=Ju(i.input,v),i[0]=Ju(i[0],v),i.index=l.lastIndex,l.lastIndex+=i[0].length):l.lastIndex=0:Ku&&i&&(l.lastIndex=l.global?i.index+i[0].length:n),Xu&&i&&i.length>1&&ue(Vu,i[0],r,(function(){for(o=1;o<arguments.length-2;o++)void 0===arguments[o]&&(i[o]=void 0)})),i&&f)for(i.groups=a=ot(null),o=0;o<f.length;o++)a[(s=f[o])[0]]=i[s[1]];return i});var Qu=$u;or({target:"RegExp",proto:!0,forced:/./.exec!==Qu},{exec:Qu});var ec=q("species"),tc=RegExp.prototype,rc=function(t,r,n,i){var o=q(t),s=!e((function(){var e={};return e[o]=function(){return 7},7!=""[t](e)})),l=s&&!e((function(){var e=!1,r=/a/;return"split"===t&&((r={}).constructor={},r.constructor[ec]=function(){return r},r.flags="",r[o]=/./[o]),r.exec=function(){return e=!0,null},r[o](""),!e}));if(!s||!l||n){var u=a(/./[o]),c=r(o,""[t],(function(e,t,r,n,i){var o=a(e),l=t.exec;return l===Qu||l===tc.exec?s&&!i?{done:!0,value:u(t,r,n)}:{done:!0,value:o(r,t,n)}:{done:!1}}));Vt(String.prototype,t,c[0]),Vt(tc,o,c[1])}i&&mt(tc[o],"sham",!0)},nc=Il.charAt,ic=function(e,t,r){return t+(r?nc(e,t).length:1)},oc=Math.floor,ac=a("".charAt),sc=a("".replace),lc=a("".slice),uc=/\$([$&'`]|\d{1,2}|<[^>]*>)/g,cc=/\$([$&'`]|\d{1,2})/g,dc=function(e,t,r,n,i,o){var a=r+e.length,s=n.length,l=cc;return void 0!==i&&(i=N(i),l=uc),sc(o,l,(function(o,l){var u;switch(ac(l,0)){case"$":return"$";case"&":return e;case"`":return lc(t,0,r);case"'":return lc(t,a);case"<":u=i[lc(l,1,-1)];break;default:var c=+l;if(0===c)return o;if(c>s){var d=oc(c/10);return 0===d?o:d<=s?void 0===n[d-1]?ac(l,1):n[d-1]+ac(l,1):o}u=n[c-1]}return void 0===u?"":u}))},fc=TypeError,_c=function(e,t){var r=e.exec;if(P(r)){var n=ue(r,e,t);return null!==n&&te(n),n}if("RegExp"===u(e))return ue(Qu,e,t);throw fc("RegExp#exec called on incompatible receiver")},pc=q("replace"),hc=Math.max,vc=Math.min,gc=a([].concat),yc=a([].push),mc=a("".indexOf),bc=a("".slice),Ec="$0"==="a".replace(/./,"$0"),wc=!!/./[pc]&&""===/./[pc]("a","$0");rc("replace",(function(e,t,r){var n=wc?"$":"$0";return[function(e,r){var n=p(this),i=null==e?void 0:ge(e,pc);return i?ue(i,e,n,r):ue(t,Ws(n),e,r)},function(e,i){var o=te(this),a=Ws(e);if("string"==typeof i&&-1===mc(i,n)&&-1===mc(i,"$<")){var s=r(t,o,a,i);if(s.done)return s.value}var l=P(i);l||(i=Ws(i));var u=o.global;if(u){var c=o.unicode;o.lastIndex=0}for(var d=[];;){var f=_c(o,a);if(null===f)break;if(yc(d,f),!u)break;""===Ws(f[0])&&(o.lastIndex=ic(a,Fe(o.lastIndex),c))}for(var _,p="",h=0,v=0;v<d.length;v++){for(var g=Ws((f=d[v])[0]),y=hc(vc(ke(f.index),a.length),0),m=[],b=1;b<f.length;b++)yc(m,void 0===(_=f[b])?_:String(_));var E=f.groups;if(l){var w=gc([g],m,y,a);void 0!==E&&yc(w,E);var O=Ws(pa(i,void 0,w))}else O=dc(g,a,y,m,E,i);y>=h&&(p+=bc(a,h,y)+O,h=y+g.length)}return p+bc(a,h)}]}),!!e((function(){var e=/./;return e.exec=function(){var e=[];return e.groups={a:"7"},e},"7"!=="".replace(e,"$<a>")}))||!Ec||wc);var Oc=q("match"),Ac=function(e){var t;return X(e)&&(void 0!==(t=e[Oc])?!!t:"RegExp"==u(e))},Cc=Du.UNSUPPORTED_Y,Sc=4294967295,Tc=Math.min,Nc=[].push,xc=a(/./.exec),Ic=a(Nc),Rc=a("".slice),Lc=!e((function(){var e=/(?:)/,t=e.exec;e.exec=function(){return t.apply(this,arguments)};var r="ab".split(e);return 2!==r.length||"a"!==r[0]||"b"!==r[1]}));rc("split",(function(e,t,r){var n;return n="c"=="abbc".split(/(b)*/)[1]||4!="test".split(/(?:)/,-1).length||2!="ab".split(/(?:ab)*/).length||4!=".".split(/(.?)(.?)/).length||".".split(/()()/).length>1||"".split(/.?/).length?function(e,r){var n=Ws(p(this)),i=void 0===r?Sc:r>>>0;if(0===i)return[];if(void 0===e)return[n];if(!Ac(e))return ue(t,n,e,i);for(var o,a,s,l=[],u=(e.ignoreCase?"i":"")+(e.multiline?"m":"")+(e.unicode?"u":"")+(e.sticky?"y":""),c=0,d=new RegExp(e.source,u+"g");(o=ue(Qu,d,n))&&!((a=d.lastIndex)>c&&(Ic(l,Rc(n,c,o.index)),o.length>1&&o.index<n.length&&pa(Nc,l,nn(o,1)),s=o[0].length,c=a,l.length>=i));)d.lastIndex===o.index&&d.lastIndex++;return c===n.length?!s&&xc(d,"")||Ic(l,""):Ic(l,Rc(n,c)),l.length>i?nn(l,0,i):l}:"0".split(void 0,0).length?function(e,r){return void 0===e&&0===r?[]:ue(t,this,e,r)}:t,[function(t,r){var i=p(this),o=null==t?void 0:ge(t,e);return o?ue(o,t,i,r):ue(n,Ws(i),t,r)},function(e,i){var o=te(this),a=Ws(e),s=r(n,o,a,i,n!==t);if(s.done)return s.value;var l=ai(o,RegExp),u=o.unicode,c=(o.ignoreCase?"i":"")+(o.multiline?"m":"")+(o.unicode?"u":"")+(Cc?"g":"y"),d=new l(Cc?"^(?:"+o.source+")":o,c),f=void 0===i?Sc:i>>>0;if(0===f)return[];if(0===a.length)return null===_c(d,a)?[a]:[];for(var _=0,p=0,h=[];p<a.length;){d.lastIndex=Cc?0:p;var v,g=_c(d,Cc?Rc(a,p):a);if(null===g||(v=Tc(Fe(d.lastIndex+(Cc?p:0)),a.length))===_)p=ic(a,p,u);else{if(Ic(h,Rc(a,_,p)),h.length===f)return h;for(var y=1;y<=g.length-1;y++)if(Ic(h,g[y]),h.length===f)return h;p=_=v}}return Ic(h,Rc(a,_)),h}]}),!Lc,Cc);var Mc=a(1..valueOf),kc=a("".replace),Pc="[\t\n\v\f\r                　\u2028\u2029\ufeff]",jc=RegExp("^"+Pc+Pc+"*"),Dc=RegExp(Pc+Pc+"*$"),Bc=function(e){return function(t){var r=Ws(p(t));return 1&e&&(r=kc(r,jc,"")),2&e&&(r=kc(r,Dc,"")),r}},Fc={start:Bc(1),end:Bc(2),trim:Bc(3)},Uc=Yt.f,Gc=Dt.f,Hc=Ie.f,Vc=Fc.trim,zc="Number",$c=E.Number,Yc=$c.prototype,Wc=E.TypeError,Zc=a("".slice),Jc=a("".charCodeAt),Kc=function(e){var t=Ee(e,"number");return"bigint"==typeof t?t:qc(t)},qc=function(e){var t,r,n,i,o,a,s,l,u=Ee(e,"number");if(fe(u))throw Wc("Cannot convert a Symbol value to a number");if("string"==typeof u&&u.length>2)if(u=Vc(u),43===(t=Jc(u,0))||45===t){if(88===(r=Jc(u,2))||120===r)return NaN}else if(48===t){switch(Jc(u,1)){case 66:case 98:n=2,i=49;break;case 79:case 111:n=8,i=55;break;default:return+u}for(a=(o=Zc(u,2)).length,s=0;s<a;s++)if((l=Jc(o,s))<48||l>i)return NaN;return parseInt(o,n)}return+u};if(nr(zc,!$c(" 0o1")||!$c("0b1")||$c("+0x1"))){for(var Xc,Qc=function(t){var r=arguments.length<1?0:$c(Kc(t)),n=this;return ce(Yc,n)&&e((function(){Mc(n)}))?bo(Object(r),n,Qc):r},ed=re?Uc($c):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,isFinite,isInteger,isNaN,isSafeInteger,parseFloat,parseInt,fromString,range".split(","),td=0;ed.length>td;td++)I($c,Xc=ed[td])&&!I(Qc,Xc)&&Hc(Qc,Xc,Gc($c,Xc));Qc.prototype=Yc,Yc.constructor=Qc,Vt(E,zc,Qc,{constructor:!0})}var rd=function(e){if(!e||e.length<=0)throw new Error("Parsing failed: the path string should not be empty");for(var t=[],r=(e=e.replace(/\n|\\|\r|\t|\f/g,"")).split(","),n=r.length,i=0;i<n;i++){for(var o="",a=!1,s=0,l=r[i],u=l.length,c=[],d=0;d<u;d++){s++;var f=l.charAt(d);if(("."===f||"]"===f)&&o||"."===f&&"]"===l.charAt(d-1)){if(!a&&"]"===f)throw new Error("Parsing failed at character position "+s);a&&"]"===f?(a=!1,o&&c.push(Number(o))):o&&c.push(o),o=""}else if("["!==f||!o&&"]"!==l.charAt(d-1))if(a){if(!("9">=f&&f>="0"))throw new Error("Parsing failed at character position "+s);o+=f}else{var _=f.charCodeAt(0);if(!("9">=f&&f>="0"||97<=_&&_<=122||65<=_&&_<=90||42===_))throw new Error("Parsing failed at character position "+s);o+=f}else a=!0,o&&c.push(o),o=""}o&&c.push(o),t.push(c)}return t},nd=function(e){for(var t=e.length,r=[],n="",i=0,o=!1,a=!1,s=0;s<t;s++){var l=e[s];if("\\"===l){if(s+1<t){var u=e[s+1];"."===u||"["===u||"]"===u||"\\"===u?(n+=u,s++):n+="\\"}}else if("."===l)n&&(r.push(n),n="");else if("["===l){if(n&&(r.push(n),n=""),0===r.length)throw new Error("The path string should not start with []: "+e);a=!0,o=!1}else if("]"===l){if(!o)throw new Error("There should be digits inside [] in the path string: "+e);a=!1,r.push(i),i=0}else if(a){if(l<"0"||l>"9")throw new Error("Only digits (0-9) can be put inside [] in the path string: "+e);o=!0,i=10*i+l.charCodeAt(0)-48}else n+=l}if(n&&r.push(n),0===t)throw new Error("The path string should not be empty");return r},id=Object.freeze({__proto__:null,parseMultiPaths:rd,parseSinglePath:nd}),od=go.filter,ad=fs("filter");or({target:"Array",proto:!0,forced:!ad},{filter:function(e){return od(this,e,arguments.length>1?arguments[1]:void 0)}});var sd=go.forEach,ld=ha("forEach")?[].forEach:function(e){return sd(this,e,arguments.length>1?arguments[1]:void 0)},ud=function(e){if(e&&e.forEach!==ld)try{mt(e,"forEach",ld)}catch(t){e.forEach=ld}};for(var cd in hu)hu[cd]&&ud(E[cd]&&E[cd].prototype);function dd(e){for(var t=[],r=0;r<e.length;r++)t[r]=e[r];return t}function fd(e,t){for(var r in t)Object.prototype.hasOwnProperty.call(e,r)&&"object"===ll(e[r])&&"object"===ll(t[r])&&null!==t[r]&&(_l(t[r])?e[r]=dd(t[r]):(e[r]=function(e){var t={};for(var r in e)t[r]=e[r];return t}(e[r]),fd(e[r],t[r])))}function _d(){}ud(yu);var pd=["created","ready","cacheAttached","attached","moved","detached","saved","restored","error","listenerChanged","performanceData"],hd=[String,Number,Boolean,Object,Array,null],vd=function(){function e(){this.properties=Object.create(null),this.methods=Object.create(null),this.listeners=Object.create(null),this.lifetimes=Object.create(null),this.pageLifetimes=Object.create(null),this.observers=[],this.relations=Object.create(null),this.ancestors=[]}return e.matchTypeWithValue=function(e,t){if(e===String){if("string"!=typeof t)return!1}else if(e===Number){if(!Number.isFinite(t))return!1}else if(e===Boolean){if("boolean"!=typeof t)return!1}else if(e===Object){if(null===t||t.constructor!==Object)return!1}else if(e===Array){if(t.constructor!==Array)return!1}else if(void 0===t)return!1;return!0},e.create=function(t){var r=new e;r.is=t.is||"",r.using=t.using||{},r.placeholder=t.placeholder||{},r.generics=t.generics||{},r.template=t.template,r.externalClasses=t.externalClasses||[],r.data=ul(t.data)?t.data:null,r.initiator=t.initiator,r.definitionFilter=t.definitionFilter,r.options={publicProperties:!!t.options&&(t.options.publicProperties||sl.publicProperties)},r._unprepared=t;var n=t.options&&void 0!==t.options.lazyRegistration?t.options.lazyRegistration:sl.lazyRegistration;return t.options&&n||e.prepare(r),t.is&&(e._list[r.is]=r),r},e.prepare=function(t){var r=t._unprepared;if(r){t._unprepared=null;for(var n=t.ancestors,i=void 0,o=_l(r.behaviors)?r.behaviors:[],a=0,s=o.length,l=void 0;a<s;a++){for(i in cl(l=o[a])&&(l=e._list[l]),l._unprepared&&e.prepare(l),"object"===ll(l.data)&&(null===t.data?t.data=l.data:fd(t.data,l.data)),l.generics){var u=l.generics[i];ul(u)||(u={}),t.generics[i]={default:u.default}}for(i in l.properties)t.properties[i]=l.properties[i];for(i in l.relations)t.relations[i]=l.relations[i];for(i in l.methods)t.methods[i]=l.methods[i];for(var c=0,d=l.ancestors;c<d.length;c++){var f=d[c];n.indexOf(f)<0&&n.push(f)}}"object"===ll(r.data)&&(null===t.data?t.data=r.data:fd(t.data,r.data));var _=void 0;for(i in r.properties)_=r.properties[i],hd.indexOf(_)>=0?_={type:_}:hd.indexOf(_.type)<0&&_.optionalTypes&&_.optionalTypes.length>0&&(_.type=_.optionalTypes[0]),void 0===_.value&&(_.type===String?_.value="":_.type===Number?_.value=0:_.type===Boolean?_.value=!1:_.type===Array?_.value=[]:_.value=null),t.properties[i]={type:_.type,optionalTypes:_.optionalTypes,value:_.value,filter:_.filter,observer:_.observer,public:!!(void 0===_.public?t.options.publicProperties:_.public),availability:_.availability,observeAssignments:!!_.observeAssignments};if(ul(r.lifetimes))for(i in r.lifetimes)t.lifetimes[i]=r.lifetimes[i];for(var p=0,h=pd;p<h.length;p++){var v=h[p],g=r[v];void 0===t.lifetimes[v]&&(t.lifetimes[v]=fl(g)?g:void 0)}for(i in r.listeners)t.listeners[i]=r.listeners[i];if(_l(r.observers))for(var y=0,m=r.observers;y<m.length;y++){l=m[y];t.observers.push({paths:rd(l.fields||"**"),observer:l.observer})}else for(i in r.observers)t.observers.push({paths:rd(i),observer:r.observers[i]});if(ul(r.pageLifetimes))for(i in r.pageLifetimes)t.pageLifetimes[i]=r.pageLifetimes[i];for(i in r.relations){var b=r.relations[i];t.relations[i]={target:b.target||i,type:b.type,linked:b.linked||_d,linkChanged:b.linkChanged||_d,unlinked:b.unlinked||_d,linkFailed:b.linkFailed||_d}}for(i in r.methods)fl(r.methods[i])&&(t.methods[i]=r.methods[i]);n.push(t)}},e.callDefinitionFilter=function(t){var r=t.definitionFilter,n=[];return _l(t.behaviors)&&t.behaviors.forEach((function(r){cl(r)&&(r=e._list[r]),r.definitionFilter&&(n.push(r.definitionFilter),r.definitionFilter.call(null,t))})),fl(r)?function(e){r(e,n)}:null},e.prototype.destroy=function(){var e;for(e in this.is=null,this.data=null,this.properties=null,this.methods)this.methods[e]=null,delete this.methods[e];for(e in this.listeners)this.listeners[e]=null,delete this.listeners[e];for(e in this.lifetimes)this.lifetimes[e]=null,delete this.lifetimes[e];for(e in this.pageLifetimes)this.pageLifetimes[e]=null,delete this.pageLifetimes[e];for(e in this.relations)this.relations[e]=null,delete this.relations[e];this.observers=null,this.using=null,this.externalClasses=null,this.generics=null,this.initiator=null,this.definitionFilter=null,this.template=null,this._unprepared=null,this.ancestors=null},e.prototype.hasBehavior=function(t){var r;this._unprepared&&e.prepare(this);for(var n=0,i=this.ancestors;n<i.length;n++)if(r=i[n],t instanceof e){if(r===t)return!0}else if(r===e._list[t])return!0;return!1},e.prototype._addObserversToDataProxy=function(e){for(var t,r=0,n=this.ancestors;r<n.length;r++)for(var i=0,o=n[r].observers;i<o.length;i++)t=o[i],e.addObserver(t.observer,t.paths)},e.prototype._getAllLifeTimeFuncs=function(){var e,t,r={};pd.forEach((function(e){r[e]=Cl.create("Lifetime Method")}));for(var n=0,i=this.ancestors;n<i.length;n++)for(t in(e=i[n]).lifetimes)fl(e.lifetimes[t])&&(r[t]||(r[t]=Cl.create("Lifetime Method")),r[t].add(e.lifetimes[t]));return r},e.prototype._getAllListeners=function(){for(var e,t,r,n={},i=0,o=this.ancestors;i<o.length;i++)for(t in(e=o[i]).listeners)r=e.listeners[t],Object.prototype.hasOwnProperty.call(n,t)?n[t].push(r):n[t]=[r];return n},e.prototype._getAllPageLifeTimeFuncs=function(){for(var e,t,r={},n=0,i=this.ancestors;n<i.length;n++)for(t in(e=i[n]).pageLifetimes)fl(e.pageLifetimes[t])&&(r[t]||(r[t]=Cl.create("Page Lifetime Method")),r[t].add(e.pageLifetimes[t]));return r},e._list=Object.create(null),e}();rc("match",(function(e,t,r){return[function(t){var r=p(this),n=null==t?void 0:ge(t,e);return n?ue(n,t,r):new RegExp(t)[e](Ws(r))},function(e){var n=te(this),i=Ws(e),o=r(t,n,i);if(o.done)return o.value;if(!n.global)return _c(n,i);var a=n.unicode;n.lastIndex=0;for(var s,l=[],u=0;null!==(s=_c(n,i));){var c=Ws(s[0]);l[u]=c,""===c&&(n.lastIndex=ic(i,Fe(n.lastIndex),a)),u++}return 0===u?null:l}]}));var gd=e((function(){Ze(1)}));or({target:"Object",stat:!0,forced:gd},{keys:function(e){return Ze(N(e))}});var yd=function(){function e(){}return e.create=function(t){var r=new e;return r._cb=t,r._noSubtreeCb=function(e){e.target===this&&t.call(this,e)},r._binded=[],r},e._createObserverTree=function(){throw new Error("Method not implemented.")},e._updateSubtreeCaches=function(t,r){t.__subtreeObserversCount+=r;var n=t.childNodes;if(n)for(var i=0;i<n.length;i++)e._updateSubtreeCaches(n[i],r)},e._callSingleObserver=function(e,t,r){var n=e[t];n&&n.call(e,[r])},e._callObservers=function(e,t,r){do{e[t]&&e[t].call(e,[r]),e=e.parentNode}while(e&&e.__subtreeObserversCount)},e.prototype.observe=function(t,r){void 0===r&&(r={});var n=0,i=r.subtree?this._cb:this._noSubtreeCb;r.properties&&(t.__propObservers||(t.__propObservers=Cl.create("Observer Callback")),this._binded.push({funcArr:t.__propObservers,id:t.__propObservers.add(i),subtree:r.subtree?t:null}),n+=1),r.childList&&(t.__childObservers||(t.__childObservers=Cl.create("Observer Callback")),this._binded.push({funcArr:t.__childObservers,id:t.__childObservers.add(i),subtree:r.subtree?t:null}),n+=1),r.characterData&&(t.__textObservers||(t.__textObservers=Cl.create("Observer Callback")),this._binded.push({funcArr:t.__textObservers,id:t.__textObservers.add(i),subtree:r.subtree?t:null}),n+=1),r.subtree&&e._updateSubtreeCaches(t,n),r.attachStatus&&(t.__attachedObservers||(t.__attachedObservers=Cl.create("Observer Callback")),this._binded.push({funcArr:t.__attachedObservers,id:t.__attachedObservers.add(i),subtree:null}))},e.prototype.disconnect=function(){for(var t=0,r=this._binded;t<r.length;t++){var n=r[t];n.funcArr.remove(n.id),n.subtree&&e._updateSubtreeCaches(n.subtree,-1)}this._binded=[]},e}(),md=function(){function e(e){this.tagName=e,this.id="",this.attrs={}}return e.toElement=function(e){var t,r=document.createElement(e.tagName);for(t in e.id&&(r.id=e.id),e.attrs)r.setAttribute(t,e.attrs[t]);return r},e.fromElement=function(t){var r=new e(t.tagName);r.id=t.id;for(var n=0,i=t.attributes;n<i.length;n++)r.attrs[i[n].name]=i[n].value;return r},e.prototype.cloneNode=function(){var t,r=new e;for(t in r.id=this.id,this.attrs)r.attrs[t]=this.attrs[t];return r},e.prototype.removeAttribute=function(e){delete this.attrs[e]},e.prototype.setAttribute=function(e,t){this.attrs[e]=t},e.prototype.getAttribute=function(e){return this.attrs[e]},e}(),bd=function(e,t,r,n){if(t&&e.ownerShadowRoot!==t.ownerShadowRoot)throw new Error("Cannot move the node from one shadow tree to another shadow tree.");var i=n?r:t,o=-1;r&&(o=e.childNodes.indexOf(r));var a=pl.element.insertChildToElement;return r&&o<0||!a(e,t,o,n)?null:i},Ed=function(e,t,r){if(e.__childObservers&&!e.__childObservers.empty||e.__subtreeObserversCount){var n=[r],i=void 0;i="add"===t?{type:"childList",target:e,addedNodes:n}:"remove"===t?{type:"childList",target:e,removedNodes:n}:{type:"childList",target:e,addedNodes:n,removedNodes:n},yd._callObservers(e,"__childObservers",i)}},wd=function e(t,r){for(var n=t.childNodes,i=0;i<n.length;i++){var o=n[i];r(t,o),o.__inheritSlots&&e(o,r)}};function Od(e,t){for(var r=0,n=void 0;r<e.__ddSlotChildren.length;r++)(n=e.__ddSlotChildren[r]).__virtual?Od(n,t):t.appendChild(n.__domElement)}function Ad(e,t){for(var r=0,n=void 0;r<e.__ddSlotChildren.length;r++)(n=e.__ddSlotChildren[r]).__virtual?Ad(n,t):t.removeChild(n.__domElement)}function Cd(e){if(e.__virtual)for(var t=0;t<e.__ddSlotChildren.length;t++)Cd(e.__ddSlotChildren[t]);else{var r=e.__domElement;r&&r.parentNode&&r.parentNode.removeChild(r)}}function Sd(e,t){for(;t<e.__ddSlotChildren.length;t++){var r=e.__ddSlotChildren[t];if(!r.__virtual)return r;var n=Sd(r,0);if(n)return n}}var Td=function(e,t,r,n,i){var o=e,a=document.createDocumentFragment();if(wl(o)){for(;o.__virtual;){var s=o.__ddSlotParent;if(!s){o=null;break}if(t&&!r){var l=s.__ddSlotChildren.indexOf(o);r=s.__ddSlotChildren[l+1]}o=s}wl(o)&&(o=o.__domElement)}if(o){var u=n,c=null,d=null;if(t&&(t.__virtual?(Od(t,a),c=a):c=t.__domElement),r)if(r.__virtual){var f=e,_=void 0;if(n?(Ad(r,o),u=!1,_=i+1):(f=r.__ddSlotParent,_=r===t?i:f.__ddSlotChildren.indexOf(r)),t){r=null;for(var p=f;!(r=Sd(p,_))&&p.__virtual;p=p.__ddSlotParent)_=p.__ddSlotParent.__ddSlotChildren.indexOf(p)+1;r&&(d=r.__domElement)}}else d=r.__domElement;u?c?o.replaceChild(c,d):o.removeChild(d):c&&(d?o.insertBefore(c,d):o.appendChild(c))}else t&&t.__ddSlotParent&&Cd(t);return i},Nd=function(e,t,r,n,i,o,a){if(n&&(r.__ddSlotParent=null),i&&(a=e.__ddSlotChildren.indexOf(r)),t){var s=t.__ddSlotParent;if(t.__ddSlotParent=e,s&&o){var l=s.__ddSlotChildren.indexOf(t);s.__ddSlotChildren.splice(l,1),s===e&&l<a&&a--}}t&&t.__backendExtracted||r&&r.__backendExtracted||(a=Td(e,t,r,n,a)),sl.writeExtraInfoToAttr&&(n&&wl(r)&&r.__domElement&&r.__domElement.removeAttribute("exparser:info-in-slot-of"),wl(t)&&t.__domElement&&(void 0!==e.__slotName&&e.ownerShadowRoot?t.__domElement.setAttribute("exparser:info-in-slot-of",e.ownerShadowRoot.__ddHost.__componentInstanceId):t.__domElement.removeAttribute("exparser:info-in-slot-of"))),i&&(-1===a&&(a=e.__ddSlotChildren.length),t?e.__ddSlotChildren.splice(a,n?1:0,t):e.__ddSlotChildren.splice(a,n?1:0))},xd=function(e,t,r,n){var i=e.childNodes;if(n){var o=t[""];if(o)for(var a=0;a<i.length;a++)Nd(o,i[a],null,!1,!1,!1,-1);else if(r[""]){o=r[""];for(a=0;a<i.length;a++)Nd(o,null,i[a],!0,!1,!1,a)}}else{!function e(n){for(var i=0;i<n.length;i++){var o=n[i],a=o.__slot||"",s=t[a];s?Nd(s,o,null,!1,!0,!0):r[a]&&(s=r[a],Nd(s,null,o,!0,!0,!0)),o.__inheritSlots&&e(o.childNodes)}}(i)}},Id=function(e){if(e.__hostAssociated&&e.__slotCacheDirty){e.__slotCacheDirty=!1;var t=e.__ddHost,r=Object.create(null),n=void 0!==t.__singleSlot?{"":t.__singleSlot}:t.__slots;!function e(t){void 0!==t.__slotName&&(r[t.__slotName]||(r[t.__slotName]=t));for(var n=t.childNodes,i=0;i<n.length;i++)wl(n[i])&&e(n[i])}(e),void 0!==t.__singleSlot?t.__singleSlot!==r[""]&&(r[""]&&(r[""].__ddSlotChildren=t.childNodes),xd(t,r,n,!0),t.__singleSlot&&(t.__singleSlot.__ddSlotChildren=[]),t.__singleSlot=r[""]||null):(xd(t,r,n,!1),t.__slots=r)}},Rd=function(e,t){if(!(!wl(e)||t.__ddHost.__idCacheDirty&&t.__slotCacheDirty)){!function e(r){r.__id&&(t.__ddHost.__idCacheDirty=!0),void 0!==r.__slotName&&(t.__slotCacheDirty=!0);for(var n=r.childNodes,i=0;i<n.length;i++){var o=n[i];wl(o)&&e(o)}}(e)}},Ld=function(e,t,r,n){for(var i=function e(t,n,i){var o=t.childNodes,a=0;for(n&&(a=o.indexOf(n)+(i?0:1));a<o.length;a++){var s=o[a];if(s.__slot===r)return s;if(s.__inheritSlots){var l=e(s,null,!1);if(l)return l}}return null};t!==e;t=t.parentNode){var o=i(t.parentNode,t,n);if(o)return o;n=!1}return null};function Md(e){if((!e.parentNode||e.parentNode.__attached)&&wl(e)){e.__attached=!0,e.__lifeTimeFuncs&&e.__lifeTimeFuncs.attached.call(e.__methodCaller,[],e),e.__relationHandler&&e.__relationHandler("attached"),e.__attachedObservers&&!e.__attachedObservers.empty&&yd._callSingleObserver(e,"__attachedObservers",{type:"attachStatus",target:e,status:"attached"}),wl(e.shadowRoot)&&Md(e.shadowRoot);for(var t=0,r=e.childNodes;t<r.length;t++)Md(r[t])}}function kd(e){if(wl(e)&&e.__attached){for(var t=0,r=e.childNodes;t<r.length;t++)kd(r[t]);wl(e.shadowRoot)&&kd(e.shadowRoot),e.__attached=!1,e.__lifeTimeFuncs&&e.__lifeTimeFuncs.detached.call(e.__methodCaller,[],e),e.__relationHandler&&e.__relationHandler("detached"),e.__attachedObservers&&!e.__attachedObservers.empty&&yd._callSingleObserver(e,"__attachedObservers",{type:"attachStatus",target:e,status:"detached"}),e.destroy&&e.destroy(!1)}}function Pd(e){var t=!0,r=!0;if(wl(e)?(e.__backendExtracted=!0,e.__domElement=null,e.$$=null,r=!1):Al(e)&&(e.__backendExtracted=!0,e.__domElement=null,e.$$=null,t=!1,r=!1),t&&e.__ddSlotChildren)for(var n=0,i=e.__ddSlotChildren;n<i.length;n++){Pd(i[n])}else if(r&&e.childNodes)for(var o=0,a=e.childNodes;o<a.length;o++){Pd(a[o])}}function jd(e,t,r){var n,i=wl(e)&&e.__virtual,o=t.childNodes?t.childNodes[r]:void 0,a=!0,s=!0;if(wl(e)){var l;if(e.__backendExtracted=!1,!1===i)if(o)e.__domElement.tagName.toUpperCase()===o.tagName?(e.__domElement=o,e.$$=o):(l=md.toElement(e.__domElement),e.__domElement=l,e.$$=l,o.parentNode.replaceChild(l,o)),n=null;else l=md.toElement(e.__domElement),e.__domElement=l,e.$$=l,n=l;s=!1}else if(Al(e)){if(e.__backendExtracted=!1,o){if(void 0!==o.textContent)o.textContent=e.textContent,e.__domElement=o,e.$$=o;else{var u=document.createTextNode(e.textContent);e.__domElement=u,e.$$=u,o.parentNode.replaceChild(u,o)}n=null}else{u=document.createTextNode(e.textContent);e.__domElement=u,e.$$=u,n=u}s=!1,a=!1}else{var c=document.createDocumentFragment();if(c.__ddSlotChildren=e.__ddSlotChildren,o&&o.childNodes)for(;o.childNodes.length;)c.appendChild(o.childNodes[0]);if(o){for(;e.childNodes&&o.childNodes&&o.childNodes.length;)e.appendChild(o.childNodes[0]);o.parentNode.replaceChild(e,o),n=null}else n=e;e=c}n?(t.appendChild(n),o=n):o=t?t.childNodes[r]:void 0;var d=0;if(a&&e.__ddSlotChildren)for(var f=0,_=e.__ddSlotChildren;f<_.length;f++){var p=_[f];if(i)r=jd(p,t,r);else if(p.asShadowRoot){for(var h=0,v=p.asShadowRoot.childNodes;h<v.length;h++){d=jd(v[h],o,d)}o.__ddSlotParent=e,o.__ddHost=e,e.shadowRoot=o,e.__ddSlotChildren[0]=o,e.__singleSlot===p&&(e.__singleSlot=o)}else d=jd(p,o,d)}else if(s&&e.childNodes)for(var g=0,y=e.childNodes;g<y.length;g++){d=jd(p=y[g],o,d)}if(i)return r;for(;o.childNodes.length>d;)o.removeChild(o.childNodes[d]);return r+1}function Dd(e,t,r,n,i){if(t===e)return!1;var o=r[n],a=!0;o.id&&o.id!==t.__id&&(a=!1);for(var s=o.classes,l=0;a&&l<s.length;l++)t.classList.contains(s[l])||(a=!1);if(!a&&">"===i)return!1;var u=t;if(a&&0===n){if(null===e)return!0;for(u=u.parentNode;u;u=u.parentNode)if(u===e)return!0;if(">>>"!==i)return!1;u=t,a=!1}for(var c=a?o.relation:i;(u=u.parentNode?u.parentNode:">>>"===c?u.__ddHost:">>>"===i?(a=!1,u.__ddHost):null)===e&&(u=null),u&&u.__virtual;);if(!u)return!1;if(a){if(Dd(e,u,r,n-1,c))return!0;if(">>>"!==i)return!1}return Dd(e,u,r,n,i)}function Bd(e,t,r){if(r.__virtual)return!1;for(var n=e.union,i=0;i<n.length;i++){var o=n[i];if(Dd(t,r,o,o.length-1,">"))return!0}return!1}function Fd(e,t,r,n,i){if(Bd(t,r,n)&&(e.push(n),i))return!0;if(n.shadowRoot&&t.crossShadow&&((n.ownerShadowRoot?n.ownerShadowRoot.__ddHost.__componentOptions.domain:sl.domain)===n.__componentOptions.domain&&Fd(e,t,r,n.shadowRoot,i)&&i))return!0;for(var o=n.childNodes,a=0;a<o.length;a++)if(wl(o[a])&&Fd(e,t,r,o[a],i)&&i)return!0;return!1}var Ud=new(function(){function e(){this.backendExtractedDefault=!1}return e.prototype.enableBackendExtractedDefault=function(){this.backendExtractedDefault=!0},e.prototype.disableBackendExtractedDefault=function(){this.backendExtractedDefault=!1},e}()),Gd=function(){function e(){}return Object.defineProperty(e.prototype,"id",{get:function(){return this.__id},set:function(e){var t=String(e);if(this.__id!==t){if(this.__id=t,this.ownerShadowRoot){var r=this.ownerShadowRoot.__ddHost;r.__idCacheDirty=!0,this.__domElement&&r.__componentOptions.writeIdToDOM&&(this.__domElement.id=t)}sl.writeExtraInfoToAttr&&this.__domElement&&this.__domElement.setAttribute("exparser:info-attr-id",t),(this.__propObservers&&!this.__propObservers.empty||this.__subtreeObserversCount)&&yd._callObservers(this,"__propObservers",{type:"properties",target:this,propertyName:"id"})}},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"slot",{get:function(){return this.__slot},set:function(e){var t=String(e);this.__slot!==t&&(this.__inheritSlots||(this.__slot=t,function(e){for(var t=e.parentNode;t&&t.__inheritSlots;)t=t.parentNode;if(t&&!t.__singleSlot){var r=e.__slot||"",n=t.__slots[r];if(n){var i=Ld(t,e,r,!1);Nd(n,e,i,!1,!0,!0)}else e.__ddSlotParent&&(n=e.__ddSlotParent,Nd(n,null,e,!0,!0,!0))}}(this),(this.__propObservers&&!this.__propObservers.empty||this.__subtreeObserversCount)&&yd._callObservers(this,"__propObservers",{type:"properties",target:this,propertyName:"slot"})))},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"attributes",{get:function(){var e=[];if(!this.__attributes)return e;for(var t in this.__attributes)e.push({name:t,value:this.__attributes[t]});return e},set:function(e){},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"class",{get:function(){return this.classList&&this.classList.getClassNames?this.classList.getClassNames():null},set:function(e){this.classList&&(this.classList.setClassNames(e),(this.__propObservers&&!this.__propObservers.empty||this.__subtreeObserversCount)&&yd._callObservers(this,"__propObservers",{type:"properties",target:this,propertyName:"class"}))},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"style",{get:function(){return this.__domElement?this.__domElement.style:null},set:function(e){this.setNodeStyle(e)},enumerable:!1,configurable:!0}),e.initialize=function(e,t,r){e.__id="",e.__slot="",e.__virtual=!1,e.__inheritSlots=!1,e.__attributes=null,e.__marks=null,e.__attached=!1,e.parentNode=null,e.childNodes=[],e.ownerShadowRoot=r,e.__ddSlotParent=null,e.__ddSlotChildren=e.childNodes,e.__subtreeObserversCount=0,e.classList=null,e.__styleSegments=[],e.__methodCaller=e,e.__relationHandler=null,e.__backendExtracted=Ud.backendExtractedDefault,e.__domElement=t,(e.$$=t)&&(t.__ddElement=e)},e.create=function(t){var r=new e;return e.initialize(r,t,null),r},e._clone=function(e,t,r,n){if(e.__id=t.__id,e.__slot=t.__slot,e.__virtual=t.__virtual,e.__inheritSlots=t.__inheritSlots,e.__marks=t.__marks?{}:null,e.__marks)for(var i in t.__marks)e.__marks[i]=t.__marks[i];for(var o in e.__attributes=Object.create(null),e.__attributes)e.__attributes[o]=t.__attributes[o];e.__attached=!1,e.parentNode=null,e.childNodes=[],e.ownerShadowRoot=n,e.__ddSlotParent=null,e.__ddSlotChildren=e.childNodes,e.__subtreeObserversCount=0,e.classList=null,e.__styleSegments=[],e.__methodCaller=e,e.__relationHandler=null,e.__backendExtracted=Ud.backendExtractedDefault,e.__domElement=r,e.$$=r,r&&(r.__ddElement=e)},e._updateIdMap=function(t){if(t.__idCacheDirty){t.__idCacheDirty=!1;var r=t.__idCache=Object.create(null);!function t(n){n.__id&&!r[n.__id]&&(r[n.__id]=n);for(var i=n.childNodes,o=0;o<i.length;o++)i[o]instanceof e&&t(i[o])}(t.shadowRoot)}},e.insertChildToElement=function(t,r,n,i){if(void 0===n&&(n=-1),void 0===i&&(i=!1),void 0!==t.__slotName)return!1;var o=0<=n?t.childNodes[n]:null;i&&r===o&&(i=!1);var a=null;if(r){a=r.parentNode,r.parentNode=t;var s=t.__subtreeObserversCount;if(a){var l=a.childNodes.indexOf(r);a.childNodes.splice(l,1),a===t&&l<n&&n--,s-=a.__subtreeObserversCount}s&&yd._updateSubtreeCaches(r,s)}for(var u=t;u&&u.__inheritSlots;)u=u.parentNode;for(var c=!(u&&u.__slots),d=!(c&&!t.__inheritSlots),f=a;f&&f.__inheritSlots;)f=f.parentNode;var _=!(f&&f.__slots),p=!(_&&!(null==a?void 0:a.__inheritSlots)),h=t;if(c)void 0!==t.__singleSlot&&(h=t.__singleSlot),h?Nd(h,r,o,i,d,p,n):r.__ddSlotParent&&Nd(r.__ddSlotParent,null,r,!0,p,!1),r&&!_&&r.__inheritSlots&&wd(r,(function(e,t){Nd(e,t,null,!1,!0,!0,-1)}));else{var v="";if(r&&(v=r.__slot||"",h=u.__slots[v]||null),o){var g=u.__slots[o.__slot||""]||null;g&&i&&Nd(g,null,o,i,!0,!1)}if(r)if(h){var y=o?Ld(u,o,v,!i):Ld(u,t,v,!1);Nd(h,r,y,!1,!0,p)}else r.__ddSlotParent&&Nd(r.__ddSlotParent,null,r,!0,p,!1);o&&i&&o.__inheritSlots&&wd(o,(function(e,t){Nd(e,t,null,!1,!0,!0,-1)})),r&&r.__inheritSlots&&wd(r,(function(e,r){var n=r.__slot||"",a=u.__slots[n]||null;if(a){var s=o?Ld(u,o,n,!i):Ld(u,t,n,!1);Nd(a,r,s,!1,!0,!0)}else r.__ddSlotParent&&Nd(r.__ddSlotParent,null,r,!0,!0,!1)}))}if(i&&(t.__subtreeObserversCount&&yd._updateSubtreeCaches(o,-t.__subtreeObserversCount),o.parentNode=null),-1===n&&(n=t.childNodes.length),r?t.childNodes.splice(n,i?1:0,r):t.childNodes.splice(n,i?1:0),t.ownerShadowRoot&&(i&&Rd(o,t.ownerShadowRoot),r&&Rd(r,t.ownerShadowRoot),Id(t.ownerShadowRoot)),i&&(kd(o),Ed(t,"remove",o)),r){if(a){r.__attached||Md(r);!function t(r){if(r instanceof e){for(var n=r.childNodes,i=0;i<n.length;i++)t(n[i]);r.shadowRoot instanceof e&&t(r.shadowRoot),r.__lifeTimeFuncs&&r.__lifeTimeFuncs.moved.call(r.__methodCaller,[],r),r.__relationHandler&&r.__relationHandler("moved")}}(r)}else Md(r);a===t?Ed(t,"move",r):(a&&Ed(a,"remove",r),Ed(t,"add",r))}return!0},e.appendChild=function(e,t){return bd(e,t,null,!1)},e.insertBefore=function(e,t,r){return bd(e,t,r,!1)},e.removeChild=function(e,t){return bd(e,null,t,!0)},e.replaceChild=function(e,t,r){return bd(e,t,r,!0)},e.extractBackend=function(e){return e.__backendExtracted?null:(Pd(e),e.__domElement)},e.getMethodCaller=function(e){return e.__methodCaller},e.setMethodCaller=function(e,t){e.__methodCaller=t},e.setSlotName=function(e,t){if(t=null==t?"":String(t),!e.__slotName){if(0!==e.childNodes.length||0!==e.__ddSlotChildren.length)return;e.__ddSlotChildren=[]}e.__slotName=t,e.ownerShadowRoot&&(e.ownerShadowRoot.__slotCacheDirty=!0,Id(e.ownerShadowRoot))},e.injectBackend=function(e,t){if(e.__backendExtracted){var r=document.createDocumentFragment();r.appendChild(t),jd(e,r,0)}},e.parseSelector=function(e){for(var t=[],r=!1,n=0,i=String(e||"").split(",");n<i.length;n++){for(var o=i[n].split(/( |\t|>+)/g),a=[],s=0,l=void 0,u="";s<o.length;s++)if((l=o[s])&&" "!==l&&"\t"!==l)if(">"!==l[0]){var c=function(e,t){var r=e.match(/^(#[_a-zA-Z][-_a-zA-Z0-9:]*|)((?:\.-?[_a-zA-Z][-_a-zA-Z0-9]*)+|)$/);if(!r)return null;var n=r[1].slice(1),i=r[2].split(".");return i.shift(),n||i.length?{id:n,classes:i,relation:t||""}:null}(l,u);if(u="",!c)break;a.push(c)}else{if(""!==u)break;">>>"===(u=l)&&(r=!0)}s===o.length&&a.length&&t.push(a)}return t.length?{crossShadow:r,union:t}:null},e.delayDestroy=function(t){if(dl(t)){var r=t,n=e.delayDestroyViewElements[r],i=__virtualDOM__.TreeManager.get(r);if(i&&_l(n))for(var o=i.nodeId,a=0,s=void 0,l=n.length;a<l;a++)s=n[a],o&&o.removeNode(s),s.destroy(!0),n[a]=null;e.delayDestroyViewElements[r]=null}else if(t&&t.__treeManager__){dl(r=t.__treeManager__.viewId)&&r>0&&(e.delayDestroyViewElements[r]||(e.delayDestroyViewElements[r]=[]),e.delayDestroyViewElements[r].push(t))}},e.prototype.appendChild=function(e){return bd(this,e,null,!1)},e.prototype.insertBefore=function(e,t){return bd(this,e,t,!1)},e.prototype.removeChild=function(e){return bd(this,null,e,!0)},e.prototype.replaceChild=function(e,t){return bd(this,e,t,!0)},e.prototype.triggerEvent=function(e,t,r){Mu.triggerEvent(this,e,t,r)},e.prototype.dispatchEvent=function(e){Mu.dispatchEvent(this,e)},e.prototype.addListener=function(e,t,r){Mu.addListenerToElement(this,e,t,r)},e.prototype.removeListener=function(e,t,r){Mu.removeListenerFromElement(this,e,t,r)},e.prototype.getAttribute=function(e){if(!this.__attributes)return null;var t=this.__attributes[e];return void 0===t?null:t},e.prototype.setAttribute=function(e,t){this.__attributes||(this.__attributes=Object.create(null)),t=String(t),this.__attributes[e]=t,this.__domElement&&this.__domElement.setAttribute(e,t)},e.prototype.removeAttribute=function(e){this.__attributes&&(delete this.__attributes[e],this.__domElement&&this.__domElement.removeAttribute(e))},e.prototype.setMark=function(e,t){this.__marks||(this.__marks={}),this.__marks[e]=t},e.prototype.collectMarks=function(){for(var e={},t=this;t;t=t.parentNode)if(t.__marks)for(var r in t.__marks)Object.prototype.hasOwnProperty.call(e,r)||(e[r]=t.__marks[r]);return e},e.prototype.setNodeStyle=function(e,t){this.__styleSegments||(this.__styleSegments=[]),this.__styleSegments[t||0]=e;var r=this.__styleSegments.join(";");if(this.__domElement&&this.ownerShadowRoot&&this.ownerShadowRoot.__childrenPropsFilter){var n=this.ownerShadowRoot.__childrenPropsFilter.style;if("function"==typeof n)return void this.__domElement.setAttribute("style",n.call(this,r))}this.__domElement&&this.__domElement.setAttribute("style",r),(this.__propObservers&&!this.__propObservers.empty||this.__subtreeObserversCount)&&yd._callObservers(this,"__propObservers",{type:"properties",target:this,propertyName:"style"})},e.replaceDocumentElement=function(e,t){e.__attached&&(t.parentNode.replaceChild(e.__domElement,t),Md(e))},e.pretendAttached=function(e){e.__attached||Md(e)},e.pretendDetached=function(e){e.__attached&&kd(e)},e.isAttached=function(e){return e.__attached},e.setInheritSlots=function(e){e.__singleSlot||e.__slots||e.__ddSlotChildren.length||(e.__ddSlotChildren=[],e.__inheritSlots=!0)},e.getInheritSlots=function(e){return e.__inheritSlots},e.prototype._querySelector=function(t){var r;if(!(r="object"===ll(t)?t:e.parseSelector(t)))return null;var n=[];return Fd(n,r,this,this,!0),n[0]||null},e._attachShadowRoot=function(e){var t=e.__ddHost;t.__ddSlotChildren=[e],Nd(t,e,null,!1,!1,0),e.__hostAssociated=!0,Id(e)},e.prototype.querySelector=function(t){var r="object"===ll(t)?t:e.parseSelector(t);if(!r)return null;var n=[];return Fd(n,r,this,this,!0),n[0]||null},e.prototype.querySelectorAll=function(t){var r="object"===ll(t)?t:e.parseSelector(t);if(!r)return[];var n=[];return Fd(n,r,this,this,!1),n},e.matchSelector=function(t,r){var n="object"===ll(t)?t:e.parseSelector(t);return!!n&&Bd(n,null,r)},e.prototype.matchSelector=function(t,r){var n="object"===ll(t)?t:e.parseSelector(t);return!!n&&Bd(n,this,r)},e.prototype.destroy=function(t){for(var r in void 0===t&&(t=!1),this.__ddEvents)this.__ddEvents[r].destroy(),this.__ddEvents[r]=void 0;for(var r in this.__ddEvents=void 0,this.__ddCaptureEvents)this.__ddCaptureEvents[r].destroy(),this.__ddCaptureEvents[r]=void 0;if(this.clearNodeRelation(),this.clearMPXProxy(),Ol(this)&&this.__dataProxy&&this.__dataProxy.destroy(),t){if(Ol(this)){if(this.__behavior){var n=Object.keys(this.__behavior.methods);for(var r in n)this[r]=null;this.__behavior&&this.__behavior.destroy()}this.__dataProxy=null,this.__using=null,this.__lifeTimeFuncs=null,this.__pageLifeTimeFuncs=null,this.__generics=null,this.__templateInstance=null,this.__innerData=null,this.__propData=null,this.__externalClassAlias=null,this.__idCacheDirty=null,this.__idCache=null,this.__relationMap=null,this.__componentInstanceId=null,this.__propertyChangeListeners=null,this.__componentOptions=null,this.__propPublic=null}this.__ddHost=null,this.__ddCaptureEvents=void 0,this.__propObservers&&this.__propObservers.destroy(),this.__propObservers=void 0,this.__childObservers&&this.__childObservers.destroy(),this.__childObservers=void 0,this.__textObservers&&this.__textObservers.destroy(),this.__textObservers=void 0,this.__attachedObservers&&this.__attachedObservers.destroy(),this.__attachedObservers=void 0,this.__vtObj=void 0,this.__treeManager__=void 0,this.__customConstructor__&&(this.__customConstructor__=void 0),this.__propData=void 0,this.__innerData=void 0,this.__dataProxy=void 0,this.dataset=null,this.classList=null,this.__styleSegments=null}else e.delayDestroy(this);this.__treeManager__=null},e.prototype.clearNodeRelation=function(){if(this.ownerShadowRoot&&(this.ownerShadowRoot.__treeManager__=null,this.ownerShadowRoot=null),this.shadowRoot&&(this.shadowRoot.__treeManager__=null,this.shadowRoot=null),this.__ddSlotParent&&(this.__ddSlotParent.__treeManager__=null,this.__ddSlotParent=void 0),this.__ddSlotChildren){for(var e=0;e<this.__ddSlotChildren.length;e++)this.__ddSlotChildren[e]&&(this.__ddSlotChildren[e].__treeManager__=null,this.__ddSlotChildren[e]=null);this.__ddSlotChildren=null}this.__ddSlotParent&&(this.__ddSlotParent=null),this.parentNode&&(this.parentNode.__treeManager__=null,this.parentNode=null)},e.prototype.clearMPXProxy=function(){if(this.__methodCaller){if(__virtualDOM__.CustomComponent.callerMap.delete(this.__methodCaller),this.__methodCaller.__mpxProxy){if(this.__methodCaller.__mpxProxy.data)for(var e=Object.keys(this.__methodCaller.__mpxProxy.data),t=0,r=void 0;t<e.length;t++)r=e[t],this.__methodCaller.__mpxProxy.data[r]=void 0,this.__methodCaller[r]=void 0;this.__methodCaller.__mpxProxy._watcher&&this.__methodCaller.__mpxProxy._watcher.cleanupDeps(),this.__methodCaller.__mpxProxy.clearWatchers(),this.__methodCaller.__mpxProxy.target=null,this.__methodCaller.__mpxProxy.data=null,this.__methodCaller.__mpxProxy=null}this.__methodCaller.__displayReporter&&(this.__methodCaller.__displayReporter=null),this.__methodCaller.__data__=null,this.__methodCaller.__exitState__=null,this.__methodCaller.__freeData__=null,this.__methodCaller=void 0}},e.delayDestroyViewElements={},e}();function Hd(e,t,r){for(var n=0,i=t;n<i.length;n++){for(var o=0,a=i[n];o<a.length;o++){var s=a[o];if(e["**"]||(e["**"]=[]),"**"===s)return void e["**"].push(r);e[s]||(e[s]={}),e=e[s]}e["~"]||(e["~"]=[]),e["~"].push(r)}}function Vd(e,t,r){for(var n=0,i=t;n<i.length;n++){for(var o=i[n],a="",s=0;s<o.length&&"**"!==(a=o[s]);s++){if(!e)return;e=e[a]}var l="**"===a?e["**"]:e["~"];if(l)for(s=0;s<l.length;s++)if(l[s]===r){l.splice(s,1);break}}}function zd(e,t,r,n,i){for(var o,a,s=0;s<e.length;s++)if(o=e[s],t[s]){t[s]=!1,a=i?void 0:n;for(var l=[],u=0,c=o.pathObj;u<c.length;u++){for(var d=0,f=c[u];d<f.length;d++){var _=f[d];if("**"===_)break;if("object"!==ll(a)){a=void 0;break}a=a[_]}l.push(a)}Cl.safeCallback("Data Observer",o.func,r.__methodCaller,l,r)}}hl(Gd);var $d=function(){function e(e){this._observerTree={},this._propFields=e,this._observerIdInc=0,this._observers=[],this._observerTree={}}return e.prototype.addObserver=function(e,t){var r=this._observerIdInc++;return this._observers[r]={pathObj:t,func:e},Hd(this._observerTree,t,r),r},e.prototype.removeObserver=function(e){var t=this._observers[e];Vd(this._observerTree,t.pathObj,e),this._observers[e]=null},e.prototype.moveObserver=function(e,t){var r=this._observers[e];Vd(this._observerTree,r.pathObj,e),r.pathObj=t,Hd(this._observerTree,t,e)},e}(),Yd=function(){function e(e,t,r,n,i,o){this._data=t,this._innerData=r,this._innerDataExclude=n,this._comp=e,this._updateCb=o,this._beforeMergeCb=null,this._beforeUpdateCb=null,this._hidingValue=!1,this._changes=[],this._doingUpdates=null,this._propFields=i._propFields,this._observers=i._observers,this._observerTree=i._observerTree,this._relatedObserverTreeObj=i,this._observerStatus=[]}return e.setPropUpdater=function(t){e.propUpdater=t},e.setPropObserver=function(t){e.propObserver=t},e.create=function(t,r,n){return new e({__methodCaller:t},r,null,null,new $d({}),n)},e._advancedCreate=function(t,r,n,i,o,a){return new e(t,r,n,i,o,a)},e._createObserverTree=function(e){return new $d(e)},e.prototype.destroy=function(){this._data=null,this._innerData=null,this._innerDataExclude=null,this._comp&&this._comp.__dataProxy&&(this._comp.__dataProxy=null),this._comp=null,this._updateCb=null,this._relatedObserverTreeObj=null,this._observerStatus=null,this._propFields=null,this._observers=null,this._observerTree=null,this._beforeMergeCb=null,this._beforeUpdateCb=null,this._hidingValue=null,this._changes=null,this._doingUpdates=null},e.prototype.scheduleReplace=function(e,t,r){_l(this._changes)&&this._changes.push([e,t,r])},e.prototype.setChanges=function(e){this._changes=e},e.prototype.doUpdates=function(t,r){var n=this._propFields,i=this._comp,o=this._hidingValue,a=this._innerDataExclude,s=!!this._doingUpdates,l=this._relatedObserverTreeObj._observerIdInc||null,u=null,c=null,d=null,f=this._changes;l?(s||(this._doingUpdates={changedPaths:[],changedValues:[],combinedChanges:[],changesTotal:0}),u=this._doingUpdates.changedPaths,c=this._doingUpdates.changedValues,d=this._doingUpdates.combinedChanges):(u=[],c=[],d=[]),this._changes=[];var _=[];this._beforeMergeCb&&this._beforeMergeCb(f,_,t);for(var p=0;p<f.length;p++){var h=f[p],v=h[0],g=v[0],y=!!a&&a.test(g),m=n[g],b=h[1],E=b,w=void 0;if(m&&1===v.length)w=this._data[g],b=e.propUpdater.call(this._comp,v,m,b,this._hidingValue),y||(this._innerData?(E=Su(b),_[p]||(this._innerData[g]=E)):E=b,h[1]=E),y&&!this._innerData||(this._data[g]=b);else{var O=this._data,A=g,C=null,S=1;if(!y||this._innerData){for(;S<v.length;S++)"number"==typeof(C=v[S])&&isFinite(C)?Cu.call(O,A)&&O[A]instanceof Array||(O[A]=[]):(!Cu.call(O,A)||null===O[A]||"object"!==ll(O[A])||O[A]instanceof Array)&&(O[A]={}),O=O[A],A=C;O[A]=b}if(this._innerData&&!y){for(O=this._innerData,A=g,S=1;S<v.length;S++)"number"==typeof(C=v[S])&&isFinite(C)?Cu.call(O,A)&&O[A]instanceof Array||(O[A]=[]):(!Cu.call(O,A)||null===O[A]||"object"!==ll(O[A])||O[A]instanceof Array)&&(O[A]={}),O=O[A],A=C;E=Su(b),_[p]||(O[A]=E),h[1]=E}}Zd(this._observerTree,this._observerStatus,v),y||(u.push(v),c.push([E,w,b]),d.push(h)),l&&(this._doingUpdates.changesTotal+=1)}if(!s){if(this._beforeUpdateCb&&this._beforeUpdateCb(t),l){var T=0;do{T=this._doingUpdates.changesTotal,zd(this._observers,this._observerStatus,i,this._data,o)}while(T!==this._doingUpdates.changesTotal);this._doingUpdates=null}this._updateCb(u,c,d,t);for(var N=0;N<c.length;N++){var x=c[N];if(x){var I=u[N],R=n[I[0]];R&&e.propObserver.call(i,x[2],x[1],I,R,o,r)}}}},e.prototype.getChanges=function(){return this._changes},e.prototype.getObserverTree=function(){return this._relatedObserverTreeObj},e.prototype.replaceWholeData=function(e){this._data=e},e.prototype.setHidingValue=function(e){this._hidingValue=!!e},e.prototype.setBeforeMergeCb=function(e){this._beforeMergeCb=e},e.prototype.setBeforeUpdateCb=function(e){this._beforeUpdateCb=e},e}();function Wd(e,t){for(var r in e)if("~"!==r)if("**"!==r)Wd(e[r],t);else for(var n=e["**"],i=0;i<n.length;i++)t[n[i]]=!0;else for(n=e["~"],i=0;i<n.length;i++)t[n[i]]=!0}function Zd(e,t,r){for(var n=0,i=r;n<i.length;n++){var o=i[n],a=e["**"];if(a&&a.forEach((function(e){t[e]=!0})),dl(o)){if(!Cu.call(e,o)){e=null;break}}else if(!/^[_a-zA-Z]/.test(o)||!Cu.call(e,o)){e=null;break}e=e[o]}e&&Wd(e,t)}var Jd=/(~|\^+)?-?[_0-9a-z][-_0-9a-z]*/gi,Kd=function(){function e(){}return e.create=function(t,r){void 0===r&&(r=null);var n=new e;for(var i in n._prefix="",n._addOriginalClass=!1,n._alias=r,n._resolvedAlias={},r)n._resolvedAlias[i]="";return n._rawNames=[],n._elem=t,n._owner=null,n},e.composeClassName=function(e){var t=e._rawNames,r=e._prefix,n=e._addOriginalClass,i=e._owner?e._owner._resolvedAlias:null,o="";r&&(r+="--");for(var a=0,s=void 0,l=t.length;a<l;a++)if(s=t[a],a>0&&(o+=" "),i&&Object.prototype.hasOwnProperty.call(i,s))o+=i[s];else if("~"===s[0])o+=s.slice(1);else if("^"===s[0]){s=s.slice(1);for(var u=e._owner||null;"^"===t[0];)s=s.slice(1),u=u?u._owner:null;var c=u?u._prefix:"";c&&(o+=(c+="--")+s)}else n&&(o+=s+" "),o+=r+s;return o},e.handleClassName=function(t){var r=t._elem.__domElement;if(r){var n=e.composeClassName(t);n?r.setAttribute("class",n):r.removeAttribute("class")}},e.aliasClassName=function(t){var r=t.classList;if(r instanceof e&&(r._alias&&e.resolveAlias(r),e.handleClassName(r)),_l(t.childNodes))for(var n=0,i=t.childNodes;n<i.length;n++){var o=i[n];wl(o)&&e.aliasClassName(o)}},e.resolveAlias=function(t){var r=t._owner;if(r){var n,i,o=!1;for(n in t._alias){var a=[];if((i=t._alias[n])&&_l(i))for(var s=void 0,l=0,u=i;l<u.length;l++){var c=u[l];s=Object.prototype.hasOwnProperty.call(r._alias,c)?r._resolvedAlias[c]:t._prefix&&c?t._prefix+"--"+c:c,a.push(s)}var d=a.join(" ");t._resolvedAlias[n]!==d&&(o=!0,t._resolvedAlias[n]=d)}o&&wl(t._elem.shadowRoot)&&e.aliasClassName(t._elem.shadowRoot)}},e.prototype.toggle=function(t,r){var n=this._rawNames.indexOf(t);r||(r=n<0),r?n<0&&(this._rawNames.push(t),e.handleClassName(this)):n>=0&&(this._rawNames.splice(n,1),e.handleClassName(this))},e.prototype.contains=function(e){for(var t=0,r=void 0,n=this._rawNames.length;t<n;t++)if("~"===(r=this._rawNames[t])[0]){if(r.slice(1)===e)return!0}else if("^"===r[0]){for(;"^"===r[0];)if(r.slice(1)===e)return!0}else if(r===e)return!0;return!1},e.prototype._setOwnerOptions=function(t,r,n){this._prefix!==r&&(this._prefix=r,this._addOriginalClass=n,this._owner=t,this._alias&&e.resolveAlias(this),e.handleClassName(this))},e.prototype._setAlias=function(t,r){var n=this._owner,i=String(r).match(Jd),o=[];if(this._alias&&i){this._alias[t]=i;for(var a=0,s=i;a<s.length;a++){var l=s[a];n&&Object.prototype.hasOwnProperty.call(n._alias,l)?o.push(n._resolvedAlias[l]):o.push(this._prefix?this._prefix+"--"+l:l)}}this._resolvedAlias[t]=o.join(" "),e.aliasClassName(this._elem.shadowRoot)},e.prototype.setClassNames=function(t){t=null==t?"":String(t),this._rawNames=t.match(Jd)||[],e.handleClassName(this)},e.prototype.getClassNames=function(){return e.composeClassName(this)},e.prototype.getPrefix=function(){return this._prefix},e.prototype.getAddOriginalClass=function(){return this._addOriginalClass},e}(),qd=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ys(t,e),t.create=function(e){return t._advancedCreate(e,null)},t.cloneNode=function(e){return t._advancedCreate(e,null)},t._advancedCreate=function(e,r){var n=new t;n.is=e.toLowerCase();var i=null;if("dom"===sl.documentBackend&&(i=Ud.backendExtractedDefault?new md(e):document.createElement(e)),Gd.initialize(n,i,r),n.classList=Kd.create(n,null),r){var o=r.__ddHost;if(n.classList._setOwnerOptions(o.classList,o.__componentOptions.classPrefix,o.__componentOptions.addGlobalClass),sl.writeExtraInfoToAttr&&i){var a=o.__componentOptions.classPrefix&&o.__componentOptions.classPrefix+"--";i.setAttribute("exparser:info-class-prefix",a)}}return n},t._advancedClone=function(e,r){var n=new t;n.is=e.is;var i=null;if(e.__domElement&&(i=e.__domElement instanceof md?Ud.backendExtractedDefault?e.__domElement.cloneNode():md.toElement(e.__domElement):Ud.backendExtractedDefault?md.fromElement(e.__domElement):document.importNode?document.importNode(e.__domElement,!1):e.__domElement.cloneNode(!1)),Gd._clone(n,e,i,r),n.classList=Kd.create(n,null),r){var o=r.__ddHost;if(n.classList._setOwnerOptions(o.classList,o.__componentOptions.classPrefix,o.__componentOptions.addGlobalClass),sl.writeExtraInfoToAttr&&i){var a=o.__componentOptions.classPrefix&&o.__componentOptions.classPrefix+"--";i.setAttribute("exparser:info-class-prefix",a)}}return n},t}(Gd);ml(qd);var Xd=function(e){var t=e.is,r=e.classPrefix,n=e.generics,i=e.initiator,o=e.behavior,a=e.options;this._unprepared=o,this.is=t||"",this.behavior=o,this.protoFunc=null,this.props=null,this.template=null,this.innerEvents=null,this.generics=n,this.initiator=i||null,this.options={availability:a.availability||sl.availability,domain:a.domain||sl.domain,writeOnly:a.writeOnly||sl.writeOnly,allowInWriteOnly:a.allowInWriteOnly||sl.allowInWriteOnly,classPrefix:r,addGlobalClass:a.addGlobalClass||sl.addGlobalClass,templateEngine:a.templateEngine||sl.templateEngine||pl.freeTemplateEngine,renderingMode:a.renderingMode||sl.renderingMode,multipleSlots:a.multipleSlots||sl.multipleSlots,reflectToAttributes:a.reflectToAttributes||sl.reflectToAttributes,writeFieldsToNode:a.writeFieldsToNode||sl.writeFieldsToNode,writeIdToDOM:a.writeIdToDOM||sl.writeIdToDOM,separateInnerData:a.separateInnerData||sl.separateInnerData,innerDataExclude:a.innerDataExclude||sl.innerDataExclude,listenerChangeLifeTimes:a.listenerChangeLifeTimes||sl.listenerChangeLifeTimes,randomizeTagName:a.randomizeTagName||sl.randomizeTagName,virtualHost:a.virtualHost||sl.virtualHost,placeholder:a.placeholder}};function Qd(e,t,r){t.__relationLinks||(t.__relationLinks={}),t.__relationLinks[r]=new Array(e.length).fill(null)}function ef(e,t,r){if(void 0===r&&(r=[]),wl(e)){if(Ol(e)){e.__pageLifeTimeFuncs[t]&&e.__pageLifeTimeFuncs[t].call(e.__methodCaller,r);for(var n=0,i=e.childNodes;n<i.length;n++)ef(i[n],t,r);e=e.shadowRoot}for(var o=0,a=e.childNodes;o<a.length;o++)ef(a[o],t,r)}}function tf(e,t,r,n,i){for(var o=El().prototype.hasBehavior,a="parent"===n,s="shadowHost"===n,l=0,u=void 0;l<e.length;l++){var c="object"===ll((u=e[l]).target)?u.target:vd._list[u.target];if(c){var d=void 0;if(!i)for(var f=s?r.ownerShadowRoot&&r.ownerShadowRoot.__ddHost:r.parentNode;f;){if(!f.__virtual&&o.call(f,c)){for(var _=0,p=a?f.__relationMap.child:s?f.__relationMap.shadowContent:f.__relationMap.descendant;_<p.length;_++){var h=p[_],v="object"===ll(h.target)?h.target:vd._list[h.target];if(v&&o.call(r,v)){d={parent:f,relation:h};break}}if(a||d)break}f=s?f.ownerShadowRoot&&f.ownerShadowRoot.__ddHost:f.parentNode}var g=t[l];t[l]=d,!g||d&&g.parent===d.parent||(Cl.safeCallback("Relation Unlinked Callback",g.relation.unlinked,g.parent.__methodCaller,[r.__methodCaller],g.parent),Cl.safeCallback("Relation Unlinked Callback",u.unlinked,r.__methodCaller,[g.parent.__methodCaller],r)),!d||g&&g.parent===d.parent||(Cl.safeCallback("Relation Linked Callback",d.relation.linked,d.parent.__methodCaller,[r.__methodCaller],d.parent),Cl.safeCallback("Relation Linked Callback",u.linked,r.__methodCaller,[d.parent.__methodCaller],r)),g&&d&&g.parent===d.parent&&(Cl.safeCallback("Relation Link Changed Callback",d.relation.linkChanged,d.parent.__methodCaller,[r.__methodCaller],d.parent),Cl.safeCallback("Relation Link Changed Callback",u.linkChanged,r.__methodCaller,[d.parent.__methodCaller],r)),i||d||Cl.safeCallback("Relation Link Failed Callback",u.linkFailed,r.__methodCaller,[],r)}}}function rf(e,t){return function(r){return e.call(t.__methodCaller,r,t)}}or({target:"Array",proto:!0},{fill:Qr}),ut("fill");var nf=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ys(t,e),t.register=function(e){var r=e.options||Object.create(null),n=vd.create(e),i=r.classPrefix||sl.classPrefix;null==i&&(i=n.is||"");var o=new Xd({is:e.is,behavior:n,classPrefix:i,generics:n.generics,initiator:n.initiator,options:r});return n._unprepared&&t.prepare(o),e.is&&(t._list[n.is]=o),o},t.isPrepared=function(e){return!e._unprepared},t.prototype.getPlaceholder=function(e){return this.__placeholder[e]},t.prepare=function(e){var r=e._unprepared;function n(){}if(!t.isPrepared(e)){e._unprepared=null;var i=void 0;r._unprepared&&vd.prepare(r);var o=e.options,a=e.props={},s={};if(o.writeOnly&&(s.data={value:null}),Object.keys(r.properties).forEach((function(e){var t=r.properties[e];a[e]={type:t.type,optionalTypes:t.optionalTypes,value:t.value,filter:fl(t.filter)?t.filter:null==t.filter?null:r.methods[t.filter],observer:fl(t.observer)?t.observer:null==t.observer?null:r.methods[t.observer],public:t.public,availability:t.availability,observeAssignments:t.observeAssignments},o.writeFieldsToNode&&(s[e]={enumerable:!0,get:function(){return this.__propData[e]},set:function(t){this.__dataProxy.scheduleReplace([e],t),this.__dataProxy.doUpdates()}})})),e.protoFunc=n,n.prototype=Object.create(t.prototype,s),n.prototype.is=e.is,n.prototype.__componentOptions=o,n.prototype.__using=r.using,n.prototype.__placeholder=r.placeholder,e.dataGroupObserverTree=Yd._createObserverTree(a),r._addObserversToDataProxy(e.dataGroupObserverTree),n.prototype.__behavior=r,o.writeFieldsToNode)for(i in r.methods)n.prototype[i]=r.methods[i];n.prototype.__lifeTimeFuncs=r._getAllLifeTimeFuncs(),n.prototype.__pageLifeTimeFuncs=r._getAllPageLifeTimeFuncs(),n.prototype.__relationMap={};var l=r.relations;for(i in l){var u=l[i];n.prototype.__relationMap[u.type]?n.prototype.__relationMap[u.type].push(u):n.prototype.__relationMap[u.type]=[u]}var c=[];n.prototype.__relationMap.parent&&c.push((function(e){tf(this.__relationMap.parent,this.__relationLinks.parent,this,"parent","detached"===e)})),n.prototype.__relationMap.ancestor&&c.push((function(e){tf(this.__relationMap.ancestor,this.__relationLinks.ancestor,this,"ancestor","detached"===e)})),n.prototype.__relationMap.shadowHost&&c.push((function(e){tf(this.__relationMap.shadowHost,this.__relationLinks.shadowHost,this,"shadowHost","detached"===e)})),e.relationHandler=function(e){for(var t=0;t<c.length;t++)c[t].call(this,e)};var d={},f={};for(i in r.data)f[i]=r.data[i];var _=void 0;for(i in a)_=a[i],f[i]=_.value,d[i]=_.public;var p=f,h=o.separateInnerData,v=o.innerDataExclude;if(v){for(i in p={},f)!1===v.test(i)&&(p[i]=f[i]);h||(f=p)}e.template=o.templateEngine.create(r,f,p,o),n.prototype.__propPublic=d,e.innerEvents=[];var g=r._getAllListeners();for(i in g){for(var y=g[i],m=i.indexOf("."),b=i.slice(m+1),E=m<1?"":i.slice(0,m),w=[],O=0,A=y.length,C=void 0;O<A;O++)fl(C=y[O])||(C=null==C?null:r.methods[C]),w.push(C);e.innerEvents.push({id:E,name:b,funcs:w})}}},t._advancedCreate=function(e,r,n,i,o){var a;if(r&&r._unprepared&&t.prepare(r),!r||!r.options)throw new Error("Framework inner error (exparser not found "+e+")");fl(r.options.availability)&&(Cl.safeCallback("Availablity Controller",r.options.availability,r,[n?n.__ddHost.__componentOptions.domain:void 0])||(r=t._list[""]));var s=new r.protoFunc,l=r.generics;if(l){var u={},c=void 0,d=void 0;for(a in l)c=l[a],"object"!==ll(d=i[a])&&(d=t._list[d]),"object"!==ll(d)&&null!=c.default&&(d=t._list[c.default]),d&&(u[a]=d);s.__generics=u}else s.__generics={};var f=null;r.options.virtualHost?(f="dom"===sl.documentBackend?void 0:null,Gd.initialize(s,f,n),s.__virtual=!0):"dom"===sl.documentBackend?(f=Ud.backendExtractedDefault?new md(e):document.createElement(e),Gd.initialize(s,f,n)):Gd.initialize(s,null,n),s.__externalClassAlias={};var _=r.behavior.externalClasses;if(_&&_l(_))for(var p=0;p<_.length;p++)s.__externalClassAlias[_[p]]=null;if(s.classList=Kd.create(s,s.__externalClassAlias),n){var h=n.__ddHost;if(s.classList._setOwnerOptions(h.classList,h.__componentOptions.classPrefix,h.__componentOptions.addGlobalClass),sl.writeExtraInfoToAttr&&f){var v=h.__componentOptions.classPrefix&&h.__componentOptions.classPrefix+"--";f.setAttribute("exparser:info-class-prefix",v)}}sl.writeExtraInfoToAttr&&f&&(s.__componentInstanceId=t.componentInstanceId++,f.setAttribute("exparser:info-component-id",String(s.__componentInstanceId))),s.__templateInstance=r.template.createInstance(s,o),s.__propData=s.__templateInstance.data;var g=r.options.separateInnerData,y=r.options.innerDataExclude;if(s.__innerData=g?Su(s.__propData):null,g&&y){var m={};for(a in s.__innerData)y.test(a)||(m[a]=s.__innerData[a]);s.__innerData=m}if(s.__dataProxy=Yd._advancedCreate(s,s.__propData,s.__innerData,y,r.dataGroupObserverTree,(function(e,t,r,n){var i=sl.separateInnerData?s.__innerData:s.__propData;s.__templateInstance.updateValues(s,i,e,t,r,n)})),s.__templateInstance.beforeMergeValues&&s.__dataProxy.setBeforeMergeCb((function(e,t,r){s.__templateInstance.beforeMergeValues(e,t,r)})),s.__templateInstance.beforeUpdateValues){var b=g?s.__innerData:s.__propData;s.__dataProxy.setBeforeUpdateCb((function(e){s.__templateInstance.beforeUpdateValues(s,b,e)}))}sl.writeOnly&&s.__dataProxy.setHidingValue(!0),s.__idCacheDirty=!1,s.__idCache=s.__templateInstance.idMap,null===s.__templateInstance.slots[""]&&(s.__templateInstance.slots[""]=f),r.options.multipleSlots?s.__slots=s.__templateInstance.slots:(s.__singleSlot=s.__templateInstance.slots[""]||null,s.__singleSlot&&(s.__singleSlot.__ddSlotChildren=s.childNodes)),wl(s.__templateInstance.shadowRoot)?(s.shadowRoot=s.__templateInstance.shadowRoot,Gd._attachShadowRoot(s.__templateInstance.shadowRoot)):(f instanceof md?(s.shadowRoot=f,s.shadowRoot.__ddHost=s,s.shadowRoot.__ddHost.__domElement.asShadowRoot=s.__templateInstance.shadowRoot):(s.shadowRoot=f,s&&s.shadowRoot&&(s.shadowRoot.__ddHost=s),s&&s.shadowRoot&&s.shadowRoot.__ddHost.__domElement.appendChild(s.__templateInstance.shadowRoot)),s.__ddSlotChildren=[f],f&&(f.__ddSlotParent=s));for(var E=0,w=s.__templateInstance.listeners;E<w.length;E++){var O=w[E];Mu.addListenerToElement(O.target,O.name,rf(O.func,s))}for(var A=0,C=r.innerEvents;A<C.length;A++){var S=C[A],T=S.id?"this"===S.id?s:s.__idCache[S.id]:s.shadowRoot;if(T)for(var N=S.name,x=0,I=S.funcs;x<I.length;x++){var R=I[x];Mu.addListenerToElement(T,N,rf(R,s))}}var L=s.__relationMap;return L.parent&&(Qd(L.parent,s,"parent"),s.__relationHandler=r.relationHandler),L.ancestor&&(Qd(L.ancestor,s,"ancestor"),s.__relationHandler=r.relationHandler),L.shadowHost&&(Qd(L.shadowHost,s,"shadowHost"),s.__relationHandler=r.relationHandler),s.__propertyChangeListeners=null,r.initiator&&Cl.safeCallback("Component Initiator",r.initiator,s.__methodCaller,[],s),s.__lifeTimeFuncs.created.call(s.__methodCaller,[],s),s},t.createWithGenerics=function(e,r,n,i){var o;if(e instanceof Xd)o=t._advancedCreate(e.is,e,null,n,i);else if(e)if(-1!==e.indexOf("-")||r){var a=r||Object.prototype.hasOwnProperty.call(t._list,e)&&t._list[e]||t._list[""];o=t._advancedCreate(e.toLowerCase(),a,null,n,i)}else o=qd.create(e);else o=t._advancedCreate("virtual",t._list[""],null,n,i);return o},t.create=function(e,r,n){var i;if(e instanceof Xd)i=t._advancedCreate(e.is,e,null,null,n);else if(e)if(-1!==e.indexOf("-")||r){var o=r||Object.prototype.hasOwnProperty.call(t._list,e)&&t._list[e]||t._list[""];i=t._advancedCreate(e.toLowerCase(),o,null,null,n)}else i=qd.create(e);else i=t._advancedCreate("virtual",t._list[""],null,null,n);return i},t.listProperties=function(e){var t=[];for(var r in e.__propPublic)void 0!==e.__propPublic[r]&&t.push(r);return t},t.listPublicProperties=function(e){var t=[];for(var r in e.__propPublic)!0===e.__propPublic[r]&&t.push(r);return t},t.hasProperty=function(e,t){return void 0!==e.__propPublic[t]},t.hasPublicProperty=function(e,t){return!0===e.__propPublic[t]},t.getMethodsFromDef=function(e){return e.behavior._unprepared&&vd.prepare(e.behavior),e.behavior.methods},t.getMethod=function(e,t){return e.__behavior.methods[t]},t.getComponentOptions=function(e){if(e)return e.__componentOptions},t.getInnerData=function(e){return e.__innerData},t.getDataProxy=function(e){return e.__dataProxy},t.replaceWholeData=function(e,t){e.__propData=t,e.__dataProxy.replaceWholeData(t)},t.prototype.triggerLifeTime=function(e,t){void 0===t&&(t=[]),this.__lifeTimeFuncs[e].call(this.__methodCaller,t||[])},t.prototype.triggerPageLifeTime=function(e,t){void 0===t&&(t=[]),ef(this,e,t)},t.prototype.hasBehavior=function(e){return"object"!==ll(e)&&Object.prototype.hasOwnProperty.call(this.__using,e)&&(e=this.__using[e]),this.__behavior instanceof vd&&this.__behavior.hasBehavior(e)},t.prototype.getRootBehavior=function(){return this.__behavior},t.prototype.getRelationNodes=function(e){var t=this.__behavior.relations[e];if(!t)return null;var r=t.type,n="child"===r,i="shadowContent"===r;if("parent"!==r&&"ancestor"!==r&&"shadowHost"!==r){var o=this,a=[];return function e(r){var s=r.childNodes;if(Array.isArray(s))for(var l=0,u=void 0;l<s.length;l++)if((u=s[l])instanceof Gd)if(u.__virtual)e(u);else{if(u.__relationLinks){var c=n?u.__relationLinks.parent:i?u.__relationLinks.shadowHost:u.__relationLinks.ancestor;if(c)for(var d=0,f=void 0;d<c.length;d++)if((f=c[d])&&f.parent===o&&f.relation===t){a.push(u);break}}i&&Ol(u)&&e(u.shadowRoot),n||e(u)}}(i?o.shadowRoot:o),a}for(var s=this.__relationMap[t.type],l=0;l<s.length;l++)if(s[l]===t)return this.__relationLinks[t.type][l]?[this.__relationLinks[t.type][l].parent]:[]},t.prototype.hasExternalClass=function(e){return Object.prototype.hasOwnProperty.call(this.__externalClassAlias,e)},t.prototype.setExternalClass=function(e,t){this.classList._setAlias(e,t)},t.prototype.setPropertyChangeListener=function(e,t){this.__propertyChangeListeners||(this.__propertyChangeListeners={}),this.__propertyChangeListeners[e]=t},t.prototype.replaceDataOnPath=function(e,t){this.__dataProxy.scheduleReplace(e,t)},t.prototype.isInnerDataExcluded=function(e){var t=this.__componentOptions.innerDataExclude;return!!t&&t.test(e)},t.prototype.applyDataUpdates=function(){this.__dataProxy.doUpdates()},t.prototype.setData=function(e){var t=this.__dataProxy;for(var r in e)t.scheduleReplace(nd(r),e[r]);t.doUpdates()},Object.defineProperty(t.prototype,"data",{get:function(){return this.__dataProxy?this.__dataProxy._data:null},set:function(e){if(this.__dataProxy){for(var t in e)this.__dataProxy.scheduleReplace([t],e[t]);this.__dataProxy.doUpdates()}},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"$",{get:function(){return Gd._updateIdMap(this),this.__idCache},set:function(e){},enumerable:!1,configurable:!0}),t._list={},t.componentInstanceId=1,t}(Gd);Yd.setPropUpdater((function(e,t,r,n){var i=e[0],o=this.__propData[i];if(r=function(e,t,r){if(r)for(var n=0;n<r.length;n++)if(vd.matchTypeWithValue(r[n],e))return e;switch(t){case String:return null===e?"":String(e);case Number:return isFinite(e)?Number(e):e;case Boolean:return!!e;case Array:return e instanceof Array?e:[];case Object:return"object"===ll(e)?e:null;default:return void 0===e?null:e}}(r,t.type,t.optionalTypes),t.availability){var a=this,s=t.availability,l=[a.ownerShadowRoot?a.ownerShadowRoot.__wxHost.__componentOptions.domain:void 0,n?void 0:r];if(!Cl.safeCallback("Availablity Controller",s,a.__methodCaller,l,a))return o}if(t.filter){var u=Cl.safeCallback("Property Filter",t.filter,this.__methodCaller,n?[]:[r,o,e],this);void 0!==u&&(r=u)}if(this.__domElement&&this.__componentOptions.reflectToAttributes&&this.__propPublic[i]){a=this;var c=i.replace(/(\w)([A-Z])/g,(function(e,t,r){return t+"-"+r.toLowerCase()})),d=ll(r);"boolean"===d?r?a.__domElement.setAttribute(c,""):a.__domElement.removeAttribute(c):"object"===d?a.__domElement.setAttribute(c,JSON.stringify(r)):a.__domElement.setAttribute(c,r)}return r})),Yd.setPropObserver((function(e,t,r,n,i,o){if(n.observeAssignments||e!==t){var a=r[0];this.__propertyChangeListeners&&this.__propertyChangeListeners[a]&&!o&&Cl.safeCallback("Property Observer",this.__propertyChangeListeners[a],this.__methodCaller,[e],this),fl(n.observer)&&Cl.safeCallback("Property Observer",n.observer,this.__methodCaller,i?[]:[e,t,r],this),n.public&&(this.__propObservers&&!this.__propObservers.empty||this.__subtreeObserversCount)&&yd._callObservers(this,"__propObservers",{type:"properties",target:this,propertyName:a})}})),vl(nf);var of=function(){function e(){}return e.create=function(t){return void 0===t&&(t=""),e._advancedCreate(t,null)},e._advancedCreate=function(t,r){void 0===t&&(t="");var n=new e;n.__slot="";var i=null;return!1===Ud.backendExtractedDefault&&("dom"===sl.documentBackend?(i=document.createTextNode(t)).__ddElement=n:n.__textContent=t),n.$$=i,n.__domElement=i,n.__backendExtracted=Ud.backendExtractedDefault,n.__subtreeObserversCount=0,n.parentNode=null,n.ownerShadowRoot=r,n},Object.defineProperty(e.prototype,"textContent",{get:function(){return this.__domElement?this.__domElement.textContent:this.__textContent},set:function(e){this.__domElement?this.__domElement.textContent=e:this.__textContent=e,(this.__textObservers&&!this.__textObservers.empty||this.__subtreeObserversCount)&&yd._callObservers(this,"__textObservers",{type:"characterData",target:this})},enumerable:!1,configurable:!0}),e.prototype.destroy=function(e){this.__textContent=null,this.parentNode=null,this.ownerShadowRoot=null,this.$$=null,this.__slot=null,this.__ddHost=null,this.__ddSlotParent=null,e?(this.__textObservers.destroy(),this.__textObservers=null):Gd.delayDestroy(this)},e}();yl(of);var af=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return ys(t,e),t.initialize=function(e,t,r){e.is=t||"";var n=null;"dom"===sl.documentBackend&&(n=void 0),Gd.initialize(e,n,r),e.__virtual=!0},t.create=function(e){var r=new t;return t.initialize(r,e,null),r},t._advancedCreate=function(e,r){var n=new t;return t.initialize(n,e,r),n},t}(Gd);bl(af);var sf=function(e){function t(t){var r=e.call(this)||this;return af.initialize(r,"shadow",r),r.__hostAssociated=!1,r.__ddHost=t,r.__childrenPropsFilter=null,r.__slotCacheDirty=!1,r}return ys(t,e),t.create=function(e){var r=new t(e);if(e.ownerShadowRoot&&e.ownerShadowRoot.__childrenPropsFilter)if(r.__childrenPropsFilter)for(var n in e.ownerShadowRoot.__childrenPropsFilter)r.__childrenPropsFilter[n]||(r.__childrenPropsFilter[n]=e.ownerShadowRoot.__childrenPropsFilter[n]);else r.__childrenPropsFilter=e.ownerShadowRoot.__childrenPropsFilter;return r},t.prototype.createTextNode=function(e){return of._advancedCreate(e,this)},t.prototype.createNativeNode=function(e){return qd._advancedCreate(e,this)},t.prototype.cloneNativeNode=function(e){return qd._advancedClone(e,this)},t.prototype.createVirtualNode=function(e){return af._advancedCreate(e,this)},t.prototype.createComponent=function(e,t,r,n){var i=Object.prototype.hasOwnProperty,o=t||e,a=this.__ddHost;if("object"!==ll(o)&&(i.call(a.__using,o)?o=a.__using[o]:i.call(a.__generics,o)&&(o=a.__generics[o]),"object"!==ll(o)&&(o=nf._list[o]||nf._list[""])),r&&(r=function(e,t){var r={};for(var n in e){var o=e[n];"object"!==ll(o)&&(i.call(t.__using,o)?o=t.__using[o]:i.call(t.__generics,o)&&(o=t.__generics[o]||nf._list[""]),r[n]=o)}return r}(r,a)),"object"===ll(e)&&(e=o.is),a.__componentOptions.randomizeTagName){e=function(){for(var e=Date.now(),t="exparser-",r=0;r<8;r++){var n=(e+Math.floor(26*Math.random()))%26;e=Math.floor(e/26),t+="abcdefghijklmnopqrstuvwxyz"[n]}return t}()}return a.__componentOptions.writeOnly&&!o.options.allowInWriteOnly&&(o=nf._list[""]),nf._advancedCreate(e,o,this,r,n)},t.prototype.tagNameUsed=function(e){var t=this.__ddHost,r=Object.prototype.hasOwnProperty;return!!r.call(t.__using,e)||!!r.call(t.__generics,e)},t.prototype.getHostNode=function(){return this.__ddHost},t.prototype.getElementById=function(e){return Gd._updateIdMap(this.__ddHost),this.__ddHost.__idCache[e]},t}(af),lf=function(){function e(){}return e.getInstance=function(){return e.instance||(e.instance=new e)},e.iterator=function(t){var r=e.getInstance();return r._iterator=r._getElementChildren(t),r._iterator},e.create=function(t,r,n){var i=new e;if(!wl(t)&&!Al(t))throw new Error("ElementIterator can only be used for exparser.Element or exparser.TextNode");i._elem=t,i._elemTypeLimit=n||Gd;var o=r.split("-");if("shadow"===o[0])i._composed=!1;else{if("composed"!==o[0])throw new Error("Unrecognized iterator type: "+r);i._composed=!0}if("ancestors"===o[1])i._relation="ancestors",i._order=0;else{if("descendants"!==o[1])throw new Error("Unrecognized iterator type: "+r);if(i._relation="descendants","root"!==o[2])throw new Error("Unrecognized iterator type: "+r);if("first"===o[3])i._order=-1;else{if("last"!==o[3])throw new Error("Unrecognized iterator type: "+r);i._order=1}}return i},e.prototype.forEach=function(e){if("ancestors"===this._relation){for(var t=this._elem;t;){if(t instanceof this._elemTypeLimit&&!1===e(t))return!1;t=this._composed&&(t.__ddSlotParent||t.__ddHost)||t.parentNode}return!0}return uf(this._elem,this._elemTypeLimit,this._composed,this._order,e)},e.prototype._getElementChildren=function(e){var t=this;return e.childNodes&&e.childNodes.length&&e.childNodes.forEach((function(e){t._getElementChildren(e)})),e},e}();function uf(e,t,r,n,i){if(n<0&&e instanceof t&&!1===i(e))return!1;var o=r&&e.__ddSlotChildren||e.childNodes;if(o)for(var a=0;a<o.length;a++){if(!1===uf(o[a],t,r,n,i))return!1}return!(0<n&&e instanceof t&&!1===i(e))}var cf=q("isConcatSpreadable"),df=z>=51||!e((function(){var e=[];return e[cf]=!1,e.concat()[0]!==e})),ff=fs("concat"),_f=function(e){if(!X(e))return!1;var t=e[cf];return void 0!==t?!!t:co(e)};function pf(){}or({target:"Array",proto:!0,arity:1,forced:!df||!ff},{concat:function(e){var t,r,n,i,o,a=N(this),s=po(a,0),l=0;for(t=-1,n=arguments.length;t<n;t++)if(_f(o=-1===t?a:arguments[t]))for(i=Ue(o),nl(l+i),r=0;r<i;r++,l++)r in o&&en(s,l,o[r]);else nl(l+1),en(s,l++,o);return s.length=l,s}});var hf={title:"browser",browser:!0,env:{},argv:[],version:"",versions:{},on:pf,addListener:pf,once:pf,off:pf,removeListener:pf,removeAllListeners:pf,emit:pf,prependListener:pf,prependOnceListener:pf,listeners:function(){return[]},binding:function(){throw new Error("process.binding is not supported")},cwd:function(){return"/"},chdir:function(){throw new Error("process.chdir is not supported")},umask:function(){return 0}};function vf(e,t,r,n,i){var o;e.linked?gf.updateBinding(e,t,r,n,i):(o=n[e.name],n[e.name]=e.exp(r,n,i),gf.updateBinding(e,t,r,n,i),n[e.name]=o)}var gf={create:function(e,t,r,n,i,o,a){for(var s={inc:1,name:e,exp:n,lp:i,scopes:{},targets:{},children:null,lu:a,__scopeBinded:[]},l=0;l<o.length;l++){var u=o[l];null===u[0]?gf.addBinding(t,u,null,s):gf.addBinding(r[u[0]],u,null,s)}return s},proxyTopScope:function(e){var t={inc:1,linked:e,scopes:{},targets:{},children:null,__scopeBinded:[]};return gf.addBinding(e,[null],null,t),t},proxySubScopes:function(e){var t={};for(var r in e)t[r]={inc:1,linked:e[r],scopes:{},targets:{},children:null,__scopeBinded:[]},gf.addBinding(e[r],[null],null,t[r]);return t},addBinding:function(e,t,r,n){for(var i=e,o=1,a=void 0;o<t.length;o++){a=t[o],i.children||(i.children=Object.create(null));var s=i.children;s[a]||(s[a]={scopes:{},targets:{},children:null}),i=s[a]}var l=e.inc++;return r?i.targets[l]=[r,n]:(i.scopes[l]=n,i.scopes[l].__scopeBinded.push([i,l])),l},addBindings:function(e,t,r,n,i){for(var o=0;o<r.length;o++){var a=r[o];a[0]?gf.addBinding(t[a[0]],a,n,i):gf.addBinding(e,a,n,i)}},updateBinding:function(e,t,r,n,i){for(var o,a=e,s=0;s<t.length;s++){for(o in a.scopes)vf(a.scopes[o],t,r,n,i);var l=t[s],u=a.children;if(!u||!u[l])return;a=u[l]}!function e(t){for(o in t.targets){var a=t.targets[o],s=a[1];s.o(a[0],s.n,s.e(r,n,i))}for(o in t.scopes)vf(t.scopes[o],[],r,n,i);for(o in t.children)e(t.children[o])}(a)},updateLvaluePath:function(e,t){e.lp=t},removeBindingsForScope:function(e){for(var t=e.__scopeBinded,r=0,n=void 0;r<t.length;r++)delete(n=t[r])[0].scopes[n[1]]}},yf=Ie.f,mf=function(e,t,r){r in e||yf(e,r,{configurable:!0,get:function(){return t[r]},set:function(e){t[r]=e}})},bf=Yt.f,Ef=Rt.enforce,wf=q("match"),Of=E.RegExp,Af=Of.prototype,Cf=E.SyntaxError,Sf=a(Af.exec),Tf=a("".charAt),Nf=a("".replace),xf=a("".indexOf),If=a("".slice),Rf=/^\?<[^\s\d!#%&*+<=>@^][^\s!#%&*+<=>@^]*>/,Lf=/a/g,Mf=/a/g,kf=new Of(Lf)!==Lf,Pf=Du.MISSED_STICKY,jf=Du.UNSUPPORTED_Y,Df=re&&(!kf||Pf||Fu||Gu||e((function(){return Mf[wf]=!1,Of(Lf)!=Lf||Of(Mf)==Mf||"/a/i"!=Of(Lf,"i")})));if(nr("RegExp",Df)){for(var Bf=function(e,t){var r,n,i,o,a,s,l=ce(Af,this),u=Ac(e),c=void 0===t,d=[],f=e;if(!l&&u&&c&&e.constructor===Bf)return e;if((u||ce(Af,e))&&(e=e.source,c&&(t=Ks(f))),e=void 0===e?"":Ws(e),t=void 0===t?"":Ws(t),f=e,Fu&&"dotAll"in Lf&&(n=!!t&&xf(t,"s")>-1)&&(t=Nf(t,/s/g,"")),r=t,Pf&&"sticky"in Lf&&(i=!!t&&xf(t,"y")>-1)&&jf&&(t=Nf(t,/y/g,"")),Gu&&(o=function(e){for(var t,r=e.length,n=0,i="",o=[],a={},s=!1,l=!1,u=0,c="";n<=r;n++){if("\\"===(t=Tf(e,n)))t+=Tf(e,++n);else if("]"===t)s=!1;else if(!s)switch(!0){case"["===t:s=!0;break;case"("===t:Sf(Rf,If(e,n+1))&&(n+=2,l=!0),i+=t,u++;continue;case">"===t&&l:if(""===c||I(a,c))throw new Cf("Invalid capture group name");a[c]=!0,o[o.length]=[c,u],l=!1,c="";continue}l?c+=t:i+=t}return[i,o]}(e),e=o[0],d=o[1]),a=bo(Of(e,t),l?this:Af,Bf),(n||i||d.length)&&(s=Ef(a),n&&(s.dotAll=!0,s.raw=Bf(function(e){for(var t,r=e.length,n=0,i="",o=!1;n<=r;n++)"\\"!==(t=Tf(e,n))?o||"."!==t?("["===t?o=!0:"]"===t&&(o=!1),i+=t):i+="[\\s\\S]":i+=t+Tf(e,++n);return i}(e),r)),i&&(s.sticky=!0),d.length&&(s.groups=d)),e!==f)try{mt(a,"source",""===f?"(?:)":f)}catch(e){}return a},Ff=bf(Of),Uf=0;Ff.length>Uf;)mf(Bf,Of,Ff[Uf++]);Af.constructor=Bf,Bf.prototype=Af,Vt(E,"RegExp",Bf,{constructor:!0})}mo("RegExp");var Gf,Hf={TAG_START:1,TAG_END:-1,TEXT:3,COMMENT:8},Vf="m",zf="f",$f="e",Yf="c",Wf="t",Zf="s",Jf={n:"\n",r:"\r",b:"\b",f:"\f",t:"\t",v:"\v",'"':'"',"'":"'","\\":"\\","\r":"\r","\n":"\n"},Kf={},qf="";for(Gf in Jf)Kf[Jf[Gf]]=Gf,qf+=Jf[Gf];var Xf=new RegExp("["+qf+"]","g"),Qf=1,e_=-1,t_=8,r_=["area","base","br","col","embed","hr","img","link","meta","input","keygen","source","param","track","wbr"];function n_(e,t){return e.substring(t)}function i_(e){var t=new RegExp("^<((?:[a-zA-Z_][\\w\\-\\.]*\\:)?[a-zA-Z_][\\w\\-\\.]*)"),r=/^\s*(\/?)>/,n=/^\s*([^\s"'<>\/=]+)(?:\s*(=)\s*(?:"([^"]*)"+|'([^']*)'+|([^\s"'=<>`]+)))?/,i=e.match(t);if(i){e=n_(e,i[0].length);for(var o={t:Qf,n:i[1],a:[],selfClose:!(r_.indexOf(i[1])<0)||void 0},a=void 0,s=void 0;!(a=e.match(r))&&(s=e.match(n));){e=n_(e,s[0].length);var l=s[3]||s[4]||s[5]||"";o.a.push({n:String(s[1]),v:String(l)})}if(a)return{match:o,html:e=n_(e,a[0].length)}}}function o_(e){var t=new RegExp("^<\\/((?:[a-zA-Z_][\\w\\-\\.]*\\:)?[a-zA-Z_][\\w\\-\\.]*)[^>]*>"),r=e.match(t);return e=n_(e,r[0].length),{match:{t:e_,n:r[1]},html:e}}function a_(e){var t=e.indexOf("--\x3e");if(t<0)throw new Error("💔fail to compile html template: comment no end");var r={t:t_,c:e.substring(4,t)};return{html:e=n_(e,t+3),match:r}}function s_(e){var t,r={t:3,c:null},n="[a-zA-Z_][\\w\\-\\.]*",i="((?:"+n+"\\:)?"+n+")",o=new RegExp("^<"+i),a=new RegExp("^<\\/"+i+"[^>]*>"),s=e.indexOf("<");if(s>=0){for(t=e.slice(s);!o.test(t)&&!a.test(t);){var l=t.indexOf("<",1);if(l<0){s+=t.length;break}s+=l,t=e.slice(s)}r.c=e.substring(0,s),e=n_(e,s)}return s<0&&(r.c=e,e=""),{match:r,html:e}}var l_={parse:function(e){var t="[a-zA-Z_][\\w\\-\\.]*",r="((?:"+t+"\\:)?"+t+")",n=new RegExp("^<"+r),i=new RegExp("^<\\/"+r+"[^>]*>"),o=new RegExp("^\x3c!--"),a=[];e=function(e){return e.replace(/\n|\r|\t|\f/g," ")}(e);try{for(;e;){var s=void 0;s=e.match(n)?i_(e):e.match(i)?o_(e):e.match(o)?a_(e):s_(e),e=s.html,a.push(s.match)}return a}catch(e){}}},u_=/^[ \n\r\t\f]+|[ \n\r\t\f]+$/g,c_=sl.hasDOMBackend?document.createElement("div"):null,d_={amp:"&",gt:">",lt:"<",nbsp:" ",quot:'"',apos:"'"},f_=function(){function e(){}return e.decodeEntities=function(e){return e.replace(/&(([a-zA-Z]+)|(#x{0,1}[\da-zA-Z]+));/gi,(function(e,t){if(d_[t])return d_[t];if(/^#[0-9]{1,4}$/.test(t))return String.fromCharCode(t.slice(1));if(/^#x[0-9a-f]{1,4}$/i.test(t))return String.fromCharCode("0"+t.slice(1));if(sl.hasDOMBackend){var r=e;return c_?(c_.innerHTML=r,c_.innerText||c_.textContent):r}return e}))},e.parse=function(t,r){for(var n=l_.parse(t)||[],i={c:[]},o=i,a=[],s=0;s<n.length;s++){var l=n[s];if(l.t===Hf.TAG_START){var u={t:Hf.TAG_START,n:l.n,a:l.a,c:[]};o.c.push(u),l.selfClose||(a.push(o),o=u)}else if(l.t===Hf.TAG_END){var c=a.length-1,d=!0;for(u=o;l.n!==u.n;)if(!(u=a[c--])){d=!1;break}if(d)for(;a.length>c;)o=a.pop()}else l.t===Hf.TEXT&&(l.c=e.decodeEntities(r?l.c:l.c.replace(u_,"")),l.c&&o.c.push(l))}return i.c},e.TAG_TYPES=Hf,e}(),__=" \n\r\t\f",p_=["true","false","null","undefined"],h_={$1:{VARIABLE:[{id:"_concat",states:["a-zA-Z_$","VARIABLE_AFTER"]}],VARIABLE_AFTER:[{id:"_concat",states:["a-zA-Z_$0-9","VARIABLE_AFTER"]},{id:"_null",states:["NULL"]}],STRING:[{id:"str^",states:["'","STRING_INNER_1"]},{id:"str^",states:['"',"STRING_INNER_2"]}],STRING_INNER_1:[{id:"str$",states:["'"]},{id:"str\\",states:["\\","nrbftv'\"\\\r\n","STRING_INNER_1"]},{id:"_concat",states:["ALL","STRING_INNER_1"]}],STRING_INNER_2:[{id:"str$",states:['"']},{id:"str\\",states:["\\","nrbftv'\"\\\r\n","STRING_INNER_2"]},{id:"_concat",states:["ALL","STRING_INNER_2"]}],NUMBER:[{id:"_concat",states:["NUMBER_BEFORE_E","NUMBER_E"]}],NUMBER_E:[{id:"_concat",states:["e","NUMBER_AFTER_E"]},{id:"_null",states:["NULL"]}],NUMBER_AFTER_E:[{id:"_concat",states:["-","NUMBER_AFTER_E-INT"]},{id:"_jump",states:["NUMBER_AFTER_E-INT"]}],"NUMBER_AFTER_E-INT":[{id:"_concat",states:["NUMBER_AFTER_E-INT","0-9"]},{id:"_jump",states:["0-9"]}],NUMBER_BEFORE_E:[{id:"_concat",states:[".","NUMBER_AFTER_DOT"]},{id:"_concat",states:["0","NUMBER_AFTER_ZERO"]},{id:"_concat",states:["1-9","NUMBER_AFTER_NON_ZERO"]}],NUMBER_AFTER_ZERO:[{id:"_concat",states:["x","NUMBER_BASE_16"]},{id:"_jump",states:["NUMBER_AFTER_NON_ZERO"]},{id:"_null",states:["NULL"],overwrite:!0}],NUMBER_BASE_16:[{id:"_concat",states:["0-9a-fA-F","NUMBER_BASE_16-AFTER"]}],"NUMBER_BASE_16-AFTER":[{id:"_concat",states:["0-9a-fA-F","NUMBER_BASE_16-AFTER"]},{id:"_null",states:["NULL"],overwrite:!0}],NUMBER_AFTER_NON_ZERO:[{id:"_concat",states:[".","NUMBER_AFTER_DOT"]},{id:"_concat",states:["0-9","NUMBER_AFTER_NON_ZERO"]},{id:"_null",states:["NULL"],overwrite:!0}],NUMBER_AFTER_DOT:[{id:"_concat",states:["NUMBER_AFTER_DOT","0-9"]},{id:"_jump",states:["0-9"]}],VALUE:[{id:"_blank",states:[__,"VALUE"],overwrite:!0},{id:"_jump",states:["VALUE_NOSPACE"]}],VALUE_NOSPACE:[{id:"_jump",states:["VALUE_NOSPACE",__]},{id:"var",states:["VARIABLE"]},{id:"str",states:["STRING"]},{id:"num",states:["NUMBER"]},{id:"()",states:["(","COMMA",")"]},{id:"al",states:["[","ARRAY_ITEMS","]"]},{id:"ol",states:["{","OBJECT_ITEMS","}"]}],ARRAY_ITEMS:[{id:"_blank",states:[__,"ARRAY_ITEMS"],overwrite:!0},{id:"_jump",states:["ARRAY_ITEMS_NOSPACE"]}],ARRAY_ITEMS_NOSPACE:[{id:"_join",states:["ARRAY_ITEMS_NOSPACE",",","ARRAY_ITEM"]},{id:"_jump",states:["ARRAY_ITEM"]},{id:"_empty",states:["NULL"],overwrite:!0}],ARRAY_ITEM:[{id:"_blank",states:[__,"ARRAY_ITEM"],overwrite:!0},{id:"_jump",states:["ARRAY_ITEM_NOSPACE"]}],ARRAY_ITEM_NOSPACE:[{id:"ai",states:["CONDITIONAL"]},{id:"aie",states:["NULL"],overwrite:!0}],OBJECT_ITEMS:[{id:"_join",states:["OBJECT_ITEMS",",","OBJECT_ITEM_AFTER_COMMA"]},{id:"_jump",states:["OBJECT_ITEM"]},{id:"_empty",states:["NULL"],overwrite:!0}],OBJECT_ITEM_AFTER_COMMA:[{id:"_blank",states:[__,"OBJECT_ITEM_AFTER_COMMA"],overwrite:!0},{id:"_jump",states:["OBJECT_ITEM"]},{id:"_empty",states:["NULL"],overwrite:!0}],OBJECT_ITEM:[{id:"_blank",states:[__,"OBJECT_ITEM"],overwrite:!0},{id:"_jump",states:["OBJECT_ITEM_NOSPACE"]}],OBJECT_ITEM_NOSPACE:[{id:"_jump",states:["OBJECT_ITEM_NOSPACE",__]},{id:"onv",states:["VARIABLE","OBJECT_ITEM_AFTER"]},{id:"ons",states:["STRING","OBJECT_ITEM_AFTER"]},{id:"onn",states:["NUMBER","OBJECT_ITEM_AFTER"]}],OBJECT_ITEM_AFTER:[{id:"_blank",states:[__,"OBJECT_ITEM_AFTER"],overwrite:!0},{id:"ov",states:[":","CONDITIONAL"]},{id:"_null",states:["NULL"]}],MEMBER:[{id:"_jump",states:["MEMBER",__]},{id:"_op2",states:["MEMBER",".","VARIABLE_WITH_BLACK"]},{id:"[]",states:["MEMBER","[","CONDITIONAL","]"]},{id:"f()",states:["MEMBER","(","FUNCARGS",")"]},{id:"_jump",states:["VALUE"]}],VARIABLE_WITH_BLACK:[{id:"_blank",states:[__,"VARIABLE_WITH_BLACK"],overwrite:!0},{id:"_jump",states:["VARIABLE"]}],FUNCARGS:[{id:"_blank",states:[__,"FUNCARGS"],overwrite:!0},{id:"_join",states:["FUNCARGS",",","CONDITIONAL"]},{id:"fa",states:["CONDITIONAL"]},{id:"_empty",states:["NULL"],overwrite:!0}],LOGICAL:[{id:"_blank",states:[__,"LOGICAL"],overwrite:!0},{id:"_jump",states:["LOGICAL_NOSPACE"]}],LOGICAL_NOSPACE:[{id:"!",states:["!","LOGICAL"]},{id:"!",states:["+","LOGICAL"]},{id:"!",states:["-","LOGICAL"]},{id:"_jump",states:["MEMBER"]}],MULTIPLY:[{id:"_op2",states:["MULTIPLY","*","LOGICAL"]},{id:"_op2",states:["MULTIPLY","/","LOGICAL"]},{id:"_op2",states:["MULTIPLY","%","LOGICAL"]},{id:"_jump",states:["LOGICAL"]}],ADDITION:[{id:"_op2",states:["ADDITION","+","MULTIPLY"]},{id:"_op2",states:["ADDITION","-","MULTIPLY"]},{id:"_jump",states:["MULTIPLY"]}],COMPARISON:[{id:"<>",states:["COMPARISON","<","COMPARISON_AFTER"]},{id:"<>",states:["COMPARISON",">","COMPARISON_AFTER"]},{id:"_jump",states:["ADDITION"]}],COMPARISON_AFTER:[{id:"a=",states:["=","ADDITION"]},{id:"_jump",states:["ADDITION"]}],EQUALITY:[{id:"=!",states:["EQUALITY","=","=","EQUALITY_AFTER"]},{id:"=!",states:["EQUALITY","!","=","EQUALITY_AFTER"]},{id:"_jump",states:["COMPARISON"]}],EQUALITY_AFTER:[{id:"a=",states:["=","COMPARISON"]},{id:"_jump",states:["COMPARISON"]}],LOGICAL_AND:[{id:"&&||",states:["LOGICAL_AND","&","&","EQUALITY"]},{id:"_jump",states:["EQUALITY"]}],LOGICAL_OR:[{id:"&&||",states:["LOGICAL_OR","|","|","LOGICAL_AND"]},{id:"_jump",states:["LOGICAL_AND"]}],CONDITIONAL:[{id:"?",states:["LOGICAL_OR","CONDITIONAL_AFTER"]}],CONDITIONAL_AFTER:[{id:"?:",states:["?","LOGICAL_OR",":","CONDITIONAL"]},{id:"_null",states:["NULL"]}],COMMA:[{id:",",states:["COMMA",",","CONDITIONAL"]},{id:"_jump",states:["CONDITIONAL"]}]},$2:{_null:function(e){},_empty:function(e){return[]},_jump:function(e){return e[0]},_concat:function(e){return(e[0]||"")+(e[1]||"")},_blank:function(e){return e[1]},"str^":function(e){return e[1]},str$:function(e){return""},"str\\":function(e){if(!Jf[e[1]])throw new Error('String escaping "\\'+e[1]+'" is currently not supported.');return Jf[e[1]]+e[2]},var:function(e){return{p:"var",v:e[0]}},str:function(e){return{p:"str",v:e[0]}},num:function(e){return{p:"num",v:Number(e[0])}},"()":function(e){return{p:"()",v:e[1]}},al:function(e){return e[1].forEach((function(t,r){null===t&&(r!==e[1].length-1?e[1][r]={p:"var",v:"undefined"}:e[1].pop())})),{p:"arr",v:e[1]}},ai:function(e){return[e[0]]},aie:function(e){return[null]},_join:function(e){return e[0].concat(e[2])},ol:function(e){for(var t={},r=e[1],n=0;n<r.length;n++)t[r[n].n]=r[n].v;return{p:"obj",v:t}},onv:function(e){return[{n:e[0],v:e[1]||{p:"var",v:e[0]}}]},ons:function(e){return[{n:e[0],v:e[1]||{p:"str",v:e[0]}}]},onn:function(e){return[{n:e[0],v:e[1]||{p:"num",v:Number(e[0])}}]},ov:function(e){return e[1]},"!":function(e){return{p:e[0]+"n",v:e[1]}},_op1:function(e){return{p:e[0],v:e[1]}},_op2:function(e){return{p:e[1],v:[e[0],e[2]]}},"f()":function(e){return{p:"f()",v:[e[0],e[2]]}},fa:function(e){return[e[0]]},"[]":function(e){return{p:"[]",v:[e[0],e[2]]}},"<>":function(e){return"a="===e[2].p?{p:e[1]+"=",v:[e[0],e[2].v]}:{p:e[1],v:[e[0],e[2]]}},"a=":function(e){return{p:"a=",v:e[1]}},"=!":function(e){return"a="===e[3].p?{p:e[1]+"==",v:[e[0],e[3].v]}:{p:e[1]+"=",v:[e[0],e[3]]}},"&&||":function(e){return{p:e[1]+e[2],v:[e[0],e[3]]}},"?":function(e){return e[1]?{p:"?:",v:[e[0],e[1][0],e[1][1]]}:e[0]},"?:":function(e){return[e[1],e[3]]},",":function(e){return{p:",",v:[e[0],e[2]]}}}},v_=function(){function e(){}return e.parse=function(t){return e.r||(e.r=zs.create(h_.$1,h_.$2)),e.r.parse("COMMA",t)},e.stringify=function(e,t){return"("+function e(r){var n=[];switch(r.p){case"var":return 0<=p_.indexOf(r.v)?r.v:0<=t.indexOf(r.v)?Zf+"."+r.v:Wf+"."+r.v;case"str":return'"'+r.v.replace(Xf,(function(e){return"\\"+Kf[e]}))+'"';case"num":return r.v;case"arr":return r.v.forEach((function(t){n.push(e(t))})),"["+n.join(",")+"]";case"obj":for(var i in r.v){var o='"'+i.replace(Xf,(function(e){return"\\"+Kf[e]}))+'"';n.push(o+":"+e(r.v[i]))}return"{"+n.join(",")+"}";case"()":return"("+e(r.v)+")";case".":return Vf+"("+e(r.v[0])+',"'+r.v[1]+'")';case"[]":return Vf+"("+e(r.v[0])+","+e(r.v[1])+")";case"f()":if("var"!==r.v[0].p)throw new Error("The function name could only be a variable identifier.");return r.v[1].forEach((function(t){n.push(e(t))})),zf+"("+Yf+","+$f+',"'+r.v[0].v+'",['+n.join(",")+"])";case"!n":case"+n":case"-n":return"("+r.p[0]+e(r.v)+")";case"+":case"-":case"*":case"/":case"%":case">":case"<":case">=":case"<=":case"==":case"!=":case"===":case"!==":case"&&":case"||":case",":return e(r.v[0])+r.p+e(r.v[1]);case"?:":return e(r.v[0])+"?"+e(r.v[1])+":"+e(r.v[2]);default:throw new Error("The AST is illegal.")}}(e)+")"},e.lvalueStringify=function(t,r){for(var n=[],i=t;i;){if("var"===i.p)return 0<=p_.indexOf(i.v)?null:0<=r.indexOf(i.v)?'["'+i.v+'",'+n.join(",")+"]":"[null,"+n.join(",")+"]";if("."!==i.p)if("[]"!==i.p){if("()"!==i.p)return null;i=i.v}else n.unshift(e.stringify(i.v[1],r)),i=i.v[0];else n.unshift('"'+i.v[1]+'"'),i=i.v[0]}return null},e.searchBindingPaths=function(t,r){var n=[],i="",o=function t(o,a,s){if(s>1)throw new Error("Dynamical binding paths are not supported.");switch(o.p){case"var":if(a){if(p_.indexOf(o.v)>=0)return;return r.indexOf(o.v)>=0?['"'+o.v+'"']:['null,"'+o.v+'"']}if(s>=1)throw new Error("Dynamical binding paths are not supported.");if(0<=p_.indexOf(o.v))return;return void(r.indexOf(o.v)>=0?n.push('["'+o.v+'"]'):n.push('[null,"'+o.v+'"]'));case"str":case"num":case"arr":case"obj":return;case"()":return t(o.v,a,s);case".":if(a){if(!(i=t(o.v[0],!0,s)))return;return i.push('"'+o.v[1]+'"'),i}if(!(i=t(o.v[0],!0,s+1)))return;return i.push('"'+o.v[1]+'"'),void n.push("["+i.join(",")+"]");case"[]":if(a){if(!(i=t(o.v[0],!0,s)))return;return t(o.v[1],!0,s),i.push(e.lvalueStringify(o.v[1])),i}if(!(i=t(o.v[0],!0,s+1)))return;return t(o.v[1],!0,s+1),i.push(e.lvalueStringify(o.v[1])),void n.push("["+i.join(",")+"]");case"f()":return t(o.v[0],!1,s),void o.v[1].forEach((function(e){t(e,!1,s)}));case"!n":case"+n":case"-n":return void t(o.v,!1,s);case"+":case"-":case"*":case"/":case"%":case">":case"<":case">=":case"<=":case"==":case"!=":case"===":case"!==":case"&&":case"||":case",":return t(o.v[0],!1,s),void t(o.v[1],!1,s);case"?:":return t(o.v[0],!1,s),t(o.v[1],!1,s),void t(o.v[2],!1,s);default:throw new Error("The AST is illegal.")}};return t.forEach((function(e){o(e,!1,0)})),"["+n.join(",")+"]"},e}(),g_=Wf+","+Zf+","+Yf,y_={requireBlock:!0,precompile:function(e,t,r){if("else"===e)return{s:[],d:"true"};var n=t.match(/^\{\{(.+)\}\}$/);if(!n)throw new Error("Illegal expression is found in dd:"+e+".");var i=v_.parse(n[1]),o=v_.searchBindingPaths([i],r);return{s:[],d:"function("+g_+"){return "+v_.stringify(i,r)+"}",b:o}},register:function(e,t,r){},create:function(e,t,r,n,i,o,a,s,l,u,c){var d=l.createVirtualNode("dd:"+e);d.__ddIfCondValue=!0,d.__ddIfNextNode=null,d.__ddIfHasTrueCond=!0;var f=null;"if"!==e&&(f=c.childNodes[c.childNodes.length-1])&&("dd:if"!==f.is&&"dd:elif"!==f.is?f=null:f.__ddIfNextNode=d),r.id&&(d.id=r.id);var _=d.__ddIfUpdateNode=function(){var e=d.__ddIfCondValue;if(f&&f.__ddIfHasTrueCond&&(e=!0),e&&!d.childNodes.length){var t=gf.proxyTopScope(o),c=gf.proxySubScopes(a);d.__ddTopScope=t,d.__ddSubScopes=c,u(r.c,l,d,n,i,t,c,s)}else if(!e&&d.childNodes.length){for(var _ in gf.removeBindingsForScope(d.__ddTopScope),d.__ddSubScopes)gf.removeBindingsForScope(d.__ddSubScopes[_]);for(;d.childNodes.length;)d.removeChild(d.childNodes[0])}d.__ddIfNextNode&&d.__ddIfNextNode.__ddIfUpdateNode()};function p(e){d.__ddIfCondValue=!!e,d.__ddIfHasTrueCond=d.__ddIfCondValue||f&&f.__ddIfHasTrueCond,_()}return"else"===e?p(!0):(gf.addBindings(o,a,t.b,d,{e:t.d,o:function(e,t,r){p(r)}}),p(t.d(n,i,null))),d}},m_=Wf+","+Zf+","+Yf,b_={requireBlock:!0,addDefaultAttrs:[{n:"wx:for-index",v:"index"},{n:"wx:for-item",v:"item"}],precompile:function(e,t,r){var n=t.match(/^\{\{(.+)\}\}$/);if(!n)throw new Error("Illegal expression is found in wx:for.");var i=v_.parse(n[1]),o=v_.lvalueStringify(i,r),a=v_.searchBindingPaths([i],r);return{s:[],d:"function("+m_+"){return "+v_.stringify(i,r)+"}",l:o,b:a}},register:function(e,t,r){},create:function(e,t,r,n,i,o,a,s,l,u){var c=r._ddForIndex||"index",d=r._ddForItem||"item",f=r._ddKey,_=l.createVirtualNode("wx:for:list");function p(e,t,n,i,f){var p=l.createVirtualNode("wx:for:item"),h=gf.proxyTopScope(o),v=gf.proxySubScopes(a);p.__ddTopScope=h,p.__ddSubScopes=v,p.__ddForToRemove=!1,p.__ddForKeyStr="";var g=gf.create(c,h,v,null,null,[]),y=gf.create(d,h,v,null,[n],[]);return v[c]=g,v[d]=y,t[c]=n,t[d]=i,u(r.c,l,p,e,t,h,v,s),void 0===f?_.appendChild(p):_.insertBefore(p,f),p}function h(e){for(var t in _.__ddSubScopes,gf.removeBindingsForScope(e.__ddTopScope),_.__ddSubScopes)gf.removeBindingsForScope(e.__ddSubScopes[t]);_.removeChild(e)}r.id&&(_.id=r.id),gf.create("",o,a,(function(e,r,n){var i=t.d(e,r,null);return v(i,e,r,n),i}),t.l,t.b);var v=function(e,t,r,i){var o="",a=e;"object"==ll(e)&&null!==e||(a=[]);var s={};for(o in r)s[o]=r[o];var l,u,v,g,y,m,b=0;if(f){var E=[],w=e instanceof Array,O=[];if(!w){var A=a;for(o in a=[],A)a.push(A[o]),O.push(o)}for(b=0;b<a.length;b++)E.push(String(a[b][f]));if(0===a.length)for(;_.childNodes.length;)h(_.childNodes[0]);else{var C=Object.create(null),S=Object.create(null),T=_.childNodes,N=null,x="";for(b=0;b<T.length;b++)0<=C[x=(N=T[b]).__ddForKeyStr]?(h(N),b--):(C[x]=b,(S[x]=N).__ddForToRemove=!0);var I=-1,R=0,L=1,M=[];for(0<=(R=C[a[0][f]])||(R=-1),T[R]&&(T[R].__ddForToRemove=!1),b=1;b<a.length;b++)0<=(L=C[a[b][f]])&&(I<R&&(R<L||L<I)&&(M.push(T[R]),I=R),T[R=L]&&(T[R].__ddForToRemove=!1));for(I<R&&M.push(T[R]),b=0;b<T.length;b++)(N=T[b]).__ddForToRemove&&(h(N),b--);var k=M.shift(),P=0;for(b=0;b<a.length;b++){var j=a[b],D=S[j[f]];if(S[j[f]]=null,D){var B=!0;if(D===k){for(;T[P]!==k;)P++;P++,k=M.shift(),B=!1}(function(e,t,r,i,o,a){var s=e.__ddSubScopes[d];gf.updateLvaluePath(s,[i]),o&&(a?_.insertBefore(e,a):_.appendChild(e));var l=e.__ddSubScopes[c];r[c]=i,gf.updateBinding(l,[],n,r,t)})(N=D,i,s,w?b:O[b],B,T[P]),B&&T[P]===N&&P++,l=N,u=[],v=t,g=s,y=a[b],m=i,g[d]=y,gf.updateBinding(l.__ddSubScopes[d],u,v,g,m)}else N=p(t,s,w?b:O[b],a[b],T[P]),P++,N.__ddForKeyStr=String(j[f])}}}else{for(;_.childNodes.length;)h(_.childNodes[0]);if(e instanceof Array)for(b=0;b<a.length;b++)p(t,s,b,a[b]);else for(o in a)p(t,s,o,a[o])}};return v(t.d(n,i,null),n,i,null),_}},E_={attachedToBlock:"for",precompile:function(e,t,r){var n=t.match(/^\s*([$_a-zA-Z][$_a-zA-Z0-9]*)\s*$/);if(!n)throw new Error("Illegal variable name is found in wx:for-item.");return{s:[n[1]],d:'"'+n[1]+'"'}},register:function(e,t,r){r._ddForItem=t.d},create:function(){}},w_={attachedToBlock:"for",precompile:function(e,t,r){var n=t.match(/^\s*([$_a-zA-Z][$_a-zA-Z0-9]*)\s*$/);if(!n)throw new Error("Illegal variable name is found in wx:for-index.");return{s:[n[1]],d:'"'+n[1]+'"'}},register:function(e,t,r){r._wxForIndex=t.d},create:function(){}},O_={attachedToBlock:!0,precompile:function(e,t,r){var n=t.match(/^\s*([$_a-zA-Z][$_a-zA-Z0-9]*)\s*$/);if(!n)throw new Error("Illegal variable name is found in wx:for-key.");return{s:[],d:'"'+n[1]+'"'}},register:function(e,t,r){r._ddKey=t.d},create:function(){}},A_=Wf+","+Zf+","+Yf,C_={requireBlock:!0,precompile:function(e,t,r){var n=t.match(/^\{\{\s*([$_a-zA-Z][$_a-zA-Z0-9]*)\s*=(.+)\}\}$/);if(!n)throw new Error("Illegal expression is found in wx:alias.");var i=n[1],o=v_.parse(n[2]),a=v_.lvalueStringify(o,r),s=v_.searchBindingPaths([o],r);return{s:[i],d:"function("+A_+"){return "+v_.stringify(o,r)+"}",l:a,b:s}},register:function(e,t,r){},create:function(e,t,r,n,i,o,a,s,l,u){var c=t.s[0],d=gf.create(c,o,a,t.d,t.l,t.b),f={},_="";for(_ in a)f[_]=a[_];f[c]=d;var p={};for(_ in i)p[_]=i[_];p[c]=t.d(n,i,null);var h=l.createVirtualNode("wx:alias");return r.id&&(h.id=r.id),u(r.c,l,h,n,p,o,f,s),h}},S_={if:y_,elif:y_,else:y_,for:b_,key:O_,"for-index":w_,"for-item":E_,alias:C_},T_=Wf+","+Zf+","+Yf,N_=Vf+","+zf+","+$f,x_=function(){function e(){}return e.toUpperCase=function(e){return e.replace(/-([a-z])/g,(function(e,t){return t.toUpperCase()}))},e.addBackSlashToSign=function(e){return'"'+e.replace(Xf,(function(e){return"\\"+Kf[e]}))+'"'},e.formatToArrayStr=function(e){return"["+e.join(",")+"]"},e.formatToObjStr=function(e){var t=[];for(var r in e)void 0!==e[r]&&(/^[_a-z]+$/i.test(r)?t.push(r+":"+e[r]):t.push(this.addBackSlashToSign(r)+":"+e[r]));return"{"+t.join(",")+"}"},e.parseDynamicValue=function(e,t){for(var r=e.split(/\{\{(.*?)\}\}/),n=[],i=[],o=null,a=0;a<r.length;a++){var s=r[a];if(a%2){var l=v_.parse(s);o=v_.lvalueStringify(l,t),n.push(v_.stringify(l,t)),i.push(l)}else n.push(this.addBackSlashToSign(s))}if(1===n.length)return{c:n[0]};var u=v_.searchBindingPaths(i,t);return'""'===n[n.length-1]&&n.pop(),2===n.length&&'""'===n[0]?{c:void 0,e:"function("+T_+"){return "+n[1]+"}",l:o,b:u}:{c:void 0,e:"function("+T_+"){return "+n.join("+")+"}",l:void 0,b:u}},e.format=function(e,t){for(var r=[],n=0;n<e.length;n++){var i=e[n];if(3!==i.t){var o={t:1,n:'"'+i.n+'"',g:void 0,v:void 0,id:void 0,cl:void 0,cpf:void 0,st:void 0,sl:void 0,sn:void 0,a:"",c:""},a=i.c;"slot"===i.n?(o.v=!0,o.sn='""',a=[]):"block"!==i.n&&"virtual"!==i.n||(o.v=!0);var s=i.a;if(s){for(var l=0,u=[],c=[],d=null,f=Object.create(null),_=Object.create(null),p=Object.create(null),h=!1,v=!1,g=!1,y=!1,m=0;m<s.length;m++){var b=s[m],E=b.n;if(!f[E]){f[E]=!0;var w=null;if("id"===E)o.id=this.addBackSlashToSign(b.v);else if("class"===E||"class$"===E||"class:"===E)(w=this.parseDynamicValue(b.v,t)).e&&(h=!0),o.cl=this.formatToObjStr({v:w.c,e:w.e,l:void 0,b:w.b});else if("style"===E||"style$"===E||"style:"===E)(w=this.parseDynamicValue(b.v,t)).e&&(v=!0),o.st=this.formatToObjStr({v:w.c,e:w.e,l:void 0,b:w.b});else if("slot"===E)o.sl=this.addBackSlashToSign(b.v);else if("name"===E&&"slot"===i.n)o.sn=this.addBackSlashToSign(b.v);else if("generic:"===E.slice(0,8))o.g="",_[E.slice(8)]=this.addBackSlashToSign(b.v);else if("filter:"===E.slice(0,7))o.cpf="",p[E.slice(7)]=this.addBackSlashToSign(b.v);else if("wx:"===E.slice(0,3)||"dd:"===E.slice(0,3)){var O=E.slice(3);if(!Object.prototype.hasOwnProperty.call(S_,O))throw new Error('Directive "'+O+'" is not found.');var A=S_[O].precompile(O,b.v,t);l+=A.s.length,t=t.concat(A.s);var C=this.formatToObjStr({s:JSON.stringify(A.s),n:'"'+O+'"',d:A.d,l:A.l,b:A.b}),S=S_[O].addDefaultAttrs;if(S&&s.push.apply(s,S),S_[O].attachedToBlock)u.push(C);else if(S_[O].requireBlock){if(null!==d)throw new Error("Uncompatible directives are used in a single element.");d=C}else c.push(C)}else{var T={n:'"'+b.n+'"',v:this.addBackSlashToSign(b.v),o:void 0,e:void 0,l:void 0,b:void 0};if("$"===E.slice(-1)?(T.o='"$"',T.n='"'+E.slice(0,-1)+'"'):":"===E.slice(-1)?(T.o='":"',T.n='"'+this.toUpperCase(E.slice(0,-1))+'"'):"&"===E.slice(-1)?(T.o='"&"',T.n='"'+this.toUpperCase(E.slice(0,-1))+'"'):"class."===E.slice(0,6)?(T.o='"c"',T.n='"'+E.slice(6)+'"',y=!0):"style."===E.slice(0,6)?(T.o='"s"',T.n='"'+E.slice(6)+'"',g=!0):"data-"===E.slice(0,5)&&(T.o='"d"',T.n='"'+this.toUpperCase(E.slice(5))+'"',y=!0),"id"===T.n||"slot"===T.n)throw new Error('"id" and "slot" do not support dynamic binding symbol.');w=this.parseDynamicValue(b.v,t),T.v=w.c,T.e=w.e,T.l=w.l,T.b=w.b,c.push(this.formatToObjStr(T))}}}if(h&&y)throw new Error("Class bindings cannot be used with dynamic class property.");if(v&&g)throw new Error("Style bindings cannot be used with dynamic style property.");o.a=this.formatToArrayStr(c),o.c=this.format(a,t),""===o.g&&(o.g=this.formatToObjStr(_)),""===o.cpf&&(o.cpf=this.formatToObjStr(p)),d?'"block"'===o.n&&"[]"===o.a?(o.a="["+u.concat(d).join(",")+"]",r.push(this.formatToObjStr(o))):r.push(this.formatToObjStr({t:1,n:'"block"',v:!0,a:"["+u.concat(d).join(",")+"]",c:"["+this.formatToObjStr(o)+"]"})):r.push(this.formatToObjStr(o)),t.splice(t.length-l,l)}}else{var N=this.parseDynamicValue(i.c,t);N.t=3,N.l=void 0,N.c=N.c||'""',r.push(this.formatToObjStr(N))}}return this.formatToArrayStr(r)},e.compile=function(t){var r=f_.parse(t),n=e.format(r,[]);return"function("+N_+"){return "+n+"}"},e}();function I_(e){return e.replace(/-([a-z])/g,(function(e,t){return t.toUpperCase()}))}function R_(e,t){if(null!==e&&"object"===ll(e)&&Object.prototype.hasOwnProperty.call(e,t))return e[t]}function L_(e,t,r){e[t]=r}function M_(e,t,r){var n=e.__dataProxy;n.scheduleReplace([t],r),n.doUpdates()}function k_(e,t,r,n){if(void 0===n&&(n=[]),Object.prototype.hasOwnProperty.call(t,r)){var i=t[r];if(fl(i))return Cl.safeCallback("Template Method",i,e,n)}}function P_(e,t,r){e.setAttribute("style",r)}function j_(e,t,r){e.class=r}function D_(e,t,r){e.setAttribute("class",r)}function B_(e,t,r){e.textContent=r}function F_(e,t,r){e.dataset||(e.dataset={}),e.dataset[t]=r}function U_(e,t,r){e.classList.toggle(t,!!r)}function G_(){return[{t:1,n:"slot",v:!0,sn:"",a:[],c:[]}]}function H_(){return[{t:1,n:"slot",a:[],c:[],p:null}]}var V_={t:1,n:'"slot"',v:!0,sn:"",a:[],c:[],p:null},z_={$:function(e,t,r){!0===r?e.setAttribute(t,""):!1===r||null==r?e.removeAttribute(t):e.setAttribute(t,r)},":":L_,c:U_,s:function(e,t,r){e.style&&(e.style[t]=r)},d:F_};function $_(e,t){return function(r){if(this[e](r),t)return!1}}function Y_(e,t,r,n,i,o,a,s){for(var l=null,u=0,c=e;u<c.length;u++){var d=c[u],f=a;if(3===d.t)l=d.e?t.createTextNode(d.e(n,i,null)):t.createTextNode(d.c),d.e&&gf.addBindings(o,a,d.b,l,d),Gd.appendChild(r,l);else{for(var _=d.id,p=d.n,h=d.a,v=d.g,g=d.cl,y=d.st,m=d.cpf,b=!1,E=0,w=h;E<w.length;E++){if((M=w[E]).d&&S_[M.n]){var O=S_[M.n].create(M.n,M,d,n,i,o,f,s,t,Y_,r);if(S_[M.n].requireBlock){l=O,Gd.appendChild(r,l),b=!0;break}}}if(b)continue;if(d.v)l=t.createVirtualNode(p);else if(d.p){l=t.cloneNativeNode(d.p);for(var A=0,C=h;A<C.length;A++){(M=C[A]).d||(M.ev?s(l,M.ev,M.v,M.evCatch):M.o===L_?l.__domElement&&(M.o(l.__domElement,M.n,M.e(n,i,null)),gf.addBindings(o,f,M.b,l.__domElement,M)):M.e&&(M.o(l,M.n,M.e(n,i,null)),M.o!==U_&&M.o!==F_||gf.addBindings(o,f,M.b,l,M)))}y&&y.e&&(l.setAttribute("style",y.e(n,i,null)),gf.addBindings(o,f,y.b,l,y))}else{if(m){var S={},T=t.__ddHost,N=void 0,x=void 0;for(N in m)x=m[N],S[N]=T.__behavior.methods[x];t.__childrenPropsFilter=S}l=t.createComponent(p,void 0,v,void 0);for(var I=void 0,R=0,L=h;R<L.length;R++){var M;(M=L[R]).d||(I=M.v,M.o===M_&&nf.hasPublicProperty(l,M.n)?M.e?(I=M.e(n,i,null),gf.addBindings(o,f,M.b,l,M)):l.__behavior.properties[M.n].type===Boolean?M_(l,M.n,!0):M_(l,M.n,I):M.ev?s(l,M.ev,I,M.evCatch):M.o!==M_&&(M.e&&(I=M.e(n,i,null),gf.addBindings(o,f,M.b,l,M)),M.o(l,M.n,I)))}y&&(y.e?(l.__domElement.setAttribute("style",y.e(n,i,null)),gf.addBindings(o,f,y.b,l.__domElement,y)):l.__domElement.setAttribute("style",y.v))}_&&(l.id=_),g&&(g.e?l.class=g.e(n,i,null):l.class=g.v,g.o&&gf.addBindings(o,f,g.b,l,g)),d.sl&&(l.slot=d.sl),void 0!==d.sn&&Gd.setSlotName(l,d.sn),Gd.appendChild(r,l),Y_(d.c,t,l,n,i,o,f,s)}}}function W_(e,t,r){for(var n=e.childNodes,i=0,o=void 0;i<n.length;i++)(o=n[i])instanceof of||(o.__id&&(t[o.__id]=o),void 0!==o.__slotName&&(r[o.__slotName]=o),W_(o,t,r))}function Z_(e,t,r,n,i,o){for(var a=null,s=0;s<e.length;s++){var l=e[s];if(void 0===l.n)a=document.createTextNode(l.c),l.e&&gf.addBindings(i,o,l.b,a,l),t.appendChild(a);else{var u=l.cl,c=l.st,d=l.a,f=l.id;a=l.v?document.createElement("virtual"):document.importNode?document.importNode(l.p,!1):l.p.cloneNode(!1);for(var _=0,p=d;_<p.length;_++){var h=p[_];h.e&&gf.addBindings(i,o,h.b,a,h)}t.appendChild(a),f&&(r[f]=a),u&&u.e&&gf.addBindings(i,o,u.b,a,u),c&&c.e&&gf.addBindings(i,o,c.b,a,c),void 0!==l.sn&&(n[l.sn]=a),Z_(l.c,a,r,n,i,o)}}}var J_=function(){function e(){}return e.prototype.updateValues=function(e,t,r){for(var n=Gd.getMethodCaller(e),i=0,o=r;i<o.length;i++){var a=o[i];gf.updateBinding(this._topScope,a,t,{},n)}},e}(),K_=function(){function e(){}return e.create=function(t,r,n,i){var o=t.template||G_;if(!fl(o)){var a="undefined"!=typeof window&&"undefined"!=typeof document;if(x_&&a){var s="__exparserFreeTmpl",l=x_.compile(o),u=document.createElement("script");u.type="text/javascript",u.innerHTML="window.__exparserFreeTmpl="+l,document.head.appendChild(u),document.head.removeChild(u),o=window[s],window[s]=null}else o=void 0!==hf&&void 0!==hf.versions&&void 0!==hf.versions.node?e.precompileAndGetCreator(o):H_}var c=new e;return c._initValuesJSON=JSON.stringify(n),c._dataJSON=r!==n?JSON.stringify(r):null,c._tagTreeRoot=function(e,t,r,n){var i="native"===n.renderingMode;i&&!sl.hasDOMBackend&&(e=H_);var o=e(R_,k_,r),a=!1,s=Object.create(null);return function e(r){for(var n=0,o=r;n<o.length;n++){var l=o[n];if(3!==l.t){var u=l.n,c=l.st,d=l.cl,f=l.a,_=l.c,p=!(i||cl(u)&&u.indexOf("-")<0);"slot"===u&&""===l.sn&&(a=!0),l.n=u,c&&c.e&&(c.o=P_,i&&(c.v=c.e(t,s,null))),d&&d.e&&(d.o=i?D_:j_,i&&(d.v=d.e(t,s,null))),p||(l.p=i?document.createElement(u):qd.create(u),c&&void 0!==c.v&&l.p.setAttribute("style",c.v),i&&d&&void 0!==d.v&&l.p.setAttribute("class",d.v));for(var h=0,v=f;h<v.length;h++){var g=v[h],y=g.n,m=void 0;g.d?i||S_[y]&&S_[y].register(g.n,g,l):(i||("bind"===y.slice(0,4)?(g.evCatch=!1,g.ev=I_(y.slice(4)),":"===g.ev[0]&&(g.ev=g.ev.slice(1))):"catch"===y.slice(0,5)&&(g.evCatch=!0,g.ev=I_(y.slice(5)),":"===g.ev[0]&&(g.ev=g.ev.slice(1)))),m=g.o,p?(m?g.o="&"===m?z_[":"]:z_[m]:(g.o=z_[":"],g.n=I_(g.n)),g.o===L_&&(g.o=M_),i&&g.e&&(g.v=g.e(t,s,null))):g.ev||(g.o=m?"&"===m?z_[":"]:z_[m]:z_.$,i?(g.e&&(g.v=g.e(t,s,null)),g.o!==U_&&g.o(l.p,g.n,g.v)):g.e||g.o(l.p,g.n,g.v)))}e(_),i&&1===_.length&&void 0!==_[0].sn&&!_[0].compressed&&(l.sn=_[0].sn,l.compressed=!0,_.pop())}else l.e&&(l.o=B_,l.c=i?l.e(t,s,null):"")}}(o),i&&(a||o.push(V_),1!==o.length||""!==o[0].sn||o[0].compressed||o.pop()),o}(o,n,t.methods,i),c._renderingMode=i.renderingMode,c},e.precompileAndGetCreator=function(e){return e},e.prototype.createInstance=function(e){var t,r=new J_,n=JSON.parse(this._initValuesJSON),i=null===this._dataJSON?n:JSON.parse(this._dataJSON),o=Object.create(null),a=Object.create(null),s=[],l=gf.create("",null,null,null,null,[],(function(){}));if("native"===this._renderingMode)"dom"===sl.documentBackend&&(t=document.createDocumentFragment()),Z_(this._tagTreeRoot,t,o,a,l,{}),a[""]||(a[""]=null);else{var u=sf.create(e);if(e.ownerShadowRoot&&e.ownerShadowRoot.__childrenPropsFilter)if(u.__childrenPropsFilter){var c=void 0;for(c in e.ownerShadowRoot.__childrenPropsFilter)u.__childrenPropsFilter[c]||(u.__childrenPropsFilter[c]=e.ownerShadowRoot.__childrenPropsFilter[c])}else u.__childrenPropsFilter=e.ownerShadowRoot.__childrenPropsFilter;Y_(this._tagTreeRoot,u,u,n,{},l,{},(function(e,t,r,n){u.__ddHost?e.addListener(t,$_(r,n).bind(u.__ddHost)):s.push({target:e,name:t,func:$_(r,n)})})),W_(u,o,a),t=u}return r.data=i,r.shadowRoot=t,r.idMap=o,r.slots=a,r.listeners=s,r._topScope=l,r},e.precompiler=x_,e.htmlParser=f_,e}();return gl(K_),function(){var e=El();delete e._list[""],e.register({is:"",options:{writeOnly:!0,allowInWriteOnly:!0,lazyRegistration:!1,classPrefix:"",addGlobalClass:!1,templateEngine:null,renderingMode:"full",multipleSlots:!1,reflectToAttributes:!1}})}(),{precompileTemplate:K_.precompiler?K_.precompiler.compile:null,precompiler:K_.precompiler?K_.precompiler:null,HtmlLLParser:K_.htmlParser?K_.htmlParser:null,LLParser:zs,dataPath:id,dataUtils:Tu,Event:Mu,EventBus:Cl,Element:Gd,TextNode:of,NativeNode:qd,VirtualNode:af,ShadowRoot:sf,Behavior:vd,Component:nf,Observer:yd,DataGroup:Yd,ElementIterator:lf,FakeDomElement:md,registerBehavior:vd.create,registerElement:nf.register,createElement:nf.create,createTextNode:of.create,createVirtualNode:af.create,appendChild:Gd.appendChild,insertBefore:Gd.insertBefore,removeChild:Gd.removeChild,replaceChild:Gd.replaceChild,addListenerToElement:Mu.addListenerToElement,removeListenerFromElement:Mu.removeListenerFromElement,triggerEvent:Mu.triggerEvent,safeCallback:Cl.safeCallback,addGlobalErrorListener:Cl.addGlobalErrorListener,removeGlobalErrorListener:Cl.removeGlobalErrorListener,globalState:Ud,globalOptions:sl}}();

!function(t){"function"==typeof define&&define.amd?define(t):t()}((function(){"use strict";var t={is:"dd-view",options:{renderingMode:"full"},template:function(t,n,e){return[{t:1,n:"slot",v:!0,sn:"",a:[],c:[]}]},properties:{hoverClass:String},listeners:{"this.touchstart":function(){this.hoverStart()},"this.touchend":function(){this.hoverEnd()},"this.canceltap":function(){this.hoverEnd()}},methods:{hoverStart:function(){},hoverEnd:function(){}}};exparser.registerElement(t)}));

exparser.globalOptions.renderingMode = 'full';
exparser.globalState.enableBackendExtractedDefault();

var __virtualDOMDataThread__ = true;
var __virtualDOMTunnelPrintLog__ = false;
var __virtualDOM__=function(){"use strict";var e="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function t(e,t,r){return e(r={path:t,exports:{},require:function(e,t){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==t&&r.path)}},r.exports),r.exports}var r,n,o=function(e){return e&&e.Math==Math&&e},i=o("object"==typeof globalThis&&globalThis)||o("object"==typeof window&&window)||o("object"==typeof self&&self)||o("object"==typeof e&&e)||function(){return this}()||Function("return this")(),a=function(e){try{return!!e()}catch(e){return!0}},s=!a((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),u=!a((function(){var e=function(){}.bind();return"function"!=typeof e||e.hasOwnProperty("prototype")})),l=Function.prototype.call,c=u?l.bind(l):function(){return l.apply(l,arguments)},d={}.propertyIsEnumerable,f=Object.getOwnPropertyDescriptor,p={f:f&&!d.call({1:2},1)?function(e){var t=f(this,e);return!!t&&t.enumerable}:d},_=function(e,t){return{enumerable:!(1&e),configurable:!(2&e),writable:!(4&e),value:t}},h=Function.prototype,v=h.bind,g=h.call,E=u&&v.bind(g,g),m=u?function(e){return e&&E(e)}:function(e){return e&&function(){return g.apply(e,arguments)}},y=m({}.toString),b=m("".slice),N=function(e){return b(y(e),8,-1)},w=Object,C=m("".split),S=a((function(){return!w("z").propertyIsEnumerable(0)}))?function(e){return"String"==N(e)?C(e,""):w(e)}:w,A=TypeError,T=function(e){if(null==e)throw A("Can't call method on "+e);return e},O=function(e){return S(T(e))},I=function(e){return"function"==typeof e},x=function(e){return"object"==typeof e?null!==e:I(e)},D=function(e){return I(e)?e:void 0},M=function(e,t){return arguments.length<2?D(i[e]):i[e]&&i[e][t]},L=m({}.isPrototypeOf),R=M("navigator","userAgent")||"",F=i.process,P=i.Deno,V=F&&F.versions||P&&P.version,k=V&&V.v8;k&&(n=(r=k.split("."))[0]>0&&r[0]<4?1:+(r[0]+r[1])),!n&&R&&(!(r=R.match(/Edge\/(\d+)/))||r[1]>=74)&&(r=R.match(/Chrome\/(\d+)/))&&(n=+r[1]);var j=n,Y=!!Object.getOwnPropertySymbols&&!a((function(){var e=Symbol();return!String(e)||!(Object(e)instanceof Symbol)||!Symbol.sham&&j&&j<41})),W=Y&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,B=Object,H=W?function(e){return"symbol"==typeof e}:function(e){var t=M("Symbol");return I(t)&&L(t.prototype,B(e))},U=String,G=function(e){try{return U(e)}catch(e){return"Object"}},$=TypeError,z=function(e){if(I(e))return e;throw $(G(e)+" is not a function")},q=function(e,t){var r=e[t];return null==r?void 0:z(r)},X=TypeError,K=Object.defineProperty,Q=function(e,t){try{K(i,e,{value:t,configurable:!0,writable:!0})}catch(r){i[e]=t}return t},Z="__core-js_shared__",J=i[Z]||Q(Z,{}),ee=t((function(e){(e.exports=function(e,t){return J[e]||(J[e]=void 0!==t?t:{})})("versions",[]).push({version:"3.24.1",mode:"global",copyright:"© 2014-2022 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.24.1/LICENSE",source:"https://github.com/zloirock/core-js"})})),te=Object,re=function(e){return te(T(e))},ne=m({}.hasOwnProperty),oe=Object.hasOwn||function(e,t){return ne(re(e),t)},ie=0,ae=Math.random(),se=m(1..toString),ue=function(e){return"Symbol("+(void 0===e?"":e)+")_"+se(++ie+ae,36)},le=ee("wks"),ce=i.Symbol,de=ce&&ce.for,fe=W?ce:ce&&ce.withoutSetter||ue,pe=function(e){if(!oe(le,e)||!Y&&"string"!=typeof le[e]){var t="Symbol."+e;Y&&oe(ce,e)?le[e]=ce[e]:le[e]=W&&de?de(t):fe(t)}return le[e]},_e=TypeError,he=pe("toPrimitive"),ve=function(e,t){if(!x(e)||H(e))return e;var r,n=q(e,he);if(n){if(void 0===t&&(t="default"),r=c(n,e,t),!x(r)||H(r))return r;throw _e("Can't convert object to primitive value")}return void 0===t&&(t="number"),function(e,t){var r,n;if("string"===t&&I(r=e.toString)&&!x(n=c(r,e)))return n;if(I(r=e.valueOf)&&!x(n=c(r,e)))return n;if("string"!==t&&I(r=e.toString)&&!x(n=c(r,e)))return n;throw X("Can't convert object to primitive value")}(e,t)},ge=function(e){var t=ve(e,"string");return H(t)?t:t+""},Ee=i.document,me=x(Ee)&&x(Ee.createElement),ye=function(e){return me?Ee.createElement(e):{}},be=!s&&!a((function(){return 7!=Object.defineProperty(ye("div"),"a",{get:function(){return 7}}).a})),Ne=Object.getOwnPropertyDescriptor,we={f:s?Ne:function(e,t){if(e=O(e),t=ge(t),be)try{return Ne(e,t)}catch(e){}if(oe(e,t))return _(!c(p.f,e,t),e[t])}},Ce=s&&a((function(){return 42!=Object.defineProperty((function(){}),"prototype",{value:42,writable:!1}).prototype})),Se=String,Ae=TypeError,Te=function(e){if(x(e))return e;throw Ae(Se(e)+" is not an object")},Oe=TypeError,Ie=Object.defineProperty,xe=Object.getOwnPropertyDescriptor,De="enumerable",Me="configurable",Le="writable",Re={f:s?Ce?function(e,t,r){if(Te(e),t=ge(t),Te(r),"function"==typeof e&&"prototype"===t&&"value"in r&&Le in r&&!r.writable){var n=xe(e,t);n&&n.writable&&(e[t]=r.value,r={configurable:Me in r?r.configurable:n.configurable,enumerable:De in r?r.enumerable:n.enumerable,writable:!1})}return Ie(e,t,r)}:Ie:function(e,t,r){if(Te(e),t=ge(t),Te(r),be)try{return Ie(e,t,r)}catch(e){}if("get"in r||"set"in r)throw Oe("Accessors not supported");return"value"in r&&(e[t]=r.value),e}},Fe=s?function(e,t,r){return Re.f(e,t,_(1,r))}:function(e,t,r){return e[t]=r,e},Pe=Function.prototype,Ve=s&&Object.getOwnPropertyDescriptor,ke=oe(Pe,"name"),je={EXISTS:ke,PROPER:ke&&"something"===function(){}.name,CONFIGURABLE:ke&&(!s||s&&Ve(Pe,"name").configurable)},Ye=m(Function.toString);I(J.inspectSource)||(J.inspectSource=function(e){return Ye(e)});var We,Be,He,Ue=J.inspectSource,Ge=i.WeakMap,$e=I(Ge)&&/native code/.test(Ue(Ge)),ze=ee("keys"),qe=function(e){return ze[e]||(ze[e]=ue(e))},Xe={},Ke="Object already initialized",Qe=i.TypeError,Ze=i.WeakMap;if($e||J.state){var Je=J.state||(J.state=new Ze),et=m(Je.get),tt=m(Je.has),rt=m(Je.set);We=function(e,t){if(tt(Je,e))throw new Qe(Ke);return t.facade=e,rt(Je,e,t),t},Be=function(e){return et(Je,e)||{}},He=function(e){return tt(Je,e)}}else{var nt=qe("state");Xe[nt]=!0,We=function(e,t){if(oe(e,nt))throw new Qe(Ke);return t.facade=e,Fe(e,nt,t),t},Be=function(e){return oe(e,nt)?e[nt]:{}},He=function(e){return oe(e,nt)}}var ot={set:We,get:Be,has:He,enforce:function(e){return He(e)?Be(e):We(e,{})},getterFor:function(e){return function(t){var r;if(!x(t)||(r=Be(t)).type!==e)throw Qe("Incompatible receiver, "+e+" required");return r}}},it=t((function(e){var t=je.CONFIGURABLE,r=ot.enforce,n=ot.get,o=Object.defineProperty,i=s&&!a((function(){return 8!==o((function(){}),"length",{value:8}).length})),u=String(String).split("String"),l=e.exports=function(e,n,a){"Symbol("===String(n).slice(0,7)&&(n="["+String(n).replace(/^Symbol\(([^)]*)\)/,"$1")+"]"),a&&a.getter&&(n="get "+n),a&&a.setter&&(n="set "+n),(!oe(e,"name")||t&&e.name!==n)&&(s?o(e,"name",{value:n,configurable:!0}):e.name=n),i&&a&&oe(a,"arity")&&e.length!==a.arity&&o(e,"length",{value:a.arity});try{a&&oe(a,"constructor")&&a.constructor?s&&o(e,"prototype",{writable:!1}):e.prototype&&(e.prototype=void 0)}catch(e){}var l=r(e);return oe(l,"source")||(l.source=u.join("string"==typeof n?n:"")),e};Function.prototype.toString=l((function(){return I(this)&&n(this).source||Ue(this)}),"toString")})),at=function(e,t,r,n){n||(n={});var o=n.enumerable,i=void 0!==n.name?n.name:t;if(I(r)&&it(r,i,n),n.global)o?e[t]=r:Q(t,r);else{try{n.unsafe?e[t]&&(o=!0):delete e[t]}catch(e){}o?e[t]=r:Re.f(e,t,{value:r,enumerable:!1,configurable:!n.nonConfigurable,writable:!n.nonWritable})}return e},st=Math.ceil,ut=Math.floor,lt=Math.trunc||function(e){var t=+e;return(t>0?ut:st)(t)},ct=function(e){var t=+e;return t!=t||0===t?0:lt(t)},dt=Math.max,ft=Math.min,pt=function(e,t){var r=ct(e);return r<0?dt(r+t,0):ft(r,t)},_t=Math.min,ht=function(e){return e>0?_t(ct(e),9007199254740991):0},vt=function(e){return ht(e.length)},gt=function(e){return function(t,r,n){var o,i=O(t),a=vt(i),s=pt(n,a);if(e&&r!=r){for(;a>s;)if((o=i[s++])!=o)return!0}else for(;a>s;s++)if((e||s in i)&&i[s]===r)return e||s||0;return!e&&-1}},Et={includes:gt(!0),indexOf:gt(!1)},mt=Et.indexOf,yt=m([].push),bt=function(e,t){var r,n=O(e),o=0,i=[];for(r in n)!oe(Xe,r)&&oe(n,r)&&yt(i,r);for(;t.length>o;)oe(n,r=t[o++])&&(~mt(i,r)||yt(i,r));return i},Nt=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],wt=Nt.concat("length","prototype"),Ct={f:Object.getOwnPropertyNames||function(e){return bt(e,wt)}},St={f:Object.getOwnPropertySymbols},At=m([].concat),Tt=M("Reflect","ownKeys")||function(e){var t=Ct.f(Te(e)),r=St.f;return r?At(t,r(e)):t},Ot=function(e,t,r){for(var n=Tt(t),o=Re.f,i=we.f,a=0;a<n.length;a++){var s=n[a];oe(e,s)||r&&oe(r,s)||o(e,s,i(t,s))}},It=/#|\.prototype\./,xt=function(e,t){var r=Mt[Dt(e)];return r==Rt||r!=Lt&&(I(t)?a(t):!!t)},Dt=xt.normalize=function(e){return String(e).replace(It,".").toLowerCase()},Mt=xt.data={},Lt=xt.NATIVE="N",Rt=xt.POLYFILL="P",Ft=xt,Pt=we.f,Vt=function(e,t){var r,n,o,a,s,u=e.target,l=e.global,c=e.stat;if(r=l?i:c?i[u]||Q(u,{}):(i[u]||{}).prototype)for(n in t){if(a=t[n],o=e.dontCallGetSet?(s=Pt(r,n))&&s.value:r[n],!Ft(l?n:u+(c?".":"#")+n,e.forced)&&void 0!==o){if(typeof a==typeof o)continue;Ot(a,o)}(e.sham||o&&o.sham)&&Fe(a,"sham",!0),at(r,n,a,e)}},kt={};kt[pe("toStringTag")]="z";var jt,Yt="[object z]"===String(kt),Wt=pe("toStringTag"),Bt=Object,Ht="Arguments"==N(function(){return arguments}()),Ut=Yt?N:function(e){var t,r,n;return void 0===e?"Undefined":null===e?"Null":"string"==typeof(r=function(e,t){try{return e[t]}catch(e){}}(t=Bt(e),Wt))?r:Ht?N(t):"Object"==(n=N(t))&&I(t.callee)?"Arguments":n},Gt=String,$t=function(e){if("Symbol"===Ut(e))throw TypeError("Cannot convert a Symbol value to a string");return Gt(e)},zt=function(){var e=Te(this),t="";return e.hasIndices&&(t+="d"),e.global&&(t+="g"),e.ignoreCase&&(t+="i"),e.multiline&&(t+="m"),e.dotAll&&(t+="s"),e.unicode&&(t+="u"),e.unicodeSets&&(t+="v"),e.sticky&&(t+="y"),t},qt=i.RegExp,Xt=a((function(){var e=qt("a","y");return e.lastIndex=2,null!=e.exec("abcd")})),Kt=Xt||a((function(){return!qt("a","y").sticky})),Qt={BROKEN_CARET:Xt||a((function(){var e=qt("^r","gy");return e.lastIndex=2,null!=e.exec("str")})),MISSED_STICKY:Kt,UNSUPPORTED_Y:Xt},Zt=Object.keys||function(e){return bt(e,Nt)},Jt=s&&!Ce?Object.defineProperties:function(e,t){Te(e);for(var r,n=O(t),o=Zt(t),i=o.length,a=0;i>a;)Re.f(e,r=o[a++],n[r]);return e},er={f:Jt},tr=M("document","documentElement"),rr=qe("IE_PROTO"),nr=function(){},or=function(e){return"<script>"+e+"</"+"script>"},ir=function(e){e.write(or("")),e.close();var t=e.parentWindow.Object;return e=null,t},ar=function(){try{jt=new ActiveXObject("htmlfile")}catch(e){}var e,t;ar="undefined"!=typeof document?document.domain&&jt?ir(jt):((t=ye("iframe")).style.display="none",tr.appendChild(t),t.src=String("javascript:"),(e=t.contentWindow.document).open(),e.write(or("document.F=Object")),e.close(),e.F):ir(jt);for(var r=Nt.length;r--;)delete ar.prototype[Nt[r]];return ar()};Xe[rr]=!0;var sr=Object.create||function(e,t){var r;return null!==e?(nr.prototype=Te(e),r=new nr,nr.prototype=null,r[rr]=e):r=ar(),void 0===t?r:er.f(r,t)},ur=i.RegExp,lr=a((function(){var e=ur(".","s");return!(e.dotAll&&e.exec("\n")&&"s"===e.flags)})),cr=i.RegExp,dr=a((function(){var e=cr("(?<a>b)","g");return"b"!==e.exec("b").groups.a||"bc"!=="b".replace(e,"$<a>c")})),fr=ot.get,pr=ee("native-string-replace",String.prototype.replace),_r=RegExp.prototype.exec,hr=_r,vr=m("".charAt),gr=m("".indexOf),Er=m("".replace),mr=m("".slice),yr=function(){var e=/a/,t=/b*/g;return c(_r,e,"a"),c(_r,t,"a"),0!==e.lastIndex||0!==t.lastIndex}(),br=Qt.BROKEN_CARET,Nr=void 0!==/()??/.exec("")[1];(yr||Nr||br||lr||dr)&&(hr=function(e){var t,r,n,o,i,a,s,u=this,l=fr(u),d=$t(e),f=l.raw;if(f)return f.lastIndex=u.lastIndex,t=c(hr,f,d),u.lastIndex=f.lastIndex,t;var p=l.groups,_=br&&u.sticky,h=c(zt,u),v=u.source,g=0,E=d;if(_&&(h=Er(h,"y",""),-1===gr(h,"g")&&(h+="g"),E=mr(d,u.lastIndex),u.lastIndex>0&&(!u.multiline||u.multiline&&"\n"!==vr(d,u.lastIndex-1))&&(v="(?: "+v+")",E=" "+E,g++),r=new RegExp("^(?:"+v+")",h)),Nr&&(r=new RegExp("^"+v+"$(?!\\s)",h)),yr&&(n=u.lastIndex),o=c(_r,_?r:u,E),_?o?(o.input=mr(o.input,g),o[0]=mr(o[0],g),o.index=u.lastIndex,u.lastIndex+=o[0].length):u.lastIndex=0:yr&&o&&(u.lastIndex=u.global?o.index+o[0].length:n),Nr&&o&&o.length>1&&c(pr,o[0],r,(function(){for(i=1;i<arguments.length-2;i++)void 0===arguments[i]&&(o[i]=void 0)})),o&&p)for(o.groups=a=sr(null),i=0;i<p.length;i++)a[(s=p[i])[0]]=o[s[1]];return o});var wr=hr;Vt({target:"RegExp",proto:!0,forced:/./.exec!==wr},{exec:wr});var Cr=pe("species"),Sr=RegExp.prototype,Ar=function(e,t,r,n){var o=pe(e),i=!a((function(){var t={};return t[o]=function(){return 7},7!=""[e](t)})),s=i&&!a((function(){var t=!1,r=/a/;return"split"===e&&((r={}).constructor={},r.constructor[Cr]=function(){return r},r.flags="",r[o]=/./[o]),r.exec=function(){return t=!0,null},r[o](""),!t}));if(!i||!s||r){var u=m(/./[o]),l=t(o,""[e],(function(e,t,r,n,o){var a=m(e),s=t.exec;return s===wr||s===Sr.exec?i&&!o?{done:!0,value:u(t,r,n)}:{done:!0,value:a(r,t,n)}:{done:!1}}));at(String.prototype,e,l[0]),at(Sr,o,l[1])}n&&Fe(Sr[o],"sham",!0)},Tr=m("".charAt),Or=m("".charCodeAt),Ir=m("".slice),xr=function(e){return function(t,r){var n,o,i=$t(T(t)),a=ct(r),s=i.length;return a<0||a>=s?e?"":void 0:(n=Or(i,a))<55296||n>56319||a+1===s||(o=Or(i,a+1))<56320||o>57343?e?Tr(i,a):n:e?Ir(i,a,a+2):o-56320+(n-55296<<10)+65536}},Dr={codeAt:xr(!1),charAt:xr(!0)},Mr=Dr.charAt,Lr=function(e,t,r){return t+(r?Mr(e,t).length:1)},Rr=TypeError,Fr=function(e,t){var r=e.exec;if(I(r)){var n=c(r,e,t);return null!==n&&Te(n),n}if("RegExp"===N(e))return c(wr,e,t);throw Rr("RegExp#exec called on incompatible receiver")};Ar("match",(function(e,t,r){return[function(t){var r=T(this),n=null==t?void 0:q(t,e);return n?c(n,t,r):new RegExp(t)[e]($t(r))},function(e){var n=Te(this),o=$t(e),i=r(t,n,o);if(i.done)return i.value;if(!n.global)return Fr(n,o);var a=n.unicode;n.lastIndex=0;for(var s,u=[],l=0;null!==(s=Fr(n,o));){var c=$t(s[0]);u[l]=c,""===c&&(n.lastIndex=Lr(o,ht(n.lastIndex),a)),l++}return 0===l?null:u}]}));var Pr=Array.isArray||function(e){return"Array"==N(e)},Vr=function(){},kr=[],jr=M("Reflect","construct"),Yr=/^\s*(?:class|function)\b/,Wr=m(Yr.exec),Br=!Yr.exec(Vr),Hr=function(e){if(!I(e))return!1;try{return jr(Vr,kr,e),!0}catch(e){return!1}},Ur=function(e){if(!I(e))return!1;switch(Ut(e)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return Br||!!Wr(Yr,Ue(e))}catch(e){return!0}};Ur.sham=!0;var Gr=!jr||a((function(){var e;return Hr(Hr.call)||!Hr(Object)||!Hr((function(){e=!0}))||e}))?Ur:Hr,$r=function(e,t,r){var n=ge(t);n in e?Re.f(e,n,_(0,r)):e[n]=r},zr=pe("species"),qr=function(e){return j>=51||!a((function(){var t=[];return(t.constructor={})[zr]=function(){return{foo:1}},1!==t[e](Boolean).foo}))},Xr=m([].slice),Kr=qr("slice"),Qr=pe("species"),Zr=Array,Jr=Math.max;Vt({target:"Array",proto:!0,forced:!Kr},{slice:function(e,t){var r,n,o,i=O(this),a=vt(i),s=pt(e,a),u=pt(void 0===t?a:t,a);if(Pr(i)&&(r=i.constructor,(Gr(r)&&(r===Zr||Pr(r.prototype))||x(r)&&null===(r=r[Qr]))&&(r=void 0),r===Zr||void 0===r))return Xr(i,s,u);for(n=new(void 0===r?Zr:r)(Jr(u-s,0)),o=0;s<u;s++,o++)s in i&&$r(n,o,i[s]);return n.length=o,n}});var en=function(e,t){var r=[][e];return!!r&&a((function(){r.call(null,t||function(){return 1},1)}))},tn=Et.indexOf,rn=m([].indexOf),nn=!!rn&&1/rn([1],1,-0)<0,on=en("indexOf");Vt({target:"Array",proto:!0,forced:nn||!on},{indexOf:function(e){var t=arguments.length>1?arguments[1]:void 0;return nn?rn(this,e,t)||0:tn(this,e,t)}});var an=Function.prototype,sn=an.apply,un=an.call,ln="object"==typeof Reflect&&Reflect.apply||(u?un.bind(sn):function(){return un.apply(sn,arguments)}),cn=pe("match"),dn=function(e){var t;return x(e)&&(void 0!==(t=e[cn])?!!t:"RegExp"==N(e))},fn=TypeError,pn=pe("species"),_n=function(e,t){var r,n=Te(e).constructor;return void 0===n||null==(r=Te(n)[pn])?t:function(e){if(Gr(e))return e;throw fn(G(e)+" is not a constructor")}(r)},hn=Array,vn=Math.max,gn=function(e,t,r){for(var n=vt(e),o=pt(t,n),i=pt(void 0===r?n:r,n),a=hn(vn(i-o,0)),s=0;o<i;o++,s++)$r(a,s,e[o]);return a.length=s,a},En=Qt.UNSUPPORTED_Y,mn=4294967295,yn=Math.min,bn=[].push,Nn=m(/./.exec),wn=m(bn),Cn=m("".slice),Sn=!a((function(){var e=/(?:)/,t=e.exec;e.exec=function(){return t.apply(this,arguments)};var r="ab".split(e);return 2!==r.length||"a"!==r[0]||"b"!==r[1]}));Ar("split",(function(e,t,r){var n;return n="c"=="abbc".split(/(b)*/)[1]||4!="test".split(/(?:)/,-1).length||2!="ab".split(/(?:ab)*/).length||4!=".".split(/(.?)(.?)/).length||".".split(/()()/).length>1||"".split(/.?/).length?function(e,r){var n=$t(T(this)),o=void 0===r?mn:r>>>0;if(0===o)return[];if(void 0===e)return[n];if(!dn(e))return c(t,n,e,o);for(var i,a,s,u=[],l=(e.ignoreCase?"i":"")+(e.multiline?"m":"")+(e.unicode?"u":"")+(e.sticky?"y":""),d=0,f=new RegExp(e.source,l+"g");(i=c(wr,f,n))&&!((a=f.lastIndex)>d&&(wn(u,Cn(n,d,i.index)),i.length>1&&i.index<n.length&&ln(bn,u,gn(i,1)),s=i[0].length,d=a,u.length>=o));)f.lastIndex===i.index&&f.lastIndex++;return d===n.length?!s&&Nn(f,"")||wn(u,""):wn(u,Cn(n,d)),u.length>o?gn(u,0,o):u}:"0".split(void 0,0).length?function(e,r){return void 0===e&&0===r?[]:c(t,this,e,r)}:t,[function(t,r){var o=T(this),i=null==t?void 0:q(t,e);return i?c(i,t,o,r):c(n,$t(o),t,r)},function(e,o){var i=Te(this),a=$t(e),s=r(n,i,a,o,n!==t);if(s.done)return s.value;var u=_n(i,RegExp),l=i.unicode,c=(i.ignoreCase?"i":"")+(i.multiline?"m":"")+(i.unicode?"u":"")+(En?"g":"y"),d=new u(En?"^(?:"+i.source+")":i,c),f=void 0===o?mn:o>>>0;if(0===f)return[];if(0===a.length)return null===Fr(d,a)?[a]:[];for(var p=0,_=0,h=[];_<a.length;){d.lastIndex=En?0:_;var v,g=Fr(d,En?Cn(a,_):a);if(null===g||(v=yn(ht(d.lastIndex+(En?_:0)),a.length))===p)_=Lr(a,_,l);else{if(wn(h,Cn(a,p,_)),h.length===f)return h;for(var E=1;E<=g.length-1;E++)if(wn(h,g[E]),h.length===f)return h;_=p=v}}return wn(h,Cn(a,p)),h}]}),!Sn,En);var An=Yt?{}.toString:function(){return"[object "+Ut(this)+"]"};Yt||at(Object.prototype,"toString",An,{unsafe:!0});var Tn=!a((function(){function e(){}return e.prototype.constructor=null,Object.getPrototypeOf(new e)!==e.prototype})),On=qe("IE_PROTO"),In=Object,xn=In.prototype,Dn=Tn?In.getPrototypeOf:function(e){var t=re(e);if(oe(t,On))return t[On];var r=t.constructor;return I(r)&&t instanceof r?r.prototype:t instanceof In?xn:null},Mn=a((function(){Dn(1)}));Vt({target:"Object",stat:!0,forced:Mn,sham:!Tn},{getPrototypeOf:function(e){return Dn(re(e))}});var Ln=RegExp.prototype,Rn=function(e){var t=e.flags;return void 0!==t||"flags"in Ln||oe(e,"flags")||!L(Ln,e)?t:c(zt,e)},Fn=je.PROPER,Pn="toString",Vn=RegExp.prototype.toString,kn=a((function(){return"/a/b"!=Vn.call({source:"a",flags:"b"})})),jn=Fn&&Vn.name!=Pn;(kn||jn)&&at(RegExp.prototype,Pn,(function(){var e=Te(this);return"/"+$t(e.source)+"/"+$t(Rn(e))}),{unsafe:!0});var Yn=m(m.bind),Wn=function(e,t){return z(e),void 0===t?e:u?Yn(e,t):function(){return e.apply(t,arguments)}},Bn=pe("species"),Hn=Array,Un=function(e,t){return new(function(e){var t;return Pr(e)&&(t=e.constructor,(Gr(t)&&(t===Hn||Pr(t.prototype))||x(t)&&null===(t=t[Bn]))&&(t=void 0)),void 0===t?Hn:t}(e))(0===t?0:t)},Gn=m([].push),$n=function(e){var t=1==e,r=2==e,n=3==e,o=4==e,i=6==e,a=7==e,s=5==e||i;return function(u,l,c,d){for(var f,p,_=re(u),h=S(_),v=Wn(l,c),g=vt(h),E=0,m=d||Un,y=t?m(u,g):r||a?m(u,0):void 0;g>E;E++)if((s||E in h)&&(p=v(f=h[E],E,_),e))if(t)y[E]=p;else if(p)switch(e){case 3:return!0;case 5:return f;case 6:return E;case 2:Gn(y,f)}else switch(e){case 4:return!1;case 7:Gn(y,f)}return i?-1:n||o?o:y}},zn={forEach:$n(0),map:$n(1),filter:$n(2),some:$n(3),every:$n(4),find:$n(5),findIndex:$n(6),filterReject:$n(7)},qn=zn.map,Xn=qr("map");Vt({target:"Array",proto:!0,forced:!Xn},{map:function(e){return qn(this,e,arguments.length>1?arguments[1]:void 0)}});var Kn=a((function(){Zt(1)}));Vt({target:"Object",stat:!0,forced:Kn},{keys:function(e){return Zt(re(e))}});var Qn=/^[-+a-z]+:\/\//i;function Zn(e,t){if(Qn.test(t))return t;var r=e.match(Qn),n="";r&&(n=r[0],e=e.slice(n.length)),0===t.indexOf("/")&&(e="");var o=e.split("/");o.pop();for(var i=t.split("/");i.length;){var a=i.shift();""!==a&&"."!==a&&(".."===a?o.pop():o.push(a))}return n+o.join("/")}function Jn(e){return e&&("[object Function]"===Object.prototype.toString.call(e)||"function"==typeof e)}function eo(e){return Array.isArray?Array.isArray(e):"[object Array]"===Object.prototype.toString.call(e)}function to(e){var t=("undefined"==typeof window?this:window).__wcc_version_info__;if(t)return t[e]}function ro(){return Math.floor(4294967296*(1+Math.random())).toString(16).slice(1)}function no(e,t,r){e instanceof exparser.Component&&(t>0&&r(e),t&&e.shadowRoot instanceof exparser.Element&&no(e.shadowRoot,t,r),t<0&&r(e));for(var n=e.childNodes||[],o=0;o<n.length;o++)n[o]instanceof exparser.Element&&no(n[o],t,r)}var oo=function(){function e(){this._idNodeMap={}}return e.prototype.getAll=function(){return this._idNodeMap},e.prototype.getNodeById=function(e){return this._idNodeMap[e]},e.prototype.getNodeId=function(e){return e.__ddTmplId},e.prototype.allocNodeId=function(e,t){var r=t||ro();return e.__ddTmplId=r,this._idNodeMap[e.__ddTmplId]=e,r},e.prototype.addNode=function(){},e.prototype.removeNode=function(e){if(e){if(e.__ddTmplId&&(this._idNodeMap[e.__ddTmplId]=null,delete this._idNodeMap[e.__ddTmplId]),e.childNodes)for(var t=0;t<e.childNodes.length;t++)this.removeNode(e.childNodes[t]);e.shadowRoot instanceof exparser.Element&&this.removeNode(e.shadowRoot)}},e.prototype.destroy=function(){var e;for(e in this._idNodeMap)this._idNodeMap[e]=null;e=null,this._idNodeMap=null},e}(),io=TypeError,ao=function(e){if(e>9007199254740991)throw io("Maximum allowed index exceeded");return e},so=TypeError,uo=function(e,t){if(!delete e[t])throw so("Cannot delete property "+G(t)+" of "+G(e))},lo=qr("splice"),co=Math.max,fo=Math.min;Vt({target:"Array",proto:!0,forced:!lo},{splice:function(e,t){var r,n,o,i,a,s,u=re(this),l=vt(u),c=pt(e,l),d=arguments.length;for(0===d?r=n=0:1===d?(r=0,n=l-c):(r=d-2,n=fo(co(ct(t),0),l-c)),ao(l+r-n),o=Un(u,n),i=0;i<n;i++)(a=c+i)in u&&$r(o,i,u[a]);if(o.length=n,r<n){for(i=c;i<l-n;i++)s=i+r,(a=i+n)in u?u[s]=u[a]:uo(u,s);for(i=l;i>l-n+r;i--)uo(u,i-1)}else if(r>n)for(i=l-n;i>c;i--)s=i+r-1,(a=i+n-1)in u?u[s]=u[a]:uo(u,s);for(i=0;i<r;i++)u[i+c]=arguments[i+2];return u.length=l-n+r,o}});var po={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0},_o=ye("span").classList,ho=_o&&_o.constructor&&_o.constructor.prototype,vo=ho===Object.prototype?void 0:ho,go=zn.forEach,Eo=en("forEach")?[].forEach:function(e){return go(this,e,arguments.length>1?arguments[1]:void 0)},mo=function(e){if(e&&e.forEach!==Eo)try{Fe(e,"forEach",Eo)}catch(t){e.forEach=Eo}};for(var yo in po)po[yo]&&mo(i[yo]&&i[yo].prototype);mo(vo);var bo=function(){return bo=Object.assign||function(e){for(var t,r=1,n=arguments.length;r<n;r++)for(var o in t=arguments[r])Object.prototype.hasOwnProperty.call(t,o)&&(e[o]=t[o]);return e},bo.apply(this,arguments)};var No={TEST:0,FLOW_DEPTH:2,FLOW_INITIAL_CREATION:3,FLOW_APPLY_PROPERTY:4,FLOW_CREATE_NODE:5,FLOW_UPDATE:6,FLOW_MINIPULATE_CHILD:7,FLOW_DATA_OBSERVER:8,FLOW_REPEAT:9,DD_EVENT:11,REQUEST_SAVE:12,COMPONENT_DEF:21,SAVE_STATE:22,RESTORE_STATE:23,FLOW_INITIAL_RENDERING_CACHE:24,FLOW_CLEAR_INITIAL_RENDERING_CACHE:25,SET_DATA_CALLBACK:32,FLOW_SET_DATA:33,FLOW_GROUP:41,FLOW_GROUP_END:42,FLUSH_BLOCKED:43,CALL_METHOD_FROM_DDS:50,REQUEST_TAB:51,COMPONENT_DEF_TAB:52,FLOW_CREATE_TAB:53,DESTROY_TAB:54,REQUEST_BROADCAST_VIEW_ID:61,RESPONSE_BROADCAST_VIEW_ID:62,FLOW_VIEW_INFO:63,RESPONSE_VIEW_INFO:64,MODEL_VALUE_CHANGE:65,BANNING_MAP:90,PERFORMANCE_DATA:91,FLOW_SET_NODE_ANIMATION_INFO:100,ANIMATION_TRANSITION_END:101,FLOW_CLEAR_NODE_ANIMATION_INFO:102,CLEAR_ANIMATION_COMPLETE:103,FLOW_SET_NODE_NEXT_ANIMATION_INFO:104,LOAD_COMPONENT_DEF:110,COMPONENT_DEF_LAZY:111,FLOW_DO_REPLACE_PLACEHOLDER:112,FLOW_REPLACE_PLACEHOLDER:113,UPDATE_PERFORMANCE_STAT:800,ENABLE_UPDATE_PERFORMANCE_STAT:801,DISABLE_UPDATE_PERFORMANCE_STAT:802,FLOW_HOT_UPDATE:900,FLOW_HOT_UPDATE_CHILD:901,FLOW_HOT_UPDATE_RESET:902,UPDATE_COMPONENT_DEF:903},wo={};Object.keys(No).forEach((function(e){wo[No[e]]=e}));var Co={RPX_RATE:20,BASE_DEVICE_WIDTH:750,SYNC_EVENT_NAME:No,STYLE_SEGMENT_INDEX:{ATTR:0,ANIMATION:1,DDS_STYLE:2},getEvName:function(e){return wo[e]||"UNKNOWN_EVENT_"+e}},So=function(){function e(e,t,r){this._treeManager=e,this._arr=t,this._depth=0,this._startCb=r}return e.prototype.destroy=function(){this._treeManager=null,this._arr=null,this._startCb=null,this._depth=null},e.prototype._consumeHead=function(){return this._arr.shift()},e.prototype.nextStepType=function(){return this._arr[0][0]},e.prototype.nextStep=function(){for(;this._arr[0][0]===Co.SYNC_EVENT_NAME.FLOW_DEPTH;)this._startCb(this._treeManager);if(this._arr[0][0]!==Co.SYNC_EVENT_NAME.FLOW_REPEAT)return this._consumeHead();var e=this._arr[0][2];return--this._arr[0][1]||this._consumeHead(),[e]},e.prototype.nextStepIf=function(e){for(;this._arr[0][0]===Co.SYNC_EVENT_NAME.FLOW_DEPTH;)this._startCb(this._treeManager);return this._arr[0][0]===e?this._consumeHead():null},e.prototype.expectStart=function(){var e=this._consumeHead(),t=e[0],r=e[1],n=e[2];if(this._depth++,t!==Co.SYNC_EVENT_NAME.FLOW_DEPTH||r!==this._depth)throw new Error("Framework inner error (expect START descriptor with depth "+this._depth+" but get "+Co.getEvName(t)+")");return n},e.prototype.expectEnd=function(){for(;this._arr[0][0]===Co.SYNC_EVENT_NAME.FLOW_DEPTH&&this._arr[0][1]!==this._depth-1;)this._startCb(this._treeManager);var e=this._consumeHead(),t=e[0],r=e[1];if(this._depth--,t!==Co.SYNC_EVENT_NAME.FLOW_DEPTH||r!==this._depth)throw new Error("Framework inner error (expect END descriptor with depth "+this._depth+" but get "+Co.getEvName(t)+")")},e.prototype.skipToEnd=function(){for(;this._arr[0];)if(this._arr[0][0]!==Co.SYNC_EVENT_NAME.FLOW_DEPTH)this._consumeHead();else{if(this._arr[0][1]===this._depth-1)break;this._startCb(this._treeManager)}},e.prototype.getQueueLength=function(){return this._arr.length},e.prototype.getDepth=function(){return this._depth},e}(),Ao=pe("isConcatSpreadable"),To=j>=51||!a((function(){var e=[];return e[Ao]=!1,e.concat()[0]!==e})),Oo=qr("concat"),Io=function(e){if(!x(e))return!1;var t=e[Ao];return void 0!==t?!!t:Pr(e)};Vt({target:"Array",proto:!0,arity:1,forced:!To||!Oo},{concat:function(e){var t,r,n,o,i,a=re(this),s=Un(a,0),u=0;for(t=-1,n=arguments.length;t<n;t++)if(Io(i=-1===t?a:arguments[t]))for(o=vt(i),ao(u+o),r=0;r<o;r++,u++)r in i&&$r(s,u,i[r]);else ao(u+1),$r(s,u++,i);return s.length=u,s}});var xo=null,Do={},Mo=-1,Lo=null,Ro=[],Fo=null,Po=null,Vo=!1;function ko(e,t){void 0===t&&(t=0);var r,n=e.shift();if(Wo()||(t=0),__virtualDOMTunnelPrintLog__&&Yo(n,e,!1,t),""===n)return Mo=t,Lo&&Lo(t),0;Do[t]&&(r=Do[t][n]),!r&&Do.$GLOBAL&&(r=Do.$GLOBAL[n]),Jn(r)&&r(e,n,t)}function jo(){(xo=Wo()?__appServiceSDK__._virtualDOMTunnel:__webViewSDK__._virtualDOMTunnel).onVdSync((function(e,t){ko(e,t)})),xo.onVdSyncBatch((function(e,t){for(var r=0;r<e.length;r++)ko(e[r],t)}))}function Yo(e,t,r,n){void 0===n&&(n=0);Wo()}function Wo(){return __virtualDOMDataThread__}function Bo(){Po=Po&&clearTimeout(Po),Ro.length&&xo.vdSyncBatch(Ro,Fo),Fo=null,Ro.length=0,Vo=!1}function Ho(e,t,r,n){if(__virtualDOMTunnelPrintLog__&&Yo(0,0,0,r),t=[e].concat(t),!Vo||n)return Bo(),Vo=!0,void xo.vdSync(t,r);Fo!==r&&Bo(),Fo=r,Ro.push(t),Vo=!0,Po=Po||setTimeout((function(){Po=null,Bo()}),15)}function Uo(e,t,r){if(void 0===r&&(r=0),""===e)return Lo=t,void(0<=Mo&&Lo(Mo));Do[r]||(Do[r]={}),Do[r][e]=t}Wo()&&"undefined"!=typeof __clientsubcontext&&__clientsubcontext?__clientsubcontext.onInitReady(jo):jo();var Go=Math.floor,$o=m("".charAt),zo=m("".replace),qo=m("".slice),Xo=/\$([$&'`]|\d{1,2}|<[^>]*>)/g,Ko=/\$([$&'`]|\d{1,2})/g,Qo=function(e,t,r,n,o,i){var a=r+e.length,s=n.length,u=Ko;return void 0!==o&&(o=re(o),u=Xo),zo(i,u,(function(i,u){var l;switch($o(u,0)){case"$":return"$";case"&":return e;case"`":return qo(t,0,r);case"'":return qo(t,a);case"<":l=o[qo(u,1,-1)];break;default:var c=+u;if(0===c)return i;if(c>s){var d=Go(c/10);return 0===d?i:d<=s?void 0===n[d-1]?$o(u,1):n[d-1]+$o(u,1):i}l=n[c-1]}return void 0===l?"":l}))},Zo=pe("replace"),Jo=Math.max,ei=Math.min,ti=m([].concat),ri=m([].push),ni=m("".indexOf),oi=m("".slice),ii="$0"==="a".replace(/./,"$0"),ai=!!/./[Zo]&&""===/./[Zo]("a","$0");function si(e,t){var r=e.$$,n={};if(t.id&&(n.id=e.id),t.dataset&&(n.dataset=e.dataset),t.mark&&(n.mark=e.collectMarks()||{}),t.rect||t.size){var o=r.getBoundingClientRect();t.rect&&(n.left=o.left,n.right=o.right,n.top=o.top,n.bottom=o.bottom),t.size&&(n.width=o.width,n.height=o.height)}if(t.properties)for(var i=void 0,a=0,s=t.properties;a<s.length;a++)i=(i=s[a]).replace(/-([a-z])/g,(function(e,t){return t.toUpperCase()})),exparser.Component.hasPublicProperty(e,i)&&(n[i]=e[i]);if(t.scrollOffset)if(e.hasBehavior("dd-positioning-container")){var u=e.getScrollPosition();n.scrollLeft=u.scrollLeft,n.scrollTop=u.scrollTop,n.scrollWidth=u.scrollWidth,n.scrollHeight=u.scrollHeight}else n.scrollLeft=0,n.scrollTop=0,n.scrollWidth=0,n.scrollHeight=0;if(t.computedStyle&&t.computedStyle.length)for(var l=window.getComputedStyle(r),c=t.computedStyle.length,d=0,f=void 0;d<c;d++)(f=t.computedStyle[d])&&l[f]&&(n[f]=l[f]);return t.context&&(n.contextIs=e.is),t.node&&(n.nodeIs=e.is,n.nodeId="function"==typeof e.getContextId&&e.getContextId(),n.nodeCanvasId=e.canvasId||"",n.nodeCanvasType=e.type||""),n}Ar("replace",(function(e,t,r){var n=ai?"$":"$0";return[function(e,r){var n=T(this),o=null==e?void 0:q(e,Zo);return o?c(o,e,n,r):c(t,$t(n),e,r)},function(e,o){var i=Te(this),a=$t(e);if("string"==typeof o&&-1===ni(o,n)&&-1===ni(o,"$<")){var s=r(t,i,a,o);if(s.done)return s.value}var u=I(o);u||(o=$t(o));var l=i.global;if(l){var c=i.unicode;i.lastIndex=0}for(var d=[];;){var f=Fr(i,a);if(null===f)break;if(ri(d,f),!l)break;""===$t(f[0])&&(i.lastIndex=Lr(a,ht(i.lastIndex),c))}for(var p,_="",h=0,v=0;v<d.length;v++){for(var g=$t((f=d[v])[0]),E=Jo(ei(ct(f.index),a.length),0),m=[],y=1;y<f.length;y++)ri(m,void 0===(p=f[y])?p:String(p));var b=f.groups;if(u){var N=ti([g],m,E,a);void 0!==b&&ri(N,b);var w=$t(ln(o,void 0,N))}else w=Qo(g,a,E,m,b,o);E>=h&&(_+=oi(a,h,E)+w,h=E+g.length)}return _+oi(a,h)}]}),!!a((function(){var e=/./;return e.exec=function(){var e=[];return e.groups={a:"7"},e},"7"!=="".replace(e,"$<a>")}))||!ii||ai);var ui={},li={},ci={},di=!1;function fi(e){return{left:e.left,top:e.top,right:e.right,bottom:e.bottom,width:e.width,height:e.height}}function pi(e,t){var r={left:e.left<t.left?t.left:e.left,top:e.top<t.top?t.top:e.top,right:e.right>t.right?t.right:e.right,bottom:e.bottom>t.bottom?t.bottom:e.bottom,width:0,height:0};return r.right>r.left?r.width=r.right-r.left:r.right=r.left=r.bottom=r.top=0,r.bottom>r.top?r.height=r.bottom-r.top:r.right=r.left=r.bottom=r.top=0,r}"undefined"!=typeof window&&"undefined"!=typeof document&&"function"==typeof document.addEventListener&&(document.addEventListener("pageReRender",(function(){vi()})),window.addEventListener("scroll",(function(){vi()}),{capture:!0,passive:!0}));function _i(e){var t=e.targetNode,r=e.relatives,n=e.thresholds,o=e.minWidthOrHeight,i=e.cb,a=e.currentRatio,s=function(e){for(var t=document.documentElement.clientWidth,r=document.documentElement.clientHeight,n=null,o=0;o<e.length;o++){var i=e[o],a=i.node,s=i.margins,u=a?a.$$.getBoundingClientRect():{left:0,top:0,right:t,bottom:r,width:t,height:r},l={left:u.left-s.left,top:u.top-s.top,right:u.right+s.right,bottom:u.bottom+s.bottom};n=n?pi(u,l):l}return n}(r),u=fi(t.$$.getBoundingClientRect());u.right-u.left<o&&(u.right=u.left+o,u.width=o),u.bottom-u.top<o&&(u.bottom=u.top+o,u.height=o);var l=pi(s,u),c=u.width*u.height,d=c?l.width*l.height/c:0;e.currentRatio=d;var f=void 0===a;a!==d&&n.forEach((function(e){void 0!==a&&(d<=e&&e<=a||e<=d&&a<=e)&&(f=!0)})),f&&i.call(t,{id:t.id,dataset:t.dataset,time:Date.now(),boundingClientRect:u,intersectionRatio:d,intersectionRect:fi(l),relativeRect:s})}function hi(e,t,r,n,o){var i=e.querySelector(t)?[e.querySelector(t)]:[],a=n||{},s=a.observeAll?e.querySelectorAll(t):i,u=[];return r.forEach((function(t){var r=t.selector,n=t.margins,o=null==r?null:e.querySelector(r);if(o||null==r){var i=n||{};u.push({node:o,margins:{left:i.left||0,top:i.top||0,right:i.right||0,bottom:i.bottom||0}})}})),u.length,function(e,t,r,n,o,i){var a=ro();if(!e.length||!t.length)return a;var s=e.length;return ci[a]=s,e.forEach((function(e,u){var l=a+"#"+u,c={targetNode:e,relatives:t,thresholds:r,currentRatio:n,minWidthOrHeight:o,cb:i},d=exparser.Observer.create((function(e){"attached"===e.status?(ui[l]=c,requestAnimationFrame((function(){_i(c)}))):"detached"===e.status&&(delete ui[l],d.disconnect(),delete li[l],--s>0&&delete ci[a])}));(li[l]=d).observe(e,{attachStatus:!0}),exparser.Element.isAttached(e)&&(ui[l]=c,requestAnimationFrame((function(){_i(c)})))})),a}(s,u,a.thresholds||[0],a.initialRatio||0,a.minWidthOrHeight||0,o)}function vi(){di||(di=!0,requestAnimationFrame((function(){for(var e in di=!1,ui)_i(ui[e])})))}function gi(e,t,r){if("addIntersectionObserver"===e.type){var n=null;if(e.nodeId){var o=t.nodeId.getNodeById(e.nodeId);if(!o)return;n=o.shadowRoot}else e.pluginId||(n=window.__DOMTree__.shadowRoot);if(!n)return;return{observerId:hi(n,e.targetSelector,e.relativeInfo,e.options,(function(e){r({info:e})}))}}if("removeIntersectionObserver"===e.type)return function(e){var t=ci[e];delete ci[e];for(var r=0;r<t;r++){var n=e+"#"+r,o=li[n];if(!o)break;delete ui[n],o.disconnect(),delete li[n]}}(e.observerId),{reqEnd:!0}}var Ei=String,mi=TypeError,yi=Object.setPrototypeOf||("__proto__"in{}?function(){var e,t=!1,r={};try{(e=m(Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set))(r,[]),t=r instanceof Array}catch(e){}return function(r,n){return Te(r),function(e){if("object"==typeof e||I(e))return e;throw mi("Can't set "+Ei(e)+" as a prototype")}(n),t?e(r,n):r.__proto__=n,r}}():void 0),bi=function(e,t,r){var n,o;return yi&&I(n=t.constructor)&&n!==r&&x(o=n.prototype)&&o!==r.prototype&&yi(e,o),e},Ni=m(1..valueOf),wi="\t\n\v\f\r                　\u2028\u2029\ufeff",Ci=m("".replace),Si="["+wi+"]",Ai=RegExp("^"+Si+Si+"*"),Ti=RegExp(Si+Si+"*$"),Oi=function(e){return function(t){var r=$t(T(t));return 1&e&&(r=Ci(r,Ai,"")),2&e&&(r=Ci(r,Ti,"")),r}},Ii={start:Oi(1),end:Oi(2),trim:Oi(3)},xi=Ct.f,Di=we.f,Mi=Re.f,Li=Ii.trim,Ri="Number",Fi=i.Number,Pi=Fi.prototype,Vi=i.TypeError,ki=m("".slice),ji=m("".charCodeAt),Yi=function(e){var t=ve(e,"number");return"bigint"==typeof t?t:Wi(t)},Wi=function(e){var t,r,n,o,i,a,s,u,l=ve(e,"number");if(H(l))throw Vi("Cannot convert a Symbol value to a number");if("string"==typeof l&&l.length>2)if(l=Li(l),43===(t=ji(l,0))||45===t){if(88===(r=ji(l,2))||120===r)return NaN}else if(48===t){switch(ji(l,1)){case 66:case 98:n=2,o=49;break;case 79:case 111:n=8,o=55;break;default:return+l}for(a=(i=ki(l,2)).length,s=0;s<a;s++)if((u=ji(i,s))<48||u>o)return NaN;return parseInt(i,n)}return+l};if(Ft(Ri,!Fi(" 0o1")||!Fi("0b1")||Fi("+0x1"))){for(var Bi,Hi=function(e){var t=arguments.length<1?0:Fi(Yi(e)),r=this;return L(Pi,r)&&a((function(){Ni(r)}))?bi(Object(t),r,Hi):t},Ui=s?xi(Fi):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,isFinite,isInteger,isNaN,isSafeInteger,parseFloat,parseInt,fromString,range".split(","),Gi=0;Ui.length>Gi;Gi++)oe(Fi,Bi=Ui[Gi])&&!oe(Hi,Bi)&&Mi(Hi,Bi,Di(Fi,Bi));Hi.prototype=Pi,Pi.constructor=Hi,at(i,Ri,Hi,{constructor:!0})}function $i(e){return $i="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},$i(e)}function zi(){return zi=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var r=arguments[t];for(var n in r)Object.prototype.hasOwnProperty.call(r,n)&&(e[n]=r[n])}return e},zi.apply(this,arguments)}var qi=Ct.f,Xi="object"==typeof window&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[],Ki={f:function(e){return Xi&&"Window"==N(e)?function(e){try{return qi(e)}catch(e){return gn(Xi)}}(e):qi(O(e))}},Qi={f:pe},Zi=i,Ji=Re.f,ea=function(e){var t=Zi.Symbol||(Zi.Symbol={});oe(t,e)||Ji(t,e,{value:Qi.f(e)})},ta=Re.f,ra=pe("toStringTag"),na=function(e,t,r){e&&!r&&(e=e.prototype),e&&!oe(e,ra)&&ta(e,ra,{configurable:!0,value:t})},oa=zn.forEach,ia=qe("hidden"),aa="Symbol",sa=ot.set,ua=ot.getterFor(aa),la=Object.prototype,ca=i.Symbol,da=ca&&ca.prototype,fa=i.TypeError,pa=i.QObject,_a=we.f,ha=Re.f,va=Ki.f,ga=p.f,Ea=m([].push),ma=ee("symbols"),ya=ee("op-symbols"),ba=ee("wks"),Na=!pa||!pa.prototype||!pa.prototype.findChild,wa=s&&a((function(){return 7!=sr(ha({},"a",{get:function(){return ha(this,"a",{value:7}).a}})).a}))?function(e,t,r){var n=_a(la,t);n&&delete la[t],ha(e,t,r),n&&e!==la&&ha(la,t,n)}:ha,Ca=function(e,t){var r=ma[e]=sr(da);return sa(r,{type:aa,tag:e,description:t}),s||(r.description=t),r},Sa=function(e,t,r){e===la&&Sa(ya,t,r),Te(e);var n=ge(t);return Te(r),oe(ma,n)?(r.enumerable?(oe(e,ia)&&e[ia][n]&&(e[ia][n]=!1),r=sr(r,{enumerable:_(0,!1)})):(oe(e,ia)||ha(e,ia,_(1,{})),e[ia][n]=!0),wa(e,n,r)):ha(e,n,r)},Aa=function(e,t){Te(e);var r=O(t),n=Zt(r).concat(xa(r));return oa(n,(function(t){s&&!c(Ta,r,t)||Sa(e,t,r[t])})),e},Ta=function(e){var t=ge(e),r=c(ga,this,t);return!(this===la&&oe(ma,t)&&!oe(ya,t))&&(!(r||!oe(this,t)||!oe(ma,t)||oe(this,ia)&&this[ia][t])||r)},Oa=function(e,t){var r=O(e),n=ge(t);if(r!==la||!oe(ma,n)||oe(ya,n)){var o=_a(r,n);return!o||!oe(ma,n)||oe(r,ia)&&r[ia][n]||(o.enumerable=!0),o}},Ia=function(e){var t=va(O(e)),r=[];return oa(t,(function(e){oe(ma,e)||oe(Xe,e)||Ea(r,e)})),r},xa=function(e){var t=e===la,r=va(t?ya:O(e)),n=[];return oa(r,(function(e){!oe(ma,e)||t&&!oe(la,e)||Ea(n,ma[e])})),n};Y||(ca=function(){if(L(da,this))throw fa("Symbol is not a constructor");var e=arguments.length&&void 0!==arguments[0]?$t(arguments[0]):void 0,t=ue(e),r=function(e){this===la&&c(r,ya,e),oe(this,ia)&&oe(this[ia],t)&&(this[ia][t]=!1),wa(this,t,_(1,e))};return s&&Na&&wa(la,t,{configurable:!0,set:r}),Ca(t,e)},da=ca.prototype,at(da,"toString",(function(){return ua(this).tag})),at(ca,"withoutSetter",(function(e){return Ca(ue(e),e)})),p.f=Ta,Re.f=Sa,er.f=Aa,we.f=Oa,Ct.f=Ki.f=Ia,St.f=xa,Qi.f=function(e){return Ca(pe(e),e)},s&&(ha(da,"description",{configurable:!0,get:function(){return ua(this).description}}),at(la,"propertyIsEnumerable",Ta,{unsafe:!0}))),Vt({global:!0,constructor:!0,wrap:!0,forced:!Y,sham:!Y},{Symbol:ca}),oa(Zt(ba),(function(e){ea(e)})),Vt({target:aa,stat:!0,forced:!Y},{useSetter:function(){Na=!0},useSimple:function(){Na=!1}}),Vt({target:"Object",stat:!0,forced:!Y,sham:!s},{create:function(e,t){return void 0===t?sr(e):Aa(sr(e),t)},defineProperty:Sa,defineProperties:Aa,getOwnPropertyDescriptor:Oa}),Vt({target:"Object",stat:!0,forced:!Y},{getOwnPropertyNames:Ia}),function(){var e=M("Symbol"),t=e&&e.prototype,r=t&&t.valueOf,n=pe("toPrimitive");t&&!t[n]&&at(t,n,(function(e){return c(r,this)}),{arity:1})}(),na(ca,aa),Xe[ia]=!0;var Da=Y&&!!Symbol.for&&!!Symbol.keyFor,Ma=ee("string-to-symbol-registry"),La=ee("symbol-to-string-registry");Vt({target:"Symbol",stat:!0,forced:!Da},{for:function(e){var t=$t(e);if(oe(Ma,t))return Ma[t];var r=M("Symbol")(t);return Ma[t]=r,La[r]=t,r}});var Ra=ee("symbol-to-string-registry");Vt({target:"Symbol",stat:!0,forced:!Da},{keyFor:function(e){if(!H(e))throw TypeError(G(e)+" is not a symbol");if(oe(Ra,e))return Ra[e]}});var Fa=M("JSON","stringify"),Pa=m(/./.exec),Va=m("".charAt),ka=m("".charCodeAt),ja=m("".replace),Ya=m(1..toString),Wa=/[\uD800-\uDFFF]/g,Ba=/^[\uD800-\uDBFF]$/,Ha=/^[\uDC00-\uDFFF]$/,Ua=!Y||a((function(){var e=M("Symbol")();return"[null]"!=Fa([e])||"{}"!=Fa({a:e})||"{}"!=Fa(Object(e))})),Ga=a((function(){return'"\\udf06\\ud834"'!==Fa("\udf06\ud834")||'"\\udead"'!==Fa("\udead")})),$a=function(e,t){var r=Xr(arguments),n=t;if((x(t)||void 0!==e)&&!H(e))return Pr(t)||(t=function(e,t){if(I(n)&&(t=c(n,this,e,t)),!H(t))return t}),r[1]=t,ln(Fa,null,r)},za=function(e,t,r){var n=Va(r,t-1),o=Va(r,t+1);return Pa(Ba,e)&&!Pa(Ha,o)||Pa(Ha,e)&&!Pa(Ba,n)?"\\u"+Ya(ka(e,0),16):e};Fa&&Vt({target:"JSON",stat:!0,arity:3,forced:Ua||Ga},{stringify:function(e,t,r){var n=Xr(arguments),o=ln(Ua?$a:Fa,null,n);return Ga&&"string"==typeof o?ja(o,Wa,za):o}});var qa=!Y||a((function(){St.f(1)}));Vt({target:"Object",stat:!0,forced:qa},{getOwnPropertySymbols:function(e){var t=St.f;return t?t(re(e)):[]}});var Xa=Re.f,Ka=i.Symbol,Qa=Ka&&Ka.prototype;if(s&&I(Ka)&&(!("description"in Qa)||void 0!==Ka().description)){var Za={},Ja=function(){var e=arguments.length<1||void 0===arguments[0]?void 0:$t(arguments[0]),t=L(Qa,this)?new Ka(e):void 0===e?Ka():Ka(e);return""===e&&(Za[t]=!0),t};Ot(Ja,Ka),Ja.prototype=Qa,Qa.constructor=Ja;var es="Symbol(test)"==String(Ka("test")),ts=m(Qa.toString),rs=m(Qa.valueOf),ns=/^Symbol\((.*)\)[^)]+$/,os=m("".replace),is=m("".slice);Xa(Qa,"description",{configurable:!0,get:function(){var e=rs(this),t=ts(e);if(oe(Za,e))return"";var r=es?is(t,7,-1):os(t,ns,"$1");return""===r?void 0:r}}),Vt({global:!0,constructor:!0,forced:!0},{Symbol:Ja})}ea("iterator");var as=Re.f,ss=pe("unscopables"),us=Array.prototype;null==us[ss]&&as(us,ss,{configurable:!0,value:sr(null)});var ls,cs,ds,fs=function(e){us[ss][e]=!0},ps={},_s=pe("iterator"),hs=!1;[].keys&&("next"in(ds=[].keys())?(cs=Dn(Dn(ds)))!==Object.prototype&&(ls=cs):hs=!0);var vs=null==ls||a((function(){var e={};return ls[_s].call(e)!==e}));vs&&(ls={}),I(ls[_s])||at(ls,_s,(function(){return this}));var gs={IteratorPrototype:ls,BUGGY_SAFARI_ITERATORS:hs},Es=gs.IteratorPrototype,ms=function(){return this},ys=je.PROPER,bs=je.CONFIGURABLE,Ns=gs.IteratorPrototype,ws=gs.BUGGY_SAFARI_ITERATORS,Cs=pe("iterator"),Ss="keys",As="values",Ts="entries",Os=function(){return this},Is=function(e,t,r,n,o,i,a){!function(e,t,r,n){var o=t+" Iterator";e.prototype=sr(Es,{next:_(+!n,r)}),na(e,o,!1),ps[o]=ms}(r,t,n);var s,u,l,d=function(e){if(e===o&&g)return g;if(!ws&&e in h)return h[e];switch(e){case Ss:case As:case Ts:return function(){return new r(this,e)}}return function(){return new r(this)}},f=t+" Iterator",p=!1,h=e.prototype,v=h[Cs]||h["@@iterator"]||o&&h[o],g=!ws&&v||d(o),E="Array"==t&&h.entries||v;if(E&&(s=Dn(E.call(new e)))!==Object.prototype&&s.next&&(Dn(s)!==Ns&&(yi?yi(s,Ns):I(s[Cs])||at(s,Cs,Os)),na(s,f,!0)),ys&&o==As&&v&&v.name!==As&&(bs?Fe(h,"name",As):(p=!0,g=function(){return c(v,this)})),o)if(u={values:d(As),keys:i?g:d(Ss),entries:d(Ts)},a)for(l in u)(ws||p||!(l in h))&&at(h,l,u[l]);else Vt({target:t,proto:!0,forced:ws||p},u);return h[Cs]!==g&&at(h,Cs,g,{name:o}),ps[t]=g,u},xs=Re.f,Ds="Array Iterator",Ms=ot.set,Ls=ot.getterFor(Ds),Rs=Is(Array,"Array",(function(e,t){Ms(this,{type:Ds,target:O(e),index:0,kind:t})}),(function(){var e=Ls(this),t=e.target,r=e.kind,n=e.index++;return!t||n>=t.length?(e.target=void 0,{value:void 0,done:!0}):"keys"==r?{value:n,done:!1}:"values"==r?{value:t[n],done:!1}:{value:[n,t[n]],done:!1}}),"values"),Fs=ps.Arguments=ps.Array;if(fs("keys"),fs("values"),fs("entries"),s&&"values"!==Fs.name)try{xs(Fs,"name",{value:"values"})}catch(e){}var Ps=Dr.charAt,Vs="String Iterator",ks=ot.set,js=ot.getterFor(Vs);Is(String,"String",(function(e){ks(this,{type:Vs,string:$t(e),index:0})}),(function(){var e,t=js(this),r=t.string,n=t.index;return n>=r.length?{value:void 0,done:!0}:(e=Ps(r,n),t.index+=e.length,{value:e,done:!1})}));var Ys=pe("iterator"),Ws=pe("toStringTag"),Bs=Rs.values,Hs=function(e,t){if(e){if(e[Ys]!==Bs)try{Fe(e,Ys,Bs)}catch(t){e[Ys]=Bs}if(e[Ws]||Fe(e,Ws,t),po[t])for(var r in Rs)if(e[r]!==Rs[r])try{Fe(e,r,Rs[r])}catch(t){e[r]=Rs[r]}}};for(var Us in po)Hs(i[Us]&&i[Us].prototype,Us);Hs(vo,"DOMTokenList");var Gs=function(e,t,r){var n,o;Te(e);try{if(!(n=q(e,"return"))){if("throw"===t)throw r;return r}n=c(n,e)}catch(e){o=!0,n=e}if("throw"===t)throw r;if(o)throw n;return Te(n),r},$s=function(e,t,r,n){try{return n?t(Te(r)[0],r[1]):t(r)}catch(t){Gs(e,"throw",t)}},zs=pe("iterator"),qs=Array.prototype,Xs=function(e){return void 0!==e&&(ps.Array===e||qs[zs]===e)},Ks=pe("iterator"),Qs=function(e){if(null!=e)return q(e,Ks)||q(e,"@@iterator")||ps[Ut(e)]},Zs=TypeError,Js=function(e,t){var r=arguments.length<2?Qs(e):t;if(z(r))return Te(c(r,e));throw Zs(G(e)+" is not iterable")},eu=Array,tu=pe("iterator"),ru=!1;try{var nu=0,ou={next:function(){return{done:!!nu++}},return:function(){ru=!0}};ou[tu]=function(){return this},Array.from(ou,(function(){throw 2}))}catch(e){}var iu=function(e,t){if(!t&&!ru)return!1;var r=!1;try{var n={};n[tu]=function(){return{next:function(){return{done:r=!0}}}},e(n)}catch(e){}return r},au=!iu((function(e){Array.from(e)}));Vt({target:"Array",stat:!0,forced:au},{from:function(e){var t=re(e),r=Gr(this),n=arguments.length,o=n>1?arguments[1]:void 0,i=void 0!==o;i&&(o=Wn(o,n>2?arguments[2]:void 0));var a,s,u,l,d,f,p=Qs(t),_=0;if(!p||this===eu&&Xs(p))for(a=vt(t),s=r?new this(a):eu(a);a>_;_++)f=i?o(t[_],_):t[_],$r(s,_,f);else for(d=(l=Js(t,p)).next,s=r?new this:[];!(u=c(d,l)).done;_++)f=i?$s(l,o,[u.value,_],!0):u.value,$r(s,_,f);return s.length=_,s}});var su=function(e){return(su="function"==typeof Symbol&&"symbol"===$i(Symbol.iterator)?function(e){return $i(e)}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":$i(e)})(e)};function uu(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var lu={},cu=1;function du(e,t){function r(e){t({matches:e.matches})}var n=function(e){if("object"!==su(e))return"";var t="";return["minWidth","maxWidth","width","minHeight","maxHeight","height"].forEach((function(r){var n,o;void 0!==e[r]&&(0<=(n=Number(e[r]))||(n=""),o=r.replace(/[A-Z]/g,(function(e){return"-"+e.toLowerCase()})),t&&(t+=" and "),t=t+"("+o+": "+n+"px)")})).orientation.forEach((function(r){var n,o;void 0!==e[r]&&(n=/^[-_a-z0-9]+$/i.test(e[r])?e[r]:"",o=r.replace(/[A-Z]/g,(function(e){return"-"+e.toLowerCase()})),t&&(t+=" and "),t=t+"("+o+": "+n+")")})),t}(e),o=window.matchMedia(n),i=cu++;return lu[i]={observer:o,listener:r},o.addListener(r),t({matches:o.matches}),i}function fu(e,t){return"addMediaQueryObserver"===e.type?{observerId:du(e.mediaQueryCond,(function(e){t({info:e})}))}:"removeMediaQueryObserver"===e.type?(function(e){var t=lu[e],r=t.observer,n=t.listener;r.removeListener(n),delete lu[e]}(e.observerId),{reqEnd:!0}):void 0}var pu=function(){function e(t,r){var n=this;for(var o in this.flowSetData=function(e){n._pendingSetDataCallbacks.push(e[0])},this.viewInfoCb=function(e){n._received.length||n._blocked?n._fetchingViewInfoCallbacks.push(n.handleViewInfo.bind(n,e)):n.handleViewInfo(e)},this.handleViewInfo=function(e){var t=e[0],r=e[1],o=e[2],i=null;"selectorQuery"===t?i=function(e,t){for(var r=[],n=e.pluginId,o=0,i=e.queue;o<i.length;o++){var a=i[o],s=a.component,u=a.selector,l=a.single,c=a.fields,d=null;if(0===s){var f={};c.id&&(f.id=""),c.dataset&&(f.dataset={}),c.mark&&(f.mark={}),c.rect&&(f.left=0,f.right=0,f.top=0,f.bottom=0),c.size&&(f.width=document.documentElement.clientWidth,f.height=document.documentElement.clientHeight),c.scrollOffset&&(f.scrollLeft=document.documentElement.scrollLeft||document.body.scrollLeft||0,f.scrollTop=document.documentElement.scrollTop||document.body.scrollTop||0,f.scrollWidth=document.documentElement.scrollWidth||document.body.scrollWidth||0,f.scrollHeight=document.documentElement.scrollHeight||document.body.scrollHeight||0),d=f}else{var p=void 0,_=!1;if((p=t.nodeId.getNodeById(s))?(exparser.Component.getComponentOptions(p).writeOnly&&(_=!0),p=p.shadowRoot):n||(p=window.__DOMTree__?window.__DOMTree__.shadowRoot:null),l){var h=p&&!_?p.querySelector(u):null;d=h?si(h,c):null}else{var v=p&&!_?p.querySelectorAll(u):[];d=[];for(var g=0;g<v.length;g++)d.push(si(v[g],c))}}r.push(d)}return r}(r,n._treeManager):"intersection"===t?i=gi(r,n._treeManager,(function(e){Ho(Co.SYNC_EVENT_NAME.RESPONSE_VIEW_INFO,[e,o])})):"matchMedia"===t&&(i=fu(r,(function(e){Ho(Co.SYNC_EVENT_NAME.RESPONSE_VIEW_INFO,[e,o])}))),i&&Ho(Co.SYNC_EVENT_NAME.RESPONSE_VIEW_INFO,[i,o])},this.receiveSyncEvent=function(t,r){if(n._received.push(function(){for(var e=0,t=0,r=arguments.length;t<r;t++)e+=arguments[t].length;var n=Array(e),o=0;for(t=0;t<r;t++)for(var i=arguments[t],a=0,s=i.length;a<s;a++,o++)n[o]=i[a];return n}([r],t)),r===Co.SYNC_EVENT_NAME.FLOW_DEPTH&&(n._depth=t[0],0===n._depth)){var o=n._received;n._received=[],n._blocked?n._blocked.push(o):(n.iterator=new So(n._treeManager,o,e._startCb),e._startCb(n._treeManager),document.dispatchEvent(new CustomEvent("pageReRender",{})),Ho(Co.SYNC_EVENT_NAME.SET_DATA_CALLBACK,[n._pendingSetDataCallbacks],-1,!0),n._pendingSetDataCallbacks=[],n.checkDelayFetchingViewInfo())}},this._viewId=t,this._treeManager=r,this._depth=0,this._curWinSize=0,this._setDataCallbackInc=1,this._pendingSetDataCallbacks=[],this._setDataCallbackMap={},this._received=[],this._cache=[],this._blocked=[],this._fetchingViewInfoCallbacks=[],Co.SYNC_EVENT_NAME)if("FLOW_"===o.slice(0,5))switch(o){case"FLOW_SET_DATA":Uo(Co.SYNC_EVENT_NAME[o],this.flowSetData,t);break;case"FLOW_VIEW_INFO":Uo(Co.SYNC_EVENT_NAME[o],this.viewInfoCb,t);break;case"FLOW_SET_NODE_ANIMATION_INFO":case"FLOW_CLEAR_NODE_ANIMATION_INFO":case"FLOW_SET_NODE_NEXT_ANIMATION_INFO":break;default:Uo(Co.SYNC_EVENT_NAME[o],this.receiveSyncEvent,t)}Uo(Co.SYNC_EVENT_NAME.SET_DATA_CALLBACK,(function(e){n.triggerSetDataCallbacks(e[0])}),t)}return e.setStartOperation=function(t){e._startCb=t},e.prototype.destroy=function(){for(var e in this.flowSetData=null,this.viewInfoCb=null,this.receiveSyncEvent=null,delete this.flowSetData,delete this.viewInfoCb,delete this.receiveSyncEvent,this.iterator&&this.iterator.destroy(),this._pendingSetDataCallbacks=null,this._received=null,this._blocked=null,this._fetchingViewInfoCallbacks=null,this._cache=null,this._treeManager=null,this._setDataCallbackMap)delete this._setDataCallbackMap[e];this._setDataCallbackMap=null},e.prototype.flushBlocked=function(){if(this._blocked){for(;this._blocked.length;)try{var t=this._blocked.shift();this.iterator=new So(this._treeManager,t,e._startCb),e._startCb(this._treeManager),document.dispatchEvent(new CustomEvent("pageReRender",{}))}catch(e){}if(!this._blocked.length){var r=Wo()?this._treeManager.viewId:-1;Ho(Co.SYNC_EVENT_NAME.SET_DATA_CALLBACK,[this._pendingSetDataCallbacks],r,!0),this._pendingSetDataCallbacks=[],this.checkDelayFetchingViewInfo()}}},e.prototype.unblock=function(){this.flushBlocked(),this._blocked&&0===this._blocked.length&&(this._blocked=null)},e.prototype.block=function(){null===this._blocked&&(this._blocked=[])},e.prototype.start=function(){this.flush(),this._depth++,Ho(Co.SYNC_EVENT_NAME.FLOW_DEPTH,[this._depth,Date.now()],this._viewId)},e.prototype.dedupe=function(){var e=this._cache;if(this._curWinSize){if(2===e.length)if(e[0][0]===e[1][2])e.shift(),e[0][1]++;else Ho((r=e.pop()).shift(),r,this._viewId)}else{var t=e[0][0];if(e.length>2&&t===e[1][0]&&t===e[2][0]&&t!==Co.SYNC_EVENT_NAME.FLOW_SET_DATA&&t!==Co.SYNC_EVENT_NAME.FLOW_VIEW_INFO)e.splice(0,3),this.flush(),this._curWinSize=1,e.unshift([Co.SYNC_EVENT_NAME.FLOW_REPEAT,3,t]);else if(e.length>3){var r;Ho((r=e.pop()).shift(),r,this._viewId)}}},e.prototype.push=function(e){this._cache.unshift(e),1===e.length?this.dedupe():this.flush()},e.prototype.flush=function(){for(this._curWinSize=0;this._cache.length;){var e=this._cache.pop();Ho(e.shift(),e,this._viewId)}},e.prototype.end=function(){this.flush(),this._depth--,Ho(Co.SYNC_EVENT_NAME.FLOW_DEPTH,this._depth,this._viewId),0===this._depth&&Bo()},e.prototype.checkDelayFetchingViewInfo=function(){var e;this._fetchingViewInfoCallbacks.length&&(e=this._fetchingViewInfoCallbacks,this._fetchingViewInfoCallbacks=[],e.forEach((function(e){e()})))},e.prototype.registerSetDataCallback=function(e,t,r){var n=this._setDataCallbackInc++;this._setDataCallbackMap[n]=[e,t,r],this.push([Co.SYNC_EVENT_NAME.FLOW_SET_DATA,n])},e.prototype.triggerSetDataCallbacks=function(e){for(var t=0;t<e.length;t++){var r=e[t],n=this._setDataCallbackMap[r],o=n[0],i=n[1],a=n[2];delete this._setDataCallbackMap[r],exparser.safeCallback("SetData Callback",o,i,[],a)}},e}(),_u={};function hu(e,t){if(e){if(eo(e.childNodes))for(var r=0,n=e.childNodes;r<n.length;r++)hu(n[r],t);if(eo(e.__ddSlotChildren)){r=0;for(var o=e.__ddSlotChildren;r<o.length;r++)hu(o[r],t)}e.shadowRoot instanceof exparser.Element&&hu(e.shadowRoot,t),t(e)}}var vu=function(){function e(e){this.listenerInited=!1,this.root=null,this.tabRoot=null,this.tabDestroyed=!1,this.usedDef=null,this.tabUsedDef=null,this.statesData=null,this.operationFlow=new pu(e,this),this.nodeId=new oo,this.rootNodeId="",this.tabNodeId="",this.rootCompName="",this.tabCompName="",this.applyAnimationCbMap={},this.clearAnimationCbMap={},this.viewInfoCbMap={},this.initialRootData=null,this.lifetimeListener=null}return e.create=function(t){var r=new e(t);return r.viewId=t,_u[t]=r,r},e.destroy=function(e){var t=_u[e],r=t.nodeId;hu(t.root,(function(e){r.removeNode(e),e.destroy(!0)})),exparser.Element.delayDestroy(e),r=null,t.destroy(),t=null,_u[e]=null,dd&&Jn(dd.triggerGC)&&dd.triggerGC()},e.get=function(e){return _u[e]},e.listViewId=function(){var e=[];for(var t in _u)e.push(_u[t].viewId);return e},e.list=function(){var e=[];for(var t in _u)e.push(_u[t]);return e},e.prototype.destroy=function(){if(this.listenerInited=null,this.root=null,this.tabRoot=null,this.tabDestroyed=null,this.usedDef=null,this.tabUsedDef=null,this.statesData=null,this.operationFlow&&this.operationFlow.destroy(),this.operationFlow=null,this.nodeId&&this.nodeId.destroy(),this.nodeId=null,this.rootNodeId=null,this.tabNodeId=null,this.rootCompName=null,this.tabCompName=null,this.applyAnimationCbMap=null,this.clearAnimationCbMap=null,this.viewInfoCbMap)for(var e in this.viewInfoCbMap)this.viewInfoCbMap[e]=null;this.viewInfoCbMap=null,this.initialRootData=null,this.lifetimeListener=null,this.viewId=null},e}(),gu=null;function Eu(){gu={};var e,t=null;__ddConfig&&__ddConfig.plugins?t=__ddConfig.plugins:"undefined"!=typeof window&&window&&window.__ddConfigAppService__&&window.__ddConfigAppService__.plugins&&(t=window.__ddConfigAppService__.plugins);var r=!1;if(t)for(var n in t){var o=t[n],i=o.provider,a=o.subpackage,s=void 0;void 0!==a&&(r=!0,"__APP__"===(s=a||"")&&(s=""),"/"===s[0]&&s.slice(1),s&&"/"!==s.slice(-1)&&(s+="/"),gu[i]=s)}if(!r){if(__ddConfig&&__ddConfig.subPackages)e=__ddConfig.subPackages;else{if("undefined"==typeof window||!window||!window.__subPackages)return;e=window.__subPackages}if(eo(e))for(var u=0,l=e;u<l.length;u++){var c=l[u],d=(i=void 0,c.root||"");if(d&&"/"!==d.slice(-1)&&(d+="/"),c.plugins)for(var n in c.plugins)Object.prototype.hasOwnProperty.call(c.plugins,n)&&(i=c.plugins[n]&&c.plugins[n].provider,gu[i]=d)}}}function mu(e){var t=e.match(/(?:^|\/)__(dd|plugin)__\/(.*)$/);return t?"dd"===t[1]?"dd://"+t[2]:"plugin-private://"+t[2]:e}function yu(e){return gu[e]||""}var bu=0;function Nu(){return bu=Date.now()+Math.random()}function wu(){return!!bu}function Cu(e){bu===e&&(bu=0)}function Su(e){var t,r=Nu();try{t=e(r)}catch(e){throw setTimeout((function(){Cu(r)}),0),e}return setTimeout((function(){Cu(r)}),0),t}var Au=a((function(){if("function"==typeof ArrayBuffer){var e=new ArrayBuffer(8);Object.isExtensible(e)&&Object.defineProperty(e,"a",{value:8})}})),Tu=Object.isExtensible,Ou=a((function(){Tu(1)}))||Au?function(e){return!!x(e)&&((!Au||"ArrayBuffer"!=N(e))&&(!Tu||Tu(e)))}:Tu,Iu=!a((function(){return Object.isExtensible(Object.preventExtensions({}))})),xu=t((function(e){var t=Re.f,r=!1,n=ue("meta"),o=0,i=function(e){t(e,n,{value:{objectID:"O"+o++,weakData:{}}})},a=e.exports={enable:function(){a.enable=function(){},r=!0;var e=Ct.f,t=m([].splice),o={};o[n]=1,e(o).length&&(Ct.f=function(r){for(var o=e(r),i=0,a=o.length;i<a;i++)if(o[i]===n){t(o,i,1);break}return o},Vt({target:"Object",stat:!0,forced:!0},{getOwnPropertyNames:Ki.f}))},fastKey:function(e,t){if(!x(e))return"symbol"==typeof e?e:("string"==typeof e?"S":"P")+e;if(!oe(e,n)){if(!Ou(e))return"F";if(!t)return"E";i(e)}return e[n].objectID},getWeakData:function(e,t){if(!oe(e,n)){if(!Ou(e))return!0;if(!t)return!1;i(e)}return e[n].weakData},onFreeze:function(e){return Iu&&r&&Ou(e)&&!oe(e,n)&&i(e),e}};Xe[n]=!0})),Du=TypeError,Mu=function(e,t){this.stopped=e,this.result=t},Lu=Mu.prototype,Ru=function(e,t,r){var n,o,i,a,s,u,l,d=r&&r.that,f=!(!r||!r.AS_ENTRIES),p=!(!r||!r.IS_RECORD),_=!(!r||!r.IS_ITERATOR),h=!(!r||!r.INTERRUPTED),v=Wn(t,d),g=function(e){return n&&Gs(n,"normal",e),new Mu(!0,e)},E=function(e){return f?(Te(e),h?v(e[0],e[1],g):v(e[0],e[1])):h?v(e,g):v(e)};if(p)n=e.iterator;else if(_)n=e;else{if(!(o=Qs(e)))throw Du(G(e)+" is not iterable");if(Xs(o)){for(i=0,a=vt(e);a>i;i++)if((s=E(e[i]))&&L(Lu,s))return s;return new Mu(!1)}n=Js(e,o)}for(u=p?e.next:n.next;!(l=c(u,n)).done;){try{s=E(l.value)}catch(e){Gs(n,"throw",e)}if("object"==typeof s&&s&&L(Lu,s))return s}return new Mu(!1)},Fu=TypeError,Pu=function(e,t){if(L(t,e))return e;throw Fu("Incorrect invocation")},Vu=function(e,t,r){var n=-1!==e.indexOf("Map"),o=-1!==e.indexOf("Weak"),s=n?"set":"add",u=i[e],l=u&&u.prototype,c=u,d={},f=function(e){var t=m(l[e]);at(l,e,"add"==e?function(e){return t(this,0===e?0:e),this}:"delete"==e?function(e){return!(o&&!x(e))&&t(this,0===e?0:e)}:"get"==e?function(e){return o&&!x(e)?void 0:t(this,0===e?0:e)}:"has"==e?function(e){return!(o&&!x(e))&&t(this,0===e?0:e)}:function(e,r){return t(this,0===e?0:e,r),this})};if(Ft(e,!I(u)||!(o||l.forEach&&!a((function(){(new u).entries().next()})))))c=r.getConstructor(t,e,n,s),xu.enable();else if(Ft(e,!0)){var p=new c,_=p[s](o?{}:-0,1)!=p,h=a((function(){p.has(1)})),v=iu((function(e){new u(e)})),g=!o&&a((function(){for(var e=new u,t=5;t--;)e[s](t,t);return!e.has(-0)}));v||((c=t((function(e,t){Pu(e,l);var r=bi(new u,e,c);return null!=t&&Ru(t,r[s],{that:r,AS_ENTRIES:n}),r}))).prototype=l,l.constructor=c),(h||g)&&(f("delete"),f("has"),n&&f("get")),(g||_)&&f(s),o&&l.clear&&delete l.clear}return d[e]=c,Vt({global:!0,constructor:!0,forced:c!=u},d),na(c,e),o||r.setStrong(c,e,n),c},ku=function(e,t,r){for(var n in t)at(e,n,t[n],r);return e},ju=pe("species"),Yu=function(e){var t=M(e),r=Re.f;s&&t&&!t[ju]&&r(t,ju,{configurable:!0,get:function(){return this}})},Wu=Re.f,Bu=xu.fastKey,Hu=ot.set,Uu=ot.getterFor,Gu={getConstructor:function(e,t,r,n){var o=e((function(e,o){Pu(e,i),Hu(e,{type:t,index:sr(null),first:void 0,last:void 0,size:0}),s||(e.size=0),null!=o&&Ru(o,e[n],{that:e,AS_ENTRIES:r})})),i=o.prototype,a=Uu(t),u=function(e,t,r){var n,o,i=a(e),u=l(e,t);return u?u.value=r:(i.last=u={index:o=Bu(t,!0),key:t,value:r,previous:n=i.last,next:void 0,removed:!1},i.first||(i.first=u),n&&(n.next=u),s?i.size++:e.size++,"F"!==o&&(i.index[o]=u)),e},l=function(e,t){var r,n=a(e),o=Bu(t);if("F"!==o)return n.index[o];for(r=n.first;r;r=r.next)if(r.key==t)return r};return ku(i,{clear:function(){for(var e=a(this),t=e.index,r=e.first;r;)r.removed=!0,r.previous&&(r.previous=r.previous.next=void 0),delete t[r.index],r=r.next;e.first=e.last=void 0,s?e.size=0:this.size=0},delete:function(e){var t=this,r=a(t),n=l(t,e);if(n){var o=n.next,i=n.previous;delete r.index[n.index],n.removed=!0,i&&(i.next=o),o&&(o.previous=i),r.first==n&&(r.first=o),r.last==n&&(r.last=i),s?r.size--:t.size--}return!!n},forEach:function(e){for(var t,r=a(this),n=Wn(e,arguments.length>1?arguments[1]:void 0);t=t?t.next:r.first;)for(n(t.value,t.key,this);t&&t.removed;)t=t.previous},has:function(e){return!!l(this,e)}}),ku(i,r?{get:function(e){var t=l(this,e);return t&&t.value},set:function(e,t){return u(this,0===e?0:e,t)}}:{add:function(e){return u(this,e=0===e?0:e,e)}}),s&&Wu(i,"size",{get:function(){return a(this).size}}),o},setStrong:function(e,t,r){var n=t+" Iterator",o=Uu(t),i=Uu(n);Is(e,t,(function(e,t){Hu(this,{type:n,target:e,state:o(e),kind:t,last:void 0})}),(function(){for(var e=i(this),t=e.kind,r=e.last;r&&r.removed;)r=r.previous;return e.target&&(e.last=r=r?r.next:e.state.first)?"keys"==t?{value:r.key,done:!1}:"values"==t?{value:r.value,done:!1}:{value:[r.key,r.value],done:!1}:(e.target=void 0,{value:void 0,done:!0})}),r?"entries":"values",!r,!0),Yu(t)}};Vu("Set",(function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}}),Gu);var $u=zn.filter,zu=qr("filter");Vt({target:"Array",proto:!0,forced:!zu},{filter:function(e){return $u(this,e,arguments.length>1?arguments[1]:void 0)}});var qu=Re.f,Xu=function(e,t,r){r in e||qu(e,r,{configurable:!0,get:function(){return t[r]},set:function(e){t[r]=e}})},Ku=Ct.f,Qu=ot.enforce,Zu=pe("match"),Ju=i.RegExp,el=Ju.prototype,tl=i.SyntaxError,rl=m(el.exec),nl=m("".charAt),ol=m("".replace),il=m("".indexOf),al=m("".slice),sl=/^\?<[^\s\d!#%&*+<=>@^][^\s!#%&*+<=>@^]*>/,ul=/a/g,ll=/a/g,cl=new Ju(ul)!==ul,dl=Qt.MISSED_STICKY,fl=Qt.UNSUPPORTED_Y,pl=s&&(!cl||dl||lr||dr||a((function(){return ll[Zu]=!1,Ju(ul)!=ul||Ju(ll)==ll||"/a/i"!=Ju(ul,"i")})));if(Ft("RegExp",pl)){for(var _l=function(e,t){var r,n,o,i,a,s,u=L(el,this),l=dn(e),c=void 0===t,d=[],f=e;if(!u&&l&&c&&e.constructor===_l)return e;if((l||L(el,e))&&(e=e.source,c&&(t=Rn(f))),e=void 0===e?"":$t(e),t=void 0===t?"":$t(t),f=e,lr&&"dotAll"in ul&&(n=!!t&&il(t,"s")>-1)&&(t=ol(t,/s/g,"")),r=t,dl&&"sticky"in ul&&(o=!!t&&il(t,"y")>-1)&&fl&&(t=ol(t,/y/g,"")),dr&&(i=function(e){for(var t,r=e.length,n=0,o="",i=[],a={},s=!1,u=!1,l=0,c="";n<=r;n++){if("\\"===(t=nl(e,n)))t+=nl(e,++n);else if("]"===t)s=!1;else if(!s)switch(!0){case"["===t:s=!0;break;case"("===t:rl(sl,al(e,n+1))&&(n+=2,u=!0),o+=t,l++;continue;case">"===t&&u:if(""===c||oe(a,c))throw new tl("Invalid capture group name");a[c]=!0,i[i.length]=[c,l],u=!1,c="";continue}u?c+=t:o+=t}return[o,i]}(e),e=i[0],d=i[1]),a=bi(Ju(e,t),u?this:el,_l),(n||o||d.length)&&(s=Qu(a),n&&(s.dotAll=!0,s.raw=_l(function(e){for(var t,r=e.length,n=0,o="",i=!1;n<=r;n++)"\\"!==(t=nl(e,n))?i||"."!==t?("["===t?i=!0:"]"===t&&(i=!1),o+=t):o+="[\\s\\S]":o+=t+nl(e,++n);return o}(e),r)),o&&(s.sticky=!0),d.length&&(s.groups=d)),e!==f)try{Fe(a,"source",""===f?"(?:)":f)}catch(e){}return a},hl=Ku(Ju),vl=0;hl.length>vl;)Xu(_l,Ju,hl[vl++]);el.constructor=_l,_l.prototype=el,at(i,"RegExp",_l,{constructor:!0})}Yu("RegExp");var gl=Math.min,El=[].lastIndexOf,ml=!!El&&1/[1].lastIndexOf(1,-0)<0,yl=en("lastIndexOf"),bl=ml||!yl?function(e){if(ml)return ln(El,this,arguments)||0;var t=O(this),r=vt(t),n=r-1;for(arguments.length>1&&(n=gl(n,ct(arguments[1]))),n<0&&(n=r+n);n>=0;n--)if(n in t&&t[n]===e)return n||0;return-1}:El;Vt({target:"Array",proto:!0,forced:bl!==[].lastIndexOf},{lastIndexOf:bl});var Nl=!0,wl=Object.create(null);function Cl(){return Nl}var Sl={},Al=function(){return this}();try{Al=globalThis||new Function("return this")()}catch(e){"object"===("undefined"==typeof window?"undefined":$i(window))&&(Al=window)}var Tl=Al,Ol=Ki.f,Il=a((function(){return!Object.getOwnPropertyNames(1)}));Vt({target:"Object",stat:!0,forced:Il},{getOwnPropertyNames:Ol});var xl,Dl=je.PROPER,Ml=Ii.trim;Vt({target:"String",proto:!0,forced:(xl="trim",a((function(){return!!wi[xl]()||"​᠎"!=="​᠎"[xl]()||Dl&&wi[xl].name!==xl})))},{trim:function(){return Ml(this)}});var Ll=Ii.trim,Rl=i.parseInt,Fl=i.Symbol,Pl=Fl&&Fl.iterator,Vl=/^[+-]?0x/i,kl=m(Vl.exec),jl=8!==Rl(wi+"08")||22!==Rl(wi+"0x16")||Pl&&!a((function(){Rl(Object(Pl))}))?function(e,t){var r=Ll($t(e));return Rl(r,t>>>0||(kl(Vl,r)?16:10))}:Rl;Vt({global:!0,forced:parseInt!=jl},{parseInt:jl});var Yl=xu.onFreeze,Wl=Object.freeze,Bl=a((function(){Wl(1)}));Vt({target:"Object",stat:!0,forced:Bl,sham:!Iu},{freeze:function(e){return Wl&&x(e)?Wl(Yl(e)):e}});var Hl={restoring:null,idDataMap:null,compIdArr:null,compExtraDataMap:null,compIdArrIndex:0};function Ul(e,t,r){var n;void 0===e.__resizers&&(e.__resizers=[],n=e,exparser.Observer.create((function(e){e.status})).observe(n,{attachStatus:!0})),e.__resizers[t]=r}var Gl=null,$l=!1,zl=!1,ql=[],Xl=null,Kl=[],Ql=0,Zl=null,Jl=Object.prototype.hasOwnProperty;function ec(e){return e instanceof exparser.Component&&exparser.Component.getComponentOptions(e).domain}function tc(e,t){var r=this;if(e){var n,o=e,i=ec(o),a=(n=o)instanceof exparser.Component&&"//"===exparser.Component.getComponentOptions(n).domain,s={selectAllComponents:function(r){if(t!==i)return[];var n=zl?e.shadowRoot.querySelectorAll(r):e.querySelectorAll(r),o=[];return n.forEach((function(e){o.push(nc(tc(e,t),!0))})),o},selectComponent:function(r){if(t!==i)return null;var n=zl?e.shadowRoot.querySelector(r):e.querySelector(r);return n?nc(tc(n,t),!0):null},removeClass:function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];if(Wo()||!o||!e.length)return r;var n=o.__wxsClass?o.__wxsClass.split(/\s+/):[],i=[];return e.forEach((function(e){(e=e.replace(/^\s+|\s+$/g,""))&&o.classList.contains(e)&&(o.classList.toggle(e),$l=!0,i.push(e))})),i.forEach((function(e){n.forEach((function(t,r){return t!==e||(n.splice(r,1),!1)}))})),o.__wxsClass=n.join(" "),r},addClass:function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];if(Wo()||!o||!e.length)return r;var n=o.__wxsClass||"",i=[];return e.forEach((function(e){(e=e.replace(/^\s+|\s+$/g,""))&&(o.classList.contains(e)||(o.classList.toggle(e),i.push(e),$l=!0))})),o.__wxsClass=n+(n?" ":"")+i.join(" "),r},hasClass:function(e){return!(Wo()||!o)&&o.classList.contains(e)},setStyle:function(e){if(Wo()||!o)return r;if(e===o.__wxsStyle)return r;var t=[];if("object"===su(e))for(var n in e=e?oc(e):{})Jl.call(e,n)&&t.push(n+":"+e[n]);else t=[String(e)];function i(){var e=dd.transformRpx(o.__wxsStyle,!0);o.setNodeStyle(e,Co.STYLE_SEGMENT_INDEX.DDS_STYLE)}return o.__wxsStyle=t.join(";"),i(),Ul(o,Co.STYLE_SEGMENT_INDEX.DDS_STYLE,i),$l=!0,r},getDataset:function(){return o?nc(o.dataset):null},getState:function(){return o?(o.__wxsState=o.__wxsState||{},o.__wxsState):null},triggerEvent:function(t,n,i){return!a&&e&&(n=n?oc(n):n,i=i?oc(i):i,Ql++,o.triggerEvent(t,n,i),Ql--),r},callMethod:function(t,n){var o,i,a=n||{};return!Wo()&&t&&(a=oc(a),zl?Ho(Co.SYNC_EVENT_NAME.CALL_METHOD_FROM_DDS,[null===(o=window.nativeParam)||void 0===o?void 0:o.webViewId,e&&e.__ddTmplId||0,t,a,wu()]):dd.callMethodFromWxs([(null===(i=window.nativeParam)||void 0===i||i.webViewId,e&&e.__ddTmplId||0),t,a,wu()])),r},requestAnimationFrame:function(e){if(!Wo()&&"function"==typeof e){var t=e;Wo()||"function"!=typeof t||(ql.push(t),Xl||window.requestAnimationFrame((function(){Xl=null;var e=ql;ql=[],e.forEach((function(e){e(),ac()}))})))}return r},getComputedStyle:function(e){Array.isArray(e)||(e=[]);var t={computedStyle:e.filter((function(e){return"string"==typeof e}))};return nc(si(o,t))},animate:function(){},clearAnimation:function(e,t){var r=Math.random()+"-"+ +new Date,n=vu.instance;"function"==typeof t?(e=oc(e),n.clearAnimationCbMap[r]=t):"function"==typeof e&&(n.clearAnimationCbMap[r]=e)}};return Object.freeze(s),s}}function rc(){return"function"==typeof Gl?Gl:null}function nc(e,t){return Gl?Gl(e,"nv_",t?2:void 0):e}function oc(e,t){var r;return 1<arguments.length&&t&&(r=2),Gl?Gl(e,void 0,r):e}function ic(e,t,r){return t?r?t+e+r:t||"":r||""}function ac(){!Wo()&&$l&&0===Ql&&($l=!1,document.dispatchEvent(new CustomEvent("pageReRender",{})))}function sc(e,t){var r=e.ownerShadowRoot?e.ownerShadowRoot.__ddHost:window.__DOMTree__,n=t?r:e;return zl=!!e.ownerShadowRoot,tc(n,ec(n))}function uc(e){var t=e[0],r=e[1],n=e[2],o=e[3],i=void 0===o?{}:o,a=e[4];if(r){var s=vu.get(t);if(!s)return;var u=s.nodeId.getNodeById(r);if(!u)return;var l=exparser.Element.getMethodCaller(u);l&&"function"==typeof l[n]&&(a?Su((function(){l[n](i)})):l[n](i))}else{var c=__appServiceEngine__.getCurrentPagesByDomain("");if(!c.length)return;var d=c[c.length-1];d&&"function"==typeof d[n]&&(a?Su((function(){d[n](i)})):d[n](i))}}function lc(e,t,r){if(e){var n=null;if(t.ownerShadowRoot&&vu.instance&&e._custom){var o=vu.instance.nodeId.getNodeId(t.ownerShadowRoot.__ddHost);if(!(e=e._custom)[o])return;e=e[o]}var i=t.is;if(e[i]&&e[i].length&&e[i][0]&&e[i][0].index===r&&(n=e[i].shift()),n){if(t.__ddsStyle=n.ddsStyle,t.__ddsClass=n.ddsClass,t.__ddsState=nc(n.ddsState),n.ddsStyle){var a=function(){var e=window.dd.transformRpx(t.__ddsStyle,!0);t.setNodeStyle(e,Co.STYLE_SEGMENT_INDEX.DDS_STYLE)};a(),Ul(t,Co.STYLE_SEGMENT_INDEX.DDS_STYLE,a)}n.ddsClass&&(t.class=ic(" ",t.class,n.ddsClass))}}}Wo()&&__appServiceSDK__.onCallMethodFromWxs(uc);var cc=null,dc=null;function fc(e){e.$$.style.display="none"}function pc(e){if(e instanceof exparser.Component)fc(e);else if(e instanceof exparser.VirtualNode)for(var t=0;t<e.childNodes.length;t++)pc(e.childNodes[t]);else e instanceof exparser.TextNode&&(e.textContent="");e.__banned=!0}function _c(e){var t,r;e&&(cc&&(t=exparser.Component.getComponentOptions(e).domain.split("/",1)[0],r=e.shadowRoot,cc[t]&&function(e,t){pc(e),dc=dc||exparser.registerElement({options:{renderingMode:"native"}});var r=e.createComponent("dd-hint",dc),n=document.createElement("div");n.innerText=t.hint,r.$$.appendChild(n),e.appendChild(r)}(r,cc[t])))}var hc={},vc=void 0!==dd&&dd.transformRpx,gc=/-[a-z]/g,Ec=/([A-Z])/g;function mc(e){return hc[e]||(hc[e]=e.replace(Ec,"-$1").toLowerCase()),hc[e]}function yc(e){return Wo()&&e instanceof exparser.Component?vu.get(e.__ddWebViewId__).nodeId.getNodeById(e.__ddExparserNodeId__):e}function bc(e,t,r){var n=yc(e);return r&&n instanceof exparser.VirtualNode&&!n.id&&!Object.getOwnPropertyNames(n.dataset).length&&(n=yc(r)),{id:t?"":n.id,offsetLeft:n.$$&&!t?n.$$.offsetLeft:0,offsetTop:n.$$&&!t?n.$$.offsetTop:0,dataset:t?{}:n.dataset}}function Nc(e,t,r){var n=yc(e);return r&&n instanceof exparser.VirtualNode&&!n.id&&!Object.getOwnPropertyNames(n.dataset).length&&(n=yc(r)),{id:t?"":n.id,dataset:t?{}:n.dataset}}function wc(e){if(e){for(var t=[],r=0,n=e;r<n.length;r++){var o=n[r];t.push({identifier:o.identifier,pageX:o.pageX,pageY:o.pageY,clientX:o.clientX,clientY:o.clientY,force:o.force||0})}return t}}function Cc(e,t,r,n,o,i,a){var s=o?"__ddEventCaptureHandleName":"__ddEventHandleName";e[s]||(e[s]=Object.create(null)),void 0===e[s][t]&&e.addListener(t,(function(r){var o=e[s][t],u=r.mutatedMarked();if((!a||!u)&&(a&&r.markMutated(),o)){r._hasListeners=!0;var l=e.ownerShadowRoot;if(l){var c=l.getHostNode();if(!c)return;var d=exparser.Component.getComponentOptions(c).writeOnly;if(!d||r._allowWriteOnly)if(Wo()){if(i&&Jn(o))return;var f=exparser.Element.getMethodCaller(c);Jn(f[o])&&f[o]({type:r.type,timeStamp:r.timeStamp,target:Nc(r.target,d,this),currentTarget:Nc(this,d,null),mark:r.mark,detail:r.detail,touches:r.touches,changedTouches:r.changedTouches,mut:u,_requireActive:r._requireActive})}else if(i){if(Jn(o)&&rc()){var p={type:r.type,timeStamp:r.timeStamp,target:bc(r.target,d,this),currentTarget:bc(this,d,null),mark:r.mark,detail:r.detail,touches:wc(r.touches),changedTouches:wc(r.changedTouches),mut:u};p.instance=sc(e);var _=o(nc(p,!0),nc(sc(e,!0),!0));if(ac(),!1===_)return _}}else{var h={type:r.type,timeStamp:r.timeStamp,target:bc(r.target,d,this),currentTarget:bc(this,d,null),mark:r.mark,detail:r.detail,touches:wc(r.touches),changedTouches:wc(r.changedTouches),mut:u,_requireActive:r._requireActive,_relatedInfo:r._relatedInfo,_userTap:wu()};Ho(Co.SYNC_EVENT_NAME.DD_EVENT,[vu.instance.nodeId.getNodeId(c),o,h],void 0,!!r._requireActive||void 0)}}if(n)return!1}}),{capture:o}),i?e[s][t]=r:(e[s][t]=null==r?"":String(r),Jn(e.__eventHandlerChangeListener__)&&e.__eventHandlerChangeListener__(r,e[s][t],o))}function Sc(e,t,r,n){if(e){e.dataset=e.dataset||{};var o=0,i=!1,a=[],s=e instanceof exparser.Component,u=s&&"//"===exparser.Component.getComponentOptions(e).domain,l=exparser.Component.getDataProxy(e);for(var c in t)v(c);i&&l.doUpdates(o,!Wo());for(var d,f,p=function(t){e.__ddPropertyListener__&&e.__ddPropertyListener__[t]||(e.setPropertyChangeListener(t,(function(r){var n=e.ownerShadowRoot.getHostNode();if(Wo())n.setData(uu({},e.__modelValueName[t],r));else{var o=vu.instance.nodeId.getNodeId(n);Ho(Co.SYNC_EVENT_NAME.MODEL_VALUE_CHANGE,{data:r,modelValueName:e.__modelValueName&&e.__modelValueName[t],nodeId:o})}})),e.__ddPropertyListener__=e.__ddPropertyListener__||{},e.__ddPropertyListener__[t]=!0)},_=0,h=a;_<h.length;_++){p(h[_])}if(!Wo()&&e.ddsObserver&&rc()&&(f=t,!(d=e).ddsObserver||Wo()||Hl.restoring||(Kl.push({node:d,props:f}),Zl=Zl||window.requestAnimationFrame((function(){Zl=null;var e=Kl;Kl=[],e.forEach((function(e){var t;for(t in d.node.ddsObserver){var r=void 0;Jl.call(d.props,t)&&e.ddsObserver[t]&&"function"==typeof e.ddsObserver[t].observer&&(r=e.ddsObserver[t].value,exparser.safeCallback("DDS Observer",e.ddsObserver[t].observer,null,[nc(d.props[t]),nc(r),nc(sc(e,!0),!0),nc(sc(e),!0)],e.ownerShadowRoot?e.ownerShadowRoot.__ddHost:void 0),e.ddsObserver[t].value=d.props[t])}}))})))),e.__component__&&!Hl.restoring)if(Wo())e.__treeManager__.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_APPLY_PROPERTY]);else if(vu.instance.operationFlow.iterator.nextStep()[0]!==Co.SYNC_EVENT_NAME.FLOW_APPLY_PROPERTY)throw new Error("Framework inner error (expect FLOW_APPLY_PROPERTY but get another)")}function v(c){var d,f,p,_,h,v=t[c],g=null,E=function(e){return null==e?"":e};if("slot"===e.is&&e instanceof exparser.VirtualNode&&"name"===c)return exparser.Element.setSlotName(e,v),"continue";if("id"===c)return e.id=E(v),"continue";if("slot"===c)return e.slot=E(v),"continue";if("class"===c&&s&&(e.class=e.__ddsClass?ic(" ",E(v),e.__ddsClass):E(v),e.hasExternalClass("class")&&e.setExternalClass("class",v)),"style"===c&&s&&e.$$&&(d=vc(v,!0),e.setNodeStyle(d,Co.STYLE_SEGMENT_INDEX.ATTR),d===v?(p=e,_=Co.STYLE_SEGMENT_INDEX.ATTR,void 0!==p.__resizers&&(p.__resizers[_]=void 0)):Ul(e,Co.STYLE_SEGMENT_INDEX.ATTR,(function(){var t=vc(v,!0);e.setNodeStyle(t,Co.STYLE_SEGMENT_INDEX.ATTR),e.__transformedPropValue=t})),e.__banned&&fc(e)),s&&exparser.Component.hasPublicProperty(e,c)){!u&&Hl.restoring||(l.scheduleReplace([c],v,null!=r?r[c]:null),u?l.doUpdates(void 0,!0):(i=!0,e.isInnerDataExcluded(c)||o++));var m=n&&n["model:"+mc(c)];if(m){var y=m.match(/^\{\{(.*?)\}\}$/);if(y){var b=y[1].match(/^\s*([_a-zA-Z$][_a-zA-Z0-9$]+)\s*$/);if(b){var N=b[1];e.__modelValueName=zi(e.__modelValueName||{},uu({},c,N)),a.push(c)}}}return"continue"}if("style"===c)return"continue";if(/^data-/.test(c)){f=c.slice(5).toLowerCase();var w=hc[f]?hc[f]:hc[f]=f.indexOf("-")<=0?f:f.replace(gc,(function(e){return e[1].toUpperCase()}));return e.dataset[w]=v,e.setAttribute(c,v),"continue"}if("$gdc"===c&&"function"==typeof(h=v)&&(Gl=h),(g=c.match(/^\$wxs:(capture-)?(mut-)?(bind|catch):?(.+)$/))&&(Jn(v)||!v))return Cc(e,g[4],v,"catch"===g[3],g[1],!0,g[2]),Wo()||e.setAttribute("exparser:info-attr-"+c.slice(4),v.name),"continue";if(g=c.match(/^(capture-)?(mut-)?(bind|catch):?(.+)$/))return Cc(e,g[4],v,"catch"===g[3],g[1],!1,g[2]),Wo()||e.setAttribute("exparser:info-attr-"+c,v),"continue";if("on"===c.slice(0,2))return Cc(e,c.slice(2),v,!1,!1,!1),"continue";if("animation"===c){if(s&&e.$$&&null!==v&&"object"===su(v)&&v.actions&&v.actions.length>0){var C=0,S=v.actions,A=v.actions.length,T=function(){if(C<A){var t=dd.animationToStyle(S[C]),r=t.transition,n=t.transitionProperty,o=t.transform,i=t.transformOrigin,a=t.style,s={transition:r,transform:o,transitionProperty:n,transformOrigin:i},u=e.__styleObj?bo(bo({},e.__styleObj),s):s;for(var l in u["-webkit-transition"]=u.transition,u["-webkit-transform"]=u.transform,u["-webkit-transition-property"]=u.transitionProperty,u["-webkit-transform-origin"]=u.transformOrigin,a)u[l]=a[l];e.__styleObj=u,""!==e.__styleObj.transform&&(e.__transformNoneEnabled=!0);var c=Object.keys(u).filter((function(t){return!(/transition/i.test(t)&&""===u[t]||""===t.trim()||void 0===u[t]||!/transform/i.test(t)&&""===u[t]||!isNaN(parseInt(t,10)))&&(/transform/i.test(t)&&""===u[t]&&e.__transformNoneEnabled&&(u[t]="none"),!0)})).map((function(e){return e.replace(/([A-Z]{1})/g,(function(e){return"-"+e.toLowerCase()}))+":"+u[e]})).join(";"),d=function(){e.setNodeStyle(vc(c,!0),Co.STYLE_SEGMENT_INDEX.ANIMATION)};d(),Ul(e,Co.STYLE_SEGMENT_INDEX.ANIMATION,d),e.__banned&&fc(e)}};e.addListener("transitionend",(function(){C+=1,T()})),T()}return"continue"}if(g=c.match(/^\$wxs:change:(.+)$/))return e.ddsObserver=e.ddsObserver||{},e.ddsObserver[g[1]]=e.ddsObserver[g[1]]||{},e.ddsObserver[g[1]].observer=v,"continue";if(g=c.match(/^mark:(.+)$/))return e.setMark(g[1],v),"continue";var O=mc(c);return s&&e.hasExternalClass(O)?(e.setExternalClass(O,v),"continue"):void 0}}var Ac={tag:"shadow",children:[]};function Tc(e,t,r){if((3!==e.wxXCkey&&4!==e.wxXCkey||Wo()||window&&window.__customComponentMode__)&&(t.__ddDynamicSync__=4===e.wxXCkey?"wx:for":"wx:if"),!Wo()){if(e.extraAttr)for(var n in e.extraAttr)t.setAttribute(n,e.extraAttr[n]);void 0!==e.wxScopeData&&(t.__wxScopeData__=e.wxScopeData)}var o=t.__component__,i=t.__placeholder__;if(o||i)if(Wo())exparser.Element.getMethodCaller(t).__ddExparserNodeId__=r.nodeId.allocNodeId(t,""),exparser.Element.getMethodCaller(t).__wxExparserNodeId__=exparser.Element.getMethodCaller(t).__ddExparserNodeId__,r.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_CREATE_NODE,r.nodeId.getNodeId(t)]);else{if(r=vu.instance,Hl.restoring){var a=Hl.idDataMap[r.nodeId.getNodeId(t)];exparser.Component.replaceWholeData(t,a,null)}else{var s=r.operationFlow.iterator.nextStep();if(s[0]!==Co.SYNC_EVENT_NAME.FLOW_CREATE_NODE)throw new Error("Framework inner error (expect FLOW_CREATE_NODE but get another)");r.nodeId.allocNodeId(t,s[1])}_c(t),t.setAttribute("is",t.is)}Sc(t,e.attr,e.raw,e.rawAttr)}function Oc(e,t){var r=e?e(t,null,Tl):Ac;return r.tag="shadow",r}function Ic(e,t,r,n,o){var i,a,s=null;if(Wo()||n||(n=vu.instance),"shadow"===e.tag&&t)r=s=exparser.ShadowRoot.create(t);else if("shadow"===e.tag||"virtual"===e.tag)i="virtual",1===e.wxXCkey||3===e.wxXCkey?i="wx:if":2!==e.wxXCkey&&4!==e.wxXCkey||(i="wx:for"),s=r.createVirtualNode(i),exparser.Element.setInheritSlots(s),Wo()?s.__treeManager__=n:s.__wxVkey__=e.wxVkey;else if("dd-slot"===e.tag)s=r.createVirtualNode("slot"),exparser.Element.setSlotName(s,"");else{var u=r.tagNameUsed(e.tag);if(Wo()&&!u)(s=r.createVirtualNode(e.tag)).__treeManager__=n;else if(u){var l=r.getHostNode().__using[e.tag],c=r.getHostNode().getPlaceholder(e.tag);Nf(n.viewId,l)&&void 0!==c?((s=r.createComponent(e.tag,c,e.generics,n)).__placeholder__=!0,a=function(t){wf(l,t,n,(function(){var t=r.createComponent(e.tag,void 0,e.generics,n);Tc(e,t,n),s.childNodes.forEach((function(e){s.removeChild(e),t.appendChild(e)})),s.parentNode&&s.parentNode.replaceChild(t,s)}))}):s=r.createComponent(e.tag,void 0,e.generics,n)}else s=r.createComponent(e.tag,void 0,e.generics,n)}Tc(e,s,n),a&&a(n.nodeId.getNodeId(s));var d=e.children;if(d)for(var f=0,p=void 0,_=d.length;f<_;++f)if(null!==(p=d[f]))if("object"===su(p))s.appendChild(Ic(p,null,r,n));else{var h=r.createTextNode(p);s.appendChild(h)}return s}var xc={id:null,prev:null,data:[],clear:function(){this.id=null,this.prev=null,this.data=[]}};function Dc(e){!function(e){var t,r=e.__page__;r&&(t=parseInt(r.scrollTop,10),requestAnimationFrame((function(){document.body.scrollTop=document.documentElement.scrollTop=t})))}(e);var t=0;window.__TAB_BAR__&&(no(window.__TAB_BAR__,1,(function(r){r.triggerLifeTime("restored",[e]),lc(e.compExtraDataMap,r,t++)})),function(e){if(!Wo()&&e){var t=window.__TAB_BAR__;t&&(t.__ddsState=nc(e.ddsTabRootState))}}(e.compExtraDataMap)),no(window.__DOMTree__,1,(function(r){r.triggerLifeTime("restored",[e]),lc(e.compExtraDataMap,r,t++)})),function(e){if(!Wo()&&e){var t=zl?vu.instance.nodeId.getNodeById(vu.instance.rootNodeId):window.__DOMTree__;t&&(t.__ddsState=e.ddsPageState)}}(e.compExtraDataMap)}function Mc(e,t){return e+"/"+t}Uo(Co.SYNC_EVENT_NAME.SAVE_STATE,(function(){Jn(dd.webViewReadyToTerminate)&&dd.webViewReadyToTerminate()})),Uo(Co.SYNC_EVENT_NAME.RESTORE_STATE,(function(e){var t=e[0],r=e[1],n=e[2];if(t&&t.isSplitData){var o=t.splitInfo,i=o.id,a=o.index,s=o.total,u=o.data;if(1!==a&&(a!==xc.prev+1||i!==xc.id))return xc.clear();if(a!==s)return xc.id=i,xc.prev=a,void xc.data.push(u);xc.data.push(u);var l=e.data.join("");try{l=JSON.parse(l)}catch(e){Reporter&&Reporter.errorReport({key:"webviewScriptError",error:new Error("Expected parse completed data with split data but got error")}),Reporter&&Reporter.ravenReport("pub_saga_error_message_bt",{key:"webviewScriptError",error:new Error("Expected parse completed data with split data but got error"),fail:function(e){}}),l=null}if(xc.clear(),!l)return;t=l[0],r=l[1],n=l[2]}Hl.restoring=t||{},Hl.idDataMap=r,Hl.compIdArr=n,Hl.compIdArrIndex=0}));var Lc,Rc={},Fc={};function Pc(e,t){Jn(Lc)&&Lc()}var Vc=exparser.dataUtils.deepCopy,kc=Object.prototype.hasOwnProperty;function jc(e){return"number"==typeof e&&isNaN(e)}function Yc(e){if(Wo())e.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_MINIPULATE_CHILD]);else if(e.operationFlow.iterator.nextStep()[0]!==Co.SYNC_EVENT_NAME.FLOW_MINIPULATE_CHILD)throw new Error("Expect FLOW_MINIPULATE_CHILD but get another")}function Wc(e,t,r,n,o){for(var i=o?Vc(e):e,a=0;a<t.length;a++){var s=t[a],u=s[0],l=s[1],c=s[2];if(void 0!==l){for(var d=i,f=u[0],p=1;p<u.length;p++)if(null!=(d=d[f])&&d.__wxspec__&&(d=d.__value__),f=u[p],null!=d&&!kc.call(d,f)){d=null;break}null!=d&&kc.call(d,f)&&(r?null!=c&&"object"===su(l)&&l instanceof Array==c instanceof Array?d[f]={__value__:c,__wxspec__:!0}:null!=d[f]&&d[f].__wxspec__||(d[f]={__value__:d[f],__wxspec__:!0}):d[f]=n?Vc(l,!1):l)}}return i}function Bc(e,t,r){if(e!==t&&(!e||r))if(null==t)r.parentNode.removeChild(r);else if("object"===su(t)){if("object"!==su(e)||null===e||e.tag!==t.tag||String(e.wxKey)!==String(t.wxKey)||"virtual"===e.tag&&e.wxVkey!==t.wxVkey){var n=Wo()?r.__treeManager__:vu.instance,o=r.parentNode,i=Ic(t,null,o.ownerShadowRoot,n);o&&("wx:for"===o.__ddDynamicSync__||"wx:if"===r.__ddDynamicSync__?(n.nodeId.addNode(i),o.replaceChild(i,r),Yc(n),n.nodeId.removeNode(r)):o.replaceChild(i,r),r.__banned&&pc(i))}else{if(t.n&&t.n.length){for(var a=t.n,s=t.attr,u={},l=0,c=a;l<c.length;l++){var d=c[l];u[d]=s[d]}Sc(r,u,t.attr,t.rawAttr)}void 0!==t.wxScopeData&&(r.__wxScopeData__=t.wxScopeData),function(e,t,r){var n=!!to("customComponents"),o=e.children,i=t.children,a="virtual"===e.tag&&(2===e.wxXCkey||4===e.wxXCkey||void 0===e.wxXCkey)||!n&&i.length!==o.length,s=null,u=null;if(a){var l=function(e,t){for(var r=function(e){for(var t={},r=0;r<e.length;++r){var n=e[r],o=n&&n.wxKey;o?kc.call(t,o)?n.wxKey=void 0:t[o]=r:jc(o)&&(n.wxKey=void 0)}return t}(e),n=function(e){for(var t={},r=[],n=0;n<e.length;++n){var o=e[n],i=o&&o.wxKey;i?kc.call(t,i)?(o.wxKey=void 0,r.push(n)):t[i]=n:(jc(i)&&(o.wxKey=void 0),r.push(n))}return[t,r]}(t),o=n[0],i=n[1],a=[],s=[],u=[],l=0,c=0,d=0;d<e.length;++d){var f=void 0,p=void 0,_=e[d].wxKey;_?kc.call(o,_)?(f=o[_],a.push(t[f])):(s.push(d-c),++c,a.push(null)):l<i.length?(p=i[l],a.push(t[p]),++l):(s.push(d-c),++c,a.push(null))}var h=a,v=0,g=[];for(d=0;d<t.length;){for(var E=t[d],m=E&&E.wxKey,y=h[v],b=y&&y.wxKey;null===y;)b=(y=h[++v])&&y.wxKey;v>=h.length?(u.push({oldIndex:r[m],index:d,pos:-1}),++v,++d):b===m?(g.push(v),++v,++d):m?(b&&o[b]!==d+1?(y=h[++v])&&y.wxKey===m?(g.push(v),++v):(--v,u.push({oldIndex:r[m],index:d,pos:v})):u.push({oldIndex:r[m],index:d,pos:v}),++d):++v}var N=0;for(d=0;d<u.length;d++){var w=u[d].pos;if(-1===w)break;for(;N<g.length&&w>g[N];)N++;N>=g.length?u[d].pos=-1:u[d].pos=g[N]}return{children:a,removes:s,inserts:u}}(o,t.children);i=l.children,s=l.removes,u=l.inserts}for(var c=r.childNodes,d=0,f=void 0,p=void 0;d<o.length;d++)f=o[d],!(p=i[d])&&a||Bc(f,p,c[d]);if(a){for(var _=Wo()?r.__treeManager__:vu.instance,h=r.childNodes,v=r.ownerShadowRoot,g=u.length,E=[],m=(d=0,void 0);d<g;d++)m=u[d],E.push({node:void 0!==m.oldIndex?h[m.oldIndex]:null,before:m.pos>=0?h[m.pos]:void 0,index:m.index});d=0;for(var y=void 0,b=s.length;d<b;d++)y=h[s[d]],r.removeChild(y),_.nodeId.removeNode(y),"wx:for"===h.__ddDynamicSync__&&(Yc(_),_.nodeId.removeNode(y));d=0;var N=void 0,w=void 0,C=void 0;for(m=void 0;d<g;d++)N=(m=E[d]).before,w=m.index,null===(C=E[d].node)&&(C=Ic(t.children[w],null,v,_)),"wx:for"===r.__ddDynamicSync__?(_.nodeId.addNode(C),r.insertBefore(C,N),Yc(_)):r.insertBefore(C,N);r.__banned&&pc(r)}}(e,t,r)}}else if("string"==typeof e)t!==e&&(r.textContent=t);else{var f=r.ownerShadowRoot.createTextNode(t);r.parentNode.replaceChild(f,r)}}var Hc={},Uc={},Gc=1,$c=[];function zc(){$c.pop()}function qc(e,t){if(Uc[e]){var r=Uc[e],n=$c[$c.length-1],o=$c[$c.length-2],i=t(r),a=i.isMergedUpdate,s=i.dataPaths,u=i.pendingStartTimestamp,l=i.updateEndTimestamp,c=i.updateStartTimestamp;Ho(Co.SYNC_EVENT_NAME.UPDATE_PERFORMANCE_STAT,[e,{isMergedUpdate:a,dataPaths:s,updateProcessId:n,parentUpdateProcessId:o,pendingStartTimestamp:u,updateStartTimestamp:c,updateEndTimestamp:l}])}}Uo(Co.SYNC_EVENT_NAME.PERFORMANCE_DATA,(function(e){var t=e[0],r=e[1];vu.get(t).root.triggerLifeTime("performanceData",[r])}));var Xc=function(){function e(){}return e.prototype.beforeMergeValues=function(e,t,r){if(Wo())if("number"!=typeof r)e.forEach((function(e,r){void 0!==e[1]?t[r]=!1:t[r]=!0}));else{for(var n=0;n<r;n++)t[n]=!1;for(var o=r;o<e.length;o++){void 0!==e[o][1]?t[o]=!1:t[o]=!0}}},e.prototype.beforeUpdateValues=function(e,t,r){if(!Wo()&&"number"==typeof r){var n=vu.instance.operationFlow.iterator.nextStepIf(Co.SYNC_EVENT_NAME.FLOW_DATA_OBSERVER);if(n){var o=n[1];if(e&&o.length){qc(vu.instance.nodeId.getNodeId(e),(function(e){return{isMergedUpdate:!0,dataPaths:e.withDataPaths?o.map((function(e){return e[0]})):void 0}}));var i=exparser.Component.getDataProxy(e);i.setChanges(o),i.doUpdates(void 0,!0)}}}},e.prototype.updateValues=function(e,t,r,n,o,i){if(!Hl.restoring){var a,s="number"!=typeof i;if(Wo())if(a=e.__treeManager__,s){a.operationFlow.start();var u=o.filter((function(e){return void 0!==e[1]})),l=a.nodeId.getNodeId(e);a.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_UPDATE,l,Vc(u)])}else{for(var c=[],d=i,f=void 0;d<o.length;d++)void 0!==(f=o[d])[1]&&c.push(f);a.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_DATA_OBSERVER,Vc(c)])}if(this._delayedUpdateValues)this._delayedUpdateValues.push([Vc(t),r,n,o,i]);else{this._delayedUpdateValues=[];try{this._updateValues(e,t,r,n,o,i);var p=this._delayedUpdateValues;this._delayedUpdateValues=null;for(var _=0,h=p;_<h.length;_++){var v=h[_];this._updateValues(e,v[0],v[1],v[2],v[3],v[4])}}catch(e){throw this._delayedUpdateValues=null,e}}s&&Wo()&&a.operationFlow.end()}},e.prototype._updateValues=function(e,t,r,n,o,i){var a="number"!=typeof i,s=Wc(t,o,!0,!1,!to("propValueDeepCopy")),u=Oc(this._generateFunc,s);Wc(t,o,!1,a,!1);var l=this._virtualTree;this._virtualTree=u,Bc(l,u,this.shadowRoot),l=null},e.prototype._resetShadowChildren=function(e,t,r){function n(){if(Wo())r.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_CHILD]);else if(r.operationFlow.iterator.nextStep()[0]!==Co.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_CHILD)throw new Error("Expect FLOW_HOT_UPDATE_CHILD but get another")}Wo()&&(r.operationFlow.start(),r.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_HOT_UPDATE,r.nodeId.getNodeId(e)]));for(var o=this.shadowRoot,i=(this._virtualTree.children||[]).length,a=0;a<i;a++)o.removeChild(o.childNodes[0]);n();var s=Oc(this._generateFunc,t);n(),this._virtualTree=s;var u=Ic(s,null,e.shadowRoot,r).childNodes;for(a=0;a<u.length;a++)o.insertBefore(u[0],o.childNodes[a]);Wo()&&r.operationFlow.end()},e}(),Kc=function(){function e(){}return e.create=function(t,r,n,o){var i=new e;i._initValues=n,i._data=r;var a,s=t.template;try{i._generateFunc="function"==typeof(a=s.func)?a:a.shift().call(void 0,a.shift())}catch(e){}return i._isSimpleComponent="simple://"===o.domain.slice(0,9),i},e.collectIdAndSlotsToMap=function(t,r,n){for(var o=t&&t.childNodes||[],i=0,a=void 0;i<o.length;i++)(a=o[i])instanceof exparser.TextNode||(a.__id&&(r[a.__id]=a),void 0!==a.__slotName&&(n[a.__slotName]=a),e.collectIdAndSlotsToMap(a,r,n))},e.prototype.createInstance=function(t,r){var n=new Xc;if(Wo()||(r=vu.instance),n._template=this,n._generateFunc=this._generateFunc,n.data=Vc(this._data),n.idMap=Object.create(null),n.slots=Object.create(null),Hl.restoring){if(Hl.compIdArrIndex>=Hl.compIdArr.length)throw new Error("Component count unmatched while page recovering");r.nodeId.allocNodeId(t,Hl.compIdArr[Hl.compIdArrIndex++]);var o=Hl.idDataMap[r.nodeId.getNodeId(t)];n._virtualTree=Oc(this._generateFunc,o)}else n._virtualTree=Oc(this._generateFunc,n.data);return n.shadowRoot=Ic(n._virtualTree,t,null,r),e.collectIdAndSlotsToMap(n.shadowRoot,n.idMap,n.slots),n.listeners=[],this._isSimpleComponent||(t.__component__=!0),Wo()&&(t.__treeManager__=r,n.shadowRoot.__treeManager__=r,r.operationFlow.registerSetDataCallback((function(){t.__methodCaller&&t.triggerLifeTime("ready")}))),n._delayedUpdateValues=null,n},e}(),Qc=xu.getWeakData,Zc=ot.set,Jc=ot.getterFor,ed=zn.find,td=zn.findIndex,rd=m([].splice),nd=0,od=function(e){return e.frozen||(e.frozen=new id)},id=function(){this.entries=[]},ad=function(e,t){return ed(e.entries,(function(e){return e[0]===t}))};id.prototype={get:function(e){var t=ad(this,e);if(t)return t[1]},has:function(e){return!!ad(this,e)},set:function(e,t){var r=ad(this,e);r?r[1]=t:this.entries.push([e,t])},delete:function(e){var t=td(this.entries,(function(t){return t[0]===e}));return~t&&rd(this.entries,t,1),!!~t}};var sd,ud={getConstructor:function(e,t,r,n){var o=e((function(e,o){Pu(e,i),Zc(e,{type:t,id:nd++,frozen:void 0}),null!=o&&Ru(o,e[n],{that:e,AS_ENTRIES:r})})),i=o.prototype,a=Jc(t),s=function(e,t,r){var n=a(e),o=Qc(Te(t),!0);return!0===o?od(n).set(t,r):o[n.id]=r,e};return ku(i,{delete:function(e){var t=a(this);if(!x(e))return!1;var r=Qc(e);return!0===r?od(t).delete(e):r&&oe(r,t.id)&&delete r[t.id]},has:function(e){var t=a(this);if(!x(e))return!1;var r=Qc(e);return!0===r?od(t).has(e):r&&oe(r,t.id)}}),ku(i,r?{get:function(e){var t=a(this);if(x(e)){var r=Qc(e);return!0===r?od(t).get(e):r?r[t.id]:void 0}},set:function(e,t){return s(this,e,t)}}:{add:function(e){return s(this,e,!0)}}),o}},ld=ot.enforce,cd=!i.ActiveXObject&&"ActiveXObject"in i,fd=function(e){return function(){return e(this,arguments.length?arguments[0]:void 0)}},pd=Vu("WeakMap",fd,ud);if($e&&cd){sd=ud.getConstructor(fd,"WeakMap",!0),xu.enable();var _d=pd.prototype,hd=m(_d.delete),vd=m(_d.has),gd=m(_d.get),Ed=m(_d.set);ku(_d,{delete:function(e){if(x(e)&&!Ou(e)){var t=ld(this);return t.frozen||(t.frozen=new sd),hd(this,e)||t.frozen.delete(e)}return hd(this,e)},has:function(e){if(x(e)&&!Ou(e)){var t=ld(this);return t.frozen||(t.frozen=new sd),vd(this,e)||t.frozen.has(e)}return vd(this,e)},get:function(e){if(x(e)&&!Ou(e)){var t=ld(this);return t.frozen||(t.frozen=new sd),vd(this,e)?gd(this,e):t.frozen.get(e)}return gd(this,e)},set:function(e,t){if(x(e)&&!Ou(e)){var r=ld(this);r.frozen||(r.frozen=new sd),vd(this,e)?Ed(this,e,t):r.frozen.set(e,t)}else Ed(this,e,t);return this}})}function md(e,t,r){e instanceof Nd&&Object.defineProperty(e,t,{value:r,writable:!0,enumerable:!0,configurable:!0})}function yd(e,t,r){var n=Nd.getExparserComponent(e);if(!n)return r?[]:null;var o=exparser.Component.getComponentOptions(n).domain,i=n.shadowRoot;if(r)return i.querySelectorAll(t).map((function(t){return bd(o,t,e)}));var a=i.querySelector(t);return a?bd(o,a,e):null}function bd(e,t,r){if(!t)return null;var n=exparser.Component.getComponentOptions(t).domain,o=exparser.Component.getMethod(t,"__export__"),i=n===e?exparser.Element.getMethodCaller(t):null;if(o){var a=n===e?r:null,s=o.call(exparser.Element.getMethodCaller(t),a);return void 0===s?i:s}return i}var Nd=function(){function e(){this.__data__=null,this.__exitState__=null}return e.getExparserComponent=function(t){return e.callerMap.get(t)},e.getExparserProtocol=function(e){return e?exparser.Component.getComponentOptions(e).domain.split("/",1)[0]:""},Object.defineProperty(e.prototype,"is",{get:function(){var t=e.getExparserComponent(this);return t?t.is:""},set:function(e){md(this,"is",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"id",{get:function(){var t=e.getExparserComponent(this);return t?exparser.Component.getComponentOptions(t).writeOnly?"":t.id:""},set:function(e){md(this,"id",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"getPageId",{get:function(){return function(){var t=e.getExparserComponent(this);return t?"pageId:"+t.__treeManager__.viewId:""}},set:function(e){md(this,"getPageId",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"dataset",{get:function(){var t=e.getExparserComponent(this);return t?exparser.Component.getComponentOptions(t).writeOnly?null:t.dataset:null},set:function(e){md(this,"dataset",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"properties",{get:function(){return this.__data__},set:function(e){md(this,"properties",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"data",{get:function(){return this.__data__},set:function(e){md(this,"data",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"setData",{get:function(){return function(t,r){var n=e.getExparserComponent(this);if(n)return Jn(r)&&n.__treeManager__.operationFlow.registerSetDataCallback(r,this,n),n.setData(t)}},set:function(e){md(this,"setData",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"groupSetData",{get:function(){return function(t){var r=e.getExparserComponent(this);if(r){var n=r.__treeManager__;n.operationFlow.start(),n.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_GROUP]);var o=null;try{t.call(this)}catch(e){o=e}if(n.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_GROUP_END]),n.operationFlow.end(),o)throw o}}},set:function(e){md(this,"setData",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"replaceDataOnPath",{get:function(){var t=this;return function(r,n){var o=e.getExparserComponent(t);return o?o.replaceDataOnPath(r,n):void 0}},set:function(e){md(this,"replaceDataOnPath",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"applyDataUpdates",{get:function(){var t=this;return function(){var r=e.getExparserComponent(t);return r?r.applyDataUpdates():void 0}},set:function(e){md(this,"applyDataUpdates",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"hasBehavior",{get:function(){var t=this;return function(r){var n=e.getExparserComponent(t);return!!n&&n.hasBehavior(r)}},set:function(e){md(this,"hasBehavior",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"triggerEvent",{get:function(){var t=this;return function(r,n,o){var i=e.getExparserComponent(t);return i?i.triggerEvent(r,n,o):void 0}},set:function(e){md(this,"triggerEvent",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"createSelectorQuery",{get:function(){var t=this;return function(){var r=e.getExparserComponent(t);return r?__appServiceSDK__._createSelectorQuery({},e.getExparserProtocol(r)).in(t):null}},set:function(e){md(this,"createSelectorQuery",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"createIntersectionObserver",{get:function(){var t=this;return function(r){var n=e.getExparserComponent(t);return n?__appServiceSDK__._createIntersectionObserver(t,r,e.getExparserProtocol(n)):null}},set:function(e){md(this,"createIntersectionObserver",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"createMediaQueryObserver",{get:function(){return function(){}},set:function(e){md(this,"createMediaQueryObserver",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"getOpenerEventChannel",{get:function(){return function(){return __appServiceEngine__.getCurrentPageWithAdditionalInfo().eventChannel}},set:function(e){md(this,"getOpenerEventChannel",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"applyAnimation",{get:function(){return function(){}},set:function(e){md(this,"applyAnimation",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"clearAnimation",{get:function(){return function(){}},set:function(e){md(this,"clearAnimation",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"animate",{get:function(){return function(){}},set:function(e){md(this,"animate",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"selectOwnerComponent",{get:function(){var t=this;return function(){var r=e.getExparserComponent(t);if(!r)return null;if(exparser.Component.getComponentOptions(r).writeOnly)return null;var n=exparser.Component.getComponentOptions(r).domain,o=r.ownerShadowRoot;if(!(o instanceof exparser.ShadowRoot))return null;var i=o.getHostNode();return i?bd(n,i,t):null}},set:function(e){md(this,"selectOwnerComponent",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"selectComponent",{get:function(){var t=this;return function(r){var n=e.getExparserComponent(t);return n?exparser.Component.getComponentOptions(n).writeOnly?null:yd(t,r,!1):null}},set:function(e){md(this,"selectComponent",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"selectAllComponents",{get:function(){var t=this;return function(r){var n=e.getExparserComponent(t);return n?exparser.Component.getComponentOptions(n).writeOnly?[]:yd(t,r,!0):[]}},set:function(e){md(this,"selectAllComponents",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"getRelationNodes",{get:function(){var t=this;return function(r){var n=e.getExparserComponent(t);if(!n)return null;var o=n.getRelationNodes(r);return null===o?null:o.map((function(e){return exparser.Element.getMethodCaller(e)}))}},set:function(e){md(this,"getRelationNodes",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"getTabBar",{get:function(){return function(){var t=e.getExparserComponent(this);if(!t)return null;var r=t.__treeManager__;return r.tabDestroyed||!r.tabRoot?null:exparser.Element.getMethodCaller(r.tabRoot)}},set:function(e){md(this,"getTabBar",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"exitState",{get:function(){return this.__exitState__},set:function(e){md(this,"exitState",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"setInitialRenderingCache",{get:function(){return function(t){var r=e.getExparserComponent(this);if(r){var n=r.__treeManager__;null===t?function(e){e.operationFlow.start(),e.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE,"",null]),e.operationFlow.end()}(n):function(e,t){var r=mu(e.rootCompName),n=ro();e.operationFlow.start(),e.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE,r,n]);var o=exparser.createElement("initial-rendering-cache",exparser.Component._list[r],e);exparser.Element.getMethodCaller(o).__ddExparserNodeId__=e.nodeId.allocNodeId(o,n),exparser.Element.getMethodCaller(o).__wxExparserNodeId__=exparser.Element.getMethodCaller(o).__ddExparserNodeId__,e.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE]),e.nodeId.addNode(),o.setData(t),e.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE,t]),e.operationFlow.end(),e.nodeId.removeNode(o)}(n,t)}}},set:function(e){md(this,"exitState",e)},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"setUpdatePerformanceListener",{get:function(){return function(t,r){var n=e.getExparserComponent(this);if(n){var o=n.__treeManager__,i=o.nodeId.getNodeId(n);"function"==typeof r?(n.__updatePerformanceListener__=r,o.operationFlow.push([Co.SYNC_EVENT_NAME.ENABLE_UPDATE_PERFORMANCE_STAT,i,t])):(n.__updatePerformanceListener__=null,o.operationFlow.push([Co.SYNC_EVENT_NAME.DISABLE_UPDATE_PERFORMANCE_STAT,i]))}}},set:function(e){md(this,"exitState",e)},enumerable:!1,configurable:!0}),e.callerMap=new WeakMap,e}();function wd(){return __ddConfigWindow__&&__ddConfigWindow__.initialRenderingCache?String(__ddConfigWindow__.initialRenderingCache):""}function Cd(e,t){var r=[],n={},o={};exparser.ElementIterator.create(e,"composed-descendants-root-first",exparser.Component).forEach((function(t){t instanceof exparser.Component&&!t.hasBehavior("dd-base")&&(n["./"+e.is+".wxss"]=!0)})),Object.keys(exparser.Component._list).forEach((function(e){o["./"+e+".wxss"]=!0}));for(var i=document.head.querySelectorAll("style")||[],a=0,s=void 0,u=void 0;a<i.length;a++)null!=(u=(s=i[a]).getAttribute("wxss:path"))&&(o[u]&&!n[u]||r.push("<style>"+s.innerHTML+"</style>"));var l=r.join("")+e.$$.innerHTML;dd.saveInitialRenderingCache({content:l,appserviceData:t})}function Sd(e,t){return"dynamic"!==wd()&&(e?Cd(e,t):dd.saveInitialRenderingCache({content:""}),!0)}var Ad,Td=1<<18,Od=Date.now();function Id(e,t){var r=vu.get(e);r&&(r.statesData=t,r.tabRoot&&no(r.tabRoot,1,(function(e){e.triggerLifeTime("saved")})),no(r.root,1,(function(e){e.triggerLifeTime("saved")})),Ho(Co.SYNC_EVENT_NAME.SAVE_STATE,[],e))}var xd={domain:"/",writeOnly:!1,allowInWriteOnly:!1,lazyRegistration:!0,classPrefix:"",templateEngine:Kc,renderingMode:"full",multipleSlots:!1,publicProperties:!0,reflectToAttributes:!1,writeFieldsToNode:!1,writeIdToDOM:!1,separateInnerData:!0,innerDataExclude:null,randomizeTagName:!1,virtualHost:!1},Dd={domain:"/",writeOnly:!1,allowInWriteOnly:!1,lazyRegistration:!0,classPrefix:"",renderingMode:"full",templateEngine:Kc,multipleSlots:!1,publicProperties:!0,reflectToAttributes:!1,writeFieldsToNode:!1,writeIdToDOM:!1,separateInnerData:!1,innerDataExclude:null,randomizeTagName:!1,virtualHost:!1},Md=1,Ld=!1,Rd=!1,Fd=[],Pd=[],Vd={},kd=new Set,jd=new Set,Yd="custom-tab-bar/index",Wd=new Set([Yd]),Bd={},Hd={},Ud=void 0,Gd={},$d={},zd={},qd={},Xd={},Kd=[],Qd=!1,Zd=Object.create(null),Jd={lazyRegistration:!0,publicProperties:!0},ef=null,tf=null,rf=null,nf={String:String,Number:Number,Boolean:Boolean,Object:Object,Array:Array,null:null},of={jsFileLoaded:!1,jsFileLoadedCallback:[],compDefLoaded:!1,compDefLoadedCallback:[]},af=function(e){of.jsFileLoaded?e():of.jsFileLoadedCallback.push(e)},sf=function(){of.compDefLoaded=!0,of.compDefLoadedCallback.forEach((function(e){e()})),of.compDefLoadedCallback=[]},uf=function(e){of.compDefLoaded?e():of.compDefLoadedCallback.push(e)},lf=function(){of={jsFileLoaded:!1,jsFileLoadedCallback:[],compDefLoaded:!1,compDefLoadedCallback:[]}},cf=!1,df=[];function ff(e){cf?e():df.push(e)}function pf(){!0!==cf&&(cf=!0,df.forEach((function(e){return e()})))}function _f(e){for(var t,r,n=Object.create(null),o=0,i=e;o<i.length;o++){var a=i[o];r="";for(var s=0,u=(t="string"==typeof a?a:a.is).length,l=void 0,c=void 0;s<u;++s)r+=(c=(l=t[s]).charCodeAt(0))>=48&&c<=57||c>=65&&c<=90||c>=97&&c<=122||45===c||95===c?l:"/"===l?"-":c;n[t]=r}return n}function hf(e,t){var r={},n=(t[e+".json"]||{}).usingComponents;for(var o in n)r["dd-"+o]=Zn(e,String(n[o]));return r}function vf(e,t){for(var r in t){var n=t[r];n.target=null!=n.target?String(n.target):Zn(e,String(r))}return t}function gf(e,t){if("undefined"!=typeof __DDML_DEP__){var r=__DDML_DEP__["./"+e+".wxml"];eo(r)&&r.forEach((function(e){var r=e.substr(2,e.length-7);Ad[r]&&t.add(r)}))}}function Ef(e,t){var r,n,o,i,a=t.set,s=t.dropLazy;a.has(e)||(a.add(e),r=Ad?Object.keys(Ad[e]||{}):[],s&&(n=new Set(r),o=Vd[e]||{},Object.keys(o).forEach((function(e){n.delete(e)})),(i=o,Object.keys(i).map((function(e){return i[e]}))).forEach((function(e){n.add(e)})),r=Array.from(n)),r.forEach((function(t){Ef(Ad[e][t],{set:a,dropLazy:s})})))}function mf(e,t,r){void 0===r&&(r=null);var n=Wo()?__ddConfig.subPackages:void 0,o=(n=(n=n||[]).filter((function(t){return 0===e.indexOf(t.root)})))[0]&&n[0].root||"",i=n[0]&&n[0].allExtendedComponents||[],a=Array.from(t).map((function(e){return-1<i.indexOf(e)?o+e:e}));Wo()&&(Bd[r]||(Bd[r]=new Set),a.forEach((function(e){return Bd[r].add(e)})));var s=a.filter((function(e){return!jf(e)}));return s.forEach((function(e){Wd.add(e)})),s}function yf(e,t,r,n){var o,i;if(void 0===n&&(n=!1),__ddConfig&&__ddConfig.isLazyLoad){var a="undefined"!=typeof __ddAppCode__?__ddAppCode__:{};for(var s in void 0===Ad&&(Ad={}),a)if(".json"===s.substr(s.length-5)){var u=s.slice(0,-5),l=a[s],c={},d={},f=l.usingComponents;for(var p in f)c[p]=Zn(u,f[p]);var _=l.componentGenerics;for(var h in _){var v=_[h].default;v&&(c[String(v)]=Zn(u,v))}var g=l.componentPlaceholder;for(var p in g)d[p]=g[p];Ad[u]=c,Vd[u]=d||{}}var E=Object.keys(Ad);ef=_f(E),n||(Pc(),Pc(0,Wo()),Pc(0,E.length)),o=new Set,Ef(e,{set:o,dropLazy:!0}),Object.keys(Vd).forEach((function(e){Ef(e,{set:jd})})),o.forEach((function(e){return gf(e,o)}));var m=mf(e,o,t);if(n||(Pc(0,m.length),Pc(),Pc()),Wo()){!function(e){if(0===e.length)return 0;var t=Date.now();Date.now()}(m.map((function(e){return"/"+e+".appservice.js"})))}else{var y=m.map((function(e){return"/"+e+".webview.js"}));i=function(t){function r(){var t,r;Pc(),void 0!==(t=("undefined"!=typeof __ddAppCode__?__ddAppCode__:{})[e+".ddss"])&&"function"==typeof t||(t=function(){}),window.__setCssStartTime__=Date.now(),t(),window.__setCssEndTime__=Date.now(),r=("undefined"!=typeof __ddAppCode__?__ddAppCode__:{})["./"+e+".ddml"],Array.isArray(r)&&(r=r[0][r[1]]),window.__ddAppCodeReadyCallback__?window.__ddAppCodeReadyCallback__(r):document.dispatchEvent(new CustomEvent("generateFuncReady",{detail:{generateFunc:r}}))}n?!0!==Qd&&(Qd=!0,Kd.forEach((function(e){e()}))):kf()?Pf(r):r()},y.length||i&&i(0)}}}function bf(e,t,r,n){var o=vu.get(r).nodeId.getNodeById(n);if(o&&t){var i=uu({},t,e);exparser.Element.getMethodCaller(o).setData(i)}}function Nf(e,t){return Wo()?t!==Yd&&!(Bd[e]&&Bd[e].has(t)):!jf(t)}function wf(e,t,r,n){kd.add(e),Hd[t]=n,void 0!==Ud&&clearTimeout(Ud),Ud=setTimeout((function(){var e=Array.from(kd),t=r.rootCompName,n=r.viewId;if(kd=new Set,Wo()){Af(e,t,n),e.forEach((function(e){jd.delete(e)}));var o=[[],[],t,Rc];e.forEach((function(e){Tf(o,e,Zd,t)})),Ho(Co.SYNC_EVENT_NAME.COMPONENT_DEF_LAZY,o,n),r.operationFlow.start(),r.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_DO_REPLACE_PLACEHOLDER]),r.operationFlow.end();var i=Object.keys(Hd);r.operationFlow.start(),r.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_REPLACE_PLACEHOLDER,i]),i.forEach((function(e){Hd[e](),delete Hd[e]})),r.operationFlow.end()}else Af(e,t,null)}),50)}function Cf(e,t){var r,n={};for(var o in e.properties){var i=e.properties[o];null===i?n[o]={type:null}:(r=i)===Number||r===String||r===Boolean||r===Object||r===Array?n[o]={type:i.name}:(void 0===i.public||i.public)&&(n[o]={type:i.type?i.type.name:null,value:i.value})}var a=e.options.innerDataExclude;return{is:e.is,using:e.using,generics:e.generics,behaviors:e.behaviors,placeholder:e.placeholder,data:e.data,properties:n,externalClasses:e.externalClasses,template:t,options:{domain:e.options.domain,writeOnly:e.options.writeOnly||void 0,multipleSlots:e.options.multipleSlots||void 0,writeIdToDOM:e.options.writeIdToDOM||void 0,styleIsolation:e.options.styleIsolation||void 0,addGlobalClass:e.options.addGlobalClass||void 0,hasObservers:!!e.observers,innerDataExcludeString:a?a.toString():null,virtualHost:e.options.virtualHost||void 0}}}function Sf(e){if(e.behaviors){for(var t=[],r=0,n=e.behaviors;r<n.length;r++){var o=n[r],i=String(o);if("/"!==i[0]&&"dd://"!==i.slice(0,5))throw new Error("Behaviors should be constructed with Behavior()");t.push(i)}e.behaviors=t,qd[e.is]=t}else e.behaviors=null}Wo()||(Wo()||(Uo(Co.SYNC_EVENT_NAME.ENABLE_UPDATE_PERFORMANCE_STAT,(function(e){var t=e[0],r=e[1];Uc[t]=r})),Uo(Co.SYNC_EVENT_NAME.DISABLE_UPDATE_PERFORMANCE_STAT,(function(e){var t=e[0];Uc[t]=null}))),"undefined"!=typeof __ddAppCode__?pf():window.__mainPageFrameReady__=pf,ff((function(){if(__ddConfig.isFirstPage){var e=__ddConfig.appLaunchInfo.path.replace(/\.html$/,"").replace(/^\//,"");setTimeout((function(){yf(e,null)}),0)}})),ff((function(){yf(Yd,null,__ddConfig.isFirstPage,!0),Pf((function(){Ff()}))})),Uo(Co.SYNC_EVENT_NAME.DESTROY_TAB,(function(){vu.instance.tabDestroyed=!0,window.__TAB_BAR__&&window.__TAB_BAR__.parentNode.removeChild(window.__TAB_BAR__)}))),Uo(Co.SYNC_EVENT_NAME.COMPONENT_DEF_LAZY,(function(e){Lf(e,!1),af((function(){sf()}))}),0),Uo(Co.SYNC_EVENT_NAME.LOAD_COMPONENT_DEF,(function(e){yf(e[0],null)}),0),Uo(Co.SYNC_EVENT_NAME.COMPONENT_DEF,(function(e){Rd?Lf(e,!1):Fd.push(e)}),0),Uo(Co.SYNC_EVENT_NAME.COMPONENT_DEF_TAB,(function(e){Rd?Lf(e[0],!0):Pd.push(e[0])}),0),Uo(Co.SYNC_EVENT_NAME.UPDATE_COMPONENT_DEF,(function(e){var t=e[0],r=vu.instance;exparser.Component._list[t.is]&&xf(t,r.rootCompName===t.is)})),Wo()||Uo(Co.SYNC_EVENT_NAME.FLUSH_BLOCKED,(function(){vu.instance.operationFlow.flushBlocked()}),0);var Af=function(e,t,r){var n=new Set;e.forEach((function(e){Ef(e,{set:n})})),n.forEach((function(e){return gf(e,n)}));var o=mf(t,n,r);o.forEach((function(e){return Wd.add(e)})),0!==o.length&&Wo()&&Array.from(o).forEach((function(e){var t=new Set;__appServiceSDK__.requireByRoute(e,t)}))};function Tf(e,t,r,n){var o;kc.call(Rc,t)&&(t=Rc[t]);var i=Gd[t];if(!i){if(jd.has(t))return;throw new Error('Component is not found in path "'+t+'"'+(n?' (using by "'+n+'")':""))}"dd://"!==t.slice(0,5)&&(e[1].unshift(i),r[t]=!0);var a,s=$d[i.is];for(o in s)kc.call(s,o)&&(r[a=s[o]]||Tf(e,a,r,t));var u,l=zd[i.is];for(o in l)kc.call(l,o)&&(u=l[o].default)&&(r[u]||Tf(e,u,r,t));var c=qd[i.is];if(c)for(var d=function e(t,r,n){if("dd://"!==r.slice(0,5)){var o=Xd[r];if(!o)throw new Error('"'+r+'" is not a behavior registered by Behavior()');t[0].unshift(o),n[r]=!0;var i=qd[o.is];if(i)for(var a=0,s=i;a<s.length;a++){var u=s[a];n[u]||e(t,u,n)}}},f=0,p=c;f<p.length;f++){var _=p[f];r[_]||d(e,_,r)}return e}function Of(e,t,r){var n=t[r+".json"]||{};void 0!==n.styleIsolation&&(e.options||(e.options={}),e.options.styleIsolation=n.styleIsolation),void 0!==n.pureDataPattern&&(e.options||(e.options={}),e.options.pureDataPattern=new RegExp(n.pureDataPattern))}function If(e,t){e.using=$d[e.is]=hf(e.is,t),e.placeholder=function(e,t){var r=t[e+".json"]||{},n={},o=r.componentPlaceholder||{};return Object.keys(o).forEach((function(e){n["dd-"+e]="dd-"+String(o[e])})),n}(e.is,t),e.generics=zd[e.is]=function(e,t){var r={},n=(t[e+".json"]||{}).componentGenerics;for(var o in n){var i=n[o];"object"===su(i)?r["dd-"+o]={default:Zn(e,String(i.default||""))}:null!=i&&(r["dd-"+o]={})}return r}(e.is,t),Sf(e);var r=e.is;t[r+".wxml"]?r+=".wxml":t[r+".ddml"]&&(r+=".ddml"),e.template={path:r,func:Sl[r]||t[r]||null},Gd[e.is]=Cf(e,r);var n=exparser.registerElement(e),o=new Nd;exparser.Behavior.prepare(n.behavior);var i=n.behavior.methods;for(var a in i)o[a]=i[a];return o}function xf(e,t,r){var n;for(n in e.properties){var o=e.properties[n].type;e.properties[n].type=nf[o]}var i="";t||(i=r?rf[e.is]:tf[e.is]);var a=e.options,s=!(!a.writeIdToDOM&&!t);e.options=Dd,e.options.multipleSlots=a.multipleSlots||!1,e.options.writeOnly=a.writeOnly||!1,e.options.writeIdToDOM=s,e.options.domain=a.domain,e.options.randomizeTagName=!1,e.options.virtualHost=a.virtualHost,e.options.innerDataExclude=function(e){if(!e)return null;var t=e.lastIndexOf("/"),r=e.slice(1,t),n=e.slice(t+1);return new RegExp(r,n)}(a.innerDataExcludeString);var u=!1;if(a.styleIsolation){var l=a.styleIsolation;"page-"===l.slice(0,5)&&(u=!0,l=l.slice(5)),"isolated"===l?(i=tf[e.is],e.options.addGlobalClass=!1):"strong-isolated"===l?(i=tf[e.is],e.options.addGlobalClass=!1,e.options.randomizeTagName=!0):"apply-shared"===l?(i=tf[e.is],e.options.addGlobalClass=!0):"shared"===l&&"/"===a.domain?(i="",e.options.addGlobalClass=!1):u=!1}else e.options.addGlobalClass=a.addGlobalClass||!1;e.options.classPrefix=i,a.hasObservers&&(e.observers={"**":function(){}});var c="undefined"!=typeof __ddAppCode__&&__ddAppCode__[e.template];window.__customComponentMode__=c;var d=c?__ddAppCode__[e.template]:window.__generateFunc__,f=e.template;return e.template={path:f,func:d},exparser.registerElement(e),{disableAppDdss:u,classPrefix:i}}function Df(e){var t=Date.now(),r=e.operationFlow.iterator,n=r.expectStart(),o=r.nextStepType();if(o===Co.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION)Mf(e,Co.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION);else if(o===Co.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE)Mf(e,Co.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE);else if(o===Co.SYNC_EVENT_NAME.FLOW_CREATE_TAB)Mf(e,Co.SYNC_EVENT_NAME.FLOW_CREATE_TAB);else if(o===Co.SYNC_EVENT_NAME.FLOW_DO_REPLACE_PLACEHOLDER)r.nextStep(),vu.instance.operationFlow.block(),vu.instance.operationFlow.unblock(),uf((function(){lf(),vu.instance.operationFlow.unblock()}));else{var i=r.nextStep(),a=void 0;if((o=i[0])===Co.SYNC_EVENT_NAME.FLOW_UPDATE){var s=i[1];if(a=e.nodeId.getNodeById(s)){var u=i[2];if(eo(u)&&u.length){var l=exparser.Component.getDataProxy(a);l.setChanges(u),l.doUpdates(void 0,!Wo()),qc(s,(function(e){return{isMergedUpdate:!1,dataPaths:e.withDataPaths?u.map((function(e){return e[0]})):void 0,pendingStartTimestamp:n,updateStartTimestamp:t,updateEndTimestamp:Date.now()}}))}}else r.skipToEnd()}else if(o===Co.SYNC_EVENT_NAME.FLOW_GROUP){var c=r.nextStep();if(c[0]!==Co.SYNC_EVENT_NAME.FLOW_GROUP_END)throw new Error("Framework inner error (expect FLOW_GROUP_END but get "+Co.getEvName(c[0])+")")}else if(o===Co.SYNC_EVENT_NAME.FLOW_REPLACE_PLACEHOLDER)i[1].forEach((function(e){Hd[e](),delete Hd[e]}));else if(o===Co.SYNC_EVENT_NAME.FLOW_HOT_UPDATE)(a=e.nodeId.getNodeById(i[1]))?a.__templateInstance._resetShadowChildren(a,a.data,e):r.skipToEnd();else{if(o!==Co.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_RESET)throw new Error("Framework inner error (expect an update event but get "+Co.getEvName(o)+")");!function(e,t){if(Cl()){Wo()&&(t.operationFlow.start(),t.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_RESET,t.nodeId.getNodeId(e)]));var r="";e===t.root?r="body":e===t.tabRoot&&(r="tab-bar");var n=e.__vtObj,o=e.ownerShadowRoot?e.ownerShadowRoot.createComponent(n.tag,void 0,n.generics,t):exparser.createElement(r,exparser.Component._list[e.is],t);if(Wo())t.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_RESET]);else if(t.operationFlow.iterator.nextStep()[0]!==Co.SYNC_EVENT_NAME.FLOW_HOT_UPDATE_RESET)throw new Error("Expect FLOW_HOT_UPDATE_RESET but get another");var i=t.nodeId.getNodeId(e);if(t.nodeId.removeNode(e),t.nodeId.allocNodeId(o,i),e===t.root){exparser.Element.pretendDetached(e),t.root=o,Wo()||(window.__DOMTree__=o,document.body=o.$$),exparser.Element.pretendAttached(o);var a={},s=!1;Object.keys(t.initialRootData).forEach((function(e){exparser.Component.hasProperty(o,e)&&(a[e]=t.initialRootData[e],s=!0)})),s&&t.root.setData(a)}else t.tabRoot;Wo()&&t.operationFlow.end()}}(e.nodeId.getNodeById(i[1]),e)}}r.expectEnd()}function Mf(e,t){var r,n,o,i,a=t===Co.SYNC_EVENT_NAME.FLOW_CREATE_TAB,s=t===Co.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE,u=e.operationFlow.iterator,l=u.nextStep(),c=null,d=l[1],f=l[2];if(a)e.tabNodeId=f,e.tabRoot=c=window.__TAB_BAR__=exparser.createElement("tab-bar",exparser.Component._list[d]);else if(s){if(!d)return void Sd(null);c=exparser.createElement("initial-rendering-cache",exparser.Component._list[d])}else{var p=l[3]||{};e.rootNodeId=f,e.root=c=window.__DOMTree__=exparser.Component.createWithGenerics("body",exparser.Component._list[d],p,e)}if(e.nodeId.allocNodeId(c,f),c.setAttribute("is",d),Hl.restoring&&!a&&(r=Hl.idDataMap[e.nodeId.getNodeId(c)],exparser.Component.replaceWholeData(c,r,null),Dc(Hl.restoring),Hl.restoring=null,Hl.idDataMap=null),(l=u.nextStep())[0]!==t)throw new Error("Framework inner error (expect "+Co.getEvName(t)+" end but get "+Co.getEvName(l[0])+")");if(e.nodeId.addNode(),a){var _=exparser.createElement("dd-tab-bar-wrapper",exparser.Component._list["dd://tab-bar-wrapper"]);_.appendChild(c),document.documentElement.insertBefore(_.$$,document.body),exparser.Element.pretendAttached(_),e.tabDestroyed&&_.removeChild(c)}else if(s){var h=document.createElement("dd-initial-rendering-cache-wrapper");if(h.setAttribute("style","height: 0; overflow: hidden"),h.appendChild(c.$$),document.documentElement.insertBefore(h,document.body),(l=u.nextStep())[0]!==Co.SYNC_EVENT_NAME.FLOW_INITIAL_RENDERING_CACHE)throw new Error("Framework inner error (expect initial rendering end but get another)");no(c,1,(function(e){e.triggerLifeTime("cacheAttached")})),Sd(c,l[1]),e.nodeId.removeNode(c),document.documentElement.removeChild(h)}else document.body=c.$$,no(c,1,(function(e){e.triggerLifeTime("cacheAttached")})),i=c,"static"===wd()&&Cd(i),exparser.Element.pretendAttached(c),n="initialRenderingDone",o=Date.now(),Hc[n]=o,setTimeout((function(){var e;Ho(Co.SYNC_EVENT_NAME.PERFORMANCE_DATA,[(null===(e=window.nativeParam)||void 0===e?void 0:e.webViewId)||0,Hc],void 0,!0)}),0)}function Lf(e,t){var r=e[0],n=e[1],o=e[2],i=e[3];t||(vu.instance.rootCompName=o);var a=__ddAppCode__[o+".wxss"]||__ddAppCode__[o+".ddss"];"function"==typeof a&&a(o);for(var s=0,u=r;s<u.length;s++){var l=u[s];l.options=Jd,exparser.registerBehavior(l)}var c,d=n.map((function(e){return e.is}));t?rf=ef||_f(d):tf=_f(n);for(var f=0,p=n;f<p.length;f++){var _=(c=p[f]).is===o&&!t;xf(c,_,t).disableAppDdss&&_&&(__webviewEngine__.disableStyleElement("app.wxss"),__webviewEngine__.disableStyleElement("app.ddss"));var h=__ddAppCode__[c.is+".wxss"]||__ddAppCode__[c.is+".ddss"];"function"==typeof h&&h(c.is)}for(var v in i)exparser.Component._list[v]=exparser.Component._list[i[v]]}function Rf(e,t,r){var n=[[],[],r=mu(r),Rc];Tf(n,r,Zd=Object.create(null),"");Ho(Co.SYNC_EVENT_NAME.COMPONENT_DEF,n,e),function(e){cc&&Ho(Co.SYNC_EVENT_NAME.BANNING_MAP,[cc],e,null)}(e),t.rootCompName=r,t.rootNodeId=ro(),t.operationFlow.start(),t.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION,r,t.rootNodeId,null]);var o=exparser.Component.createWithGenerics("body",exparser.Component._list[r],null,t);return t.root=o,t.usedDef=n,exparser.Element.getMethodCaller(o).__ddExparserNodeId__=t.nodeId.allocNodeId(o,t.rootNodeId),exparser.Element.getMethodCaller(o).__wxExparserNodeId__=exparser.Element.getMethodCaller(o).__ddExparserNodeId__,t.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION]),t.nodeId.addNode(),o}function Ff(){Ld||(Ld=!0,Ho(Co.SYNC_EVENT_NAME.REQUEST_TAB,[]))}function Pf(e){__ddConfig&&__ddConfig.isLazyLoad&&!Qd?Kd.push(e):e()}function Vf(e,t){if(kf()){var r=vu.get(e)||vu.create(e);if(!r.tabRoot&&!r.tabDestroyed){yf(Yd,e,0,!0);var n=mu(Yd),o=[[],[],n,{}];Tf(o,n,Object.create(null),""),r.operationFlow.push([Co.SYNC_EVENT_NAME.COMPONENT_DEF_TAB,o,e]),r.tabCompName=n,r.tabNodeId=ro(),r.operationFlow.start(),r.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_CREATE_TAB,n,r.tabNodeId]);var i=exparser.createElement("tab-bar",exparser.Component._list[n],r);r.tabRoot=i,r.tabUsedDef=o,exparser.Element.getMethodCaller(i).__ddExparserNodeId__=r.nodeId.allocNodeId(i,r.tabNodeId),exparser.Element.getMethodCaller(i).__wxExparserNodeId__=exparser.Element.getMethodCaller(i).__ddExparserNodeId__,r.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_CREATE_TAB]),r.nodeId.addNode(),exparser.Element.pretendAttached(r.tabRoot),r.operationFlow.end(),t&&r.operationFlow.push([Co.SYNC_EVENT_NAME.FLUSH_BLOCKED,[],e]),r.rootCompName&&function(e,t,r){var n=!0,o=__ddConfig.tabBar&&__ddConfig.tabBar.list;o instanceof Array&&(o=o.map((function(e){return e&&e.pagePath}))).indexOf(t+".html")&&(n=!1),n&&(e.tabDestroyed=!0,Ho(Co.SYNC_EVENT_NAME.DESTROY_TAB,[],r))}(r,r.rootCompName,e)}}}function kf(){var e=!1;return __ddConfig.tabBar&&!0===__ddConfig.tabBar.custom&&(e=!0),function(e){e=mu(e),kc.call(Rc,e)&&(e=Rc[e]);return Gd[e]}(Yd)||(e=!1),__ddConfig.appLaunchInfo&&"singlePage"===__ddConfig.appLaunchInfo.mode&&(e=!1),e}function jf(e){return Wd.has(e)}var Yf={sendData:Ho,setDataListener:Uo,TreeManager:vu,requestViewInfo:function(e,t,r,n){var o=Math.random()+"-"+Date.now(),i=vu.get(r);if(i)return i.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_VIEW_INFO,e,t,o]),Jn(n)&&(i.viewInfoCbMap[o]=n),o},endViewInfoCallback:function(e,t){var r=vu.get(e);r&&delete r.viewInfoCbMap[t]},setModelValueData:bf,getLazyCompPlaceholder:function(e){if(!Vd[e])return{};var t={};return Object.keys(Vd[e]).forEach((function(r){t["dd-"+r]="dd-"+Vd[e][r]})),t},componentLoaded:jf,shouldUsePlaceholder:Nf,arrangePlaceholderReplace:wf,getOwnerPluginAppId:function(e){var t=Nd.getExparserComponent(e);return t?Nd.getExparserProtocol(t):""},Behavior:function(e){var t="/"+Md+++"/"+ro(),r={},n=e.behaviors;if(n&&n.length)for(var o=0;o<n.length;o++){var i=String(n[o]);-1!==i.indexOf("wx://")&&(n[o]="dd://"+i.substr(5))}for(var a in r.behaviors=n,e)r[a]="data"===a?Vc(e[a]):e[a];return r.is=t,Sf(r),r.options=Jd,Xd[t]=Cf(r),r.definitionFilter=exparser.Behavior.callDefinitionFilter(r),exparser.registerBehavior(r),r.is},CustomComponent:Nd,Component:function e(t,r,n,o){var i=o||__ddAppCurrentFile__,a=n||__ddAppCode__,s=a[i+"on"];if(!i||!s)return"";var u=t.behaviors;if(u&&u.length)for(var l=0;l<u.length;l++){var c=String(u[l]);-1!==c.indexOf("wx://")&&(u[l]="dd://"+c.substr(5))}t.behaviors=u;var d=i.slice(0,-3);if(s.component&&"simple"===s.component.type)return function(e,t,r,n){Of(e,n,t);var o={is:t,using:hf(t,n),properties:e.properties,externalClasses:e.externalClasses,options:xd},i=e.options||{};o.options=bo(bo({},xd),{multipleSlots:i.multipleSlots||!1,writeOnly:!0,writeIdToDOM:!1,domain:"simple://"+(r||"/"),styleIsolation:i.styleIsolation||"",addGlobalClass:i.addGlobalClass||!1,innerDataExclude:null,virtualHost:!1});var a=t;n[a+".wxml"]?a+=".wxml":n[a+".ddml"]&&(a+=".ddml");Gd[t]=Cf(o,a)}(t,d,r,a),d;Of(t,a,d);var f=exparser.Behavior.callDefinitionFilter(t),p=t.options||{},_={is:d,properties:t.properties,data:Vc(t.data),methods:t.methods,behaviors:t.behaviors,lifetimes:t.lifetimes,pageLifetimes:t.pageLifetimes,created:t.created,attached:t.attached,ready:t.ready,moved:t.moved,detached:t.detached,saved:t.saved,restored:t.restored,relations:t.relations?vf(i,t.relations):void 0,externalClasses:t.externalClasses,observers:t.observers,definitionFilter:f,options:bo(bo({},xd),{addGlobalClass:p.addGlobalClass||!1,multipleSlots:p.multipleSlots||!1,writeOnly:p.writeOnly||!1,writeIdToDOM:!1,domain:(p.writeOnly?"wo://":"")+(r||"/"),styleIsolation:p.styleIsolation||"",innerDataExclude:p.pureDataPattern||null,virtualHost:p.virtualHost||!1}),initiator:function(){this.__customConstructor__=e;var t=Object.create(h);Nd.callerMap.set(t,this),exparser.Element.setMethodCaller(this,t),Object.defineProperties(t,{__data__:{value:this.data,writable:!0,enumerable:!1},__ddWebViewId__:{value:this.__treeManager__.viewId,writable:!0,enumerable:!1}})}},h=If(_,a);return _.is},Page:function e(t,r,n,o){var i=o||__ddAppCurrentFile__;if(!i)return"";var a,s=i.slice(0,-3),u=n||"undefined"!=typeof __ddAppCode__&&__ddAppCode__||{},l=Object.create(null),c={methods:{}};for(a in t)"data"===a?c.data=t.data:Jn(t[a])?c.methods[a]=t[a]:"methods"===a?l.methods=t.methods:c[a]=t[a];var d=c.behaviors;if(d&&d.length)for(var f=0;f<d.length;f++){var p=String(d[f]);-1!==p.indexOf("wx://")&&(d[f]="dd://"+p.substr(5))}c.behaviors=d;var _,h=function(e){if(!e)return!1;if(eo(e)){for(var t=0;t<e.length;t++){var r=String(e[t]);if("dd://"!==r.slice(0,5)&&!Xd[r])return!1}return!0}return!1}(c.behaviors);for(a in Of(c,u,s),h&&exparser.Behavior.callDefinitionFilter(c),c)"data"!==a&&"methods"!==a&&(l[a]=c[a]);var v=c.options||{},g={is:s,behaviors:h?c.behaviors:void 0,data:Vc(c.data),methods:c.methods,properties:void 0===t.properties?c.properties:void 0,lifetimes:void 0===t.lifetimes?c.lifetimes:void 0,pageLifetimes:void 0===t.pageLifetimes?c.pageLifetimes:void 0,created:void 0===t.created?c.created:void 0,attached:void 0===t.attached?c.attached:void 0,ready:void 0===t.ready?c.ready:void 0,moved:void 0===t.moved?c.moved:void 0,detached:void 0===t.detached?c.detached:void 0,saved:void 0===t.saved?c.saved:void 0,restored:void 0===t.restored?c.restored:void 0,relations:void 0===t.relations&&c.relations?vf(i,c.relations):void 0,externalClasses:void 0===t.externalClasses?c.externalClasses:void 0,observers:void 0===t.observers?c.observers:void 0,options:bo(bo({},xd),{multipleSlots:!1,writeOnly:!1,writeIdToDOM:!0,domain:r||"/",styleIsolation:v.styleIsolation||"shared",addGlobalClass:!1,innerDataExclude:v.pureDataPattern||null,virtualHost:v.virtualHost||!1}),initiator:function(){this.__customConstructor__=e;var t=Object.create(_);Nd.callerMap.set(t,this),exparser.Element.setMethodCaller(this,t),Object.defineProperties(t,{__data__:{value:this.data,writable:!0,enumerable:!1},__ddWebViewId__:{value:this.__treeManager__.viewId,writable:!0,enumerable:!1}})}};return(_=If(g,u)).__freeData__=l,g.is},initViewThread:function(){pu.setStartOperation((function(e){$c.push(Gc),Gc+=1;try{Df(e)}catch(e){zc();var t="[webview-error]: flowUpdateView error\n";throw e.name&&(t+="["+e.name+"] "),e.message&&(t+=e.message+"\n"),e.stack&&(t+=e.stack),t.length>1e3&&(t=t.substr(0,1e3)+" ..."),Reporter.errorReport({key:"webview-error",type:"flowUpdateView",error:t}),Reporter.ravenReport("pub_saga_error_message_bt",{key:"webview-error",type:"flowUpdateView",error:t,fail:function(e){}}),e}zc()})),vu.instance=vu.create(0)},runComponentDef:function(){Rd=!0,Ff(),Fd.forEach((function(e){return Lf(e,!1)})),Fd=[],Pd.forEach((function(e){return Lf(e,!0)})),Pd=[]},sendTabBarCreationRequest:Ff,addView:function(e,t,r){var n=vu.get(e)||vu.create(e);n.lifetimeListener=r,n.operationFlow.unblock(),function(e,t){t.listenerInited||(t.listenerInited=!0,Uo(Co.SYNC_EVENT_NAME.DD_EVENT,(function(r){var n=r[0],o=r[1],i=r[2],a=t.nodeId.getNodeById(n);if(a){var s=exparser.Element.getMethodCaller(a),u=i._userTap,l=i._requireActive,c=i._relatedInfo;if(l){var d=__appServiceEngine__.getCurrentPagesByDomain("");if(d[d.length-1].__ddWebViewId__!==e)return;delete i._requireActive}c&&delete i._relatedInfo;var f=s&&s[o];Jn(f)&&(u?Su((function(){exparser.safeCallback("Event Handler",f,s,[i],a)})):exparser.safeCallback("Event Handler",f,s,[i],a))}}),e),Uo(Co.SYNC_EVENT_NAME.MODEL_VALUE_CHANGE,(function(e,t,r){var n=e[0];bf(n.data,n.modelValueName,r,n.nodeId)}),e),Uo(Co.SYNC_EVENT_NAME.REQUEST_SAVE,(function(t){Id(e,t)}),e),Uo(Co.SYNC_EVENT_NAME.CALL_METHOD_FROM_DDS,(function(e){uc(e)}),e),Uo(Co.SYNC_EVENT_NAME.ANIMATION_TRANSITION_END,(function(e){var r,n;e&&e[0]&&e[0].reqId&&("function"==typeof(r=t.applyAnimationCbMap[e[0].reqId])&&(delete t.applyAnimationCbMap[e[0].reqId],exparser.safeCallback("Animation",r,null,[])),n=JSON.parse(e[0].args),t.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_SET_NODE_NEXT_ANIMATION_INFO,n]))}),e),Uo(Co.SYNC_EVENT_NAME.CLEAR_ANIMATION_COMPLETE,(function(e){var r;e&&e[0]&&e[0].reqId&&"function"==typeof(r=t.clearAnimationCbMap[e[0].reqId])&&(delete t.clearAnimationCbMap[e[0].reqId],exparser.safeCallback("Clear Animation",r,null,[]))}),e),Uo(Co.SYNC_EVENT_NAME.RESPONSE_VIEW_INFO,(function(e){var r=e[0],n=e[1];if(n){var o=t.viewInfoCbMap[n];o&&o(r)}}),e),Uo(Co.SYNC_EVENT_NAME.UPDATE_PERFORMANCE_STAT,(function(e){var r=e[0],n=e[1],o=t.nodeId.getNodeById(r);o&&o.__updatePerformanceListener__&&exparser.safeCallback("Update Performance Listener",o.__updatePerformanceListener__,exparser.Element.getMethodCaller(o),[n],o)}),e))}(e,n),t=mu(t),Ho(Co.SYNC_EVENT_NAME.LOAD_COMPONENT_DEF,[t],e),yf(t,e),!1;var o=Rf(e,n,t);return function(e){var t=__ddConfig.tabBar&&__ddConfig.tabBar.list;return t instanceof Array&&(t=t.map((function(e){return e&&e.pagePath}))).indexOf(e)>=0}(t)&&Vf(e,!0),o},attachView:function(e,t){var r=vu.get(e);if(r){var n=r.root,o=!1,i={};Object.keys(t).forEach((function(e){exparser.Component.hasProperty(n,e)&&(i[e]=t[e],o=!0)})),o&&r.root.setData(i),Cl()&&(r.initialRootData=t),exparser.Element.pretendAttached(n),r.root.__treeManager__.operationFlow.end()}},removeView:function(e){var t=vu.get(e);t&&(exparser.Element.pretendDetached(t.root),vu.destroy(e),function(e){for(var t in Do[e])Do[e][t]=null,delete Do[e][t];delete Do[e]}(e))},componentAliases:Rc,componentPathToAlias:Fc,getDomainByPluginId:Mc,publishDomainComponents:function(e,t){var r;for(var n in t){var o=t[n];if(!(r=o.match(/^plugin-private:\/\/(.*?)\//)))return;if(Mc(r[1],"0")!==e)return;if(!(r=n.match(/^plugin:\/\/(.*?)\//)))return;Mc(r[1],"0")===e&&(exparser.Component._list[n]||(exparser.Component._list[n]=exparser.Component._list[o],Rc[n]=o,Fc[o]=n))}return{componentAliases:Rc,componentPathToAlias:Fc}},getNodeById:function(e,t){if(Wo()){var r=vu.get(t);return r?r.nodeId.getNodeById(e):null}return vu.instance?vu.instance.nodeId.getNodeById(e):null},getNodeId:function(e,t){return Wo()?vu.get(t).nodeId.getNodeId(e):vu.instance?vu.instance.nodeId.getNodeId(e):""},getRootNodeId:function(e){if(Wo()){var t=vu.get(e);return t?t.rootNodeId:""}return vu.instance.rootNodeId},saveView:Id,restoreView:function(e){var t=vu.get(e);if(t){var r=t.nodeId.getAll(),n={},o=[],i=function(e){var i=t.nodeId.getNodeId(e);o.push(i),n[i]=r[i].data};t.tabRoot&&!t.tabDestroyed&&no(t.tabRoot,1,i),no(t.root,1,i);var a=[t.statesData||{},n,o],s=JSON.stringify(a),u=s.length;if(u>Td){for(var l=[],c=0;c<u;)l.push(s.substr(c,Td)),c+=Td;for(var d=++Od,f=l.length,p=0;p<f;p++)Ho(Co.SYNC_EVENT_NAME.RESTORE_STATE,[{isSplitData:!0,splitInfo:{id:d,index:p+1,total:f,data:l[p]}}],e)}else Ho(Co.SYNC_EVENT_NAME.RESTORE_STATE,a,e);if(t.statesData=void 0,!t.tabDestroyed&&t.tabRoot){Ho(Co.SYNC_EVENT_NAME.COMPONENT_DEF_TAB,t.tabUsedDef,e);var _=t.tabRoot;t.operationFlow.start(),t.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_CREATE_TAB,_.is,t.nodeId.getNodeId(_)]),t.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_CREATE_TAB]),t.operationFlow.end()}Ho(Co.SYNC_EVENT_NAME.COMPONENT_DEF,t.usedDef,e);var h=t.root;t.operationFlow.start(),t.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION,h.is,t.nodeId.getNodeId(h),{}]),t.operationFlow.push([Co.SYNC_EVENT_NAME.FLOW_INITIAL_CREATION]),t.operationFlow.end(),t.tabRoot&&no(t.tabRoot,1,(function(e){e.triggerLifeTime("restored")})),no(t.root,1,(function(e){e.triggerLifeTime("restored")}))}},convertRouteToComponentAlias:mu,convertComponentAliasToRoute:function(e){gu||Eu();var t=exparser.Component._list[e]&&exparser.Component._list[e].is||e;return t=(t=t.replace(/^plugin-private:\/\/([0-9a-zA-Z]+)\//,(function(e,t){return(gu[t]||"")+"__plugin__/"+t+"/"}))).replace(/^dd:\/\//,"__dd__/")},getPluginRoutePrefix:function(e){return gu||Eu(),yu(e)+"__plugin__/"+e+"/"},getPluginSubPackagePrefix:yu,initBannedMap:function(e){Object.keys(e).length>0&&(cc=e,vu.listViewId().forEach((function(t){Ho(Co.SYNC_EVENT_NAME.BANNING_MAP,[e],t,null)})))},beginTapMark:Nu,endTapMark:Cu,checkTapMark:wu,wrapTapMark:Su,updateDdAppCode:function(e,t){var r=wl[e];if(Wo()){if(r)return Sl[e]=t,r(t)}else if(r)return Sl[e]=t,__ddAppCode__[e]=t,r(t)},enableUpdateDdAppCode:function(){Nl=!0},mergeData:function(e){return e},globalThis:Tl};return exparser.globalOptions.createFakeDomElement=!1,exparser.globalOptions.inDocument=!1,exparser.globalOptions.documentBackend="none",exparser.registerBehavior({is:"dd://form-field",properties:{name:{type:null,public:!0},value:{type:null,public:!0}}}),exparser.registerBehavior({is:"dd://form-field-group"}),exparser.registerBehavior({is:"dd://form-field-button"}),exparser.registerBehavior({is:"dd://style-filter"}),exparser.registerBehavior({is:"dd://request-filter"}),exparser.registerBehavior({is:"dd://request-sender"}),exparser.registerBehavior({is:"dd://component-export",definitionFilter:function(e){"function"==typeof e.export&&("object"===su(e.methods)?e.methods.__export__=e.export:e.methods={__export__:e.export})}}),Yf}();


var __appServiceEngine__=function(){"use strict";function e(t){return e="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},e(t)}function t(){return t=Object.assign||function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)Object.prototype.hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},t.apply(this,arguments)}var n="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{};function r(e,t,n){return e(n={path:t,exports:{},require:function(e,t){return function(){throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs")}(null==t&&n.path)}},n.exports),n.exports}var o,i,a=function(e){return e&&e.Math==Math&&e},c=a("object"==typeof globalThis&&globalThis)||a("object"==typeof window&&window)||a("object"==typeof self&&self)||a("object"==typeof n&&n)||function(){return this}()||Function("return this")(),u=function(e){try{return!!e()}catch(e){return!0}},f=!u((function(){return 7!=Object.defineProperty({},1,{get:function(){return 7}})[1]})),l=!u((function(){var e=function(){}.bind();return"function"!=typeof e||e.hasOwnProperty("prototype")})),s=Function.prototype.call,p=l?s.bind(s):function(){return s.apply(s,arguments)},d={}.propertyIsEnumerable,g=Object.getOwnPropertyDescriptor,v={f:g&&!d.call({1:2},1)?function(e){var t=g(this,e);return!!t&&t.enumerable}:d},_=function(e,t){return{enumerable:!(1&e),configurable:!(2&e),writable:!(4&e),value:t}},h=Function.prototype,y=h.bind,b=h.call,m=l&&y.bind(b,b),w=l?function(e){return e&&m(e)}:function(e){return e&&function(){return b.apply(e,arguments)}},S=w({}.toString),P=w("".slice),O=function(e){return P(S(e),8,-1)},R=Object,I=w("".split),T=u((function(){return!R("z").propertyIsEnumerable(0)}))?function(e){return"String"==O(e)?I(e,""):R(e)}:R,E=TypeError,C=function(e){if(null==e)throw E("Can't call method on "+e);return e},x=function(e){return T(C(e))},k=function(e){return"function"==typeof e},j=function(e){return"object"==typeof e?null!==e:k(e)},D=function(e){return k(e)?e:void 0},A=function(e,t){return arguments.length<2?D(c[e]):c[e]&&c[e][t]},L=w({}.isPrototypeOf),B=A("navigator","userAgent")||"",M=c.process,N=c.Deno,F=M&&M.versions||N&&N.version,V=F&&F.v8;V&&(i=(o=V.split("."))[0]>0&&o[0]<4?1:+(o[0]+o[1])),!i&&B&&(!(o=B.match(/Edge\/(\d+)/))||o[1]>=74)&&(o=B.match(/Chrome\/(\d+)/))&&(i=+o[1]);var U=i,G=!!Object.getOwnPropertySymbols&&!u((function(){var e=Symbol();return!String(e)||!(Object(e)instanceof Symbol)||!Symbol.sham&&U&&U<41})),$=G&&!Symbol.sham&&"symbol"==typeof Symbol.iterator,K=Object,W=$?function(e){return"symbol"==typeof e}:function(e){var t=A("Symbol");return k(t)&&L(t.prototype,K(e))},H=String,J=function(e){try{return H(e)}catch(e){return"Object"}},z=TypeError,Y=function(e){if(k(e))return e;throw z(J(e)+" is not a function")},q=function(e,t){var n=e[t];return null==n?void 0:Y(n)},Q=TypeError,X=Object.defineProperty,Z=function(e,t){try{X(c,e,{value:t,configurable:!0,writable:!0})}catch(n){c[e]=t}return t},ee="__core-js_shared__",te=c[ee]||Z(ee,{}),ne=r((function(e){(e.exports=function(e,t){return te[e]||(te[e]=void 0!==t?t:{})})("versions",[]).push({version:"3.24.1",mode:"global",copyright:"© 2014-2022 Denis Pushkarev (zloirock.ru)",license:"https://github.com/zloirock/core-js/blob/v3.24.1/LICENSE",source:"https://github.com/zloirock/core-js"})})),re=Object,oe=function(e){return re(C(e))},ie=w({}.hasOwnProperty),ae=Object.hasOwn||function(e,t){return ie(oe(e),t)},ce=0,ue=Math.random(),fe=w(1..toString),le=function(e){return"Symbol("+(void 0===e?"":e)+")_"+fe(++ce+ue,36)},se=ne("wks"),pe=c.Symbol,de=pe&&pe.for,ge=$?pe:pe&&pe.withoutSetter||le,ve=function(e){if(!ae(se,e)||!G&&"string"!=typeof se[e]){var t="Symbol."+e;G&&ae(pe,e)?se[e]=pe[e]:se[e]=$&&de?de(t):ge(t)}return se[e]},_e=TypeError,he=ve("toPrimitive"),ye=function(e,t){if(!j(e)||W(e))return e;var n,r=q(e,he);if(r){if(void 0===t&&(t="default"),n=p(r,e,t),!j(n)||W(n))return n;throw _e("Can't convert object to primitive value")}return void 0===t&&(t="number"),function(e,t){var n,r;if("string"===t&&k(n=e.toString)&&!j(r=p(n,e)))return r;if(k(n=e.valueOf)&&!j(r=p(n,e)))return r;if("string"!==t&&k(n=e.toString)&&!j(r=p(n,e)))return r;throw Q("Can't convert object to primitive value")}(e,t)},be=function(e){var t=ye(e,"string");return W(t)?t:t+""},me=c.document,we=j(me)&&j(me.createElement),Se=function(e){return we?me.createElement(e):{}},Pe=!f&&!u((function(){return 7!=Object.defineProperty(Se("div"),"a",{get:function(){return 7}}).a})),Oe=Object.getOwnPropertyDescriptor,Re={f:f?Oe:function(e,t){if(e=x(e),t=be(t),Pe)try{return Oe(e,t)}catch(e){}if(ae(e,t))return _(!p(v.f,e,t),e[t])}},Ie=f&&u((function(){return 42!=Object.defineProperty((function(){}),"prototype",{value:42,writable:!1}).prototype})),Te=String,Ee=TypeError,Ce=function(e){if(j(e))return e;throw Ee(Te(e)+" is not an object")},xe=TypeError,ke=Object.defineProperty,je=Object.getOwnPropertyDescriptor,De="enumerable",Ae="configurable",Le="writable",Be={f:f?Ie?function(e,t,n){if(Ce(e),t=be(t),Ce(n),"function"==typeof e&&"prototype"===t&&"value"in n&&Le in n&&!n.writable){var r=je(e,t);r&&r.writable&&(e[t]=n.value,n={configurable:Ae in n?n.configurable:r.configurable,enumerable:De in n?n.enumerable:r.enumerable,writable:!1})}return ke(e,t,n)}:ke:function(e,t,n){if(Ce(e),t=be(t),Ce(n),Pe)try{return ke(e,t,n)}catch(e){}if("get"in n||"set"in n)throw xe("Accessors not supported");return"value"in n&&(e[t]=n.value),e}},Me=f?function(e,t,n){return Be.f(e,t,_(1,n))}:function(e,t,n){return e[t]=n,e},Ne=Function.prototype,Fe=f&&Object.getOwnPropertyDescriptor,Ve=ae(Ne,"name"),Ue={EXISTS:Ve,PROPER:Ve&&"something"===function(){}.name,CONFIGURABLE:Ve&&(!f||f&&Fe(Ne,"name").configurable)},Ge=w(Function.toString);k(te.inspectSource)||(te.inspectSource=function(e){return Ge(e)});var $e,Ke,We,He=te.inspectSource,Je=c.WeakMap,ze=k(Je)&&/native code/.test(He(Je)),Ye=ne("keys"),qe=function(e){return Ye[e]||(Ye[e]=le(e))},Qe={},Xe="Object already initialized",Ze=c.TypeError,et=c.WeakMap;if(ze||te.state){var tt=te.state||(te.state=new et),nt=w(tt.get),rt=w(tt.has),ot=w(tt.set);$e=function(e,t){if(rt(tt,e))throw new Ze(Xe);return t.facade=e,ot(tt,e,t),t},Ke=function(e){return nt(tt,e)||{}},We=function(e){return rt(tt,e)}}else{var it=qe("state");Qe[it]=!0,$e=function(e,t){if(ae(e,it))throw new Ze(Xe);return t.facade=e,Me(e,it,t),t},Ke=function(e){return ae(e,it)?e[it]:{}},We=function(e){return ae(e,it)}}var at={set:$e,get:Ke,has:We,enforce:function(e){return We(e)?Ke(e):$e(e,{})},getterFor:function(e){return function(t){var n;if(!j(t)||(n=Ke(t)).type!==e)throw Ze("Incompatible receiver, "+e+" required");return n}}},ct=r((function(e){var t=Ue.CONFIGURABLE,n=at.enforce,r=at.get,o=Object.defineProperty,i=f&&!u((function(){return 8!==o((function(){}),"length",{value:8}).length})),a=String(String).split("String"),c=e.exports=function(e,r,c){"Symbol("===String(r).slice(0,7)&&(r="["+String(r).replace(/^Symbol\(([^)]*)\)/,"$1")+"]"),c&&c.getter&&(r="get "+r),c&&c.setter&&(r="set "+r),(!ae(e,"name")||t&&e.name!==r)&&(f?o(e,"name",{value:r,configurable:!0}):e.name=r),i&&c&&ae(c,"arity")&&e.length!==c.arity&&o(e,"length",{value:c.arity});try{c&&ae(c,"constructor")&&c.constructor?f&&o(e,"prototype",{writable:!1}):e.prototype&&(e.prototype=void 0)}catch(e){}var u=n(e);return ae(u,"source")||(u.source=a.join("string"==typeof r?r:"")),e};Function.prototype.toString=c((function(){return k(this)&&r(this).source||He(this)}),"toString")})),ut=function(e,t,n,r){r||(r={});var o=r.enumerable,i=void 0!==r.name?r.name:t;if(k(n)&&ct(n,i,r),r.global)o?e[t]=n:Z(t,n);else{try{r.unsafe?e[t]&&(o=!0):delete e[t]}catch(e){}o?e[t]=n:Be.f(e,t,{value:n,enumerable:!1,configurable:!r.nonConfigurable,writable:!r.nonWritable})}return e},ft=Math.ceil,lt=Math.floor,st=Math.trunc||function(e){var t=+e;return(t>0?lt:ft)(t)},pt=function(e){var t=+e;return t!=t||0===t?0:st(t)},dt=Math.max,gt=Math.min,vt=function(e,t){var n=pt(e);return n<0?dt(n+t,0):gt(n,t)},_t=Math.min,ht=function(e){return e>0?_t(pt(e),9007199254740991):0},yt=function(e){return ht(e.length)},bt=function(e){return function(t,n,r){var o,i=x(t),a=yt(i),c=vt(r,a);if(e&&n!=n){for(;a>c;)if((o=i[c++])!=o)return!0}else for(;a>c;c++)if((e||c in i)&&i[c]===n)return e||c||0;return!e&&-1}},mt={includes:bt(!0),indexOf:bt(!1)},wt=mt.indexOf,St=w([].push),Pt=function(e,t){var n,r=x(e),o=0,i=[];for(n in r)!ae(Qe,n)&&ae(r,n)&&St(i,n);for(;t.length>o;)ae(r,n=t[o++])&&(~wt(i,n)||St(i,n));return i},Ot=["constructor","hasOwnProperty","isPrototypeOf","propertyIsEnumerable","toLocaleString","toString","valueOf"],Rt=Ot.concat("length","prototype"),It={f:Object.getOwnPropertyNames||function(e){return Pt(e,Rt)}},Tt={f:Object.getOwnPropertySymbols},Et=w([].concat),Ct=A("Reflect","ownKeys")||function(e){var t=It.f(Ce(e)),n=Tt.f;return n?Et(t,n(e)):t},xt=function(e,t,n){for(var r=Ct(t),o=Be.f,i=Re.f,a=0;a<r.length;a++){var c=r[a];ae(e,c)||n&&ae(n,c)||o(e,c,i(t,c))}},kt=/#|\.prototype\./,jt=function(e,t){var n=At[Dt(e)];return n==Bt||n!=Lt&&(k(t)?u(t):!!t)},Dt=jt.normalize=function(e){return String(e).replace(kt,".").toLowerCase()},At=jt.data={},Lt=jt.NATIVE="N",Bt=jt.POLYFILL="P",Mt=jt,Nt=Re.f,Ft=function(e,t){var n,r,o,i,a,u=e.target,f=e.global,l=e.stat;if(n=f?c:l?c[u]||Z(u,{}):(c[u]||{}).prototype)for(r in t){if(i=t[r],o=e.dontCallGetSet?(a=Nt(n,r))&&a.value:n[r],!Mt(f?r:u+(l?".":"#")+r,e.forced)&&void 0!==o){if(typeof i==typeof o)continue;xt(i,o)}(e.sham||o&&o.sham)&&Me(i,"sham",!0),ut(n,r,i,e)}},Vt={};Vt[ve("toStringTag")]="z";var Ut,Gt="[object z]"===String(Vt),$t=ve("toStringTag"),Kt=Object,Wt="Arguments"==O(function(){return arguments}()),Ht=Gt?O:function(e){var t,n,r;return void 0===e?"Undefined":null===e?"Null":"string"==typeof(n=function(e,t){try{return e[t]}catch(e){}}(t=Kt(e),$t))?n:Wt?O(t):"Object"==(r=O(t))&&k(t.callee)?"Arguments":r},Jt=String,zt=function(e){if("Symbol"===Ht(e))throw TypeError("Cannot convert a Symbol value to a string");return Jt(e)},Yt=function(){var e=Ce(this),t="";return e.hasIndices&&(t+="d"),e.global&&(t+="g"),e.ignoreCase&&(t+="i"),e.multiline&&(t+="m"),e.dotAll&&(t+="s"),e.unicode&&(t+="u"),e.unicodeSets&&(t+="v"),e.sticky&&(t+="y"),t},qt=c.RegExp,Qt=u((function(){var e=qt("a","y");return e.lastIndex=2,null!=e.exec("abcd")})),Xt=Qt||u((function(){return!qt("a","y").sticky})),Zt={BROKEN_CARET:Qt||u((function(){var e=qt("^r","gy");return e.lastIndex=2,null!=e.exec("str")})),MISSED_STICKY:Xt,UNSUPPORTED_Y:Qt},en=Object.keys||function(e){return Pt(e,Ot)},tn=f&&!Ie?Object.defineProperties:function(e,t){Ce(e);for(var n,r=x(t),o=en(t),i=o.length,a=0;i>a;)Be.f(e,n=o[a++],r[n]);return e},nn={f:tn},rn=A("document","documentElement"),on=qe("IE_PROTO"),an=function(){},cn=function(e){return"<script>"+e+"</"+"script>"},un=function(e){e.write(cn("")),e.close();var t=e.parentWindow.Object;return e=null,t},fn=function(){try{Ut=new ActiveXObject("htmlfile")}catch(e){}var e,t;fn="undefined"!=typeof document?document.domain&&Ut?un(Ut):((t=Se("iframe")).style.display="none",rn.appendChild(t),t.src=String("javascript:"),(e=t.contentWindow.document).open(),e.write(cn("document.F=Object")),e.close(),e.F):un(Ut);for(var n=Ot.length;n--;)delete fn.prototype[Ot[n]];return fn()};Qe[on]=!0;var ln=Object.create||function(e,t){var n;return null!==e?(an.prototype=Ce(e),n=new an,an.prototype=null,n[on]=e):n=fn(),void 0===t?n:nn.f(n,t)},sn=c.RegExp,pn=u((function(){var e=sn(".","s");return!(e.dotAll&&e.exec("\n")&&"s"===e.flags)})),dn=c.RegExp,gn=u((function(){var e=dn("(?<a>b)","g");return"b"!==e.exec("b").groups.a||"bc"!=="b".replace(e,"$<a>c")})),vn=at.get,_n=ne("native-string-replace",String.prototype.replace),hn=RegExp.prototype.exec,yn=hn,bn=w("".charAt),mn=w("".indexOf),wn=w("".replace),Sn=w("".slice),Pn=function(){var e=/a/,t=/b*/g;return p(hn,e,"a"),p(hn,t,"a"),0!==e.lastIndex||0!==t.lastIndex}(),On=Zt.BROKEN_CARET,Rn=void 0!==/()??/.exec("")[1];(Pn||Rn||On||pn||gn)&&(yn=function(e){var t,n,r,o,i,a,c,u=this,f=vn(u),l=zt(e),s=f.raw;if(s)return s.lastIndex=u.lastIndex,t=p(yn,s,l),u.lastIndex=s.lastIndex,t;var d=f.groups,g=On&&u.sticky,v=p(Yt,u),_=u.source,h=0,y=l;if(g&&(v=wn(v,"y",""),-1===mn(v,"g")&&(v+="g"),y=Sn(l,u.lastIndex),u.lastIndex>0&&(!u.multiline||u.multiline&&"\n"!==bn(l,u.lastIndex-1))&&(_="(?: "+_+")",y=" "+y,h++),n=new RegExp("^(?:"+_+")",v)),Rn&&(n=new RegExp("^"+_+"$(?!\\s)",v)),Pn&&(r=u.lastIndex),o=p(hn,g?n:u,y),g?o?(o.input=Sn(o.input,h),o[0]=Sn(o[0],h),o.index=u.lastIndex,u.lastIndex+=o[0].length):u.lastIndex=0:Pn&&o&&(u.lastIndex=u.global?o.index+o[0].length:r),Rn&&o&&o.length>1&&p(_n,o[0],n,(function(){for(i=1;i<arguments.length-2;i++)void 0===arguments[i]&&(o[i]=void 0)})),o&&d)for(o.groups=a=ln(null),i=0;i<d.length;i++)a[(c=d[i])[0]]=o[c[1]];return o});var In=yn;Ft({target:"RegExp",proto:!0,forced:/./.exec!==In},{exec:In});var Tn=ve("species"),En=RegExp.prototype,Cn=function(e,t,n,r){var o=ve(e),i=!u((function(){var t={};return t[o]=function(){return 7},7!=""[e](t)})),a=i&&!u((function(){var t=!1,n=/a/;return"split"===e&&((n={}).constructor={},n.constructor[Tn]=function(){return n},n.flags="",n[o]=/./[o]),n.exec=function(){return t=!0,null},n[o](""),!t}));if(!i||!a||n){var c=w(/./[o]),f=t(o,""[e],(function(e,t,n,r,o){var a=w(e),u=t.exec;return u===In||u===En.exec?i&&!o?{done:!0,value:c(t,n,r)}:{done:!0,value:a(n,t,r)}:{done:!1}}));ut(String.prototype,e,f[0]),ut(En,o,f[1])}r&&Me(En[o],"sham",!0)},xn=w("".charAt),kn=w("".charCodeAt),jn=w("".slice),Dn=function(e){return function(t,n){var r,o,i=zt(C(t)),a=pt(n),c=i.length;return a<0||a>=c?e?"":void 0:(r=kn(i,a))<55296||r>56319||a+1===c||(o=kn(i,a+1))<56320||o>57343?e?xn(i,a):r:e?jn(i,a,a+2):o-56320+(r-55296<<10)+65536}},An={codeAt:Dn(!1),charAt:Dn(!0)},Ln=An.charAt,Bn=function(e,t,n){return t+(n?Ln(e,t).length:1)},Mn=TypeError,Nn=function(e,t){var n=e.exec;if(k(n)){var r=p(n,e,t);return null!==r&&Ce(r),r}if("RegExp"===O(e))return p(In,e,t);throw Mn("RegExp#exec called on incompatible receiver")};Cn("match",(function(e,t,n){return[function(t){var n=C(this),r=null==t?void 0:q(t,e);return r?p(r,t,n):new RegExp(t)[e](zt(n))},function(e){var r=Ce(this),o=zt(e),i=n(t,r,o);if(i.done)return i.value;if(!r.global)return Nn(r,o);var a=r.unicode;r.lastIndex=0;for(var c,u=[],f=0;null!==(c=Nn(r,o));){var l=zt(c[0]);u[f]=l,""===l&&(r.lastIndex=Bn(o,ht(r.lastIndex),a)),f++}return 0===f?null:u}]}));var Fn={CSSRuleList:0,CSSStyleDeclaration:0,CSSValueList:0,ClientRectList:0,DOMRectList:0,DOMStringList:0,DOMTokenList:1,DataTransferItemList:0,FileList:0,HTMLAllCollection:0,HTMLCollection:0,HTMLFormElement:0,HTMLSelectElement:0,MediaList:0,MimeTypeArray:0,NamedNodeMap:0,NodeList:1,PaintRequestList:0,Plugin:0,PluginArray:0,SVGLengthList:0,SVGNumberList:0,SVGPathSegList:0,SVGPointList:0,SVGStringList:0,SVGTransformList:0,SourceBufferList:0,StyleSheetList:0,TextTrackCueList:0,TextTrackList:0,TouchList:0},Vn=Se("span").classList,Un=Vn&&Vn.constructor&&Vn.constructor.prototype,Gn=Un===Object.prototype?void 0:Un,$n=w(w.bind),Kn=function(e,t){return Y(e),void 0===t?e:l?$n(e,t):function(){return e.apply(t,arguments)}},Wn=Array.isArray||function(e){return"Array"==O(e)},Hn=function(){},Jn=[],zn=A("Reflect","construct"),Yn=/^\s*(?:class|function)\b/,qn=w(Yn.exec),Qn=!Yn.exec(Hn),Xn=function(e){if(!k(e))return!1;try{return zn(Hn,Jn,e),!0}catch(e){return!1}},Zn=function(e){if(!k(e))return!1;switch(Ht(e)){case"AsyncFunction":case"GeneratorFunction":case"AsyncGeneratorFunction":return!1}try{return Qn||!!qn(Yn,He(e))}catch(e){return!0}};Zn.sham=!0;var er=!zn||u((function(){var e;return Xn(Xn.call)||!Xn(Object)||!Xn((function(){e=!0}))||e}))?Zn:Xn,tr=ve("species"),nr=Array,rr=function(e,t){return new(function(e){var t;return Wn(e)&&(t=e.constructor,(er(t)&&(t===nr||Wn(t.prototype))||j(t)&&null===(t=t[tr]))&&(t=void 0)),void 0===t?nr:t}(e))(0===t?0:t)},or=w([].push),ir=function(e){var t=1==e,n=2==e,r=3==e,o=4==e,i=6==e,a=7==e,c=5==e||i;return function(u,f,l,s){for(var p,d,g=oe(u),v=T(g),_=Kn(f,l),h=yt(v),y=0,b=s||rr,m=t?b(u,h):n||a?b(u,0):void 0;h>y;y++)if((c||y in v)&&(d=_(p=v[y],y,g),e))if(t)m[y]=d;else if(d)switch(e){case 3:return!0;case 5:return p;case 6:return y;case 2:or(m,p)}else switch(e){case 4:return!1;case 7:or(m,p)}return i?-1:r||o?o:m}},ar={forEach:ir(0),map:ir(1),filter:ir(2),some:ir(3),every:ir(4),find:ir(5),findIndex:ir(6),filterReject:ir(7)},cr=function(e,t){var n=[][e];return!!n&&u((function(){n.call(null,t||function(){return 1},1)}))},ur=ar.forEach,fr=cr("forEach")?[].forEach:function(e){return ur(this,e,arguments.length>1?arguments[1]:void 0)},lr=function(e){if(e&&e.forEach!==fr)try{Me(e,"forEach",fr)}catch(t){e.forEach=fr}};for(var sr in Fn)Fn[sr]&&lr(c[sr]&&c[sr].prototype);lr(Gn);var pr=TypeError,dr=function(e){if(e>9007199254740991)throw pr("Maximum allowed index exceeded");return e},gr=function(e,t,n){var r=be(t);r in e?Be.f(e,r,_(0,n)):e[r]=n},vr=ve("species"),_r=function(e){return U>=51||!u((function(){var t=[];return(t.constructor={})[vr]=function(){return{foo:1}},1!==t[e](Boolean).foo}))},hr=ve("isConcatSpreadable"),yr=U>=51||!u((function(){var e=[];return e[hr]=!1,e.concat()[0]!==e})),br=_r("concat"),mr=function(e){if(!j(e))return!1;var t=e[hr];return void 0!==t?!!t:Wn(e)};Ft({target:"Array",proto:!0,arity:1,forced:!yr||!br},{concat:function(e){var t,n,r,o,i,a=oe(this),c=rr(a,0),u=0;for(t=-1,r=arguments.length;t<r;t++)if(mr(i=-1===t?a:arguments[t]))for(o=yt(i),dr(u+o),n=0;n<o;n++,u++)n in i&&gr(c,u,i[n]);else dr(u+1),gr(c,u++,i);return c.length=u,c}});var wr=Function.prototype,Sr=wr.apply,Pr=wr.call,Or="object"==typeof Reflect&&Reflect.apply||(l?Pr.bind(Sr):function(){return Pr.apply(Sr,arguments)}),Rr=Math.floor,Ir=w("".charAt),Tr=w("".replace),Er=w("".slice),Cr=/\$([$&'`]|\d{1,2}|<[^>]*>)/g,xr=/\$([$&'`]|\d{1,2})/g,kr=function(e,t,n,r,o,i){var a=n+e.length,c=r.length,u=xr;return void 0!==o&&(o=oe(o),u=Cr),Tr(i,u,(function(i,u){var f;switch(Ir(u,0)){case"$":return"$";case"&":return e;case"`":return Er(t,0,n);case"'":return Er(t,a);case"<":f=o[Er(u,1,-1)];break;default:var l=+u;if(0===l)return i;if(l>c){var s=Rr(l/10);return 0===s?i:s<=c?void 0===r[s-1]?Ir(u,1):r[s-1]+Ir(u,1):i}f=r[l-1]}return void 0===f?"":f}))},jr=ve("replace"),Dr=Math.max,Ar=Math.min,Lr=w([].concat),Br=w([].push),Mr=w("".indexOf),Nr=w("".slice),Fr="$0"==="a".replace(/./,"$0"),Vr=!!/./[jr]&&""===/./[jr]("a","$0");Cn("replace",(function(e,t,n){var r=Vr?"$":"$0";return[function(e,n){var r=C(this),o=null==e?void 0:q(e,jr);return o?p(o,e,r,n):p(t,zt(r),e,n)},function(e,o){var i=Ce(this),a=zt(e);if("string"==typeof o&&-1===Mr(o,r)&&-1===Mr(o,"$<")){var c=n(t,i,a,o);if(c.done)return c.value}var u=k(o);u||(o=zt(o));var f=i.global;if(f){var l=i.unicode;i.lastIndex=0}for(var s=[];;){var p=Nn(i,a);if(null===p)break;if(Br(s,p),!f)break;""===zt(p[0])&&(i.lastIndex=Bn(a,ht(i.lastIndex),l))}for(var d,g="",v=0,_=0;_<s.length;_++){for(var h=zt((p=s[_])[0]),y=Dr(Ar(pt(p.index),a.length),0),b=[],m=1;m<p.length;m++)Br(b,void 0===(d=p[m])?d:String(d));var w=p.groups;if(u){var S=Lr([h],b,y,a);void 0!==w&&Br(S,w);var P=zt(Or(o,void 0,S))}else P=kr(h,a,y,b,w,o);y>=v&&(g+=Nr(a,v,y)+P,v=y+h.length)}return g+Nr(a,v)}]}),!!u((function(){var e=/./;return e.exec=function(){var e=[];return e.groups={a:"7"},e},"7"!=="".replace(e,"$<a>")}))||!Fr||Vr);var Ur=mt.indexOf,Gr=w([].indexOf),$r=!!Gr&&1/Gr([1],1,-0)<0,Kr=cr("indexOf");Ft({target:"Array",proto:!0,forced:$r||!Kr},{indexOf:function(e){var t=arguments.length>1?arguments[1]:void 0;return $r?Gr(this,e,t)||0:Ur(this,e,t)}});var Wr=Gt?{}.toString:function(){return"[object "+Ht(this)+"]"};Gt||ut(Object.prototype,"toString",Wr,{unsafe:!0});var Hr=RegExp.prototype,Jr=function(e){var t=e.flags;return void 0!==t||"flags"in Hr||ae(e,"flags")||!L(Hr,e)?t:p(Yt,e)},zr=Ue.PROPER,Yr="toString",qr=RegExp.prototype.toString,Qr=u((function(){return"/a/b"!=qr.call({source:"a",flags:"b"})})),Xr=zr&&qr.name!=Yr;(Qr||Xr)&&ut(RegExp.prototype,Yr,(function(){var e=Ce(this);return"/"+zt(e.source)+"/"+zt(Jr(e))}),{unsafe:!0});var Zr=ve("match"),eo=function(e){var t;return j(e)&&(void 0!==(t=e[Zr])?!!t:"RegExp"==O(e))},to=TypeError,no=ve("species"),ro=function(e,t){var n,r=Ce(e).constructor;return void 0===r||null==(n=Ce(r)[no])?t:function(e){if(er(e))return e;throw to(J(e)+" is not a constructor")}(n)},oo=Array,io=Math.max,ao=function(e,t,n){for(var r=yt(e),o=vt(t,r),i=vt(void 0===n?r:n,r),a=oo(io(i-o,0)),c=0;o<i;o++,c++)gr(a,c,e[o]);return a.length=c,a},co=Zt.UNSUPPORTED_Y,uo=4294967295,fo=Math.min,lo=[].push,so=w(/./.exec),po=w(lo),go=w("".slice),vo=!u((function(){var e=/(?:)/,t=e.exec;e.exec=function(){return t.apply(this,arguments)};var n="ab".split(e);return 2!==n.length||"a"!==n[0]||"b"!==n[1]}));Cn("split",(function(e,t,n){var r;return r="c"=="abbc".split(/(b)*/)[1]||4!="test".split(/(?:)/,-1).length||2!="ab".split(/(?:ab)*/).length||4!=".".split(/(.?)(.?)/).length||".".split(/()()/).length>1||"".split(/.?/).length?function(e,n){var r=zt(C(this)),o=void 0===n?uo:n>>>0;if(0===o)return[];if(void 0===e)return[r];if(!eo(e))return p(t,r,e,o);for(var i,a,c,u=[],f=(e.ignoreCase?"i":"")+(e.multiline?"m":"")+(e.unicode?"u":"")+(e.sticky?"y":""),l=0,s=new RegExp(e.source,f+"g");(i=p(In,s,r))&&!((a=s.lastIndex)>l&&(po(u,go(r,l,i.index)),i.length>1&&i.index<r.length&&Or(lo,u,ao(i,1)),c=i[0].length,l=a,u.length>=o));)s.lastIndex===i.index&&s.lastIndex++;return l===r.length?!c&&so(s,"")||po(u,""):po(u,go(r,l)),u.length>o?ao(u,0,o):u}:"0".split(void 0,0).length?function(e,n){return void 0===e&&0===n?[]:p(t,this,e,n)}:t,[function(t,n){var o=C(this),i=null==t?void 0:q(t,e);return i?p(i,t,o,n):p(r,zt(o),t,n)},function(e,o){var i=Ce(this),a=zt(e),c=n(r,i,a,o,r!==t);if(c.done)return c.value;var u=ro(i,RegExp),f=i.unicode,l=(i.ignoreCase?"i":"")+(i.multiline?"m":"")+(i.unicode?"u":"")+(co?"g":"y"),s=new u(co?"^(?:"+i.source+")":i,l),p=void 0===o?uo:o>>>0;if(0===p)return[];if(0===a.length)return null===Nn(s,a)?[a]:[];for(var d=0,g=0,v=[];g<a.length;){s.lastIndex=co?0:g;var _,h=Nn(s,co?go(a,g):a);if(null===h||(_=fo(ht(s.lastIndex+(co?g:0)),a.length))===d)g=Bn(a,g,f);else{if(po(v,go(a,d,g)),v.length===p)return v;for(var y=1;y<=h.length-1;y++)if(po(v,h[y]),v.length===p)return v;g=d=_}}return po(v,go(a,d)),v}]}),!vo,co);var _o,ho,yo,bo,mo="process"==O(c.process),wo=String,So=TypeError,Po=Object.setPrototypeOf||("__proto__"in{}?function(){var e,t=!1,n={};try{(e=w(Object.getOwnPropertyDescriptor(Object.prototype,"__proto__").set))(n,[]),t=n instanceof Array}catch(e){}return function(n,r){return Ce(n),function(e){if("object"==typeof e||k(e))return e;throw So("Can't set "+wo(e)+" as a prototype")}(r),t?e(n,r):n.__proto__=r,n}}():void 0),Oo=Be.f,Ro=ve("toStringTag"),Io=function(e,t,n){e&&!n&&(e=e.prototype),e&&!ae(e,Ro)&&Oo(e,Ro,{configurable:!0,value:t})},To=ve("species"),Eo=function(e){var t=A(e),n=Be.f;f&&t&&!t[To]&&n(t,To,{configurable:!0,get:function(){return this}})},Co=TypeError,xo=w([].slice),ko=TypeError,jo=function(e,t){if(e<t)throw ko("Not enough arguments");return e},Do=/(?:ipad|iphone|ipod).*applewebkit/i.test(B),Ao=c.setImmediate,Lo=c.clearImmediate,Bo=c.process,Mo=c.Dispatch,No=c.Function,Fo=c.MessageChannel,Vo=c.String,Uo=0,Go={},$o="onreadystatechange";try{_o=c.location}catch(e){}var Ko=function(e){if(ae(Go,e)){var t=Go[e];delete Go[e],t()}},Wo=function(e){return function(){Ko(e)}},Ho=function(e){Ko(e.data)},Jo=function(e){c.postMessage(Vo(e),_o.protocol+"//"+_o.host)};Ao&&Lo||(Ao=function(e){jo(arguments.length,1);var t=k(e)?e:No(e),n=xo(arguments,1);return Go[++Uo]=function(){Or(t,void 0,n)},ho(Uo),Uo},Lo=function(e){delete Go[e]},mo?ho=function(e){Bo.nextTick(Wo(e))}:Mo&&Mo.now?ho=function(e){Mo.now(Wo(e))}:Fo&&!Do?(bo=(yo=new Fo).port2,yo.port1.onmessage=Ho,ho=Kn(bo.postMessage,bo)):c.addEventListener&&k(c.postMessage)&&!c.importScripts&&_o&&"file:"!==_o.protocol&&!u(Jo)?(ho=Jo,c.addEventListener("message",Ho,!1)):ho=$o in Se("script")?function(e){rn.appendChild(Se("script")).onreadystatechange=function(){rn.removeChild(this),Ko(e)}}:function(e){setTimeout(Wo(e),0)});var zo,Yo,qo,Qo,Xo,Zo,ei,ti,ni={set:Ao,clear:Lo},ri=/ipad|iphone|ipod/i.test(B)&&void 0!==c.Pebble,oi=/web0s(?!.*chrome)/i.test(B),ii=Re.f,ai=ni.set,ci=c.MutationObserver||c.WebKitMutationObserver,ui=c.document,fi=c.process,li=c.Promise,si=ii(c,"queueMicrotask"),pi=si&&si.value;pi||(zo=function(){var e,t;for(mo&&(e=fi.domain)&&e.exit();Yo;){t=Yo.fn,Yo=Yo.next;try{t()}catch(e){throw Yo?Qo():qo=void 0,e}}qo=void 0,e&&e.enter()},Do||mo||oi||!ci||!ui?!ri&&li&&li.resolve?((ei=li.resolve(void 0)).constructor=li,ti=Kn(ei.then,ei),Qo=function(){ti(zo)}):mo?Qo=function(){fi.nextTick(zo)}:(ai=Kn(ai,c),Qo=function(){ai(zo)}):(Xo=!0,Zo=ui.createTextNode(""),new ci(zo).observe(Zo,{characterData:!0}),Qo=function(){Zo.data=Xo=!Xo}));var di=pi||function(e){var t={fn:e,next:void 0};qo&&(qo.next=t),Yo||(Yo=t,Qo()),qo=t},gi=function(e){try{return{error:!1,value:e()}}catch(e){return{error:!0,value:e}}},vi=function(){this.head=null,this.tail=null};vi.prototype={add:function(e){var t={item:e,next:null};this.head?this.tail.next=t:this.head=t,this.tail=t},get:function(){var e=this.head;if(e)return this.head=e.next,this.tail===e&&(this.tail=null),e.item}};var _i,hi,yi,bi=vi,mi=c.Promise,wi="object"==typeof Deno&&Deno&&"object"==typeof Deno.version,Si=!wi&&!mo&&"object"==typeof window&&"object"==typeof document,Pi=(mi&&mi.prototype,ve("species")),Oi=!1,Ri=k(c.PromiseRejectionEvent),Ii=Mt("Promise",(function(){var e=He(mi),t=e!==String(mi);if(!t&&66===U)return!0;if(!U||U<51||!/native code/.test(e)){var n=new mi((function(e){e(1)})),r=function(e){e((function(){}),(function(){}))};if((n.constructor={})[Pi]=r,!(Oi=n.then((function(){}))instanceof r))return!0}return!t&&(Si||wi)&&!Ri})),Ti={CONSTRUCTOR:Ii,REJECTION_EVENT:Ri,SUBCLASSING:Oi},Ei=function(e){var t,n;this.promise=new e((function(e,r){if(void 0!==t||void 0!==n)throw TypeError("Bad Promise constructor");t=e,n=r})),this.resolve=Y(t),this.reject=Y(n)},Ci={f:function(e){return new Ei(e)}},xi=ni.set,ki="Promise",ji=Ti.CONSTRUCTOR,Di=Ti.REJECTION_EVENT,Ai=Ti.SUBCLASSING,Li=at.getterFor(ki),Bi=at.set,Mi=mi&&mi.prototype,Ni=mi,Fi=Mi,Vi=c.TypeError,Ui=c.document,Gi=c.process,$i=Ci.f,Ki=$i,Wi=!!(Ui&&Ui.createEvent&&c.dispatchEvent),Hi="unhandledrejection",Ji=function(e){var t;return!(!j(e)||!k(t=e.then))&&t},zi=function(e,t){var n,r,o,i=t.value,a=1==t.state,c=a?e.ok:e.fail,u=e.resolve,f=e.reject,l=e.domain;try{c?(a||(2===t.rejection&&Zi(t),t.rejection=1),!0===c?n=i:(l&&l.enter(),n=c(i),l&&(l.exit(),o=!0)),n===e.promise?f(Vi("Promise-chain cycle")):(r=Ji(n))?p(r,n,u,f):u(n)):f(i)}catch(e){l&&!o&&l.exit(),f(e)}},Yi=function(e,t){e.notified||(e.notified=!0,di((function(){for(var n,r=e.reactions;n=r.get();)zi(n,e);e.notified=!1,t&&!e.rejection&&Qi(e)})))},qi=function(e,t,n){var r,o;Wi?((r=Ui.createEvent("Event")).promise=t,r.reason=n,r.initEvent(e,!1,!0),c.dispatchEvent(r)):r={promise:t,reason:n},!Di&&(o=c["on"+e])?o(r):e===Hi&&function(e,t){var n=c.console;n&&n.error&&(1==arguments.length?n.error(e):n.error(e,t))}("Unhandled promise rejection",n)},Qi=function(e){p(xi,c,(function(){var t,n=e.facade,r=e.value;if(Xi(e)&&(t=gi((function(){mo?Gi.emit("unhandledRejection",r,n):qi(Hi,n,r)})),e.rejection=mo||Xi(e)?2:1,t.error))throw t.value}))},Xi=function(e){return 1!==e.rejection&&!e.parent},Zi=function(e){p(xi,c,(function(){var t=e.facade;mo?Gi.emit("rejectionHandled",t):qi("rejectionhandled",t,e.value)}))},ea=function(e,t,n){return function(r){e(t,r,n)}},ta=function(e,t,n){e.done||(e.done=!0,n&&(e=n),e.value=t,e.state=2,Yi(e,!0))},na=function(e,t,n){if(!e.done){e.done=!0,n&&(e=n);try{if(e.facade===t)throw Vi("Promise can't be resolved itself");var r=Ji(t);r?di((function(){var n={done:!1};try{p(r,t,ea(na,n,e),ea(ta,n,e))}catch(t){ta(n,t,e)}})):(e.value=t,e.state=1,Yi(e,!1))}catch(t){ta({done:!1},t,e)}}};if(ji&&(Fi=(Ni=function(e){!function(e,t){if(L(t,e))return e;throw Co("Incorrect invocation")}(this,Fi),Y(e),p(_i,this);var t=Li(this);try{e(ea(na,t),ea(ta,t))}catch(e){ta(t,e)}}).prototype,(_i=function(e){Bi(this,{type:ki,done:!1,notified:!1,parent:!1,reactions:new bi,rejection:!1,state:0,value:void 0})}).prototype=ut(Fi,"then",(function(e,t){var n=Li(this),r=$i(ro(this,Ni));return n.parent=!0,r.ok=!k(e)||e,r.fail=k(t)&&t,r.domain=mo?Gi.domain:void 0,0==n.state?n.reactions.add(r):di((function(){zi(r,n)})),r.promise})),hi=function(){var e=new _i,t=Li(e);this.promise=e,this.resolve=ea(na,t),this.reject=ea(ta,t)},Ci.f=$i=function(e){return e===Ni||undefined===e?new hi(e):Ki(e)},k(mi)&&Mi!==Object.prototype)){yi=Mi.then,Ai||ut(Mi,"then",(function(e,t){var n=this;return new Ni((function(e,t){p(yi,n,e,t)})).then(e,t)}),{unsafe:!0});try{delete Mi.constructor}catch(e){}Po&&Po(Mi,Fi)}Ft({global:!0,constructor:!0,wrap:!0,forced:ji},{Promise:Ni}),Io(Ni,ki,!1),Eo(ki);var ra={},oa=ve("iterator"),ia=Array.prototype,aa=function(e){return void 0!==e&&(ra.Array===e||ia[oa]===e)},ca=ve("iterator"),ua=function(e){if(null!=e)return q(e,ca)||q(e,"@@iterator")||ra[Ht(e)]},fa=TypeError,la=function(e,t){var n=arguments.length<2?ua(e):t;if(Y(n))return Ce(p(n,e));throw fa(J(e)+" is not iterable")},sa=function(e,t,n){var r,o;Ce(e);try{if(!(r=q(e,"return"))){if("throw"===t)throw n;return n}r=p(r,e)}catch(e){o=!0,r=e}if("throw"===t)throw n;if(o)throw r;return Ce(r),n},pa=TypeError,da=function(e,t){this.stopped=e,this.result=t},ga=da.prototype,va=function(e,t,n){var r,o,i,a,c,u,f,l=n&&n.that,s=!(!n||!n.AS_ENTRIES),d=!(!n||!n.IS_RECORD),g=!(!n||!n.IS_ITERATOR),v=!(!n||!n.INTERRUPTED),_=Kn(t,l),h=function(e){return r&&sa(r,"normal",e),new da(!0,e)},y=function(e){return s?(Ce(e),v?_(e[0],e[1],h):_(e[0],e[1])):v?_(e,h):_(e)};if(d)r=e.iterator;else if(g)r=e;else{if(!(o=ua(e)))throw pa(J(e)+" is not iterable");if(aa(o)){for(i=0,a=yt(e);a>i;i++)if((c=y(e[i]))&&L(ga,c))return c;return new da(!1)}r=la(e,o)}for(u=d?e.next:r.next;!(f=p(u,r)).done;){try{c=y(f.value)}catch(e){sa(r,"throw",e)}if("object"==typeof c&&c&&L(ga,c))return c}return new da(!1)},_a=ve("iterator"),ha=!1;try{var ya=0,ba={next:function(){return{done:!!ya++}},return:function(){ha=!0}};ba[_a]=function(){return this},Array.from(ba,(function(){throw 2}))}catch(e){}var ma=function(e,t){if(!t&&!ha)return!1;var n=!1;try{var r={};r[_a]=function(){return{next:function(){return{done:n=!0}}}},e(r)}catch(e){}return n},wa=Ti.CONSTRUCTOR||!ma((function(e){mi.all(e).then(void 0,(function(){}))}));Ft({target:"Promise",stat:!0,forced:wa},{all:function(e){var t=this,n=Ci.f(t),r=n.resolve,o=n.reject,i=gi((function(){var n=Y(t.resolve),i=[],a=0,c=1;va(e,(function(e){var u=a++,f=!1;c++,p(n,t,e).then((function(e){f||(f=!0,i[u]=e,--c||r(i))}),o)})),--c||r(i)}));return i.error&&o(i.value),n.promise}});var Sa=Ti.CONSTRUCTOR,Pa=mi&&mi.prototype;if(Ft({target:"Promise",proto:!0,forced:Sa,real:!0},{catch:function(e){return this.then(void 0,e)}}),k(mi)){var Oa=A("Promise").prototype.catch;Pa.catch!==Oa&&ut(Pa,"catch",Oa,{unsafe:!0})}Ft({target:"Promise",stat:!0,forced:wa},{race:function(e){var t=this,n=Ci.f(t),r=n.reject,o=gi((function(){var o=Y(t.resolve);va(e,(function(e){p(o,t,e).then(n.resolve,r)}))}));return o.error&&r(o.value),n.promise}}),Ft({target:"Promise",stat:!0,forced:Ti.CONSTRUCTOR},{reject:function(e){var t=Ci.f(this);return p(t.reject,void 0,e),t.promise}});var Ra=Ti.CONSTRUCTOR;A("Promise");Ft({target:"Promise",stat:!0,forced:Ra},{resolve:function(e){return function(e,t){if(Ce(e),j(t)&&t.constructor===e)return t;var n=Ci.f(e);return(0,n.resolve)(t),n.promise}(this,e)}});var Ia=Be.f,Ta=ve("unscopables"),Ea=Array.prototype;null==Ea[Ta]&&Ia(Ea,Ta,{configurable:!0,value:ln(null)});var Ca,xa,ka,ja=function(e){Ea[Ta][e]=!0},Da=!u((function(){function e(){}return e.prototype.constructor=null,Object.getPrototypeOf(new e)!==e.prototype})),Aa=qe("IE_PROTO"),La=Object,Ba=La.prototype,Ma=Da?La.getPrototypeOf:function(e){var t=oe(e);if(ae(t,Aa))return t[Aa];var n=t.constructor;return k(n)&&t instanceof n?n.prototype:t instanceof La?Ba:null},Na=ve("iterator"),Fa=!1;[].keys&&("next"in(ka=[].keys())?(xa=Ma(Ma(ka)))!==Object.prototype&&(Ca=xa):Fa=!0);var Va=null==Ca||u((function(){var e={};return Ca[Na].call(e)!==e}));Va&&(Ca={}),k(Ca[Na])||ut(Ca,Na,(function(){return this}));var Ua={IteratorPrototype:Ca,BUGGY_SAFARI_ITERATORS:Fa},Ga=Ua.IteratorPrototype,$a=function(){return this},Ka=Ue.PROPER,Wa=Ue.CONFIGURABLE,Ha=Ua.IteratorPrototype,Ja=Ua.BUGGY_SAFARI_ITERATORS,za=ve("iterator"),Ya="keys",qa="values",Qa="entries",Xa=function(){return this},Za=function(e,t,n,r,o,i,a){!function(e,t,n,r){var o=t+" Iterator";e.prototype=ln(Ga,{next:_(+!r,n)}),Io(e,o,!1),ra[o]=$a}(n,t,r);var c,u,f,l=function(e){if(e===o&&h)return h;if(!Ja&&e in g)return g[e];switch(e){case Ya:case qa:case Qa:return function(){return new n(this,e)}}return function(){return new n(this)}},s=t+" Iterator",d=!1,g=e.prototype,v=g[za]||g["@@iterator"]||o&&g[o],h=!Ja&&v||l(o),y="Array"==t&&g.entries||v;if(y&&(c=Ma(y.call(new e)))!==Object.prototype&&c.next&&(Ma(c)!==Ha&&(Po?Po(c,Ha):k(c[za])||ut(c,za,Xa)),Io(c,s,!0)),Ka&&o==qa&&v&&v.name!==qa&&(Wa?Me(g,"name",qa):(d=!0,h=function(){return p(v,this)})),o)if(u={values:l(qa),keys:i?h:l(Ya),entries:l(Qa)},a)for(f in u)(Ja||d||!(f in g))&&ut(g,f,u[f]);else Ft({target:t,proto:!0,forced:Ja||d},u);return g[za]!==h&&ut(g,za,h,{name:o}),ra[t]=h,u},ec=Be.f,tc="Array Iterator",nc=at.set,rc=at.getterFor(tc),oc=Za(Array,"Array",(function(e,t){nc(this,{type:tc,target:x(e),index:0,kind:t})}),(function(){var e=rc(this),t=e.target,n=e.kind,r=e.index++;return!t||r>=t.length?(e.target=void 0,{value:void 0,done:!0}):"keys"==n?{value:r,done:!1}:"values"==n?{value:t[r],done:!1}:{value:[r,t[r]],done:!1}}),"values"),ic=ra.Arguments=ra.Array;if(ja("keys"),ja("values"),ja("entries"),f&&"values"!==ic.name)try{ec(ic,"name",{value:"values"})}catch(e){}var ac=An.charAt,cc="String Iterator",uc=at.set,fc=at.getterFor(cc);Za(String,"String",(function(e){uc(this,{type:cc,string:zt(e),index:0})}),(function(){var e,t=fc(this),n=t.string,r=t.index;return r>=n.length?{value:void 0,done:!0}:(e=ac(n,r),t.index+=e.length,{value:e,done:!1})}));var lc=ve("iterator"),sc=ve("toStringTag"),pc=oc.values,dc=function(e,t){if(e){if(e[lc]!==pc)try{Me(e,lc,pc)}catch(t){e[lc]=pc}if(e[sc]||Me(e,sc,t),Fn[t])for(var n in oc)if(e[n]!==oc[n])try{Me(e,n,oc[n])}catch(t){e[n]=oc[n]}}};for(var gc in Fn)dc(c[gc]&&c[gc].prototype,gc);dc(Gn,"DOMTokenList");var vc=TypeError,_c=function(e,t){if(!delete e[t])throw vc("Cannot delete property "+J(t)+" of "+J(e))},hc=_r("splice"),yc=Math.max,bc=Math.min;Ft({target:"Array",proto:!0,forced:!hc},{splice:function(e,t){var n,r,o,i,a,c,u=oe(this),f=yt(u),l=vt(e,f),s=arguments.length;for(0===s?n=r=0:1===s?(n=0,r=f-l):(n=s-2,r=bc(yc(pt(t),0),f-l)),dr(f+n-r),o=rr(u,r),i=0;i<r;i++)(a=l+i)in u&&gr(o,i,u[a]);if(o.length=r,n<r){for(i=l;i<f-r;i++)c=i+n,(a=i+r)in u?u[c]=u[a]:_c(u,c);for(i=f;i>f-r+n;i--)_c(u,i-1)}else if(n>r)for(i=f-r;i>l;i--)c=i+n-1,(a=i+r-1)in u?u[c]=u[a]:_c(u,c);for(i=0;i<n;i++)u[i+l]=arguments[i+2];return u.length=f-r+n,o}});var mc=u((function(){en(1)}));Ft({target:"Object",stat:!0,forced:mc},{keys:function(e){return en(oe(e))}});var wc=_r("slice"),Sc=ve("species"),Pc=Array,Oc=Math.max;Ft({target:"Array",proto:!0,forced:!wc},{slice:function(e,t){var n,r,o,i=x(this),a=yt(i),c=vt(e,a),u=vt(void 0===t?a:t,a);if(Wn(i)&&(n=i.constructor,(er(n)&&(n===Pc||Wn(n.prototype))||j(n)&&null===(n=n[Sc]))&&(n=void 0),n===Pc||void 0===n))return xo(i,c,u);for(r=new(void 0===n?Pc:n)(Oc(u-c,0)),o=0;c<u;c++,o++)c in i&&gr(r,o,i[c]);return r.length=o,r}});var Rc,Ic="\t\n\v\f\r                　\u2028\u2029\ufeff",Tc=w("".replace),Ec="["+Ic+"]",Cc=RegExp("^"+Ec+Ec+"*"),xc=RegExp(Ec+Ec+"*$"),kc=function(e){return function(t){var n=zt(C(t));return 1&e&&(n=Tc(n,Cc,"")),2&e&&(n=Tc(n,xc,"")),n}},jc={start:kc(1),end:kc(2),trim:kc(3)},Dc=Ue.PROPER,Ac=jc.trim;Ft({target:"String",proto:!0,forced:(Rc="trim",u((function(){return!!Ic[Rc]()||"​᠎"!=="​᠎"[Rc]()||Dc&&Ic[Rc].name!==Rc})))},{trim:function(){return Ac(this)}});var Lc=function(e,t,n){var r,o;return Po&&k(r=t.constructor)&&r!==n&&j(o=r.prototype)&&o!==n.prototype&&Po(e,o),e},Bc=w(1..valueOf),Mc=It.f,Nc=Re.f,Fc=Be.f,Vc=jc.trim,Uc="Number",Gc=c.Number,$c=Gc.prototype,Kc=c.TypeError,Wc=w("".slice),Hc=w("".charCodeAt),Jc=function(e){var t=ye(e,"number");return"bigint"==typeof t?t:zc(t)},zc=function(e){var t,n,r,o,i,a,c,u,f=ye(e,"number");if(W(f))throw Kc("Cannot convert a Symbol value to a number");if("string"==typeof f&&f.length>2)if(f=Vc(f),43===(t=Hc(f,0))||45===t){if(88===(n=Hc(f,2))||120===n)return NaN}else if(48===t){switch(Hc(f,1)){case 66:case 98:r=2,o=49;break;case 79:case 111:r=8,o=55;break;default:return+f}for(a=(i=Wc(f,2)).length,c=0;c<a;c++)if((u=Hc(i,c))<48||u>o)return NaN;return parseInt(i,r)}return+f};if(Mt(Uc,!Gc(" 0o1")||!Gc("0b1")||Gc("+0x1"))){for(var Yc,qc=function(e){var t=arguments.length<1?0:Gc(Jc(e)),n=this;return L($c,n)&&u((function(){Bc(n)}))?Lc(Object(t),n,qc):t},Qc=f?Mc(Gc):"MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,EPSILON,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,isFinite,isInteger,isNaN,isSafeInteger,parseFloat,parseInt,fromString,range".split(","),Xc=0;Qc.length>Xc;Xc++)ae(Gc,Yc=Qc[Xc])&&!ae(qc,Yc)&&Fc(qc,Yc,Nc(Gc,Yc));qc.prototype=$c,$c.constructor=qc,ut(c,Uc,qc,{constructor:!0})}var Zc=ar.map,eu=_r("map");Ft({target:"Array",proto:!0,forced:!eu},{map:function(e){return Zc(this,e,arguments.length>1?arguments[1]:void 0)}});var tu=ar.findIndex,nu="findIndex",ru=!0;nu in[]&&Array(1).findIndex((function(){ru=!1})),Ft({target:"Array",proto:!0,forced:ru},{findIndex:function(e){return tu(this,e,arguments.length>1?arguments[1]:void 0)}}),ja(nu);var ou=Math.min,iu=[].lastIndexOf,au=!!iu&&1/[1].lastIndexOf(1,-0)<0,cu=cr("lastIndexOf"),uu=au||!cu?function(e){if(au)return Or(iu,this,arguments)||0;var t=x(this),n=yt(t),r=n-1;for(arguments.length>1&&(r=ou(r,pt(arguments[1]))),r<0&&(r=n+r);r>=0;r--)if(r in t&&t[r]===e)return r||0;return-1}:iu;Ft({target:"Array",proto:!0,forced:uu!==[].lastIndexOf},{lastIndexOf:uu});var fu=Be.f,lu=function(e,t,n){n in e||fu(e,n,{configurable:!0,get:function(){return t[n]},set:function(e){t[n]=e}})},su=It.f,pu=at.enforce,du=ve("match"),gu=c.RegExp,vu=gu.prototype,_u=c.SyntaxError,hu=w(vu.exec),yu=w("".charAt),bu=w("".replace),mu=w("".indexOf),wu=w("".slice),Su=/^\?<[^\s\d!#%&*+<=>@^][^\s!#%&*+<=>@^]*>/,Pu=/a/g,Ou=/a/g,Ru=new gu(Pu)!==Pu,Iu=Zt.MISSED_STICKY,Tu=Zt.UNSUPPORTED_Y,Eu=f&&(!Ru||Iu||pn||gn||u((function(){return Ou[du]=!1,gu(Pu)!=Pu||gu(Ou)==Ou||"/a/i"!=gu(Pu,"i")})));if(Mt("RegExp",Eu)){for(var Cu=function(e,t){var n,r,o,i,a,c,u=L(vu,this),f=eo(e),l=void 0===t,s=[],p=e;if(!u&&f&&l&&e.constructor===Cu)return e;if((f||L(vu,e))&&(e=e.source,l&&(t=Jr(p))),e=void 0===e?"":zt(e),t=void 0===t?"":zt(t),p=e,pn&&"dotAll"in Pu&&(r=!!t&&mu(t,"s")>-1)&&(t=bu(t,/s/g,"")),n=t,Iu&&"sticky"in Pu&&(o=!!t&&mu(t,"y")>-1)&&Tu&&(t=bu(t,/y/g,"")),gn&&(i=function(e){for(var t,n=e.length,r=0,o="",i=[],a={},c=!1,u=!1,f=0,l="";r<=n;r++){if("\\"===(t=yu(e,r)))t+=yu(e,++r);else if("]"===t)c=!1;else if(!c)switch(!0){case"["===t:c=!0;break;case"("===t:hu(Su,wu(e,r+1))&&(r+=2,u=!0),o+=t,f++;continue;case">"===t&&u:if(""===l||ae(a,l))throw new _u("Invalid capture group name");a[l]=!0,i[i.length]=[l,f],u=!1,l="";continue}u?l+=t:o+=t}return[o,i]}(e),e=i[0],s=i[1]),a=Lc(gu(e,t),u?this:vu,Cu),(r||o||s.length)&&(c=pu(a),r&&(c.dotAll=!0,c.raw=Cu(function(e){for(var t,n=e.length,r=0,o="",i=!1;r<=n;r++)"\\"!==(t=yu(e,r))?i||"."!==t?("["===t?i=!0:"]"===t&&(i=!1),o+=t):o+="[\\s\\S]":o+=t+yu(e,++r);return o}(e),n)),o&&(c.sticky=!0),s.length&&(c.groups=s)),e!==p)try{Me(a,"source",""===p?"(?:)":p)}catch(e){}return a},xu=su(gu),ku=0;xu.length>ku;)lu(Cu,gu,xu[ku++]);vu.constructor=Cu,Cu.prototype=vu,ut(c,"RegExp",Cu,{constructor:!0})}Eo("RegExp");var ju=It.f,Du="object"==typeof window&&window&&Object.getOwnPropertyNames?Object.getOwnPropertyNames(window):[],Au={f:function(e){return Du&&"Window"==O(e)?function(e){try{return ju(e)}catch(e){return ao(Du)}}(e):ju(x(e))}},Lu={f:ve},Bu=c,Mu=Be.f,Nu=function(e){var t=Bu.Symbol||(Bu.Symbol={});ae(t,e)||Mu(t,e,{value:Lu.f(e)})},Fu=ar.forEach,Vu=qe("hidden"),Uu="Symbol",Gu=at.set,$u=at.getterFor(Uu),Ku=Object.prototype,Wu=c.Symbol,Hu=Wu&&Wu.prototype,Ju=c.TypeError,zu=c.QObject,Yu=Re.f,qu=Be.f,Qu=Au.f,Xu=v.f,Zu=w([].push),ef=ne("symbols"),tf=ne("op-symbols"),nf=ne("wks"),rf=!zu||!zu.prototype||!zu.prototype.findChild,of=f&&u((function(){return 7!=ln(qu({},"a",{get:function(){return qu(this,"a",{value:7}).a}})).a}))?function(e,t,n){var r=Yu(Ku,t);r&&delete Ku[t],qu(e,t,n),r&&e!==Ku&&qu(Ku,t,r)}:qu,af=function(e,t){var n=ef[e]=ln(Hu);return Gu(n,{type:Uu,tag:e,description:t}),f||(n.description=t),n},cf=function(e,t,n){e===Ku&&cf(tf,t,n),Ce(e);var r=be(t);return Ce(n),ae(ef,r)?(n.enumerable?(ae(e,Vu)&&e[Vu][r]&&(e[Vu][r]=!1),n=ln(n,{enumerable:_(0,!1)})):(ae(e,Vu)||qu(e,Vu,_(1,{})),e[Vu][r]=!0),of(e,r,n)):qu(e,r,n)},uf=function(e,t){Ce(e);var n=x(t),r=en(n).concat(pf(n));return Fu(r,(function(t){f&&!p(ff,n,t)||cf(e,t,n[t])})),e},ff=function(e){var t=be(e),n=p(Xu,this,t);return!(this===Ku&&ae(ef,t)&&!ae(tf,t))&&(!(n||!ae(this,t)||!ae(ef,t)||ae(this,Vu)&&this[Vu][t])||n)},lf=function(e,t){var n=x(e),r=be(t);if(n!==Ku||!ae(ef,r)||ae(tf,r)){var o=Yu(n,r);return!o||!ae(ef,r)||ae(n,Vu)&&n[Vu][r]||(o.enumerable=!0),o}},sf=function(e){var t=Qu(x(e)),n=[];return Fu(t,(function(e){ae(ef,e)||ae(Qe,e)||Zu(n,e)})),n},pf=function(e){var t=e===Ku,n=Qu(t?tf:x(e)),r=[];return Fu(n,(function(e){!ae(ef,e)||t&&!ae(Ku,e)||Zu(r,ef[e])})),r};G||(Wu=function(){if(L(Hu,this))throw Ju("Symbol is not a constructor");var e=arguments.length&&void 0!==arguments[0]?zt(arguments[0]):void 0,t=le(e),n=function(e){this===Ku&&p(n,tf,e),ae(this,Vu)&&ae(this[Vu],t)&&(this[Vu][t]=!1),of(this,t,_(1,e))};return f&&rf&&of(Ku,t,{configurable:!0,set:n}),af(t,e)},Hu=Wu.prototype,ut(Hu,"toString",(function(){return $u(this).tag})),ut(Wu,"withoutSetter",(function(e){return af(le(e),e)})),v.f=ff,Be.f=cf,nn.f=uf,Re.f=lf,It.f=Au.f=sf,Tt.f=pf,Lu.f=function(e){return af(ve(e),e)},f&&(qu(Hu,"description",{configurable:!0,get:function(){return $u(this).description}}),ut(Ku,"propertyIsEnumerable",ff,{unsafe:!0}))),Ft({global:!0,constructor:!0,wrap:!0,forced:!G,sham:!G},{Symbol:Wu}),Fu(en(nf),(function(e){Nu(e)})),Ft({target:Uu,stat:!0,forced:!G},{useSetter:function(){rf=!0},useSimple:function(){rf=!1}}),Ft({target:"Object",stat:!0,forced:!G,sham:!f},{create:function(e,t){return void 0===t?ln(e):uf(ln(e),t)},defineProperty:cf,defineProperties:uf,getOwnPropertyDescriptor:lf}),Ft({target:"Object",stat:!0,forced:!G},{getOwnPropertyNames:sf}),function(){var e=A("Symbol"),t=e&&e.prototype,n=t&&t.valueOf,r=ve("toPrimitive");t&&!t[r]&&ut(t,r,(function(e){return p(n,this)}),{arity:1})}(),Io(Wu,Uu),Qe[Vu]=!0;var df=G&&!!Symbol.for&&!!Symbol.keyFor,gf=ne("string-to-symbol-registry"),vf=ne("symbol-to-string-registry");Ft({target:"Symbol",stat:!0,forced:!df},{for:function(e){var t=zt(e);if(ae(gf,t))return gf[t];var n=A("Symbol")(t);return gf[t]=n,vf[n]=t,n}});var _f=ne("symbol-to-string-registry");Ft({target:"Symbol",stat:!0,forced:!df},{keyFor:function(e){if(!W(e))throw TypeError(J(e)+" is not a symbol");if(ae(_f,e))return _f[e]}});var hf=A("JSON","stringify"),yf=w(/./.exec),bf=w("".charAt),mf=w("".charCodeAt),wf=w("".replace),Sf=w(1..toString),Pf=/[\uD800-\uDFFF]/g,Of=/^[\uD800-\uDBFF]$/,Rf=/^[\uDC00-\uDFFF]$/,If=!G||u((function(){var e=A("Symbol")();return"[null]"!=hf([e])||"{}"!=hf({a:e})||"{}"!=hf(Object(e))})),Tf=u((function(){return'"\\udf06\\ud834"'!==hf("\udf06\ud834")||'"\\udead"'!==hf("\udead")})),Ef=function(e,t){var n=xo(arguments),r=t;if((j(t)||void 0!==e)&&!W(e))return Wn(t)||(t=function(e,t){if(k(r)&&(t=p(r,this,e,t)),!W(t))return t}),n[1]=t,Or(hf,null,n)},Cf=function(e,t,n){var r=bf(n,t-1),o=bf(n,t+1);return yf(Of,e)&&!yf(Rf,o)||yf(Rf,e)&&!yf(Of,r)?"\\u"+Sf(mf(e,0),16):e};hf&&Ft({target:"JSON",stat:!0,arity:3,forced:If||Tf},{stringify:function(e,t,n){var r=xo(arguments),o=Or(If?Ef:hf,null,r);return Tf&&"string"==typeof o?wf(o,Pf,Cf):o}});var xf=!G||u((function(){Tt.f(1)}));Ft({target:"Object",stat:!0,forced:xf},{getOwnPropertySymbols:function(e){var t=Tt.f;return t?t(oe(e)):[]}});var kf=Be.f,jf=c.Symbol,Df=jf&&jf.prototype;if(f&&k(jf)&&(!("description"in Df)||void 0!==jf().description)){var Af={},Lf=function(){var e=arguments.length<1||void 0===arguments[0]?void 0:zt(arguments[0]),t=L(Df,this)?new jf(e):void 0===e?jf():jf(e);return""===e&&(Af[t]=!0),t};xt(Lf,jf),Lf.prototype=Df,Df.constructor=Lf;var Bf="Symbol(test)"==String(jf("test")),Mf=w(Df.toString),Nf=w(Df.valueOf),Ff=/^Symbol\((.*)\)[^)]+$/,Vf=w("".replace),Uf=w("".slice);kf(Df,"description",{configurable:!0,get:function(){var e=Nf(this),t=Mf(e);if(ae(Af,e))return"";var n=Bf?Uf(t,7,-1):Vf(t,Ff,"$1");return""===n?void 0:n}}),Ft({global:!0,constructor:!0,forced:!0},{Symbol:Lf})}var Gf=u((function(){Ma(1)}));Ft({target:"Object",stat:!0,forced:Gf,sham:!Da},{getPrototypeOf:function(e){return Ma(oe(e))}}),Nu("iterator");var $f=function(e,t,n,r){try{return r?t(Ce(n)[0],n[1]):t(n)}catch(t){sa(e,"throw",t)}},Kf=Array,Wf=!ma((function(e){Array.from(e)}));Ft({target:"Array",stat:!0,forced:Wf},{from:function(e){var t=oe(e),n=er(this),r=arguments.length,o=r>1?arguments[1]:void 0,i=void 0!==o;i&&(o=Kn(o,r>2?arguments[2]:void 0));var a,c,u,f,l,s,d=ua(t),g=0;if(!d||this===Kf&&aa(d))for(a=yt(t),c=n?new this(a):Kf(a);a>g;g++)s=i?o(t[g],g):t[g],gr(c,g,s);else for(l=(f=la(t,d)).next,c=n?new this:[];!(u=p(l,f)).done;g++)s=i?$f(f,o,[u.value,g],!0):u.value,gr(c,g,s);return c.length=g,c}});var Hf=Object.prototype.toString;function Jf(e){return!!/(?:^|\/)__(dd|plugin)__\//.test(e)||!!("undefined"!=typeof __ddAppCode__&&__ddAppCode__["".concat(e,".json")]||{}).usingComponents}function zf(){}function Yf(t){var n=e(t);return null!==t&&"object"!==n&&"function"!==n?t:null}function qf(e,t){if("function"!=typeof t)throw new TypeError("customizer is must be a Function");if("function"==typeof e)return e;var n=Hf.call(e);if("[object Array]"===n)return[];if("[object Object]"===n&&e.constructor===Object)return{};if("[object Date]"===n)return new Date(e.getTime());if("[object RegExp]"===n){var r=String(e),o=r.lastIndexOf("/");return new RegExp(r.slice(1,o),r.slice(o+1))}var i=t(e);return void 0!==i?i:null}var Qf="function"==typeof Object.keys?function(e){return Object.keys(e)}:function(t){var n,r=e(t);if(null===t||"function"!==r&&"object"!==r)throw new TypeError("obj must be an Object");var o=[];for(n in t)Object.prototype.hasOwnProperty.call(t,n)&&o.push(n);return o};function Xf(e,t){if("[object Array]"!==Hf.call(e))throw new TypeError("array must be an Array");for(var n,r=e.length,o=0;o<r;++o)if((n=e[o])===t||n!=n&&t!=t)return o;return-1}function Zf(t){for(var n=[],r=1;r<arguments.length;r++)n[r-1]=arguments[r];var o=0<n.length&&void 0!==n[0]?n[0]:zf;if(null===t)return null;var i=Yf(t);if(null!==i)return i;var a=qf(t,o),c=null!==a?a:t,u=function t(n,r,o,i,a){if(null===n)return null;var c=Yf(n);if(null!==c)return c;for(var u,f,l,s,p,d,g,v,_,h="function"==typeof Symbol?function(e){return Object.getOwnPropertySymbols(e)}:function(){return[]},y=Qf(n).concat(h(n)),b=y.length,m=0;m<b;++m)d=p=s=void 0,-1===(l=Xf(i,f=n[u=y[m]]))?(v=r,p=null!==(s=null!==(_=Yf(g=f))?_:qf(g,v))?s:f,null!==f&&/^(?:function|object)$/.test(e(f))&&(i.push(f),a.push(p))):d=a[l],o[u]=d||t(f,r,p,i,a);return o};return u(t,o,c,[t],[c])}function el(e){var t;return((t=e).options||{}).addGlobalClass,t.pageLifetimes,t.lifetimes,t.definitionFilter,t.behaviors&&t.behaviors.forEach((function(e){})),t}function tl(e,t){(null===t||t>e.length)&&(t=e.length);for(var n=new Array(t),r=0;r<t;r++)n[r]=e[r];return n}var nl=__virtualDOM__.convertComponentAliasToRoute,rl=__virtualDOM__.convertRouteToComponentAlias;function ol(e){return"[object Object]"===Object.prototype.toString.call(e)}function il(e,t){return e.__ddExparserNodeId__&&Object.prototype.hasOwnProperty.call(Object.getPrototypeOf(e),t)||Object.prototype.hasOwnProperty.call(e,t)}function al(e,t){for(var n,r={},o=e,i=0;i<t.length;i++)Number(t[i])===t[i]&&t[i]%1==0?Array.isArray(o)||(r[n]=[],o=r[n]):ol(o)||(r[n]={},o=r[n]),n=t[i],o=(r=o)[t[i]];return{obj:r,key:n}}var cl,ul={hostAppId:null},fl=null,ll={scene:0,scene_note:null,sessionid:null,usedstate:null,referpagepath:null,clickTimestamp:null,prescene:null,prescene_note:null,publicLibVersion:null,hostAppId:null},sl=function(){function e(){this.isInitialLoading=!0,this.orientationChangeCount=0,this.startCostTime=null,this.startType=null}return e.prototype.setQuery=function(e){this.query=e},e.prototype.setOnAppShow=function(n){ul=t(ul,n),e._assignForClientOnShow(ul,n)},e.prototype.setOnAppHide=function(e){fl=t(fl,e)},e.prototype.setOnLaunch=function(n){(ll=t(ll,n)).hostAppId=__ddConfig.host&&__ddConfig.host.appId||"",e._assignForClientOnShow(ll,n)},e.prototype.reportShowPage=function(){e._checkDeferred(),e.checkShowOptions()},e.prototype.setReadyTime=function(t){this.pageReadyTime=t,e._checkDeferred()},e.prototype.reportHidePage=function(){e._checkDeferred(),e.checkShowOptions()},e.checkShowOptions=function(){var t=ll,n=e.showOptions||{};n.scene=t.scene||0,n.scene_note=t.scene_note,n.sessionid=t.sessionid,n.usedstate=t.usedstate,n.referpagepath=t.referpagepath,n.clickTimestamp=t.clickTimestamp,n.prescene=t.prescene,n.prescene_note=t.prescene_note,n.publicLibVersion=t.publicLibVersion;var r=e.query,o=[];r&&Object.keys(r)&&Object.keys(r).forEach((function(e){o.push("".concat(encodeURIComponent(e),"=").concat(encodeURIComponent(r[e])))})),n.query=o.join("&")},e._checkDeferred=function(){if(this.deferred&&this.deferred.length)for(var e=this.deferred;e.length;)e.pop()()},e._assignForClientOnShow=function(e,t){e.scene_note=t.scene_note||t.sceneNote||"",e.referpagepath=t.referpagepath||"",e.usedstate=t.usedstate||t.usedState,e.prescene=t.prescene,e.prescene_note=t.prescene_note||t.presceneNote||"",e.clickTimestamp=Date.now()},e}(),pl=["onLoad","onReady","onShow","onHide","onUnload","onResize","onStackShow","onStackHide"],dl=0,gl=1,vl=5,_l=6,hl=7,yl={appLaunchTime:0,appFgTime:0,appRouteTime:0,newPageTime:0,pageReadyTime:0},bl=function(){},ml=function(){function e(){}return e.create=function(e,t){var n=__virtualDOM__.addView(e?Number(e):1,t),r=exparser.Element.getMethodCaller(n);if(r.__ddWebViewId__=Number(e)||1,r.__route__=t,r.route=t,r.__displayReporter=new sl,n.__customConstructor__===__virtualDOM__.Page){var o=n.getRootBehavior().methods,i=r.__freeData__;for(var a in o)r[a]=o[a].bind(r);for(var a in i)r[a]=Zf(i[a])}var c=!0;return r.__callPageLifeTime__=function(e){for(var t,o=[],i=1;i<arguments.length;i++)o[i-1]=arguments[i];var a=this[e]||bl;if(e)switch(e){case"onLoad":var u=r.__displayReporter;u.setQuery.apply(u,o);break;case"onShow":r.__displayReporter.reportShowPage(),n.triggerPageLifeTime("show",o);break;case"onReady":r.__displayReporter.setReadyTime(Date.now());break;case"onHide":case"onUnload":var f=this.__toRoute__,l=this.__isBack__,s=this.__notReportHide__;delete this.__toRoute__,delete this.__isBack__,delete this.__notReportHide__,s||r.__displayReporter.reportHidePage(f,l),"onHide"===e&&n.triggerPageLifeTime("hide",o),"onUnload"===e&&(null===(t=null===__appServiceSDK__||void 0===__appServiceSDK__?void 0:__appServiceSDK__.dd)||void 0===t||t.skiaCanvasRemove(r.__ddWebViewId__));break;case"onResize":var p=o[0]||{};c!==p.deviceOrientation&&(c=p.deviceOrientation,r.__displayReporter.addOrientationChangeCount()),n.triggerPageLifeTime("resize",o);break;case"onStackShow":r.__displayReporter.reportShowPage(),n.triggerPageLifeTime("stackShow",o);break;case"onStackHide":r.__displayReporter.reportShowPage(),n.triggerPageLifeTime("stackHide",o)}"".concat(this.__route__,": ").concat(e," have been invoked2");var d=a.apply(this,o);return d},pl.forEach((function(e){var t=r[e];r[e]=function(){for(var e,n=[],r=0;r<arguments.length;r++)n[r]=arguments[r];var o=t||bl;try{e=o.apply(this,n)}catch(e){__appServiceSDK__.reportUncaughtError({info:e.toString(),stack:e.stack})}return e}.bind(r)})),{page:r,node:n}},e.destroy=function(t){var n=t&&t.__ddWebViewId__;"number"==typeof n&&n>0&&(__virtualDOM__.removeView(n),e.safeDestroyLifeCycleWithContext(t))},e.safeDestroyLifeCycleWithContext=function(e){try{for(var t=void 0,n=0,r=pl;n<r.length;n++)e[t=r[n]]=null;e.__displayReporter=null;var o=__virtualDOM__.TreeManager.get(e&&e.__ddWebViewId__);if(o&&o.root){var i=o.root.getRootBehavior().methods;for(t in i)e[t]=null}if(e.__freeData__)for(t in e.__freeData__)e[t]=null;e.__callPageLifeTime__=null}catch(e){}},e}();function wl(e,t,n,r){return new(n||(n=Promise))((function(o,i){function a(e){try{u(r.next(e))}catch(e){i(e)}}function c(e){try{u(r.throw(e))}catch(e){i(e)}}function u(e){var t;e.done?o(e.value):(t=e.value,t instanceof n?t:new n((function(e){e(t)}))).then(a,c)}u((r=r.apply(e,t||[])).next())}))}function Sl(e,t){var n,r,o,i,a={label:0,sent:function(){if(1&o[0])throw o[1];return o[1]},trys:[],ops:[]};return i={next:c(0),throw:c(1),return:c(2)},"function"==typeof Symbol&&(i[Symbol.iterator]=function(){return this}),i;function c(i){return function(c){return function(i){if(n)throw new TypeError("Generator is already executing.");for(;a;)try{if(n=1,r&&(o=2&i[0]?r.return:i[0]?r.throw||((o=r.return)&&o.call(r),0):r.next)&&!(o=o.call(r,i[1])).done)return o;switch(r=0,o&&(i=[2&i[0],o.value]),i[0]){case 0:case 1:o=i;break;case 4:return a.label++,{value:i[1],done:!1};case 5:a.label++,r=i[1],i=[0];continue;case 7:i=a.ops.pop(),a.trys.pop();continue;default:if(!(o=a.trys,(o=o.length>0&&o[o.length-1])||6!==i[0]&&2!==i[0])){a=0;continue}if(3===i[0]&&(!o||i[1]>o[0]&&i[1]<o[3])){a.label=i[1];break}if(6===i[0]&&a.label<o[1]){a.label=o[1],o=i;break}if(o&&a.label<o[2]){a.label=o[2],a.ops.push(i);break}o[2]&&a.ops.pop(),a.trys.pop();continue}i=t.call(e,a)}catch(e){i=[6,e],r=0}finally{n=o=0}if(5&i[0])throw i[1];return{value:i[0]?i[1]:void 0,done:!0}}([i,c])}}}function Pl(e,t){return wl(this,void 0,void 0,(function(){var n,r,o,i,a,c,u,f,l,s;return Sl(this,(function(p){switch(p.label){case 0:if(n=t[e],d=n.packages,"[object Array]"!==Object.prototype.toString.call(d))return[2,Promise.reject("packages must be an array.")];for(r=[],o=[],i=0,a=n.packages;i<a.length;i++)c=a[i],__subPackageNames__&&Object.prototype.hasOwnProperty.call(__subPackageNames__,c)&&(c=__subPackageNames__[c]),__appServiceSDK__.getPackageLoadStatus(c)?r.push(c):o.push(c);if(0===o.length)return[2,n.packages.length!==o.length?"These packages have already been loaded [".concat(r.join(", "),"]"):"Packages empty."];p.label=1;case 1:return p.trys.push([1,5,,6]),u=[],[4,Promise.all(o.map((function(e){return new Promise((function(t){didiJsBridge.invoke({method:"preloadSubPackage",data:{package:e},callback:function(n){var r=e;__appServiceSDK__.getPackageLoadStatus(e)?r+=" loaded.":n&&n.data&&n.data.success||u.push(n.data.errMsg),t(r)}})}))})))];case 2:return f=p.sent(),u.length?[4,Promise.reject(u.join("\r\n"))]:[3,4];case 3:return[2,p.sent()];case 4:return l="(Rule page: ".concat(e,") Loaded subPackages [").concat(f.join(", "),"]"),r.length&&(l+="\r\n"+"ignore subPackages [".concat(r.join(", "),"]")),[2,l];case 5:return s=p.sent(),[2,Promise.reject(s)];case 6:return[2]}var d}))}))}var Ol,Rl,Il={},Tl={},El={},Cl=[],xl="",kl=null,jl={},Dl=["onLaunch","onShow","onHide","onUnlaunch","onError"],Al=[],Ll={},Bl=null,Ml=[],Nl={click:null},Fl=[],Vl=!1,Ul=[],Gl=!1,$l=Object.prototype.hasOwnProperty,Kl=0,Wl=0,Hl=0,Jl=0,zl=0,Yl=0,ql=null,Ql=null,Xl=!0,Zl=!1,es={},ts={},ns=[],rs=function(e){"string"==typeof e&&(xl=e)},os=!1,is=function(){},as=function(){function e(){}return e.App=function(e){t(e,Ll),Ll={},Bl=new ls(e)},e.Page=function(e){cs(e,"/")},e.Component=function(e){el(e),function(e,t,n,r,o){var i;i=void 0!==o?o:{};var a=!1;(i.__wxRouteBegin||cl)&&(a=!0);i.__wxRouteBegin?i.__wxRouteBegin=!1:cl=!1;var c=__virtualDOM__.Component(e,t,n,r),u=nl(c);c&&(jl[u]=exparser.Component._list[c]),El[u]=a,String(c)}(e,"/")},e.Behavior=function(e){return el(e),__virtualDOM__.Behavior(e)},e.getCurrentRoute=function(){return xl},e.hasPageRoute=function(e){return!!function(e){for(var t=0;t<__ddConfig.pages.length;t++)if(__ddConfig.pages[t]===e)return!0;return!1}(e)||void 0!==El[e]},e.getCurrentPagesByDomain=function(e){var t=[];return Cl.forEach((function(n){e&&function(e){if(/^__dd__\//.test(e||""))return"//";var t=e.match(/(?:^|\/)__plugin__\/(.*?)\//);return t?t[1]:"/"}(n.route)!==e?t.push(null):t.push(n.page)})),t},e.getCurrentPages=function(){return e.getCurrentPagesByDomain("/")},e.setCurrentRoute=function(e){xl=e},e.getPageByWebviewId=function(e){return $l.call(Il,e)?Il[e].page:null},e.getCurrentPageWithAdditionalInfo=function(){return Ol},e.registerGetApp=function(e){ls(e)},e.getApp=function(e){return(arguments.length>0&&void 0!==e?e:{}).allowDefault?Bl||Ll:Bl},e.__createPluginGlobal=function(t,n){var r={__wxAppCode__:{},__wxAppCurrentFile__:""},o="".concat(t,"/").concat(n);return{__wxAppCode__:{},__wxAppCurrentFile__:"",Page:function(e){cs(e,o,r.__wxAppCode__,r.__wxAppCurrentFile__,r)},getCurrentPages:function(){return e.getCurrentPagesByDomain(t)},Behavior:function(e){return __virtualDOM__.Behavior(e)},publishDomainComponents:function(e){return __virtualDOM__.publishDomainComponents(o,e)},beforeFactory:function(){}}},e}();function cs(e,t,n,r,o){var i={__wxRoute:!1,__wxRouteBegin:!1};arguments.length<4&&void 0!==o&&(i=o);var a=i.__wxRoute?"":__ddAppCurrentFile__&&__ddAppCurrentFile__.replace(/\.js$/,""),c=rl(a),u=nl(c),f=Jf(u),l=__virtualDOM__.Page(e,t,n,"".concat(a,".js"));jl[u]=e,f&&(jl[u]=exparser.Component._list[l]),El[u]=!0}var us=[];function fs(e){var t=__ddConfig.tabBar&&__ddConfig.tabBar.list||[];if(!t&&!t.length)return!1;t.forEach((function(e){us.push(e.pagePath)}));var n=-1!==us.indexOf(e.route)||-1!==us.indexOf("".concat(e.route,".html"));return us=[],n}function ls(e){var t=this;void 0===e&&(e={});var n=this,r=this;function o(e){for(var t=0;t<Dl.length;++t)if(Dl[t]===e)return!0;return!1}for(var i in Dl.forEach((function(r){n[r]=function(){for(var n=[],o=0;o<arguments.length;o++)n[o]=arguments[o];var i=e[r]||is;try{i.apply(t,n)}catch(e){__appServiceSDK__.reportUncaughtError({info:e.toString(),stack:e.stack})}}.bind(n)})),e)"getCurrentPage"===i?"App's ".concat(i," is write-protected"):o(i)||("function"==typeof e[i]?n[i]=function(n){for(var r,o=[],i=1;i<arguments.length;i++)o[i-1]=arguments[i];try{r=e[n].apply(t,o)}catch(e){}return r}.bind(n,i):n[i]=e[i]);var a=__appServiceSDK__.getLaunchOptionsSync(),c=__appServiceSDK__.getEnterOptionsSync();r.__appId__=null==a?void 0:a.appId,r.onLaunch(a),r.onShow(c),Al.push({app:r,preventOnShow:!0,preventStackOnShow:!0})}function ss(e){try{!function(e,t,n,r,o,i,a){t=Number(t),yl.appRouteTime=Date.now();var c=Object.keys(n).map((function(e){return"".concat(encodeURIComponent(e)," = ").concat(n[e])})).join("&"),u="/".concat(e).concat(c?"?".concat(c):""),f=a.stackId||-1;if("navigateTo"===r){if(Reporter.traceBeginEvent("framework","onnavigateto"),fs({route:e}))return;o?(Ol&&ps(Ol,e),"min"===o?(kl=Cl[Cl.length-1],$l.call(Il,t)?"navigateTo with an already exist webViewId ".concat(t):vs(e,u,t,n)):"max"===o&&kl&&(rs(e),Ol=kl,Cl.push(Ol),Ol.page.__callPageLifeTime__("onShow"),kl=null)):(Ol&&ps(Ol,e),$l.call(Il,t)?"navigateTo with an already exist webViewId ".concat(t):vs(e,u,t,n,{initialRenderingCacheData:i})),Reporter.traceEndEvent()}else if("redirectTo"===r){if(Reporter.traceBeginEvent("framework","onredirectto"),fs({route:e}))return;Ol&&_s(Ol,e),$l.call(Il,t)?"redirectTo with an already exist webViewId ".concat(t):vs(e,u,t,n,{initialRenderingCacheData:i}),Reporter.traceEndEvent()}else if("navigateBack"===r)-1===t&&(kl=null),o?"min"===o?(kl=Cl[Cl.length-1],ys(t,!0)):"max"===o&&(kl=null,ys(t)):ys(t);else if("switchTab"===r){if(!fs({route:e}))return;if(Reporter.traceBeginEvent("framework","onswitchtab"),Cl&&Cl.length&&Cl[Cl.length-1].webViewId===t)return;var l=void 0,s=void 0,p=!0,d=!0;if(0===Cl.length)return vs(e,u,t,n,{initialRenderingCacheData:i}),void ws();for(;1<Cl.length;)kl&&kl.webViewId===Cl[Cl.length-1].webViewId?(Cl=Cl.slice(0,Cl.length-1)).length?rs(Cl[Cl.length-1].route):rs(""):_s(Cl[Cl.length-1],e),p=!1;if(Cl[0].webViewId===t)Ol=Cl[0],kl=Cl[0],p||(Ol.page.__callPageLifeTime__("onShow"),ws());else if(fs(Cl[0])?(d=!1,p&&ps(Cl[0],e)):kl&&kl.webViewId===Cl[0].webViewId?(Cl=Cl.slice(0,Cl.length-1),rs("")):_s(Cl[0],e),$l.call(Il,t)){var g=void 0;l=(g=Il[t]).page,s=g.node,Cl=[Ol={webViewId:t,route:e,page:l,node:s}],l.__callPageLifeTime__("onShow"),ws(),kl=Cl[0],Ss("enterPage",l),Ss("switchTab",l)}else Cl=[],vs(e,u,t,n,{isMainTabBarPage:d,initialRenderingCacheData:i}),ws();Reporter.traceEndEvent()}else if("pageReload"===r){Reporter.traceBeginEvent("framework","onpagereload");for(var v=0;v<Cl.length;++v){var _=Cl[v];_.webViewId===t&&(_.page.__toRoute__=e,_.page.__callPageLifeTime__("onUnload"),_.node&&ml.destroy(_.page),delete Il[_.webViewId])}m=e,w=u,S=t,P=n,O=i,R=a.prerender,yl.appLaunchTime=Date.now(),yl.appFgTime=Date.now(),vs(m,w,S,P,{initialRenderingCacheData:O,prerender:R},!0),Reporter.traceEndEvent()}else if("appLaunch"===r||"appLaunchStack"===r)Reporter.traceBeginEvent("framework","onapplaunch"),yl.appLaunchTime=Date.now(),yl.appFgTime=Date.now(),$l.call(Il,t)?"appLaunch with an already exist webViewId ".concat(t):vs(e,u,t,n,{initialRenderingCacheData:i,prerender:a.prerender},!1,f),Reporter.traceEndEvent();else if("reLaunch"===r||"autoReLaunch"===r){Reporter.traceBeginEvent("framework","onrelaunch");var h=!1;for("reLaunch"===r&&(h=!0);0<Cl.length;){var y=!0;h=h&&(y=!1),_s(Cl[Cl.length-1],e,!1,y)}vs(e,u,t,n,{initialRenderingCacheData:i,prerender:a.prerender}),Reporter.traceEndEvent()}else"dismissPip"===r?kl&&(b=kl)&&(0<=Cl.findIndex((function(e){return e.webViewId===kl.webViewId}))?kl=null:(b.page.__callPageLifeTime__("onUnload"),b.node&&ml.destroy(b.page),delete Il[b.webViewId],Ss("pageUnload",b.page),Ss("leavePage",b.page))):"Illegal open type: ".concat(r);var b;var m,w,S,P,O,R}(e.path,e.webViewId,e.query||{},e.openType,e.pipMode,e.initialRenderingCacheData,e)}catch(e){Reporter.errorReport({key:"service-error",type:"appRouteTrigger",error:"[service-error]: appRouteTrigger error : ".concat(e)}),Reporter.ravenReport("pub_saga_error_message_bt",{key:"service-error",type:"appRouteTrigger",error:"[service-error]: appRouteTrigger error : ".concat(e),fail:function(e){}})}}didiJsBridge.subscribe({event:"listenServiceInjectCostTiming",callback:function(e){var t=e.data&&e.data.timing;__appServiceSDK__.reportToMiniBackend("tech_saga_js_timing",{timing:injectServiceTiming+t})}}),didiJsBridge.on({event:"destroyInstance",callback:function(){try{didiJsBridge.clearAll(),(__virtualDOM__.TreeManager.listViewId()||[]).forEach((function(e){__virtualDOM__.removeView(e)})),__ddAppCode__=null,__appServiceEngine__=null,__WXML_GLOBAL__=null,__appServiceSDK__=null}catch(e){}}}),didiJsBridge.on({event:"showStack",callback:function(e){var t,n=e.stackId||(null===(t=e.data)||void 0===t?void 0:t.stackId)||-1;if(n){currentStackId=n;var r,o=__appServiceSDK__.getEnterOptionsSync();void 0===(r=o)&&(r={}),Al.forEach((function(e){e.preventStackOnShow||e.app.onShow(r),e.preventStackOnShow=!1})),Tl[n]?(Cl=Tl[n],(Ol=Cl&&Cl.length&&Cl[Cl.length-1]||null)&&Ol.page&&Ol.page.__callPageLifeTime__("onStackShow",o),Ol&&Ol.page&&Ol.page.__callPageLifeTime__("onShow")):(Tl[n]=[],Cl=Tl[n],rs(""))}}}),didiJsBridge.on({event:"hideStack",callback:function(e){var t,n,r,o=e.stackId||(null===(t=e.data)||void 0===t?void 0:t.stackId)||-1;o&&Tl[o]&&(Tl[o]=Cl,Ol&&(null===(n=null==Ol?void 0:Ol.page)||void 0===n||n.__callPageLifeTime__("onHide")),null===(r=null==Ol?void 0:Ol.page)||void 0===r||r.__callPageLifeTime__("onStackHide"))}}),didiJsBridge.on({event:"removeStack",callback:function(e){var t,n=e.stackId||(null===(t=e.data)||void 0===t?void 0:t.stackId)||-1;if(n&&Tl[n]){for(var r=Tl[n],o=r.length-1;o>=0;o--)_s(r[o],r[o].path);delete Tl[n]}}}),didiJsBridge.on({event:"onAppError",callback:function(e){var t=__appServiceEngine__.getApp();t&&t.onError&&t.onError(e.data)}}),didiJsBridge.on({event:"switchTabLoadJSFileToDataThreadRequire"},(function(e){var t=e.data.route,n=e.data.index;e.fromNative&&__ddConfig&&__ddConfig.tabBar&&__ddConfig.tabBar.list&&__ddConfig.tabBar.list[n]&&tabBarTapList.push({index:n,pagePath:(__ddConfig.tabBar.list[n].pagePath||"").replace(/\.html$/,""),text:__ddConfig.tabBar.list[n].text}),__appServiceSDK__.installPackageByRoute(t,(function(){didiJsBridge.invoke({method:"switchTabLoadJSFileToDataThreadFinish",data:{index:n}})}))})),__appServiceSDK__.onPageReload((function(e){e.path;!function(e,t){if($l.call(Il,t)){var n=Il[t].statesData;Il[t].statesData=void 0,__virtualDOM__.restoreView(t),gs(Il[t],t,Date.now(),n||{},!0)}}(0,e.webViewId)})),__appServiceSDK__.onAppShow((function(e){void 0===e&&(e={isLaunch:!1,path:""}),e.isLaunch&&Ss("launch"),rs(e.path),function(e){e=e||ts,Al.forEach((function(t){t.preventOnShow||t.app.onShow(e),t.preventOnShow=!1})),ts=e}(__appServiceSDK__.getEnterOptionsSync()),Ss("foreground");var t=void 0;(t=as.getCurrentPagesByDomain("")).length&&("function"==typeof t[t.length-1].__callPageLifeTime__&&t[t.length-1].__callPageLifeTime__("onShow"),Ss("enterPage",t[t.length-1],!0))})),__appServiceSDK__.onAppRoute((function(e){__ddConfig&&__ddConfig.preloadRule&&Object.prototype.hasOwnProperty.call(__ddConfig.preloadRule,e.path)&&dd.nextTick((function(){Pl(e.path,__ddConfig.preloadRule).then((function(e){})).catch((function(e){}))}));var t=__appServiceSDK__.RouteTask.getCurrentTask();null===t||t.resolved?ss(e):t.rejected?(Reporter.errorReport({key:"service-error",type:"getCurrentTask",error:"[service-error]: getCurrentTask error"}),Reporter.ravenReport("pub_saga_error_message_bt",{key:"service-error",type:"getCurrentTask",error:"[service-error]: getCurrentTask error",fail:function(e){}})):t.pending&&t.addTask(ss.bind(void 0,e))})),__appServiceSDK__.onAppRouteDone((function(){Zl=!0,Fl.forEach((function(e){Ss.apply(void 0,function(e){return function(e){if(Array.isArray(e))return tl(e)}(e)||function(e){if("undefined"!=typeof Symbol&&Symbol.iterator in Object(e))return Array.from(e)}(e)||function(e,t){if(e){if("string"==typeof e)return tl(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);return"Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n?Array.from(n):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?tl(e,t):void 0}}(e)||function(){throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()}(e))})),Fl=[]})),__appServiceSDK__.onPullDownRefresh((function(){var e=as.getCurrentPagesByDomain("");if(e.length){var t=e[e.length-1];"function"==typeof t.__callPageLifeTime__&&t.__callPageLifeTime__("onPullDownRefresh");var n=as.getCurrentPageWithAdditionalInfo().page;n&&Ss("pullDownRefresh",n,!0)}}));function ps(e,t){Reporter.traceBeginEvent("framework","onhidepage"),e.page.__toRoute__=t,e.page.__callPageLifeTime__("onHide"),Ss("leavePage",e.page),Reporter.traceEndEvent()}didiJsBridge.subscribe({event:"initReadyForPrerender",callback:function(e){__appServiceSDK__.onAppRouteInit(e)}}),didiJsBridge.subscribe({event:"onShareAppMessage",callback:function(e){var t={};Ol.page.onShareAppMessage&&(t=Ol.page.onShareAppMessage.apply(Ol.page,[e.data||{}])||{});var n,r=t.promise;delete t.promise,"Promise"!==(n=r,Object.prototype.toString.call(n).split(" ")[1].split("]")[0])&&(r=Promise.resolve(t));var o=new Promise((function(e){setTimeout((function(){e(t)}),3e3)}));Promise.race([o,r]).then((function(e){void 0===e&&(e={}),dd.customShare({type:"miniApp",title:e.title,content:e.title,image:e.imageUrl,ext:{path:e.path}})}))}}),didiJsBridge.subscribe({event:"PAGE_EVENT",callback:function(e){if("__DOMReady"===(e=e.data||{}).eventName&&Ol&&Ol.page&&(Reporter.pageLoadReport(Ol.page.route,Ol.page.__ddWebViewId__),Ol.page.__callPageLifeTime__&&Ol.page.__callPageLifeTime__("onReady")),Ol.page&&Ol.page[e.eventName])return Ol.page[e.eventName].apply(Ol.page,[e.data])}}),didiJsBridge.on({event:"onPageScroll"},(function(e){if(Ol.page&&"function"==typeof Ol.page.onPageScroll)return Ol.page.onPageScroll.apply(Ol.page,[e.data])})),didiJsBridge.invoke({method:"getSdkReportPoint",data:{event:"tech_saga_launch_app"},callback:function(e){try{e.data.data&&Reporter.reportAppLaunchTime(e.data.data)}catch(e){}}}),__appServiceSDK__.onAppHide((function(e){void 0===e&&(e={mode:""});var t,n=as.getCurrentPagesByDomain("");n.length&&("function"==typeof n[n.length-1].__callPageLifeTime__&&n[n.length-1].__callPageLifeTime__("onHide"),Ss("leavePage",as.getCurrentPageWithAdditionalInfo().page,!0)),t=e,Al&&Al.forEach((function(e){7===__ddConfig.appType?e.app.onHide(t):e.app.onHide()})),Ss("background")})),__appServiceSDK__.onAppEnterBackground();var ds={emit:function(e,t,n){__appServiceSDK__.invokeWebviewMethod("appDataChange",e,t,n)}};function gs(e,t,n,r,o,i){var a=e.page,c=Object();c.webViewId=t,c.enablePullUpRefresh=il(a,"onReachBottom"),c.enablePageScroll=il(a,"onPageScroll"),c.onReachBottomDistance=function(e){try{var t=__ddConfig.page[e].window&&__ddConfig.page[e].window.onReachBottomDistance;if(__ddConfig.page[e].onReachBottomDistance&&(t=__ddConfig.page[e].onReachBottomDistance),"number"==typeof t)return t}catch(e){}}(a.__route__),c.statesData=r,c.scene=undefined,c.route=a.__route__,c.query=a.options,c.lastRoute=e.lastRoute,c.lastQuery=e.lastQuery,c.wxConfig={accountInfo:__ddConfig&&__ddConfig.accountInfo||{},appContactInfo:__ddConfig&&__ddConfig.appContactInfo||{},appLaunchInfo:__ddConfig&&__ddConfig.appLaunchInfo||{},plugins:__ddConfig&&__ddConfig.plugins||{}},c.windowConfig=__ddConfig&&__ddConfig.page&&__ddConfig.page[a.__route__]&&__ddConfig.page[a.__route__].window||{},c.onPageScrollThrottle=__ddConfig&&__ddConfig.page&&__ddConfig.page[a.__route__]&&__ddConfig.page[a.__route__].onPageScrollThrottle||null,c.keyScrollTop=__ddConfig&&__ddConfig.page&&__ddConfig.page[a.__route__]&&__ddConfig.page[a.__route__].keyScrollTop||null,c.debug=__ddConfig&&__ddConfig.debug,c.appId=__ddConfig&&__ddConfig.accountInfo&&__ddConfig.accountInfo.appId,c.appLaunchTime=yl.appLaunchTime,c.appFgTime=yl.appFgTime,c.isTabBarPage=e.isTabBarPage,c.isMainTabBarPage=e.isMainTabBarPage,c.navigationStyle=__ddConfig&&__ddConfig.global&&__ddConfig.global.window&&__ddConfig.global.window.navigationStyle,c.needGetSubjectInfo=!os,c.perfData=(Ml[vl]=Date.now(),Ml[dl]=Xl?1:0,Ml[hl]=__ddConfig.isSubContext?1:0,Ml[gl]=__ddConfig.onReadyStart,Ml[_l]=__ddConfig.onReadyEnd||0,Xl=!1,Ml),c.isReload=o,c.fontFaceRecords=__appServiceSDK__.fontFaceRecords,c.prerender=i;var u={ext:c,options:{firstRender:!0,timestamp:n,path:a.__route__}};ds.emit(u,t),Ss("pageReady",a)}function vs(e,t,n,r,o,i,a){void 0===o&&(o={}),void 0===i&&(i=!1);var c=function(e){void 0===e&&(e=-1);if(e<0)return Cl;return Tl[e]=Tl[e]||[],Tl[e]}(a);Reporter.traceBeginEvent("framework","pushpageinfostask");var u=Rl;Rl=void 0;var f=Jf(e);yl.newPageTime=Date.now(),rs(e);var l=ml.create(n,e),s=l.page,p=Zf(r);if((Ol={page:s,webViewId:n,route:e,rawPath:t,lastRoute:Ol?Ol.route:"",lastQuery:Ol?Ol.page.options:{},node:l.node,isTabBarPage:null}).isMainTabBarPage=o.isMainTabBarPage||!1,i){for(var d=-1,g=0;g<c.length;g++)c[g].webViewId===n&&(d=g);-1!==d&&(c.splice(d,1,Ol),d===c.length&&(c.length?rs(c[c.length-1].route):rs("")))}else c.push(Ol);s.__exitState__=u;var v={};Object.keys(p).forEach((function(e){var t=p[e];try{v[e]=decodeURIComponent(t)}catch(n){v[e]=t}})),__virtualDOM__.attachView(n,v),/^__dd__\//.test(e)&&n.setData(undefined),s.options=p,gs(Ol,n,yl.newPageTime,!0,!1,o.prerender||!1),o.initialRenderingCacheData&&s.setData(o.initialRenderingCacheData),s.__callPageLifeTime__("onLoad",r),s.__callPageLifeTime__("onShow"),Il[n]={page:s,route:e,rawPath:t,webViewId:n,statesData:null,node:f?l.node:void 0},Ss("pageLoad",s),Ss("enterPage",s),Reporter.traceEndEvent()}function _s(e,t,n,r){Reporter.traceBeginEvent("framework","unloadpage"),e.page.__toRoute__=t,e.page.__isBack__=n,e.page.__notReportHide__=r,e.page.__callPageLifeTime__("onUnload"),e.node&&ml.destroy(e.page),delete Il[e.webViewId],(Cl=Cl.slice(0,Cl.length-1)).length?rs(Cl[Cl.length-1].route):rs(""),Ss("pageUnload",e.page),Ss("leavePage",e.page),Tl[currentStackId]=null,Tl[currentStackId]=Cl,Reporter.traceEndEvent()}function hs(e){e.__ddSlotChildren&&e.__ddSlotChildren.length>0&&e.__ddSlotChildren.forEach((function(e){hs(e),"dd-web-view"===e.is&&e.__methodCaller&&e.__methodCaller.triggerEvent("message",{data:ns})}))}function ys(e,t){Reporter.traceBeginEvent("framework","navigateback");for(var n,r=1<arguments.length&&void 0!==t&&t,o=!1,i=Cl.length-1,a=Il&&Il[e]&&Il[e].route||"";0<i;i--){var c=Cl[i];if(c&&ns.length&&c.node&&(hs(c.node),ns.length=0),c.webViewId===e){o=!0,Ol=c;break}if(!r&&kl&&kl.webViewId===c.webViewId)Cl=Cl.slice(0,Cl.length-1);else{r&&kl&&kl.webViewId===c.webViewId?(ps(c),(Cl=Cl.slice(0,Cl.length-1)).length?rs(Cl[Cl.length-1].route):rs("")):_s(c,a,!0)}}1!==Cl.length||o||(n=Cl[0]).webViewId===e&&(o=!0,Ol=n),o?(Ol.page.__callPageLifeTime__("onShow"),Ss("enterPage",Ol.page)):"navigateBack with an unexist webViewId ".concat(e),Reporter.traceEndEvent()}function bs(e,t){Object.keys(e.data||{}).forEach((function(n){var r,o,i,a,c,u,f,l,s=e.data[n],p=t&&t.data||{};if("$"!==s.charAt(0)||void 0===(r=function(e){var t=0;switch(e){case"PAGE_TIME":return 0<=(t=Hl?Date.now()-Hl-Jl:0)?t:null;case"APP_TIME":return 0<=(t=Kl?Date.now()-Kl-Wl:0)?t:null;case"CURRENT_PAGE":return Ql||null;case"LAST_PAGE":return ql||null;default:return}}(s.substr(1)))){if(0===s.indexOf("$APP"))return i=n,c=(o=e).data[i],void((u=al((l&&l.allowDefault?Bl||Ll:Bl)||{},c.replace("$APP.",""))).obj&&void 0!==u.obj[u.key]&&("number"!=typeof(a=u.obj[u.key])&&"string"!=typeof a&&"boolean"!=typeof a||(es[o.eventID].data[i]=a)));if(t&&(e.page===t.__route__||"ANY_PAGE"===e.page)){if(0===s.indexOf("$DATASET")&&(f=s.replace("$DATASET.",""),r=al(e.dataset||{},function(e){for(var t=[],n=e.length,r="",o=0,i=!1,a=0;a<n;a++){var c=e[a];"\\"===c?a+1<n&&("."===e[a+1]||"["===e[a+1]||"]"===e[a+1])?(r+=e[a+1],a++):r+="\\":"."===c?r&&(t.push(r),r=""):"["===c?i=!0:"]"===c?(i=!1,t.push(o),o=0):i?o=10*o+c.charCodeAt(0)-48:r+=c}return t}(f)),r.obj&&void 0!==r.obj[r.key]&&(es[e.eventID].data[n]=r.obj[r.key],!0)),0===s.indexOf("$COMP")&&"number"==typeof e.nodeId){var d=__virtualDOM__.getNoapproutedeById(e.nodeId,e.webViewId);if(!(d=__virtualDOM__.getNodeById(e.nodeId,e.webViewId)))return;var g=exparser.Element.getMethodCaller(d);g&&(s=s.replace("$COMP.",""),p=g.data)}if(-1<s.indexOf("[]")){if((e.index||[]).forEach((function(e){s=s.replace("[]","[".concat(e,"]"))})),-1<s.indexOf("[-1]")||-1<s.indexOf("[]"))return;var v=s.match(/\[(\d+)\]\.\$INDEX$/);v&&(es[e.eventID].data[n]=Number(v[1]),!0)}if(void 0===(r=al(p,s)).obj||void 0===r.key||void 0===r.obj[r.key])return;es[e.eventID].data[n]=r.obj[r.key]}}else null!==r&&(es[e.eventID].data[n]=r)}))}function ms(e,t){if("start"!==e.action&&("start_and_report"!==e.action||(es[e.eventID]={eventID:e.eventID,data:{},extra:e.extra})),es[e.eventID]){var n,r,o=t||as.getCurrentPageWithAdditionalInfo()&&as.getCurrentPageWithAdditionalInfo().page;bs(e,o),"report"!==e.action&&"start_and_report"!==e.action||(n=e.eventID,r=[],Object.keys(es[n].data).forEach((function(e){r.push({id:e,value:es[n].data[e]})})),es[n].data=r,es[n].page=o,es[n].version=("undefined"!=typeof __libVersionInfo__?__libVersionInfo__.version:0)||0,es[n].uid=Date.now().toString(16)+Math.random().toString(16).substr(2),es[n].type=0)}}function ws(){for(var e=0;e<tabBarTapList.length;e++){var t=tabBarTapList.shift();if(t.pagePath===Ol.route||t.pagePath==="/".concat(Ol.route)||"/".concat(t.pagePath)===Ol.route){Ol.page.onTabItemTap&&Ol.page.onTabItemTap.call(Ol.page,t);break}}}function Ss(e,t,n){var r,o;if("pageReady"===e&&t){if(t){var i=t.__route__,a=Nl.click;r=[],a&&(a.forEach((function(e){e.page!==i&&"ANY_PAGE"!==e.page||!e.element||r.push({eventID:e.eventID,page:e.page,element:e.element,action:e.action})})),0!==r.length&&__appServiceSDK__.publishAnalyticsConfig(r,[Number(t&&t.__ddWebViewId__)]))}}else if(Gl)Ul.push(e);else{if("launch"===e&&!Vl)return Kl=Date.now(),Gl=Vl=!0,Ul.push(e),void __appServiceSDK__.getAppConfig({type:1,complete:function(e){Gl=!1,e.data&&function(e,t){var n={};try{n=JSON.parse(e.data)}catch(e){n={}}var r={},o=as.getCurrentPageWithAdditionalInfo(),i=n;"[object Array]"===Object.prototype.toString.call(i)&&i.forEach((function(e){var t=e.eventTarget;"[object Object]"===Object.prototype.toString.call(t)&&(t=[t]),t&&t.length&&t.forEach((function(t){var n=t.trigger||"click";r[n]||(r[n]=[]),("click"!==n||/^([.#][a-zA-Z_][^.#]* ?)+$/.test(t.element&&t.element.trim()))&&r[n].push({eventID:e.eventID,page:t.page,element:t.element&&t.element.trim(),data:t.data,action:t.action,extra:e.extra})}))})),Nl=r,r={},t||(Ul.forEach((function(e){Ss(e,o&&o.page,!0)})),Ul=[]),Ss("pageReady",o&&o.page)}(e)}});if(Zl){n||("enterPage"===e?(Hl=Date.now(),Jl=0,Ql=t&&t.__route__):"leavePage"===e?ql=t&&t.__route__:"background"===e?zl=Date.now():"foreground"===e&&(Yl=Date.now(),zl&&zl<Yl&&(Jl+=Yl-zl,Wl+=Yl-zl)));var c=["enterPage","leavePage","pageLoad","pageUnload","pullDownRefresh","switchTab"];(o=Nl[e])&&("enterPage"===e&&t&&"page/component/index"===t.__route__&&__ddConfig.accountInfo&&o.map((function(e){return e.eventID})),o.forEach((function(n){n&&(-1<c.indexOf(e)?(t&&n.page===(t&&t.__route__)||"ANY_PAGE"===n.page)&&ms(n,t):ms(n))})))}}}return didiJsBridge.subscribe({event:"h5PostMessage"},(function(e){var t=e&&e.data&&e.data.params;if(t&&t.data){var n=t.data;for(var r in"string"==typeof n&&(n=JSON.parse(n)),n)"data"===r&&ns.push(n[r])}})),{App:as.App,Component:as.Component,Page:as.Page,Behavior:as.Behavior,getApp:as.getApp,__createPluginGlobal:as.__createPluginGlobal,getCurrentRoute:as.getCurrentRoute,getCurrentPagesByDomain:as.getCurrentPagesByDomain,getCurrentPages:as.getCurrentPages,getCurrentPageWithAdditionalInfo:as.getCurrentPageWithAdditionalInfo}}();

!function(global) {
  /**
   * 将 page 等挂在 global 上
   */
  global.navigateBack = __appServiceSDK__.navigateBackNative;
  global.App = __appServiceEngine__.App;
  global.Page = __appServiceEngine__.Page;
  global.Behavior = __appServiceEngine__.Behavior;
  global.Component = __appServiceEngine__.Component;
  global.getApp = __appServiceEngine__.getApp;
  global.getCurrentPages = __appServiceEngine__.getCurrentPages;
  // global.wx = global.dd = __appServiceSDK__.dd;
  global.wx = global.dd = __appServiceSDK__.proxySDK;
  /**
   * 将 wx 的方法挂在全局上
   */
  var wxApiMap = [
    "drawCanvas",
    "createContext",
    "createCanvasContext",
    "canvasToTempFilePath",
    "canvasGetImageData",
    "canvasPutImageData",
    "createOffscreenCanvas",
    "getAccountInfoSync",
    "getShareInfo",
    "authPrivateMessage",
    "pageScrollTo",
    "chooseInvoiceTitle",
    "chooseInvoice",
    "arrayBufferToBase64",
    "base64ToArrayBuffer",
    "openSetting",
    "getExtConfig",
    "chooseMedia",
    "previewMedia",
    "chooseMultiMedia",
    "chooseMessageFile",
    "chooseWeChatContact",
    "uploadEncryptedFileToCDN",
    "onUploadEncryptedFileToCDNProgress",
    "uploadToCommonCDN",
    "getExtConfigSync",
    "showShareMenu",
    "hideShareMenu",
    "updateShareMenu",
    "shareAppMessageForFakeNative",
    "openUrl",
    "setNavigationBarColor",
    "setNavigationBarAlpha",
    "showShareImageMenu",
    "vibrateShort",
    "vibrateLong",
    "getSetting",
    "checkIsSupportFacialRecognition",
    "startFacialRecognitionVerify",
    "startFacialRecognitionVerifyAndUploadVideo",
    "startCustomFacialRecognitionVerify",
    "startCustomFacialRecognitionVerifyAndUploadVideo",
    "sendBizRedPacket",
    "sendGoldenRedPacket",
    "openGoldenRedPacketDetail",
    "showRedPackage",
    "addPhoneContact",
    "setScreenBrightness",
    "getScreenBrightness",
    "shareToWeRun",
    "getWeRunData",
    "uploadWeRunData",
    "addWeRunData",
    "canIUse",
    "setPageStyle",
    "triggerGettingWidgetData",
    "navigateToMiniProgram",
    "navigateToMiniProgramDirectly",
    "navigateToDevMiniProgram",
    "navigateBackMiniProgram",
    "launchMiniProgram",
    "launchApplicationDirectly",
    "launchApplicationForNative",
    "setNavigationBarRightButton",
    "onTapNavigationBarRightButton",
    "setTopBarText",
    "setTabBarBadge",
    "removeTabBarBadge",
    "showTabBarRedDot",
    "hideTabBarRedDot",
    "showTabBar",
    "hideTabBar",
    "setTabBarStyle",
    "setTabBarItem",
    "setBackgroundColor",
    "setBackgroundTextStyle",
    "setEnableDebug",
    "captureScreen",
    "onUserCaptureScreen",
    "offUserCaptureScreen",
    "setKeepScreenOn",
    "checkIsSupportSoterAuthentication",
    "startSoterAuthentication",
    "checkIsSoterEnrolledInDevice",
    "openDeliveryList",
    "navigateBackH5",
    "openBusinessView",
    "navigateBackApplication",
    "navigateBackNative",
    "reportIDKey",
    "reportKeyValue",
    "setWindowSize",
    "setNavigationBarTitle",
    "showNavigationBarLoading",
    "hideNavigationBarLoading",
    "hideHomeButton",
    "startPullDownRefresh",
    "stopPullDownRefresh",
    "operateWXData",
    "getOpenDeviceId",
    "getMenuButtonBoundingClientRect",
    "getSelectedTextRange",
    "enableAlertBeforeUnload",
    "disableAlertBeforeUnload",
    "makeBluetoothPair",
    "openBluetoothAdapter",
    "closeBluetoothAdapter",
    "getBluetoothAdapterState",
    "onBluetoothAdapterStateChange",
    "offBluetoothAdapterStateChange",
    "startBluetoothDevicesDiscovery",
    "stopBluetoothDevicesDiscovery",
    "getBluetoothDevices",
    "getConnectedBluetoothDevices",
    "createBLEConnection",
    "setBLEMTU",
    "closeBLEConnection",
    "getBLEDeviceServices",
    "getBLEDeviceRSSI",
    "getBLEDeviceCharacteristics",
    "createBLEPeripheralServer",
    "onBLEPeripheralConnectionStateChanged",
    "offBLEPeripheralConnectionStateChanged",
    "notifyBLECharacteristicValueChanged",
    "notifyBLECharacteristicValueChange",
    "readBLECharacteristicValue",
    "writeBLECharacteristicValue",
    "onBluetoothDeviceFound",
    "offBluetoothDeviceFound",
    "onBLEConnectionStateChanged",
    "onBLEConnectionStateChange",
    "onBLECharacteristicValueChange",
    "offBLEConnectionStateChanged",
    "offBLEConnectionStateChange",
    "offBLECharacteristicValueChange",
    "startBeaconDiscovery",
    "stopBeaconDiscovery",
    "getBeacons",
    "onBeaconUpdate",
    "offBeaconUpdate",
    "onBeaconServiceChange",
    "offBeaconServiceChange",
    "startWifi",
    "stopWifi",
    "getWifiList",
    "getConnectedWifi",
    "connectWifi",
    "presetWifiList",
    "setWifiList",
    "onGetWifiList",
    "onWifiConnected",
    "offGetWifiList",
    "offWifiConnected",
    "onEvaluateWifi",
    "getHCEState",
    "startHCE",
    "stopHCE",
    "sendHCEMessage",
    "onHCEMessage",
    "offHCEMessage",
    "getNFCAdapter",
    "startLocalServiceDiscovery",
    "stopLocalServiceDiscovery",
    "onLocalServiceFound",
    "offLocalServiceFound",
    "onLocalServiceLost",
    "offLocalServiceLost",
    "onLocalServiceDiscoveryStop",
    "offLocalServiceDiscoveryStop",
    "onLocalServiceResolveFail",
    "offLocalServiceResolveFail",
    "redirectTo",
    "reLaunch",
    "navigateTo",
    "switchTab",
    "navigateBack",
    "onAppShow",
    "offAppShow",
    "onAppHide",
    "offAppHide",
    "onError",
    "offError",
    "onUnhandledRejection",
    "offUnhandledRejection",
    "getLaunchOptionsSync",
    "getEnterOptionsSync",
    "onWindowResize",
    "offWindowResize",
    "setPageOrientation",
    "getStorage",
    "getStorageSync",
    "setStorage",
    "setStorageSync",
    "removeStorage",
    "removeStorageSync",
    "clearStorage",
    "clearStorageSync",
    "getStorageInfo",
    "getStorageInfoSync",
    "getBackgroundFetchData",
    "onBackgroundFetchData",
    "setBackgroundFetchToken",
    "getBackgroundFetchToken",
    "request",
    "connectSocket",
    "closeSocket",
    "sendSocketMessage",
    "onSocketOpen",
    "onSocketClose",
    "onSocketMessage",
    "onSocketError",
    "uploadFile",
    "downloadFile",
    "addNativeDownloadTask",
    "downloadApp",
    "installDownloadApp",
    "getAppInstallState",
    "queryDownloadAppTask",
    "cancelDownloadAppTask",
    "resumeDownloadAppTask",
    "pauseDownloadAppTask",
    "onDownloadAppStateChange",
    "downloadAppForIOS",
    "calRqt",
    "secureTunnel",
    "chooseImage",
    "previewImage",
    "getImageInfo",
    "saveImageToPhotosAlbum",
    "compressImage",
    "startRecord",
    "stopRecord",
    "playVoice",
    "pauseVoice",
    "stopVoice",
    "onVoicePlayEnd",
    "chooseVideo",
    "saveVideoToPhotosAlbum",
    "getVideoInfo",
    "compressVideo",
    "loadFontFace",
    "createMediaContainer",
    "createMediaRecorder",
    "createVideoDecoder",
    "openVideoEditor",
    "createMediaAudioPlayer",
    "getLocation",
    "openLocation",
    "chooseLocation",
    "onLocationChange",
    "offLocationChange",
    "startLocationUpdateBackground",
    "startLocationUpdate",
    "stopLocationUpdate",
    "getNetworkType",
    "onNetworkStatusChange",
    "offNetworkStatusChange",
    "getSystemInfo",
    "getSystemInfoSync",
    "getSystemInfoAsync",
    "getBatteryInfo",
    "getBatteryInfoSync",
    "startAccelerometer",
    "stopAccelerometer",
    "onAccelerometerChange",
    "offAccelerometerChange",
    "startCompass",
    "stopCompass",
    "onCompassChange",
    "offCompassChange",
    "startDeviceMotionListening",
    "stopDeviceMotionListening",
    "onDeviceMotionChange",
    "offDeviceMotionChange",
    "startGyroscope",
    "stopGyroscope",
    "onGyroscopeChange",
    "offGyroscopeChange",
    "checkIsOpenAccessibility",
    "reportAction",
    "getBackgroundAudioManager",
    "getRecorderManager",
    "getBackgroundAudioPlayerState",
    "playBackgroundAudio",
    "pauseBackgroundAudio",
    "seekBackgroundAudio",
    "stopBackgroundAudio",
    "onBackgroundAudioPlay",
    "onBackgroundAudioPause",
    "onBackgroundAudioStop",
    "joinVoIPChat",
    "exitVoIPChat",
    "updateVoIPChatMuteConfig",
    "onVoIPChatMembersChanged",
    "onVoIPChatSpeakersChanged",
    "onVoIPChatInterrupted",
    "offVoIPChatMembersChanged",
    "offVoIPChatSpeakersChanged",
    "offVoIPChatInterrupted",
    "subscribeVoIPVideoMembers",
    "onVoIPVideoMembersChanged",
    "offVoIPVideoMembersChanged",
    "join1v1Chat",
    "setEnable1v1Chat",
    "requestSubscribeMessage",
    "login",
    "logout",
    "checkSession",
    "authorize",
    "getUserInfo",
    "requestPayment",
    "verifyPaymentPassword",
    "bindPaymentCard",
    "requestPaymentToBank",
    "requestVirtualPayment",
    "openOfflinePayView",
    "openWCPayCardList",
    "requestMallPayment",
    "setCurrentPaySpeech",
    "loadPaySpeechDialectConfig",
    "requestJointPayment",
    "getWCPayOverseaPrepayRequest",
    "requestH5Transaction",
    "openWCPayOverseaPaymentReceive",
    "handleWCPayOverseaWalletBuffer",
    "requestVerifyUserIdentity",
    "phoneBindCardVerifySms",
    "faceVerifyForPay",
    "openOfficialAccountProfile",
    "openUserProfile",
    "requestBizSplitBillPayment",
    "openSelectPayment",
    "requestEntrustAuthorization",
    "requestFacetoFacePayment",
    "requestQueryCashier",
    "openMiniProgramProfile",
    "openMiniProgramSearch",
    "openMiniProgramHistoryList",
    "openMiniProgramStarList",
    "batchGetContactDirectly",
    "preloadMiniProgramEnvDirectly",
    "predownloadMiniProgramPackageDirectly",
    "preventApplePayUI",
    "getWxSecData",
    "addCard",
    "openCard",
    "checkTrafficCardConditions",
    "queryTrafficCardInfo",
    "issueTrafficCard",
    "rechargeTrafficCard",
    "setDefaultTrafficCard",
    "scanCode",
    "openQRCode",
    "scanItem",
    "chooseAddress",
    "saveFile",
    "openDocument",
    "getSavedFileList",
    "getSavedFileInfo",
    "getFileInfo",
    "removeSavedFile",
    "getFileSystemManager",
    "saveFileToDisk",
    "getABTestConfig",
    "chooseContact",
    "removeUserCloudStorage",
    "setUserCloudStorage",
    "makePhoneCall",
    "makeVoIPCall",
    "onAppRoute",
    "onAppRouteDone",
    "onAppEnterBackground",
    "onAppEnterForeground",
    "onAppUnhang",
    "onPageReload",
    "onPageNotFound",
    "offPageNotFound",
    "onThemeChange",
    "offThemeChange",
    "onCopyUrl",
    "offCopyUrl",
    "createAnimation",
    "createInnerAudioContext",
    "getAvailableAudioSources",
    "onAudioInterruptionBegin",
    "offAudioInterruptionBegin",
    "onAudioInterruptionEnd",
    "offAudioInterruptionEnd",
    "setInnerAudioOption",
    "createAudioContext",
    "createVideoContext",
    "createMapContext",
    "createCameraContext",
    "createLivePlayerContext",
    "createLivePusherContext",
    "onWebviewEvent",
    "onNativeEvent",
    "hideKeyboard",
    "onKeyboardHeightChange",
    "offKeyboardHeightChange",
    "getPublicLibVersion",
    "showModal",
    "showToast",
    "hideToast",
    "showLoading",
    "hideLoading",
    "showActionSheet",
    "showShareActionSheet",
    "reportAnalytics",
    "reportMonitor",
    "getClipboardData",
    "setClipboardData",
    "createSelectorQuery",
    "createIntersectionObserver",
    "createMediaQueryObserver",
    "nextTick",
    "updatePerfData",
    "traceEvent",
    "onMemoryWarning",
    "offMemoryWarning",
    "reportPerformance",
    "getPerformance",
    "getUpdateManager",
    "updateWeChatApp",
    "createWorker",
    "voiceSplitJoint",
    "uploadSilkVoice",
    "downloadSilkVoice",
    "getResPath",
    "setResPath",
    "setCookies",
    "getCookies",
    "faceDetect",
    "initFaceDetect",
    "stopFaceDetect",
    "createBufferURL",
    "revokeBufferURL",
    "createSignal",
    "bindGroup",
    "joinGroup",
    "getLabInfo",
    "setLabInfo",
    "createUDPSocket",
    "env",
    "error",
    "isSystemError",
    "isSDKError",
    "isThirdError",
    "createRewardedVideoAd",
    "createInterstitialAd",
    "createCustomAd",
    "preloadVideoAd",
    "preloadAd",
    "getLogManager",
    "getRealtimeLogManager",
    "getExptInfoSync",
    "reportEvent",
    "getChannelsLiveInfo",
    "openChannelsLive",
    "openChannelsActivity",
    "openChannelsUserProfile",
    "cloud",
    "serviceMarket",
    "version",
    "chooseShareGroup",
    "enterContact",
    "getGroupEnterInfo",
    "getBaseMethods",
    "updateCoverView",
  ];
  var noop = function() {

  };
  for (var key of wxApiMap) {
    if (!wx.hasOwnProperty(key)) {
      wx[key] = noop;
    }
  }

  /**
   * Modules Logic (__wxModule__)
   */

  // 开发者的 JS 逻辑模块
  var JSModules = {};
  var exportPackages = {}; // 存储导出模块
  var MODULES_STATUS_UNLOAD = 1; // 未加载
  var MODULES_STATUS_LOADED = 2; // 已加载
  var MAIN_PACKAGE_NAME = '';

  /**
   * require & define
   */
  /**
   * @param path 文件路径
   * @returns string[] 每一级的文件名列表
   */
  function getFolderNameList(path) {
    var result = []
    var n = path.split("/")
    for (var i = 0, len = n.length; i < len; ++i) {
      var token = n[i];
      if ("" !== token && "." !== token)
        if (".." === token) {
          if (0 === result.length) {
            result = null;
            break
          }
          result.pop()
        } else {
          i + 1 < len && ".." === n[i + 1]
            ? i++
            : result.push(token)
        }
    }
    return result
  }

  function p(e) {
    var t = getFolderNameList(e + "/index.js").join("/");
    return getFolderNameList[t]
      ? t
      : (t = getFolderNameList(e).join("/"), /\.js$/.test(t) || (t += ".js"), getFolderNameList[t] ? t : "")
  }

  /**
   * 返回 define 内部 code 运行时的 require 函数
   * @param name {string} 声明的模块名
   * @returns {Function}
   */
  function requireFactory(name) {
    // var matchVal = name.match(/(.*)\/([^/]+)?$/)
    // var modulePath = matchVal && matchVal[1] ? matchVal[1] : './'
    /**
     * 业务代码中的 require 函数
     * @param modulePath {string} 引用的模块名
     */
    return function(requireModulePath) {
      var matchVal = name.match(/(.*)\/([^/]+)?$/)
      var modulePath = matchVal && matchVal[1] ? matchVal[1] : './'
      if (typeof requireModulePath !== 'string') {
        throw new Error("require args must be a string")
      }
      var absFolderNameList = getFolderNameList(modulePath + '/' + requireModulePath)
      try {
        var __requirePath = absFolderNameList.join("/")
        __requirePath = function(e, t, n) {
          var r = e;
          if (!(/\.js$/.test(r))) {
            r += ".js"
          }
          if ("string" == typeof r && JSModules[r]) {
            return r
          }
          var o = getFolderNameList(t);
          if (!o) {
            throw new Error("can not find module : " + n)
          }
          for (var i = e.substring(o.join("/").length); o.length;) {
            var a, s = o.join("/") + "/miniprogram_npm" + i;
            if (a = p(s)) break;
            o.pop()
          }
          return a || (i = "/" === i[0] ? i : "/" + i, a = p(s = "miniprogram_npm" + i)), a || e
        }(__requirePath, modulePath, requireModulePath);

        return require(__requirePath)
      } catch (e) {
        throw e
      }
    }
  }

  /**
   * 定义 js 逻辑模块
   * @param name {string}
   * @param factoryLogicContent {Function} 包装开发者 JS 文件逻辑的可执行函数 (使用形参占位来屏蔽敏感变量)
   */
  var define = function(name, factoryLogicContent) {
    JSModules[name] = {
      status: MODULES_STATUS_UNLOAD,
      factory: factoryLogicContent,
      exports: undefined
    }
  }

  // let require_ts = 0
  // let now = 0
  // let ts = 0
  /**
   * 执行某 js 逻辑模块
   * @param name {string}
   * @param multi {boolean} 是否会引用多次
   */
  var require = function(name, multi = true) {
    if (typeof name !== 'string') {
      throw new Error("require args must be a string")
    }
    name.endsWith('.js') || (name += '.js');
    var requireModule = JSModules[name] // 反解此处还有不少 npm 包的加载与其他 check 逻辑，暂时省略
    if (!requireModule) {
      throw new Error('module "' + name + '" is not defined')
    }
    var module = {
      exports: {}
    }
    var factory = requireModule.factory

    // 如果仅引用一次
    if (!multi || exportPackages[name]) {
      delete requireModule.exports
      requireModule.status = MODULES_STATUS_UNLOAD
      exportPackages[name] = true;
      factory && factory(requireFactory(name), module, module.exports, Foundation.getExportConfig(), Foundation.getExportConfig())
      return module.exports
    }

    if (requireModule.status === MODULES_STATUS_UNLOAD) {
      requireModule.exports = module.exports
      requireModule.status = MODULES_STATUS_LOADED
      var result
      try {
        if (factory) {
          result = factory(requireFactory(name), module, module.exports, Foundation.getExportConfig(), Foundation.getExportConfig())
        }
      } catch (err) {
        requireModule.status = MODULES_STATUS_UNLOAD
        // 执行js模块未处理异常
        __appServiceSDK__.reportUncaughtError({
          info: err.toString(),
          stack: err.stack
        })
      }
      requireModule.exports = module.exports === undefined
        ? result
        : module.exports
    }

    return requireModule.exports
  }

  var definePackageLogicMap = {}; // 定义 js 模块的代码块

  /**
   * 收集代码包的逻辑
   * @param packageName {string} 代码包名
   * @param define {Function} 定义 (js 运行时代码)
   */
  function blockPackageLogic(packageName, define) {
    definePackageLogicMap[packageName] = define
  }

  /**
   * 释放代码包逻辑
   * @param state
   * @param packageDir
   */
  function flushPackageLogic(packageDir = __MAIN_PKG_DIR__) {
    if (typeof definePackageLogicMap[packageDir] === 'function') {
      definePackageLogicMap[packageDir]()
      definePackageLogicMap[packageDir] = null
      delete definePackageLogicMap[packageDir]
    }
  }

  global.require = require;
  global.define = define;
  global.__block__ = blockPackageLogic;
  global.__define__ = flushPackageLogic; //  定义代码包
}(globalThis);
// 由于Foundation模块会改写__ddConfig的引用,所以__wxConfig最后赋值
__wxConfig = __ddConfig
var __ddAppCode__ = __ddAppCode__ || {};
typeof __ddLibrary.onEnd === 'function' && __ddLibrary.onEnd();
__ddLibrary = undefined;
var dmServiceInvokeCostTime = Date.now() - dmServiceInvokeStartTime
